/* @thoughtspot/visual-embed-sdk version 1.38.0 */
'use client';
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.tsembed = {}));
})(this, (function (exports) { 'use strict';

    function _mergeNamespaces(n, m) {
        m.forEach(function (e) {
            e && typeof e !== 'string' && !Array.isArray(e) && Object.keys(e).forEach(function (k) {
                if (k !== 'default' && !(k in n)) {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () { return e[k]; }
                    });
                }
            });
        });
        return Object.freeze(n);
    }

    // istanbul ignore next
    const isObject$1 = (obj) => {
        if (typeof obj === "object" && obj !== null) {
            if (typeof Object.getPrototypeOf === "function") {
                const prototype = Object.getPrototypeOf(obj);
                return prototype === Object.prototype || prototype === null;
            }
            return Object.prototype.toString.call(obj) === "[object Object]";
        }
        return false;
    };
    const merge = (...objects) => objects.reduce((result, current) => {
        if (Array.isArray(current)) {
            throw new TypeError("Arguments provided to ts-deepmerge must be objects, not arrays.");
        }
        Object.keys(current).forEach((key) => {
            if (["__proto__", "constructor", "prototype"].includes(key)) {
                return;
            }
            if (Array.isArray(result[key]) && Array.isArray(current[key])) {
                result[key] = merge.options.mergeArrays
                    ? merge.options.uniqueArrayItems
                        ? Array.from(new Set(result[key].concat(current[key])))
                        : [...result[key], ...current[key]]
                    : current[key];
            }
            else if (isObject$1(result[key]) && isObject$1(current[key])) {
                result[key] = merge(result[key], current[key]);
            }
            else {
                result[key] =
                    current[key] === undefined
                        ? merge.options.allowUndefinedOverrides
                            ? current[key]
                            : result[key]
                        : current[key];
            }
        });
        return result;
    }, {});
    const defaultOptions = {
        allowUndefinedOverrides: true,
        mergeArrays: true,
        uniqueArrayItems: true,
    };
    merge.options = defaultOptions;
    merge.withOptions = (options, ...objects) => {
        merge.options = Object.assign(Object.assign({}, defaultOptions), options);
        const result = merge(...objects);
        merge.options = defaultOptions;
        return result;
    };

    /**
     * Copyright (c) 2023
     *
     * Common utility functions for ThoughtSpot Visual Embed SDK
     * @summary Utils
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    /**
     * Construct a runtime filters query string from the given filters.
     * Refer to the following docs for more details on runtime filter syntax:
     * https://cloud-docs.thoughtspot.com/admin/ts-cloud/apply-runtime-filter.html
     * https://cloud-docs.thoughtspot.com/admin/ts-cloud/runtime-filter-operators.html
     * @param runtimeFilters
     */
    const getFilterQuery = (runtimeFilters) => {
        if (runtimeFilters && runtimeFilters.length) {
            const filters = runtimeFilters.map((filter, valueIndex) => {
                const index = valueIndex + 1;
                const filterExpr = [];
                filterExpr.push(`col${index}=${encodeURIComponent(filter.columnName)}`);
                filterExpr.push(`op${index}=${filter.operator}`);
                filterExpr.push(filter.values.map((value) => {
                    const encodedValue = typeof value === 'bigint' ? value.toString() : value;
                    return `val${index}=${encodeURIComponent(String(encodedValue))}`;
                }).join('&'));
                return filterExpr.join('&');
            });
            return `${filters.join('&')}`;
        }
        return null;
    };
    /**
     * Construct a runtime parameter override query string from the given option.
     * @param runtimeParameters
     */
    const getRuntimeParameters = (runtimeParameters) => {
        if (runtimeParameters && runtimeParameters.length) {
            const params = runtimeParameters.map((param, valueIndex) => {
                const index = valueIndex + 1;
                const filterExpr = [];
                filterExpr.push(`param${index}=${encodeURIComponent(param.name)}`);
                filterExpr.push(`paramVal${index}=${encodeURIComponent(param.value)}`);
                return filterExpr.join('&');
            });
            return `${params.join('&')}`;
        }
        return null;
    };
    /**
     * Convert a value to a string representation to be sent as a query
     * parameter to the ThoughtSpot app.
     * @param value Any parameter value
     */
    const serializeParam = (value) => {
        // do not serialize primitive types
        if (typeof value === 'string' || typeof value === 'number' || typeof value === 'boolean') {
            return value;
        }
        return JSON.stringify(value);
    };
    /**
     * Convert a value to a string:
     * in case of an array, we convert it to CSV.
     * in case of any other type, we directly return the value.
     * @param value
     */
    const paramToString = (value) => (Array.isArray(value) ? value.join(',') : value);
    /**
     * Return a query param string composed from the given params object
     * @param queryParams
     * @param shouldSerializeParamValues
     */
    const getQueryParamString = (queryParams, shouldSerializeParamValues = false) => {
        const qp = [];
        const params = Object.keys(queryParams);
        params.forEach((key) => {
            const val = queryParams[key];
            if (val !== undefined) {
                const serializedValue = shouldSerializeParamValues
                    ? serializeParam(val)
                    : paramToString(val);
                qp.push(`${key}=${serializedValue}`);
            }
        });
        if (qp.length) {
            return qp.join('&');
        }
        return null;
    };
    /**
     * Get a string representation of a dimension value in CSS
     * If numeric, it is considered in pixels.
     * @param value
     */
    const getCssDimension = (value) => {
        if (typeof value === 'number') {
            return `${value}px`;
        }
        return value;
    };
    const getSSOMarker = (markerId) => {
        const encStringToAppend = encodeURIComponent(markerId);
        return `tsSSOMarker=${encStringToAppend}`;
    };
    /**
     * Append a string to a URL's hash fragment
     * @param url A URL
     * @param stringToAppend The string to append to the URL hash
     */
    const appendToUrlHash = (url, stringToAppend) => {
        let outputUrl = url;
        const encStringToAppend = encodeURIComponent(stringToAppend);
        const marker = `tsSSOMarker=${encStringToAppend}`;
        let splitAdder = '';
        if (url.indexOf('#') >= 0) {
            // If second half of hash contains a '?' already add a '&' instead of
            // '?' which appends to query params.
            splitAdder = url.split('#')[1].indexOf('?') >= 0 ? '&' : '?';
        }
        else {
            splitAdder = '#?';
        }
        outputUrl = `${outputUrl}${splitAdder}${marker}`;
        return outputUrl;
    };
    /**
     *
     * @param url
     * @param stringToAppend
     * @param path
     */
    function getRedirectUrl(url, stringToAppend, path = '') {
        const targetUrl = path ? new URL(path, window.location.origin).href : url;
        return appendToUrlHash(targetUrl, stringToAppend);
    }
    const getEncodedQueryParamsString = (queryString) => {
        if (!queryString) {
            return queryString;
        }
        return btoa(queryString).replace(/\+/g, '-').replace(/\//g, '_').replace(/=+$/, '');
    };
    const getOffsetTop = (element) => {
        const rect = element.getBoundingClientRect();
        return rect.top + window.scrollY;
    };
    const embedEventStatus = {
        START: 'start',
        END: 'end',
    };
    const setAttributes = (element, attributes) => {
        Object.keys(attributes).forEach((key) => {
            element.setAttribute(key, attributes[key].toString());
        });
    };
    const isCloudRelease = (version) => version.endsWith('.cl');
    /* For Search Embed: ReleaseVersionInBeta */
    const checkReleaseVersionInBeta = (releaseVersion, suppressBetaWarning) => {
        if (releaseVersion !== '' && !isCloudRelease(releaseVersion)) {
            const splittedReleaseVersion = releaseVersion.split('.');
            const majorVersion = Number(splittedReleaseVersion[0]);
            const isBetaVersion = majorVersion < 8;
            return !suppressBetaWarning && isBetaVersion;
        }
        return false;
    };
    const getCustomisations = (embedConfig, viewConfig) => {
        var _a, _b, _c, _d;
        const customizationsFromViewConfig = viewConfig.customizations;
        const customizationsFromEmbedConfig = embedConfig.customizations
            || embedConfig.customisations;
        const customizations = {
            style: {
                ...customizationsFromEmbedConfig === null || customizationsFromEmbedConfig === void 0 ? void 0 : customizationsFromEmbedConfig.style,
                ...customizationsFromViewConfig === null || customizationsFromViewConfig === void 0 ? void 0 : customizationsFromViewConfig.style,
                customCSS: {
                    ...(_a = customizationsFromEmbedConfig === null || customizationsFromEmbedConfig === void 0 ? void 0 : customizationsFromEmbedConfig.style) === null || _a === void 0 ? void 0 : _a.customCSS,
                    ...(_b = customizationsFromViewConfig === null || customizationsFromViewConfig === void 0 ? void 0 : customizationsFromViewConfig.style) === null || _b === void 0 ? void 0 : _b.customCSS,
                },
                customCSSUrl: ((_c = customizationsFromViewConfig === null || customizationsFromViewConfig === void 0 ? void 0 : customizationsFromViewConfig.style) === null || _c === void 0 ? void 0 : _c.customCSSUrl)
                    || ((_d = customizationsFromEmbedConfig === null || customizationsFromEmbedConfig === void 0 ? void 0 : customizationsFromEmbedConfig.style) === null || _d === void 0 ? void 0 : _d.customCSSUrl),
            },
            content: {
                ...customizationsFromEmbedConfig === null || customizationsFromEmbedConfig === void 0 ? void 0 : customizationsFromEmbedConfig.content,
                ...customizationsFromViewConfig === null || customizationsFromViewConfig === void 0 ? void 0 : customizationsFromViewConfig.content,
            },
        };
        return customizations;
    };
    const getRuntimeFilters = (runtimefilters) => getFilterQuery(runtimefilters || []);
    /**
     * Gets a reference to the DOM node given
     * a selector.
     * @param domSelector
     */
    function getDOMNode(domSelector) {
        return typeof domSelector === 'string' ? document.querySelector(domSelector) : domSelector;
    }
    const deepMerge = (target, source) => merge(target, source);
    const getOperationNameFromQuery = (query) => {
        const regex = /(?:query|mutation)\s+(\w+)/;
        const matches = query.match(regex);
        return matches === null || matches === void 0 ? void 0 : matches[1];
    };
    /**
     *
     * @param obj
     */
    function removeTypename(obj) {
        if (!obj || typeof obj !== 'object')
            return obj;
        // eslint-disable-next-line no-restricted-syntax
        for (const key in obj) {
            if (key === '__typename') {
                delete obj[key];
            }
            else if (typeof obj[key] === 'object') {
                removeTypename(obj[key]);
            }
        }
        return obj;
    }
    /**
     * Sets the specified style properties on an HTML element.
     * @param {HTMLElement} element - The HTML element to which the styles should be applied.
     * @param {Partial<CSSStyleDeclaration>} styleProperties - An object containing style
     * property names and their values.
     * @example
     * // Apply styles to an element
     * const element = document.getElementById('myElement');
     * const styles = {
     *   backgroundColor: 'red',
     *   fontSize: '16px',
     * };
     * setStyleProperties(element, styles);
     */
    const setStyleProperties = (element, styleProperties) => {
        if (!(element === null || element === void 0 ? void 0 : element.style))
            return;
        Object.keys(styleProperties).forEach((styleProperty) => {
            element.style[styleProperty] = styleProperties[styleProperty].toString();
        });
    };
    /**
     * Removes specified style properties from an HTML element.
     * @param {HTMLElement} element - The HTML element from which the styles should be removed.
     * @param {string[]} styleProperties - An array of style property names to be removed.
     * @example
     * // Remove styles from an element
     * const element = document.getElementById('myElement');
     * element.style.backgroundColor = 'red';
     * const propertiesToRemove = ['backgroundColor'];
     * removeStyleProperties(element, propertiesToRemove);
     */
    const removeStyleProperties = (element, styleProperties) => {
        if (!(element === null || element === void 0 ? void 0 : element.style))
            return;
        styleProperties.forEach((styleProperty) => {
            element.style.removeProperty(styleProperty);
        });
    };
    const isUndefined$1 = (value) => value === undefined;
    // Return if the value is a string, double or boolean.
    const getTypeFromValue = (value) => {
        if (typeof value === 'string') {
            return ['char', 'string'];
        }
        if (typeof value === 'number') {
            return ['double', 'double'];
        }
        if (typeof value === 'boolean') {
            return ['boolean', 'boolean'];
        }
        return ['', ''];
    };
    const sdkWindowKey = '_tsEmbedSDK';
    /**
     * Stores a value in the global `window` object under the `_tsEmbedSDK` namespace.
     * @param key - The key under which the value will be stored.
     * @param value - The value to store.
     * @param options - Additional options.
     * @param options.ignoreIfAlreadyExists - Does not set if value for key is set.
     *
     * @returns The stored value.
     *
     * @version SDK: 1.36.2 | ThoughtSpot: *
     */
    function storeValueInWindow(key, value, options = {}) {
        if (!window[sdkWindowKey]) {
            window[sdkWindowKey] = {};
        }
        if (options.ignoreIfAlreadyExists && key in window[sdkWindowKey]) {
            return window[sdkWindowKey][key];
        }
        window[sdkWindowKey][key] = value;
        return value;
    }
    /**
     * Retrieves a stored value from the global `window` object under the `_tsEmbedSDK` namespace.
     * @param key - The key whose value needs to be retrieved.
     * @returns The stored value or `undefined` if the key is not found.
     */
    const getValueFromWindow = (key) => { var _a; return (_a = window === null || window === void 0 ? void 0 : window[sdkWindowKey]) === null || _a === void 0 ? void 0 : _a[key]; };

    /**
     * Copyright (c) 2023
     *
     * TypeScript type definitions for ThoughtSpot Visual Embed SDK
     * @summary Type definitions for Embed SDK
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    /**
     * The authentication mechanism for allowing access to the
     * the embedded app
     * @group Authentication / Init
     */
    // eslint-disable-next-line no-shadow
    exports.AuthType = void 0;
    (function (AuthType) {
        /**
         * No authentication on the SDK. Pass-through to the embedded App. Alias for
         * `Passthrough`.
         * @example
         * ```js
         * init({
         *   // ...
         *   authType: AuthType.None,
         *  });
         * ```
         */
        AuthType["None"] = "None";
        /**
         * Passthrough SSO to the embedded application within the iframe. Requires least
         * configuration, but may not be supported by all IDPs. This will behave like `None`
         * if SSO is not configured on ThoughtSpot.
         *
         * To use this:
         * Your SAML or OpenID provider must allow iframe redirects.
         * For example, if you are using Okta as IdP, you can enable iframe embedding.
         * @example
         * ```js
         * init({
         *   // ...
         *   authType: AuthType.EmbeddedSSO,
         *  });
         * ```
         * @version: SDK: 1.15.0 | ThoughtSpot: 8.8.0.cl
         */
        AuthType["EmbeddedSSO"] = "EmbeddedSSO";
        /**
         * SSO using SAML
         * @deprecated Use {@link SAMLRedirect} instead
         * @hidden
         */
        AuthType["SSO"] = "SSO_SAML";
        /**
         * SSO using SAML
         * @deprecated Use {@link SAMLRedirect} instead
         * @hidden
         */
        AuthType["SAML"] = "SSO_SAML";
        /**
         * SSO using SAML
         * Makes the host application redirect to the SAML IdP. Use this
         * if your IdP does not allow itself to be embedded.
         *
         * This redirects the host application to the SAML IdP. The host application
         * will be redirected back to the ThoughtSpot app after authentication.
         * @example
         * ```js
         * init({
         *   // ...
         *   authType: AuthType.SAMLRedirect,
         *  });
         * ```
         *
         * This opens the SAML IdP in a popup window. The popup is triggered
         * when the user clicks the trigger button. The popup window will be
         * closed automatically after authentication.
         * @example
         * ```js
         * init({
         *   // ...
         *   authType: AuthType.SAMLRedirect,
         *   authTriggerText: 'Login with SAML',
         *   authTriggerContainer: '#embed-container',
         *   inPopup: true,
         * });
         * ```
         *
         * Can also use the event to trigger the popup flow. Works the same
         * as the above example.
         * @example
         * ```js
         * const authEE = init({
         *  // ...
         *  authType: AuthType.SAMLRedirect,
         *  inPopup: true,
         * });
         *
         * someButtonOnYourPage.addEventListener('click', () => {
         *  authEE.emit(AuthEvent.TRIGGER_SSO_POPUP);
         * });
         * ```
         */
        AuthType["SAMLRedirect"] = "SSO_SAML";
        /**
         * SSO using OIDC
         * @hidden
         * @deprecated Use {@link OIDCRedirect} instead
         */
        AuthType["OIDC"] = "SSO_OIDC";
        /**
         * SSO using OIDC
         * Will make the host application redirect to the OIDC IdP.
         * See code samples in {@link SAMLRedirect}.
         */
        AuthType["OIDCRedirect"] = "SSO_OIDC";
        /**
         * Trusted authentication server
         * @hidden
         * @deprecated Use {@link TrustedAuth} instead
         */
        AuthType["AuthServer"] = "AuthServer";
        /**
         * Trusted authentication server. Use your own authentication server
         * which returns a bearer token, generated using the `secret_key` obtained
         * from ThoughtSpot.
         * @example
         * ```js
         * init({
         *  // ...
         *  authType: AuthType.TrustedAuthToken,
         *  getAuthToken: () => {
         *    return fetch('https://my-backend.app/ts-token')
         *      .then((response) => response.json())
         *      .then((data) => data.token);
         *  }
         * });
         * ```
         */
        AuthType["TrustedAuthToken"] = "AuthServer";
        /**
         * Trusted authentication server Cookieless, Use your own authentication
         * server which returns a bearer token, generated using the `secret_key`
         * obtained from ThoughtSpot. This uses a cookieless authentication
         * approach, recommended to bypass the third-party cookie-blocking restriction
         * implemented by some browsers.
         * @example
         * ```js
         * init({
         *  // ...
         *  authType: AuthType.TrustedAuthTokenCookieless,
         *  getAuthToken: () => {
         *    return fetch('https://my-backend.app/ts-token')
         *      .then((response) => response.json())
         *      .then((data) => data.token);
         *  }
         * ```
         * @version SDK: 1.22.0| ThoughtSpot: 9.3.0.cl, 9.5.1.sw
         */
        AuthType["TrustedAuthTokenCookieless"] = "AuthServerCookieless";
        /**
         * Use the ThoughtSpot login API to authenticate to the cluster directly.
         *
         * Warning: This feature is primarily intended for developer testing. It is
         * strongly advised not to use this authentication method in production.
         */
        AuthType["Basic"] = "Basic";
    })(exports.AuthType || (exports.AuthType = {}));
    /**
     *
     * This option does not apply to the classic homepage experience.
     * To access the updated modular homepage,
     * set `modularHomeExperience` to `true`
     * (available as Early Access feature in 9.12.5.cl).
     *
     */
    exports.HomeLeftNavItem = void 0;
    (function (HomeLeftNavItem) {
        /**
         * @version SDK: 1.28.0| ThoughtSpot: 9.12.5.cl
         */
        HomeLeftNavItem["SearchData"] = "search-data";
        /**
         * @version SDK: 1.28.0| ThoughtSpot: 9.12.5.cl
         */
        HomeLeftNavItem["Home"] = "insights-home";
        /**
         * @version SDK: 1.28.0| ThoughtSpot: 9.12.5.cl
         */
        HomeLeftNavItem["Liveboards"] = "liveboards";
        /**
         * @version SDK: 1.28.0| ThoughtSpot: 9.12.5.cl
         */
        HomeLeftNavItem["Answers"] = "answers";
        /**
         * @version SDK: 1.28.0| ThoughtSpot: 9.12.5.cl
         */
        HomeLeftNavItem["MonitorSubscription"] = "monitor-alerts";
        /**
         * @version SDK: 1.28.0| ThoughtSpot: 9.12.5.cl
         */
        HomeLeftNavItem["SpotIQAnalysis"] = "spotiq-analysis";
        /**
         * @version SDK: 1.34.0| ThoughtSpot: 10.3.0.cl
         */
        HomeLeftNavItem["LiveboardSchedules"] = "liveboard-schedules";
        /**
         * Create new options in the insights left navigation,
         * available when new navigation V3 is enabled.
         * @version SDK: 1.39.0 | ThoughtSpot: 10.10.0.cl
         */
        HomeLeftNavItem["Create"] = "create";
        /**
         * Spotter option in the insights left navigation,
         * available when new navigation V3 is enabled.
         * @version SDK: 1.39.0 | ThoughtSpot: 10.10.0.cl
         */
        HomeLeftNavItem["Spotter"] = "spotter";
    })(exports.HomeLeftNavItem || (exports.HomeLeftNavItem = {}));
    /**
     * A map of the supported runtime filter operations
     */
    // eslint-disable-next-line no-shadow
    exports.RuntimeFilterOp = void 0;
    (function (RuntimeFilterOp) {
        /**
         * Equals
         */
        RuntimeFilterOp["EQ"] = "EQ";
        /**
         * Does not equal
         */
        RuntimeFilterOp["NE"] = "NE";
        /**
         * Less than
         */
        RuntimeFilterOp["LT"] = "LT";
        /**
         * Less than or equal to
         */
        RuntimeFilterOp["LE"] = "LE";
        /**
         * Greater than
         */
        RuntimeFilterOp["GT"] = "GT";
        /**
         * Greater than or equal to
         */
        RuntimeFilterOp["GE"] = "GE";
        /**
         * Contains
         */
        RuntimeFilterOp["CONTAINS"] = "CONTAINS";
        /**
         * Begins with
         */
        RuntimeFilterOp["BEGINS_WITH"] = "BEGINS_WITH";
        /**
         * Ends with
         */
        RuntimeFilterOp["ENDS_WITH"] = "ENDS_WITH";
        /**
         * Between, inclusive of higher value
         */
        RuntimeFilterOp["BW_INC_MAX"] = "BW_INC_MAX";
        /**
         * Between, inclusive of lower value
         */
        RuntimeFilterOp["BW_INC_MIN"] = "BW_INC_MIN";
        /**
         * Between, inclusive of both higher and lower value
         */
        RuntimeFilterOp["BW_INC"] = "BW_INC";
        /**
         * Between, non-inclusive
         */
        RuntimeFilterOp["BW"] = "BW";
        /**
         * Is included in this list of values
         */
        RuntimeFilterOp["IN"] = "IN";
        /**
         * Is not included in this list of values
         */
        RuntimeFilterOp["NOT_IN"] = "NOT_IN";
    })(exports.RuntimeFilterOp || (exports.RuntimeFilterOp = {}));
    /**
     * Home page module that can be hidden.
     * **Note**: This option does not apply to the classic homepage.
     * To access the updated modular homepage, set
     * `modularHomeExperience` to `true` (available as Early Access feature in 9.12.5.cl).
     * @version SDK: 1.28.0 | ThoughtSpot: 9.12.5.cl, 10.1.0.sw
     */
    // eslint-disable-next-line no-shadow
    exports.HomepageModule = void 0;
    (function (HomepageModule) {
        /**
         * Search bar
         */
        HomepageModule["Search"] = "SEARCH";
        /**
         * kPI watchlist module
         */
        HomepageModule["Watchlist"] = "WATCHLIST";
        /**
         * favorite objects
         */
        HomepageModule["Favorite"] = "FAVORITE";
        /**
         * List of answers and Liveboards
         */
        HomepageModule["MyLibrary"] = "MY_LIBRARY";
        /**
         * Trending list
         */
        HomepageModule["Trending"] = "TRENDING";
        /**
         * Learning videos
         */
        HomepageModule["Learning"] = "LEARNING";
    })(exports.HomepageModule || (exports.HomepageModule = {}));
    /**
     * List page columns that can be hidden.
     * **Note**: This option is applicable to full app embedding only.
     * @version SDK: 1.38.0 | ThoughtSpot: 10.9.0.cl
     */
    // eslint-disable-next-line no-shadow
    exports.ListPageColumns = void 0;
    (function (ListPageColumns) {
        /**
         * Favourite
         */
        ListPageColumns["Favourite"] = "FAVOURITE";
        /**
         * Tags
         */
        ListPageColumns["Tags"] = "TAGS";
        /**
         * Author
         */
        ListPageColumns["Author"] = "AUTHOR";
        /**
         * Last viewed/Last modified
         */
        ListPageColumns["DateSort"] = "DATE_SORT";
        /**
         * Share
         */
        ListPageColumns["Share"] = "SHARE";
    })(exports.ListPageColumns || (exports.ListPageColumns = {}));
    /**
     * Event types emitted by the embedded ThoughtSpot application.
     *
     * To add an event listener use the corresponding
     * {@link LiveboardEmbed.on} or {@link AppEmbed.on} or {@link SearchEmbed.on} method.
     *  @example
     * ```js
     * import { EmbedEvent } from '@thoughtspot/visual-embed-sdk';
     * // Or
     * // const { EmbedEvent } = window.tsembed;
     *
     * // create the liveboard embed.
     *
     * liveboardEmbed.on(EmbedEvent.Drilldown, (drilldown) => {
     *   console.log('Drilldown event', drilldown);
     * }));
     * ```
     *
     * If you are using React components for embedding, you can register to any
     * events from the `EmbedEvent` list by using the `on<EventName>` convention.
     * For example,`onAlert`, `onCopyToClipboard` and so on.
     *  @example
     * ```js
     * // ...
     * const MyComponent = ({ dataSources }) => {
     *      const onLoad = () => {
     *      console.log(EmbedEvent.Load, {});
     *      };
     *
     *      return (
     *          <SearchEmbed
     *              dataSources={dataSources}
     *              onLoad = {logEvent("Load")}
     *          />
     *     );
     * };
     * ```
     * @group Events
     */
    // eslint-disable-next-line no-shadow
    exports.EmbedEvent = void 0;
    (function (EmbedEvent) {
        /**
         * Rendering has initialized.
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Init, showLoader)
         *  //show a loader
         * function showLoader() {
         * document.getElementById("loader");
         * }
         *```
         * @returns timestamp - The timestamp when the event was generated.
         */
        EmbedEvent["Init"] = "init";
        /**
         * Authentication has either succeeded or failed.
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.AuthInit, payload => {
         *    console.log('AuthInit', payload);
         * })
         *```
         * @returns isLoggedIn - A Boolean specifying whether authentication was successful.
         */
        EmbedEvent["AuthInit"] = "authInit";
        /**
         * The embed object container has loaded.
         * @returns timestamp - The timestamp when the event was generated.
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Load, hideLoader)
         *    //hide loader
         * function hideLoader() {
         *   document.getElementById("loader");
         * }
         *```
         */
        EmbedEvent["Load"] = "load";
        /**
         * Data pertaining to an Answer or Liveboard is received.
         * The event payload includes the raw data of the object.
         * @return data -  Answer of Liveboard data
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Data, payload => {
         *    console.log('data', payload);
         * })
         *```
         * @important
         */
        EmbedEvent["Data"] = "data";
        /**
         * Search query has been updated by the user.
         * @version SDK: 1.4.0 | ThoughtSpot: ts7.sep.cl, 8.4.1.sw
         * @example
         *```js
         * searchEmbed.on(EmbedEvent.QueryChanged, payload => console.log('data', payload))
         *```
         */
        EmbedEvent["QueryChanged"] = "queryChanged";
        /**
         * A drill-down operation has been performed.
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @returns additionalFilters - Any additional filters applied
         * @returns drillDownColumns - The columns on which drill down was performed
         * @returns nonFilteredColumns - The columns that were not filtered
         * @example
         *```js
         * searchEmbed.on(EmbedEvent.DrillDown, {
         *    points: {
         *        clickedPoint,
         *        selectedPoints: selectedPoint
         *    },
         *    autoDrillDown: true,
         * })
         *```
         * In this example, `VizPointDoubleClick` event is used for
         * triggering the `DrillDown` event when an area or specific
         * data point on a table or chart is double-clicked.
         * @example
         *```js
         * searchEmbed.on(EmbedEvent.VizPointDoubleClick, (payload) => {
         *   console.log(payload);
         *   const clickedPoint = payload.data.clickedPoint;
         *   const selectedPoint = payload.data.selectedPoints;
         *   console.log('>>> called', clickedPoint);
         *   embed.trigger(HostEvent.DrillDown, {
         *      points: {
         *      clickedPoint,
         *          selectedPoints: selectedPoint
         *     },
         *   autoDrillDown: true,
         *     })
         * })
         *```
         */
        EmbedEvent["Drilldown"] = "drillDown";
        /**
         * One or more data sources have been selected.
         * @returns dataSourceIds - the list of data sources
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         * ```js
         * searchEmbed.on(EmbedEvent.DataSourceSelected, payload => {
         *    console.log('DataSourceSelected', payload);
         * })
         * ```
         */
        EmbedEvent["DataSourceSelected"] = "dataSourceSelected";
        /**
         * One or more data columns have been selected.
         * @returns columnIds - the list of columns
         * @version SDK: 1.10.0 | ThoughtSpot: 8.2.0.cl, 8.4.1.sw
         * @example
         * ```js
         * appEmbed.on(EmbedEvent.AddRemoveColumns, payload => {
         *   console.log('AddRemoveColumns', payload);
         * })
         * ```
         */
        EmbedEvent["AddRemoveColumns"] = "addRemoveColumns";
        /**
         * A custom action has been triggered.
         * @returns actionId - ID of the custom action
         * @returns payload {@link CustomActionPayload} - Response payload with the
         * Answer or Liveboard data
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         * ```js
         * appEmbed.on(EmbedEvent.customAction, payload => {
         *     const data = payload.data;
         *     if (data.id === 'insert Custom Action ID here') {
         *         console.log('Custom Action event:', data.embedAnswerData);
         *     }
         * })
         * ```
         */
        EmbedEvent["CustomAction"] = "customAction";
        /**
         * Listen to double click actions on a visualization.
         * @return ContextMenuInputPoints - Data point that is double-clicked
         * @version SDK: 1.5.0 | ThoughtSpot: ts7.oct.cl, 7.2.1
         * @example
         * ```js
         * livebaordEmbed.on(EmbedEvent.VizPointDoubleClick, payload => {
         *      console.log('VizPointDoubleClick', payload);
         * })
         * ```
         */
        EmbedEvent["VizPointDoubleClick"] = "vizPointDoubleClick";
        /**
         * Listen to clicks on a visualization in a Liveboard or Search result.
         * @return viz, clickedPoint - metadata about the point that is clicked
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @important
         * @example
         * ```js
         * embed.on(EmbedEvent.VizPointClick, ({data}) => {
         *   console.log(
         *    data.vizId, // viz id
         *    data.clickedPoint.selectedAttributes[0].value,
         *    data.clickedPoint.selectedAttributes[0].column.name,
         *    data.clickedPoint.selectedMeasures[0].value,
         *    data.clickedPoint.selectedMeasures[0].column.name,
         *   )
         * });
         * ```
         */
        EmbedEvent["VizPointClick"] = "vizPointClick";
        /**
         * An error has occurred. This event is fired for the following error types:
         *
         * `API` - API call failure error.
         * `FULLSCREEN` - Error when presenting a Liveboard or visualization in full screen
         * mode. `SINGLE_VALUE_FILTER` - Error due to multiple values in the single value
         * filter. `NON_EXIST_FILTER` - Error due to a non-existent filter.
         * `INVALID_DATE_VALUE` - Invalid date value error.
         * `INVALID_OPERATOR` - Use of invalid operator during filter application.
         *
         * For more information, see https://developers.thoughtspot.com/docs/events-app-integration#errorType
         * @returns error - An error object or message
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         * ```js
         * // API error
         * SearchEmbed.on(EmbedEvent.Error, (error) => {
         *   console.log(error);
         *  // { type: "Error", data: { errorType: "API", error: { message: '...', error: '...' } } }
         * });
         * ```
         * @example
         * ```js
         * // Fullscreen error (Errors during presenting of a liveboard)
         * LiveboardEmbed.on(EmbedEvent.Error, (error) => {
         *   console.log(error);
         *   // { type: "Error", data: { errorType: "FULLSCREEN", error: {
         *   //   message: "Fullscreen API is not enabled",
         *   //   stack: "..."
         *   // } }}
         * })
         * ```
         */
        EmbedEvent["Error"] = "Error";
        /**
         * The embedded object has sent an alert.
         * @returns alert - An alert object
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 8.4.1.sw
         * @example
         * ```js
         * searchEmbed.on(EmbedEvent.Alert)
         * ```
         */
        EmbedEvent["Alert"] = "alert";
        /**
         * The ThoughtSpot authentication session has expired.
         * @version SDK: 1.4.0 | ThoughtSpot: ts7.sep.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.AuthExpire, showAuthExpired)
         * //show auth expired banner
         * function showAuthExpired() {
         *    document.getElementById("authExpiredBanner");
         * }
         *```
         */
        EmbedEvent["AuthExpire"] = "ThoughtspotAuthExpired";
        /**
         * ThoughtSpot failed to validate the auth session.
         * @hidden
         */
        EmbedEvent["AuthFailure"] = "ThoughtspotAuthFailure";
        /**
         * ThoughtSpot failed to re validate the auth session.
         * @hidden
         */
        EmbedEvent["IdleSessionTimeout"] = "IdleSessionTimeout";
        /**
         * ThoughtSpot failed to validate the auth session.
         * @hidden
         */
        EmbedEvent["AuthLogout"] = "ThoughtspotAuthLogout";
        /**
         * The height of the embedded Liveboard or visualization has been computed.
         * @returns data - The height of the embedded Liveboard or visualization
         * @hidden
         */
        EmbedEvent["EmbedHeight"] = "EMBED_HEIGHT";
        /**
         * The center of visible iframe viewport is calculated.
         * @returns data - The center of the visible Iframe viewport.
         * @hidden
         */
        EmbedEvent["EmbedIframeCenter"] = "EmbedIframeCenter";
        /**
         * Emitted when the **Get Data** action is initiated.
         * Applicable to `SearchBarEmbed` only.
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         * @example
         *```js
         * searchbarEmbed.on(EmbedEvent.GetDataClick)
         *  .then(data => {
         *  console.log('Answer Data:', data);
         * })
         *```
         */
        EmbedEvent["GetDataClick"] = "getDataClick";
        /**
         * Detects the route change.
         * @version SDK: 1.7.0 | ThoughtSpot: 8.0.0.cl, 8.4.1.sw
         * @example
         *```js
         * searchEmbed.on(EmbedEvent.RouteChange, payload =>
         *    console.log('data', payload))
         *```
         */
        EmbedEvent["RouteChange"] = "ROUTE_CHANGE";
        /**
         * The v1 event type for Data
         * @hidden
         */
        EmbedEvent["V1Data"] = "exportVizDataToParent";
        /**
         * Emitted when the embed does not have cookie access. This happens
         * when Safari and other Web browsers block third-party cookies
         * are blocked by default. `NoCookieAccess` can trigger.
         * @example
         *```js
         * appEmbed.on(EmbedEvent.NoCookieAccess)
         *```
         * @version SDK: 1.1.0 | ThoughtSpot: ts7.may.cl, 7.2.1.sw
         */
        EmbedEvent["NoCookieAccess"] = "noCookieAccess";
        /**
         * Emitted when SAML is complete
         * @private
         * @hidden
         */
        EmbedEvent["SAMLComplete"] = "samlComplete";
        /**
         * Emitted when any modal is opened in the app
         * @version SDK: 1.6.0 | ThoughtSpot: ts8.nov.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.DialogOpen, payload => {
         *    console.log('dialog open', payload);
         *  })
         *```
         */
        EmbedEvent["DialogOpen"] = "dialog-open";
        /**
         * Emitted when any modal is closed in the app
         * @version SDK: 1.6.0 | ThoughtSpot: ts8.nov.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.DialogClose, payload => {
         *     console.log('dialog close', payload);
         * })
         *```
         */
        EmbedEvent["DialogClose"] = "dialog-close";
        /**
         * Emitted when the Liveboard shell loads.
         * You can use this event as a hook to trigger
         * other events on the rendered Liveboard.
         * @version SDK: 1.9.1 | ThoughtSpot: 8.1.0.cl, 8.4.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.LiveboardRendered, payload => {
               console.log('Liveboard is rendered', payload);
           })
         *```
         * The following example shows how to trigger
         * `SetVisibleVizs` event using LiveboardRendered embed event:
         * @example
         *```js
         * const embedRef = useEmbedRef();
         * const onLiveboardRendered = () => {
         * embed.trigger(HostEvent.SetVisibleVizs, ['viz1', 'viz2']);
         * };
         *```
         */
        EmbedEvent["LiveboardRendered"] = "PinboardRendered";
        /**
         * Emits all events.
         * @Version SDK: 1.10.0 | ThoughtSpot: 8.2.0.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.ALL, payload => {
         *  console.log('Embed Events', payload)
         * })
         *```
         */
        EmbedEvent["ALL"] = "*";
        /**
         * Emitted when an Answer is saved in the app
         * @Version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //Emit when action starts
         *  searchEmbed.on(EmbedEvent.Save, payload => {
         *    console.log('Save', payload)
         *  }, {
         *    start: true
         * })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.Save, payload => {
         *    console.log('Save', payload)
         * })
         *```
         */
        EmbedEvent["Save"] = "save";
        /**
         * Emitted when the download action is triggered on an Answer.
         *
         * **Note**: This event is deprecated in v1.21.0.
         * To fire an event when a download action is initiated on a chart or table,
         * use `EmbedEvent.DownloadAsPng`, `EmbedEvent.DownloadAsPDF`,
         * `EmbedEvent.DownloadAsCSV`, or `EmbedEvent.DownloadAsXLSX`
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Download, {
         * vizId: '730496d6-6903-4601-937e-2c691821af3c'
         * })
         *```
         */
        EmbedEvent["Download"] = "download";
        /**
         * Emitted when the download action is triggered on an Answer.
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.4.0.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.DownloadAsPng, payload => {
         *   console.log('download PNG', payload)}, {start: true })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.DownloadAsPng, payload => {
         *   console.log('download PNG', payload)})
         *```
         */
        EmbedEvent["DownloadAsPng"] = "downloadAsPng";
        /**
         * Emitted when the Download as PDF action is triggered on an Answer
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.DownloadAsPdf, payload => {
         *   console.log('download PDF', payload)}, {start: true })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.DownloadAsPdf, payload => {
         *   console.log('download PDF', payload)})
         *```
         */
        EmbedEvent["DownloadAsPdf"] = "downloadAsPdf";
        /**
         * Emitted when the Download as CSV action is triggered on an Answer.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.DownloadAsCSV, payload => {
         *   console.log('download CSV', payload)}, {start: true })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.DownloadAsCSV, payload => {
         *    console.log('download CSV', payload)})
         *```
         */
        EmbedEvent["DownloadAsCsv"] = "downloadAsCsv";
        /**
         * Emitted when the Download as XLSX action is triggered on an Answer.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.DownloadAsXlsx, payload => {
         *   console.log('download Xlsx', payload)}, { start: true })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.DownloadAsXlsx, payload => {
         *   console.log('download Xlsx', payload)})
         *```
         */
        EmbedEvent["DownloadAsXlsx"] = "downloadAsXlsx";
        /**
         * Emitted when an Answer is deleted in the app
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * appEmbed.on(EmbedEvent.AnswerDelete, payload => {
         *    console.log('delete answer', payload)}, {start: true })
         * //trigger when action is completed
         * appEmbed.on(EmbedEvent.AnswerDelete, payload => {
         *    console.log('delete answer', payload)})
         *```
         */
        EmbedEvent["AnswerDelete"] = "answerDelete";
        /**
         * Emitted when a user initiates the Pin action to
         *  add an Answer to a Liveboard.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.Pin, payload => {
         *    console.log('pin', payload)
         * }, {
         * start: true
         * })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.Pin, payload => {
         *    console.log('pin', payload)
         * })
         *```
         */
        EmbedEvent["Pin"] = "pin";
        /**
         * Emitted when SpotIQ analysis is triggered
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.SpotIQAnalyze, payload => {
         *   console.log('SpotIQAnalyze', payload)
         * }, {
         * start: true
         * })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.SpotIQAnalyze, payload => {
         *   console.log('SpotIQ analyze', payload)
         * })
         *```
         */
        EmbedEvent["SpotIQAnalyze"] = "spotIQAnalyze";
        /**
         * Emitted when a user shares an object with another user or group
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.Share, payload => {
         *    console.log('Share', payload)
         * }, {
         * start: true
         * })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.Share, payload => {
         *   console.log('Share', payload)
         * })
         *```
         */
        EmbedEvent["Share"] = "share";
        /**
         * Emitted when a user clicks the **Include** action to include a specific value or
         * data on a chart or table.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.DrillInclude, payload => {
         *    console.log('Drill include', payload);
         * })
         *```
         */
        EmbedEvent["DrillInclude"] = "context-menu-item-include";
        /**
         * Emitted when a user clicks the **Exclude** action to exclude a specific value or
         * data on a chart or table
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.DrillExclude, payload => {
         *     console.log('Drill exclude', payload);
         * })
         *```
         */
        EmbedEvent["DrillExclude"] = "context-menu-item-exclude";
        /**
         * Emitted when a column value is copied in the embedded app.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * seachEmbed.on(EmbedEvent.CopyToClipboard, payload => {
         *    console.log('copy to clipboard', payload);
         * })
         *```
         */
        EmbedEvent["CopyToClipboard"] = "context-menu-item-copy-to-clipboard";
        /**
         * Emitted when a user clicks the **Update TML** action on
         * embedded Liveboard.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.UpdateTML)
         * })
         *```
         */
        EmbedEvent["UpdateTML"] = "updateTSL";
        /**
         * Emitted when a user clicks the **Edit TML** action
         * on an embedded Liveboard.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.EditTML, payload => {
         *    console.log('Edit TML', payload);
         * })
         *```
         */
        EmbedEvent["EditTML"] = "editTSL";
        /**
         * Emitted when the **Export TML** action is triggered on an
         * an embedded object in the app
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * searchEmbed.on(EmbedEvent.ExportTML, payload => {
         *     console.log('Export TML', payload)}, { start: true })
         * //emit when action ends
         * searchEmbed.on(EmbedEvent.ExportTML, payload => {
         *     console.log('Export TML', payload)})
         *```
         */
        EmbedEvent["ExportTML"] = "exportTSL";
        /**
         * Emitted when an Answer is saved as a View.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * appEmbed.on(EmbedEvent.SaveAsView, payload => {
         *    console.log('View', payload);
         * })
         *```
         */
        EmbedEvent["SaveAsView"] = "saveAsView";
        /**
         * Emitted when the user creates a copy of an Answer.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * //emit when action starts
         * appEmbed.on(EmbedEvent.CopyAEdit, payload => {
         *    console.log('Copy and edit', payload)}, {start: true })
         * //emit when action ends
         * appEmbed.on(EmbedEvent.CopyAEdit, payload => {
         *    console.log('Copy and edit', payload)})
         *```
         */
        EmbedEvent["CopyAEdit"] = "copyAEdit";
        /**
         * Emitted when a user clicks *Show underlying data* on an Answer.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.ShowUnderlyingData, payload => {
         *    console.log('show data', payload);
         * })
         *```
         */
        EmbedEvent["ShowUnderlyingData"] = "showUnderlyingData";
        /**
         * Emitted when an Answer is switched to a chart or table view.
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         * @example
         *```js
         * searchEmbed.on(EmbedEvent.AnswerChartSwitcher, payload => {
         *    console.log('switch view', payload);
         * })
         *```
         */
        EmbedEvent["AnswerChartSwitcher"] = "answerChartSwitcher";
        /**
         * Internal event to communicate the initial settings back to the ThoughtSpot app
         * @hidden
         */
        EmbedEvent["APP_INIT"] = "appInit";
        /**
         * Emitted when a user clicks **Show Liveboard details** on a Liveboard
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.AnswerChartSwitcher, payload => {
         *    console.log('Liveboard details', payload);
         * })
         *```
         */
        EmbedEvent["LiveboardInfo"] = "pinboardInfo";
        /**
         * Emitted when a user clicks on the Favorite icon on a Liveboard
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.AddToFavorites, payload => {
         *    console.log('favorites', payload);
         * })
         *```
         */
        EmbedEvent["AddToFavorites"] = "addToFavorites";
        /**
         * Emitted when a user clicks **Schedule** on a Liveboard
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Schedule, payload => {
         *    console.log(`Liveboard schedule', payload);
         * })
         *```
         */
        EmbedEvent["Schedule"] = "subscription";
        /**
         * Emitted when a user clicks **Edit** on a Liveboard or visualization
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Edit, payload => {
         *    console.log(`Liveboard edit', payload);
         * })
         *```
         */
        EmbedEvent["Edit"] = "edit";
        /**
         * Emitted when a user clicks *Make a copy* on a Liveboard
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.MakeACopy, payload => {
         *    console.log(`Copy', payload);
         * })
         *```
         */
        EmbedEvent["MakeACopy"] = "makeACopy";
        /**
         * Emitted when a user clicks **Present** on a Liveboard or visualization
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Present)
         *```
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Present, {
         *   vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         * })
         *```
         */
        EmbedEvent["Present"] = "present";
        /**
         * Emitted when a user clicks **Delete** on a visualization
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Delete,
         *   {vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         *```
         */
        EmbedEvent["Delete"] = "delete";
        /**
         * Emitted when a user clicks Manage schedules on a Liveboard
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.SchedulesList)
         *```
         */
        EmbedEvent["SchedulesList"] = "schedule-list";
        /**
         * Emitted when a user clicks **Cancel** in edit mode on a Liveboard
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Cancel)
         *```
         */
        EmbedEvent["Cancel"] = "cancel";
        /**
         * Emitted when a user clicks **Explore** on a visualization
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.Explore,  {
         *   vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         *```
         */
        EmbedEvent["Explore"] = "explore";
        /**
         * Emitted when a user clicks **Copy link** action on a visualization.
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.CopyLink, {
         *   vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         *```
         */
        EmbedEvent["CopyLink"] = "embedDocument";
        /**
         * Emitted when a user interacts with cross filters on a
         * visualization or Liveboard.
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.0.sw
         * @example
         *```js
         * liveboardEmbed.on(EmbedEvent.CrossFilterChanged, {
         *    vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         *```
         */
        EmbedEvent["CrossFilterChanged"] = "cross-filter-changed";
        /**
         * Emitted when a user right clicks on a visualization (chart or table)
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.0.sw
         * @example
         *```js
         * LiveboardEmbed.on(EmbedEvent.VizPointRightClick, payload => {
         *    console.log('VizPointClick', payload)
         * })
         *```
         */
        EmbedEvent["VizPointRightClick"] = "vizPointRightClick";
        /**
         * Emitted when a user clicks **Insert to slide** on a visualization
         * @hidden
         */
        EmbedEvent["InsertIntoSlide"] = "insertInToSlide";
        /**
         * Emitted when a user changes any filter on a Liveboard.
         * Returns filter type and name, column name and ID, and runtime
         * filter details.
         * @example
         *
         *```js
         * LiveboardEmbed.on(EmbedEvent.FilterChanged, (payload) => {
         *    console.log('payload', payload);
         * })
         *
         * @version SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl, 9.5.0.sw
         */
        EmbedEvent["FilterChanged"] = "filterChanged";
        /**
         *  Emitted when a user clicks the **Go** button to initiate
         *  a Natural Language Search query
         * @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        EmbedEvent["SageEmbedQuery"] = "sageEmbedQuery";
        /**
         * Emitted when a user selects a data source on the embedded
         * Natural Language Search interface.
         *
         * @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        EmbedEvent["SageWorksheetUpdated"] = "sageWorksheetUpdated";
        /**
         * Emitted when a user updates a connection on the **Data** page
         * @version SDK : 1.27.0 | ThoughtSpot: 9.8.0.cl, 9.8.0.sw
         */
        EmbedEvent["UpdateConnection"] = "updateConnection";
        /**
         * Emitted when a user updates a connection on the **Data** page
         * @version SDK : 1.27.0 | ThoughtSpot: 9.8.0.cl, 9.8.0.sw
         */
        EmbedEvent["CreateConnection"] = "createConnection";
        /**
         * Emitted when name, status (private or public) or filter values of a
         * Personalised view is updated.
         * @returns viewName: string
         * @returns viewId: string
         * @returns liveboardId: string
         * @returns isPublic: boolean
         * @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        EmbedEvent["UpdatePersonalisedView"] = "updatePersonalisedView";
        /**
         * Emitted when a Personalised view is saved.
         * @returns viewName: string
         * @returns viewId: string
         * @returns liveboardId: string
         * @returns isPublic: boolean
         * @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        EmbedEvent["SavePersonalisedView"] = "savePersonalisedView";
        /**
         * Emitted when a Liveboard is reset.
         * @returns viewName: string
         * @returns viewId: string
         * @returns liveboardId: string
         * @returns isPublic: boolean
         * @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        EmbedEvent["ResetLiveboard"] = "resetLiveboard";
        /**
         * Emitted when a PersonalisedView is deleted.
         * @returns views: string[]
         * @returns liveboardId: string
         * @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        EmbedEvent["DeletePersonalisedView"] = "deletePersonalisedView";
        /**
         * Emitted when a user creates a Worksheet.
         * @version SDK : 1.27.0 | ThoughtSpot: 9.8.0.cl, 9.8.0.sw
         */
        EmbedEvent["CreateWorksheet"] = "createWorksheet";
        /**
         * Emitted when the *Ask Sage* is initialized.
         * @returns viewName: string
         * @returns viewId: string
         * @returns liveboardId: string
         * @returns isPublic: boolean
         * @version SDK : 1.29.0 | ThoughtSpot Cloud: 9.12.0.cl
         */
        EmbedEvent["AskSageInit"] = "AskSageInit";
        /**
         * Emitted when a Liveboard or visualization is renamed.
         * @version SDK : 1.28.0 | ThoughtSpot: 9.10.5.cl, 10.1.0.sw
         */
        EmbedEvent["Rename"] = "rename";
        /**
         *
         * This event can be emitted to intercept search execution initiated by
         * the users and implement the logic to allow or restrict search execution.
         * You can can also show custom error text if the search query must be
         * restricted due to your application or business requirements.

         * Prerequisite: Set `isOnBeforeGetVizDataInterceptEnabled` to `true`
         * for this embed event to get emitted.
         * @param: payload
         * @param: responder
         * Contains elements that lets developers define whether ThoughtSpot
         * should run the search, and if not, what error message
         * should be shown to the user.
         *
         * execute: When execute returns `true`, the search will be run.
         * When execute returns `false`, the search will not be executed.
         *
         * error: Developers can customize the error message text when `execute`
         * returns `false` using the error parameter in responder.
         * @version SDK : 1.29.0 | ThoughtSpot : 10.3.0.cl
         * @example
         *```js
         * .on(EmbedEvent.OnBeforeGetVizDataIntercept,
         * (payload, responder) => {
         *  responder({
         *      data: {
         *          execute:false,
         *          error: {
         *          //Provide a custom error message to explain to your end user
         *          //why their search did not run
         *          errorText: "This search query cannot be run.
         *          Please contact your administrator for more details."
         *          }
         *  }})
         * })
         * ```
         *
         *```js
         * .on(EmbedEvent.OnBeforeGetVizDataIntercept,
         * (payload, responder) => {
         * const query = payload.data.data.answer.search_query
         * responder({
         *  data: {
         *      // returns true as long as the query does not include
         *      // both the 'sales' AND the 'county' column
         *      execute: !(query.includes("sales")&&query.includes("county")),
         *      error: {
         *      //Provide a custom error message to explain to your end user
         *      // why their search did not run, and which searches are accepted by your custom logic.
         *      errorText: "You can't use this query :" + query + ".
         *      The 'sales' measures can never be used at the 'county' level.
         *      Please try another measure, or remove 'county' from your search."
         *      }
         *  }})
         * })
         *```
         */
        EmbedEvent["OnBeforeGetVizDataIntercept"] = "onBeforeGetVizDataIntercept";
        /**
         * Emitted when parameter changes in an Answer
         * or Liveboard.
         * ```js
         * liveboardEmbed.on(EmbedEvent.ParameterChanged, (payload) => {
         *     console.log('payload', payload);
         * })
         *```
         * @version SDK : 1.29.0 | ThoughtSpot : 10.3.0.cl
         */
        EmbedEvent["ParameterChanged"] = "parameterChanged";
        /**
         * Emits when a table visualization is rendered in
         * the ThoughtSpot embedded app.
         *
         * You can also use this event as a hook to trigger host events
         * such as `HostEvent.TransformTableVizData` on the table visualization.
         * The event payload contains the data used in the rendered table.
         * You can extract the relevant data from the payload
         * stored in `payload.data.data.columnDataLite`.
         *
         * `columnDataLite` is a multidimensional array that contains
         * data values for each column, which was used in the query to
         * generate the table visualization. To find and modify specific cell data,
         * you can either loop through the array or directly access a cell if
         * you know its position and data index.
         *
         * In the following code sample, the first cell in the first column
         * (`columnDataLite[0].dataValue[0]`) is set to `new fob`.
         * Note that any changes made to the data in the payload will only update the
         * visual presentation and do not affect the underlying data.
         * To persist data value modifications after a reload or during chart
         * interactions such as drill down, ensure that the modified
         * payload in the `columnDataLite` is passed on to
         * `HostEvent.TransformTableVizData` and trigger an update to
         * the table visualization.
         *
         * If the Row-Level Security (RLS) rules are applied on the
         * Worksheet or Model, exercise caution when changing column
         * or table cell values to maintain data security.
         *
         * @example
         * ```js
         * searchEmbed.on(EmbedEvent.TableVizRendered, (payload) => {
         *      console.log(payload);
         *      const columnDataLite = payload.data.data.columnDataLite;
         *      columnDataLite[0].dataValue[0]="new fob";
         *      console.log('>>> new Data', columnDataLite);
         *      searchEmbed.trigger(HostEvent.TransformTableVizData, columnDataLite);
         * })
         * ```
         * @version SDK: 1.37.0 | ThoughtSpot: 10.8.0.cl
         */
        EmbedEvent["TableVizRendered"] = "TableVizRendered";
        /**
        * Emitted when the liveboard is created from pin modal or Liveboard list page.
        * You can use this event as a hook to trigger
        * other events on liveboard creation.
        *
        * ```js
        * liveboardEmbed.on(EmbedEvent.CreateLiveboard, (payload) => {
        *     console.log('payload', payload);
        * })
        *```
        * @version SDK : 1.37.0 | ThoughtSpot : 10.8.0.cl
        */
        EmbedEvent["CreateLiveboard"] = "createLiveboard";
        /**
         * Emitted when a user creates a Model.
         * @version SDK : 1.37.0 | ThoughtSpot : 10.8.0.cl
         */
        EmbedEvent["CreateModel"] = "createModel";
    })(exports.EmbedEvent || (exports.EmbedEvent = {}));
    /**
     * Event types that can be triggered by the host application
     * to the embedded ThoughtSpot app.
     *
     * To trigger an event use the corresponding
     * {@link LiveboardEmbed.trigger} or {@link AppEmbed.trigger} or {@link
     * SearchEmbed.trigger} method.
     * @example
     * ```js
     * import { HostEvent } from '@thoughtspot/visual-embed-sdk';
     * // Or
     * // const { HostEvent } = window.tsembed;
     *
     * // create the liveboard embed.
     *
     * liveboardEmbed.trigger(HostEvent.UpdateRuntimeFilters, [
     *   { columnName: 'state, operator: RuntimeFilterOp.EQ, values: ['california']}
     * ]);
     * ```
     * @example
     * If using React components to embed, use the format shown in this example:
     *
     * ```js
     *  const selectVizs = () => {
     *      embedRef.current.trigger(HostEvent.SetVisibleVizs, [
     *         "715e4613-c891-4884-be44-aa8d13701c06",
     *         "3f84d633-e325-44b2-be25-c6650e5a49cf"
     *      ]);
     *    };
     * ```
     *
     *
     * You can also attach an Embed event to a Host event to trigger
     * a specific action as shown in this example:
     * @example
     * ```js
     *  const EmbeddedComponent = () => {
     *       const embedRef = useRef(null); // import { useRef } from react
     *       const onLiveboardRendered = () => {
     *          embedRef.current.trigger(HostEvent.SetVisibleVizs, ['viz1', 'viz2']);
     *      };
     *
     *      return (
     *          <LiveboardEmbed
     *              ref={embedRef}
     *              liveboardId="<liveboard-guid>"
     *              onLiveboardRendered={onLiveboardRendered}
     *          />
     *      );
     *  }
     * ```
     * @group Events
     */
    // eslint-disable-next-line no-shadow
    exports.HostEvent = void 0;
    (function (HostEvent) {
        /**
         * Triggers a search operation with the search tokens specified in
         * the search query string.
         * Supported in `AppEmbed` and `SearchEmbed` deployments.
         * Includes the following properties:
         * @param - `searchQuery` - query string with search tokens
         * @param - `dataSources` - Data source GUID to Search on
         *                        - Although an array, only a single source
         *                          is supported.
         * @param - `execute` - executes search and updates the existing query
         * @example
         * ```js
         * searchembed.trigger(HostEvent.Search, {
             searchQuery: "[sales] by [item type]",
             dataSources: ["cd252e5c-b552-49a8-821d-3eadaa049cca"],
             execute: true
           });
         * ```
         */
        HostEvent["Search"] = "search";
        /**
         * Triggers a drill on certain points of the specified column
         * Includes the following properties:
         * @param - points - an object containing selectedPoints/clickedPoints
         * to drill to. For example, { selectedPoints: []}
         * @param - columnGuid - Optional. GUID of the column to drill
         * by. If not provided it will auto drill by the configured
         *   column.
         * @param - autoDrillDown - Optional. If true, the drill down will be
         * done automatically on the most popular column.
         * @param - vizId [TS >= 9.8.0] - Optional. The GUID of the visualization to drill
         * in case of a Liveboard.
         * @example
         * ```js
         * searchEmbed.on(EmbedEvent.VizPointDoubleClick, (payload) => {
         *       console.log(payload);
         *       const clickedPoint = payload.data.clickedPoint;
         *       const selectedPoint = payload.data.selectedPoints;
         *       console.log('>>> called', clickedPoint);
         *       searchEmbed.trigger(HostEvent.DrillDown, {
         *             points: {
         *                  clickedPoint,
         *                  selectedPoints: selectedPoint
         *             },
         *             autoDrillDown: true,
         *       });
         * })
         * ```
         * @example
         * ```js
         *  // Works with TS 9.8.0 and above
         *
         *  liveboardEmbed.on(EmbedEvent.VizPointDoubleClick, (payload) => {
         *    console.log(payload);
         *    const clickedPoint = payload.data.clickedPoint;
         *    const selectedPoint = payload.data.selectedPoints;
         *    console.log('>>> called', clickedPoint);
         *    liveboardEmbed.trigger(HostEvent.DrillDown, {
         *      points: {
         *        clickedPoint,
         *        selectedPoints: selectedPoint
         *      },
         *      columnGuid: "<guid of the column to drill>",
         *      vizId: payload.data.vizId
         *    });
         *  })
         * ```
         * @version SDK: 1.5.0 | ThoughtSpot: ts7.oct.cl, 7.2.1
         */
        HostEvent["DrillDown"] = "triggerDrillDown";
        /**
         * Apply filters
         * @hidden
         */
        HostEvent["Filter"] = "filter";
        /**
         * Reload the Answer or visualization
         * @hidden
         */
        HostEvent["Reload"] = "reload";
        /**
         * Get iframe URL for the current embed view on the playground.
         * Developers can use this URL to embed a ThoughtSpot object
         * in apps like Salesforce or Sharepoint.
         * @example
         * ```js
         * const url = embed.trigger(HostEvent.GetIframeUrl);
         * console.log("iFrameURL",url);
         * ```
         * @version SDK: 1.35.0 | ThoughtSpot: 10.4.0.cl
         */
        HostEvent["GetIframeUrl"] = "GetIframeUrl";
        /**
         * Display specific visualizations on a Liveboard.
         * @param - An array of GUIDs of the visualization to show. The visualization IDs not passed
         *  in this parameter will be hidden.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SetVisibleVizs, [
         *  '730496d6-6903-4601-937e-2c691821af3c',
         *  'd547ec54-2a37-4516-a222-2b06719af726'])
         * ```
         * @version SDK: 1.6.0 | ThoughtSpot: ts8.nov.cl, 8.4.1.sw
         */
        HostEvent["SetVisibleVizs"] = "SetPinboardVisibleVizs";
        /**
         * Set a Liveboard tab as an active tab.
         * @param - tabId - string of id of Tab to show
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SetActiveTab,{
         *  tabId:'730496d6-6903-4601-937e-2c691821af3c'
         * })
         * ```
         * @version SDK: 1.24.0 | ThoughtSpot: 9.5.0.cl, 9.5.1-sw
         */
        HostEvent["SetActiveTab"] = "SetActiveTab";
        /**
         * Updates the runtime filters applied on a Liveboard. The filter
         * attributes passed with this event are appended to the existing runtime
         * filters applied on a Liveboard.
         *
         * **Note**: `HostEvent.UpdateRuntimeFilters` is supported in `LiveboardEmbed`
         * and `AppEmbed` only. In full application embedding, this event updates
         * the runtime filters applied on the Liveboard and saved Answer objects.
         *
         * @param - Pass an array of {@link RuntimeFilter} with the following attributes:
         * `columnName` - _String_. The name of the column to filter on.
         *
         * `operator` - {@link RuntimeFilterOp} to apply. For more information,
         * see link:https://developers.thoughtspot.com/docs/?pageid=runtime-filters#rtOperator[Developer Documentation].
         *
         * `values` - List of operands. Some operators such as EQ and LE allow a
         * single value, whereas BW and IN accept multiple values.
         *
         * **Note**: Updating runtime filters resets the ThoughtSpot
         * object to its original state and applies new filter conditions.
         * Any user changes (like drilling into a visualization)
         * will be cleared, restoring the original visualization
         * with the updated filters.
         *

         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdateRuntimeFilters, [
         *   {columnName: "state",operator: RuntimeFilterOp.EQ,values: ["michigan"]},
         *   {columnName: "item type",operator: RuntimeFilterOp.EQ,values: ["Jackets"]}
         * ])
         * ```
         * @version SDK: 1.9.0 | ThoughtSpot: 8.1.0.cl, 8.4.1.sw
         * @important
         */
        HostEvent["UpdateRuntimeFilters"] = "UpdateRuntimeFilters";
        /**
         * Navigate to a specific page in the embedded ThoughtSpot application.
         * This is the same as calling `appEmbed.navigateToPage(path, true)`.
         * @param - `path` - the path to navigate to to go forward or back. The path value can
         * be a number; for example, `1`, `-1`.
         * @example
         * ```js
         * appEmbed.navigateToPage(-1)
         * ```
         * @version SDK: 1.12.0 | ThoughtSpot 8.4.0.cl, 8.4.1.sw
         */
        HostEvent["Navigate"] = "Navigate";
        /**
         * Open the filter panel for a particular column.
         * Works with Search and Liveboard embed.
         * @param - { columnId: string,
         *  name: string,
         *  type: INT64/CHAR/DATE,
         *  dataType: ATTRIBUTE/MEASURE }
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.OpenFilter,
         *  {column: { columnId: '<column-GUID>', name: 'column name', type: 'INT64', dataType: 'ATTRIBUTE'}})
         * ```
         * @example
         * ```js
         * LiveboardEmbed.trigger(HostEvent.OpenFilter,
         *   { column: {columnId: '<column-GUID>'}})
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl
         */
        HostEvent["OpenFilter"] = "openFilter";
        /**
         * Add columns to the current search query.
         * @param - { columnIds: string[] }
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.AddColumns, { columnIds: ['<column-GUID>','<column-GUID>'] })
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl
         */
        HostEvent["AddColumns"] = "addColumns";
        /**
         * Remove a column from the current search query.
         * @param - { columnId: string }
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.RemoveColumn, { columnId: '<column-Guid>' })
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl
         */
        HostEvent["RemoveColumn"] = "removeColumn";
        /**
         * Get the transient state of a Liveboard as encoded content.
         * This includes unsaved and ad hoc changes such as
         * Liveboard filters, runtime filters applied on visualizations on a
         * Liveboard, and Liveboard layout, changes to visualizations such as
         * sorting, toggling of legends, and data drill down.
         * For more information, see
         * link:https://developers.thoughtspot.com/docs/fetch-data-and-report-apis#transient-lb-content[Liveboard data with unsaved changes].
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.getExportRequestForCurrentPinboard).then(
         * data=>console.log(data))
         * ```
         * @version SDK: 1.13.0 | ThoughtSpot: 8.5.0.cl, 8.8.1.sw
         */
        HostEvent["getExportRequestForCurrentPinboard"] = "getExportRequestForCurrentPinboard";
        /**
         * Trigger **Pin** action on an embedded object.
         * If no parameters are defined, the pin action is triggered
         * for the Answer that the user is currently on
         * and a modal opens for Liveboard selection.
         * To add an Answer or visualization to a Liveboard programmatically without
         * showing requiring additional user input via *Pin to Liveboard* modal, define
         * the following parameters:
         *
         * @param
         * `vizId`-  GUID of the saved Answer or visualization to pin to a Liveboard.
         *  Optional when pinning a new chart or table generated from a Search query.
         * @param
         * `liveboardID` - GUID of the Liveboard to pin an Answer. If there is no Liveboard,
         *  specify the `newLiveboardName` parameter to create a new Liveboard.
         * @param
         * `tabId` - GUID of the Liveboard tab. Adds the Answer to the Liveboard tab
         *  specified in the code.
         * @param
         * `newVizName` - Name string for the Answer or visualization. If defined,
         *  this parameter adds a new visualization object or creates a copy of the
         *  Answer or visualization specified in `vizId`.
         *  Required attribute.
         * @param
         * `newLiveboardName` - Name string for the Liveboard.
         *  Creates a new Liveboard object with the specified name.
         * @param
         * `newTabName` - Name of the tab. Adds a new tab Liveboard specified
         *  in the code.
         *
         * @example
         * ```js
         * const pinResponse = await appEmbed.trigger(HostEvent.Pin, {
         *     vizId: "123",
         *     newVizName: "Sales by region",
         *     liveboardId: "123",
         *     tabId: "123"
         *  });
         * ```
         * @example
         * ```js
         * const pinResponse = await appEmbed.trigger(HostEvent.Pin, {
         *     newVizName: "Total sales of Jackets",
         *     liveboardId: "123"
         *  });
         * ```
         *
         * @example
         * ```js
         * const pinResponse = await searchEmbed.trigger(HostEvent.Pin, {
         *     newVizName: "Sales by state",
         *     newLiveboardName: "Sales",
         *     newTabName: "Products"
         *  });
         * ```
         * @example
         * ```js
         * appEmbed.trigger(HostEvent.Pin)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["Pin"] = "pin";
        /**
         * Trigger the **Show Liveboard details** action
         * on an embedded Liveboard.
         * @example
         *```js
         * liveboardEmbed.trigger(HostEvent.LiveboardInfo)
         *```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["LiveboardInfo"] = "pinboardInfo";
        /**
         * Trigger the **Schedule** action on an embedded Liveboard.
         * @example
         * ```js
         *  liveboardEmbed.trigger(HostEvent.Schedule)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["Schedule"] = "subscription";
        /**
         * Trigger the **Manage schedule** action on an embedded Liveboard
         * @example
         * ```js
         *  liveboardEmbed.trigger(HostEvent.ScheduleList)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["SchedulesList"] = "schedule-list";
        /**
         * Trigger the **Export TML** action on an embedded Liveboard or
         * Answer.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.ExportTML)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["ExportTML"] = "exportTSL";
        /**
         * Trigger the **Edit TML** action on an embedded Liveboard or
         * saved Answers in the full application embedding.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.EditTML)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["EditTML"] = "editTSL";
        /**
         * Trigger the **Update TML** action on an embedded Liveboard.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdateTML)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["UpdateTML"] = "updateTSL";
        /**
         * Trigger the **Download PDF** action on an embedded Liveboard,
         * visualization or Answer.
         *
         * **NOTE**: The **Download** > **PDF** action is available on
         * visualizations and Answers if the data is in tabular format.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.DownloadAsPdf)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["DownloadAsPdf"] = "downloadAsPdf";
        /**
         * Trigger the **Make a copy** action on a Liveboard,
         * visualization, or Answer page.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.MakeACopy)
         * ```
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.MakeACopy, {
         * vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * @example
         * ```js
         * vizEmbed.trigger(HostEvent.MakeACopy)
         * ```
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.MakeACopy)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["MakeACopy"] = "makeACopy";
        /**
         * Trigger the **Delete** action for a Liveboard.
         * @example
         * ```js
         * appEmbed.trigger(HostEvent.Remove)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         * * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Remove)
         * ```
         * @version SDK: 1.37.0 | ThoughtSpot: 10.8.0.cl, 10.10.0.sw
         */
        HostEvent["Remove"] = "delete";
        /**
         * Trigger the **Explore** action on a visualization.
         * @param - an object with `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Explore, {vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["Explore"] = "explore";
        /**
         * Trigger the **Create alert** action on a KPI chart
         * in a Liveboard or saved Answer.
         * @param - an object with `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.CreateMonitor, {
         *  vizId: '730496d6-6903-4601-937e-2c691821af3c'
         * })
         * ```
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.CreateMonitor)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["CreateMonitor"] = "createMonitor";
        /**
         * Trigger the **Manage alerts** action on a KPI chart
         * in a visualization or saved Answer.
         * @param - an object with `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.ManageMonitor, {
         *  vizId: '730496d6-6903-4601-937e-2c691821af3c'
         * })
         * ```
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.ManageMonitor)
         * ```
         * @example
         * ```js
         * vizEmbed.trigger(HostEvent.ManageMonitor)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["ManageMonitor"] = "manageMonitor";
        /**
         * Trigger the **Edit** action on a Liveboard or a visualization
         * on a Liveboard.
         *
         * This event is not supported in visualization embed and search embed.
         * @param - object - To trigger the action for a specific visualization
         * in Liveboard embed, pass in `vizId` as a key.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Edit)
         * ```
         * ```js
         * liveboardEmbed.trigger(HostEvent.Edit, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["Edit"] = "edit";
        /**
         * Trigger the **Copy link** action on a Liveboard or visualization
         * @param - object - to trigger the action for a
         * specific visualization in Liveboard embed, pass in `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.CopyLink)
         * ```
         * ```js
         * liveboardEmbed.trigger(HostEvent.CopyLink, {vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger((HostEvent.CopyLink)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["CopyLink"] = "embedDocument";
        /**
         * Trigger the **Present** action on a Liveboard or visualization
         * @param - object - to trigger the action for a specific visualization
         *  in Liveboard embed, pass in `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Present)
         * ```
         * ```js
         * liveboardEmbed.trigger(HostEvent.Present, {vizId: '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger((HostEvent.Present)
         * ```
         * @version SDK: 1.15.0 | ThoughtSpot: 8.7.0.cl, 8.8.1.sw
         */
        HostEvent["Present"] = "present";
        /**
         * Get TML for the current search.
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.GetTML).then((tml) => {
         *   console.log(
         *      tml.answer.search_query // TML representation of the search query
         *   );
         * })
         * ```
         * @version SDK: 1.18.0 | ThoughtSpot: 8.10.0.cl, 9.0.1.sw
         * @important
         */
        HostEvent["GetTML"] = "getTML";
        /**
         * Trigger the **Show underlying data** action on a
         * chart or table.
         *
         * @param - an object with vizId as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.ShowUnderlyingData, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.ShowUnderlyingData)
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.ShowUnderlyingData)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["ShowUnderlyingData"] = "showUnderlyingData";
        /**
         * Trigger the **Delete** action for a visualization
         * in an embedded Liveboard, or a chart or table
         * generated from Search.
         * @param - Liveboard embed takes an object with `vizId` as a key.
         * Can be left empty if embedding Search or visualization.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Delete, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.Delete)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["Delete"] = "onDeleteAnswer";
        /**
         * Trigger the **SpotIQ analyze** action on a
         * chart or table.
         * @param - Liveboard embed takes `vizId` as a
         * key. Can be left undefined when embedding Search or
         * visualization.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SpotIQAnalyze, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.SpotIQAnalyze)
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.SpotIQAnalyze)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["SpotIQAnalyze"] = "spotIQAnalyze";
        /**
         * Trigger the **Download** action on charts in
         * the embedded view.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Download, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * embed.trigger(HostEvent.Download)
         * ```
         * @deprecated from SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl ,9.4.1.sw
         * Use {@link DownloadAsPng}
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["Download"] = "downloadAsPng";
        /**
         * Trigger the **Download** > **PNG** action on
         * charts in the embedded view.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.DownloadAsPng,
         * {vizId:'730496d6-6903-4601-937e-2c691821af3c'})
         *
         * vizEmbed.trigger(HostEvent.DownloadAsPng)
         *
         * searchEmbed.trigger(HostEvent.DownloadAsPng)
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.4.1.sw
         */
        HostEvent["DownloadAsPng"] = "downloadAsPng";
        /**
         * Trigger the **Download** > **CSV**  action on tables in
         * the embedded view.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.DownloadAsCsv, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.DownloadAsCsv)
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.DownloadAsCsv)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["DownloadAsCsv"] = "downloadAsCSV";
        /**
         * Trigger the **Download** > **XLSX**  action on tables
         * in the embedded view.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.DownloadAsXlsx, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.DownloadAsXlsx)
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.DownloadAsXlsx)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["DownloadAsXlsx"] = "downloadAsXLSX";
        /**
         * Trigger the **Share** action on an embedded
         * Liveboard or Answer.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Share)
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.Share)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["Share"] = "share";
        /**
         * Trigger the **Save**  action on a Liveboard or Answer.
         * Saves the changes.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.Save)
         * ```
         * ```js
         * searchEmbed.trigger(HostEvent.Save)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["Save"] = "save";
        /**
         * Trigger the **Sync to Sheets** action on an embedded visualization or Answer
         * Sends data from an Answer or Liveboard visualization to a Google sheet.
         * @param - an object with `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SyncToSheets, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.SyncToSheets)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["SyncToSheets"] = "sync-to-sheets";
        /**
         * Trigger the **Sync to Other Apps** action on an embedded visualization or Answer
         * Sends data from an Answer or Liveboard visualization to third-party apps such
         * as Slack, Salesforce, Microsoft Teams, ServiceNow and so on.
         * @param - an object with vizId as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SyncToOtherApps, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.SyncToOtherApps)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["SyncToOtherApps"] = "sync-to-other-apps";
        /**
         * Trigger the **Manage pipelines** action on an embedded
         * visualization or Answer.
         * Allows users to manage ThoughtSpot Sync pipelines.
         * @param - an object with `vizId` as a key
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.ManagePipelines, {vizId:
         * '730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * ```js
         * vizEmbed.trigger(HostEvent.ManagePipelines)
         * ```
         * @version SDK: 1.19.0 | ThoughtSpot: 9.0.0.cl, 9.0.1.sw
         */
        HostEvent["ManagePipelines"] = "manage-pipeline";
        /**
         * Reset search operation on the Search or Answer page.
         * @example
         * ```js
         * searchEmbed.trigger(HostEvent.ResetSearch)
         * ```
         * ```js
         * appEmbed.trigger(HostEvent.ResetSearch)
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.0.1.sw
         */
        HostEvent["ResetSearch"] = "resetSearch";
        /**
         * Get details of filters applied on the Liveboard.
         * Returns arrays containing Liveboard filter and runtime filter elements.
         * @example
         * ```js
         * const data = await liveboardEmbed.trigger(HostEvent.GetFilters);
         *     console.log('data', data);
         * ```
         * @version SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl
         */
        HostEvent["GetFilters"] = "getFilters";
        /**
         * Update one or several filters applied on a Liveboard.
         * @param - `filter`: a single filter object containing column name,
         * filter operator, and values.
         * @param - `filters`: multiple filter objects with column name, filter operator,
         * and values for each.
         *
         * Each filter object must include the following attributes:
         *
         * `column` - Name of the column to filter on.
         *
         * `oper`  - Filter operator, for example, EQ, IN, CONTAINS.
         *  For information about the supported filter operators,
         *  see link:https://developers.thoughtspot.com/docs/runtime-filters#rtOperator[Developer Documentation].
         *
         * `values` - An array of one or several values. The value definition on the
         *  data type you choose to filter on. For a complete list of supported data types,
         *  see
         *  link:https://developers.thoughtspot.com/docs/runtime-filters#_supported_data_types[Supported
         *  data types].
         *
         * `type`  - To update filters for date time, specify the date format type.
         * For more information and examples, see link:https://developers.thoughtspot.com/docs/embed-liveboard#_date_filters[Date filters].
         * @example
         * ```js
         *
         * liveboardEmbed.trigger(HostEvent.UpdateFilters, {
         *     filter: {
         *         column: "item type",
         *         oper: "IN",
         *         values: ["bags","shirts"]
         *        }
         *    });
         * ```
         * @example
         * ```js
         *
         * liveboardEmbed.trigger(HostEvent.UpdateFilters, {
         *     filter: {
         *         column: "date",
         *         oper: "EQ",
         *         values: ["JULY","2023"],
         *         type: "MONTH_YEAR"
         *        }
         *    });
         * ```
         * @example
         *
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdateFilters, {
         *  filters: [{
         *      column: "Item Type",
         *      oper: 'IN',
         *      values: ["bags","shirts"]
         *  },
         *    {
         *      column: "Region",
         *      oper: 'IN',
         *      values: ["West","Midwest"]
         *  },
         *    {
         *      column: "Date",
         *      oper: 'EQ',
         *      values: ["2023-07-31"],
         *      types: "EXACT_DATE"
         *    }]
         * });
         * ```
         * If there are multiple columns with the same name, consider
         * using `WORKSHEET_NAME::COLUMN_NAME` format.
         *
         * @example
         *
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdateFilters, {
         *  filters: [{
         *      column: "(Sample) Retail - Apparel::city",
         *      oper: 'IN',
         *      values: ["atlanta"]
         *  },
         *  {
         *      column: "(Sample) Retail - Apparel::Region",
         *      oper: 'IN',
         *      values: ["West","Midwest"]
         *  }]
         * });
         * ```
         * @version SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl
         */
        HostEvent["UpdateFilters"] = "updateFilters";
        /**
         * Get tab details for the current Liveboard.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.GetTabs).then((tabDetails) => {
         *   console.log(
         *      tabDetails // TabDetails of current Liveboard
         *   );
         * })
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.7.0.cl
         */
        HostEvent["GetTabs"] = "getTabs";
        /**
         * Set the visible tabs on a Liveboard.
         * @param - an array of ids of tabs to show, the IDs not passed
         *          will be hidden.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SetVisibleTabs, [
         *  '430496d6-6903-4601-937e-2c691821af3c',
         *  'f547ec54-2a37-4516-a222-2b06719af726'])
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        HostEvent["SetVisibleTabs"] = "SetPinboardVisibleTabs";
        /**
         * Set the hidden tabs on a Liveboard.
         * @param - an array of the IDs of the tabs to hide.
         * The IDs not passed will be shown.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.SetHiddenTabs, [
         *  '630496d6-6903-4601-937e-2c691821af3c',
         *  'i547ec54-2a37-4516-a222-2b06719af726'])
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        HostEvent["SetHiddenTabs"] = "SetPinboardHiddenTabs";
        /**
         * Updates the search query string for Natural Language Search operations.
         * @param - `queryString`: Text string in Natural Language format
         * @param - `executeSearch`: Boolean to execute search and update search query
         * @example
         * ```js
         * sageEmbed.trigger(HostEvent.UpdateSageQuery, {
         *  queryString: 'revenue per year',
         *  executeSearch: true,
         * })
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.8.0.cl, 9.8.0.sw
         */
        HostEvent["UpdateSageQuery"] = "updateSageQuery";
        /**
         * Get the Answer session for a Search or
         * Liveboard visualization.
         *
         * Note: This event is not typically used directly. Instead, use the
         * `getAnswerService()` method on the embed instance to get an AnswerService
         * object that provides a more convenient interface for working with answers.
         *
         * @example
         * ```js
         * // Preferred way to get an AnswerService
         * const service = await embed.getAnswerService();
         *
         * // Alternative direct usage (not recommended)
         * const {session} = await embed.trigger(
         *  HostEvent.GetAnswerSession, {
         *      vizId: '123', // For Liveboard Visualization.
         *  })
         * ```
         * @example
         * ```js
         * // Preferred way to get an AnswerService
         * const service = await embed.getAnswerService();
         *
         * // Alternative direct usage (not recommended)
         * const {session} = await embed.trigger( HostEvent.GetAnswerSession )
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.10.0.cl, 10.1.0.sw
         */
        HostEvent["GetAnswerSession"] = "getAnswerSession";
        /**
         * Trigger the *Ask Sage* action for visualizations
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.AskSage,
         * {vizId:'730496d6-6903-4601-937e-2c691821af3c'})
         * ```
         * @version SDK: 1.29.0 | ThoughtSpot Cloud: 9.12.0.cl
         */
        HostEvent["AskSage"] = "AskSage";
        /**
         * Trigger cross filter update action on a Liveboard.
         *
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdateCrossFilter, {
         *      vizId: 'b535c760-8bbe-4e6f-bb26-af56b4129a1e',
         *      conditions: [
         *      { columnName: 'Category', values: ['mfgr#12','mfgr#14'] },
         *      { columnName: 'color', values: ['mint','hot'] },
         *    ],
         * });
         * ```
         * @version SDK: 1.29.0 | ThoughtSpot Cloud: 10.0.0.cl, 10.1.0.sw
         */
        HostEvent["UpdateCrossFilter"] = "UpdateCrossFilter";
        /**
         * Trigger reset action for a personalized Liveboard view.
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.ResetLiveboardPersonalisedView);
         * ```
         * @version SDK: 1.29.0 | ThoughtSpot Cloud: 10.1.0.cl, 10.1.0.sw
         */
        HostEvent["ResetLiveboardPersonalisedView"] = "ResetLiveboardPersonalisedView";
        /**
         * Triggers an action to update Parameter values on embedded
         * Answers and Liveboard.
         *
         * @example
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdateParameters, [{
         * name: "Color",
         * value: "almond"
         * }])
         *
         * @version SDK: 1.29.0 | ThoughtSpot: 10.1.0.cl, 10.1.0.sw
         */
        HostEvent["UpdateParameters"] = "UpdateParameters";
        /**
         * Triggers GetParameters to fetch the runtime Parameters.
         * ```js
         * liveboardEmbed.trigger(HostEvent.GetParameters).then((parameter) => {
         *  console.log('parameters', parameter);
         * });
         *```
         * @version SDK: 1.29.0 | ThoughtSpot: 10.1.0.cl, 10.1.0.sw
         */
        HostEvent["GetParameters"] = "GetParameters";
        /**
         * Triggers an event to update a personalized view of a Liveboard.
         * ```js
         * liveboardEmbed.trigger(HostEvent.UpdatePersonalisedView, {viewId: '1234'})
         * ```
         * @version SDK: 1.36.0 | ThoughtSpot: 10.6.0.cl
         */
        HostEvent["UpdatePersonalisedView"] = "UpdatePersonalisedView";
        /**
         * @hidden
         * Notify when info call is completed successfully
         * ```js
         * liveboardEmbed.trigger(HostEvent.InfoSuccess, data);
         *```
         * @version SDK: 1.36.0 | ThoughtSpot: 10.6.0.cl
         */
        HostEvent["InfoSuccess"] = "InfoSuccess";
        /**
         * Trigger the save action for an Answer.
         * To programmatically save an answer without opening the
         * *Describe your Answer* modal, define the `name` and `description`
         * properties.
         * If no parameters are specified, the save action is
         * triggered with a modal to prompt users to
         * add a name and description for the Answer.
         * @param - optional attributes to set Answer properties.
         *  `name` - Name string for the Answer.
         *  `description` - Description text for the Answer.
         *
         * @example
         * ```js
         * const saveAnswerResponse = await searchEmbed.trigger(HostEvent.SaveAnswer, {
         *      name: "Sales by states",
         *      description: "Total sales by states in MidWest"
         *   });
         * ```
         * @version SDK: 1.36.0 | ThoughtSpot: 10.6.0.cl
         */
        HostEvent["SaveAnswer"] = "saveAnswer";
        /**
         * EmbedApi
         * @hidden
         */
        HostEvent["UIPassthrough"] = "UiPassthrough";
        /**
         * Triggers the table visualization re-render with the updated data.
         * Includes the following properties:
         * @param - `columnDataLite` - an array of object containing the
         * data value modifications retrieved from the `EmbedEvent.TableVizRendered`
         * payload.For example, { columnDataLite: []}`.
         *
         * @example
         * ```js
         * searchEmbed.on(EmbedEvent.TableVizRendered, (payload) => {
         *      console.log(payload);
         *      const columnDataLite = payload.data.data.columnDataLite;
         *      columnDataLite[0].dataValue[0]="new fob";
         *      console.log('>>> new Data', columnDataLite);
         *      searchEmbed.trigger(HostEvent.TransformTableVizData, columnDataLite);
         * })
         * ```
         * @version SDK: 1.37.0 | ThoughtSpot: 10.8.0.cl
         */
        HostEvent["TransformTableVizData"] = "TransformTableVizData";
    })(exports.HostEvent || (exports.HostEvent = {}));
    /**
     * The different visual modes that the data sources panel within
     * search could appear in, such as hidden, collapsed, or expanded.
     */
    // eslint-disable-next-line no-shadow
    exports.DataSourceVisualMode = void 0;
    (function (DataSourceVisualMode) {
        /**
         * The data source panel is hidden.
         */
        DataSourceVisualMode["Hidden"] = "hide";
        /**
         * The data source panel is collapsed, but the user can manually expand it.
         */
        DataSourceVisualMode["Collapsed"] = "collapse";
        /**
         * The data source panel is expanded, but the user can manually collapse it.
         */
        DataSourceVisualMode["Expanded"] = "expand";
    })(exports.DataSourceVisualMode || (exports.DataSourceVisualMode = {}));
    /**
     * The query params passed down to the embedded ThoughtSpot app
     * containing configuration and/or visual information.
     */
    // eslint-disable-next-line no-shadow
    var Param;
    (function (Param) {
        Param["EmbedApp"] = "embedApp";
        Param["DataSources"] = "dataSources";
        Param["DataSourceMode"] = "dataSourceMode";
        Param["DisableActions"] = "disableAction";
        Param["DisableActionReason"] = "disableHint";
        Param["ForceTable"] = "forceTable";
        Param["preventLiveboardFilterRemoval"] = "preventPinboardFilterRemoval";
        Param["SearchQuery"] = "searchQuery";
        Param["HideActions"] = "hideAction";
        Param["HideObjects"] = "hideObjects";
        Param["HostAppUrl"] = "hostAppUrl";
        Param["EnableVizTransformations"] = "enableVizTransform";
        Param["EnableSearchAssist"] = "enableSearchAssist";
        Param["EnablePendoHelp"] = "enablePendoHelp";
        Param["HideResult"] = "hideResult";
        Param["UseLastSelectedDataSource"] = "useLastSelectedSources";
        Param["Tag"] = "tag";
        Param["AutoLogin"] = "autoLogin";
        Param["searchTokenString"] = "searchTokenString";
        Param["executeSearch"] = "executeSearch";
        Param["fullHeight"] = "isFullHeightPinboard";
        Param["livedBoardEmbed"] = "isLiveboardEmbed";
        Param["searchEmbed"] = "isSearchEmbed";
        Param["vizEmbed"] = "isVizEmbed";
        Param["StringIDsUrl"] = "overrideStringIDsUrl";
        Param["Version"] = "sdkVersion";
        Param["ViewPortHeight"] = "viewPortHeight";
        Param["ViewPortWidth"] = "viewPortWidth";
        Param["VisibleActions"] = "visibleAction";
        Param["DisableLoginRedirect"] = "disableLoginRedirect";
        Param["visibleVizs"] = "pinboardVisibleVizs";
        Param["LiveboardV2Enabled"] = "isPinboardV2Enabled";
        Param["DataPanelV2Enabled"] = "enableDataPanelV2";
        Param["ShowAlerts"] = "showAlerts";
        Param["Locale"] = "locale";
        Param["CustomStyle"] = "customStyle";
        Param["ForceSAMLAutoRedirect"] = "forceSAMLAutoRedirect";
        // eslint-disable-next-line @typescript-eslint/no-shadow
        Param["AuthType"] = "authType";
        Param["IconSpriteUrl"] = "iconSprite";
        Param["cookieless"] = "cookieless";
        // Deprecated: `isContextMenuEnabledOnLeftClick`
        // Introduced: `contextMenuEnabledOnWhichClick` with values: 'left',
        // 'right', or 'both'. This update only affects ThoughtSpot URL parameters
        // and does not impact existing workflows or use cases. Added support for
        // 'both' clicks in `contextMenuTrigger` configuration.
        Param["ContextMenuTrigger"] = "contextMenuEnabledOnWhichClick";
        Param["LinkOverride"] = "linkOverride";
        Param["blockNonEmbedFullAppAccess"] = "blockNonEmbedFullAppAccess";
        Param["ShowInsertToSlide"] = "insertInToSlide";
        Param["PrimaryNavHidden"] = "primaryNavHidden";
        Param["HideProfleAndHelp"] = "profileAndHelpInNavBarHidden";
        Param["NavigationVersion"] = "navigationVersion";
        Param["HideHamburger"] = "hideHamburger";
        Param["HideObjectSearch"] = "hideObjectSearch";
        Param["HideNotification"] = "hideNotification";
        Param["HideApplicationSwitcher"] = "applicationSwitcherHidden";
        Param["HideOrgSwitcher"] = "orgSwitcherHidden";
        Param["IsSageEmbed"] = "isSageEmbed";
        Param["HideWorksheetSelector"] = "hideWorksheetSelector";
        Param["DisableWorksheetChange"] = "disableWorksheetChange";
        Param["HideSourceSelection"] = "hideSourceSelection";
        Param["DisableSourceSelection"] = "disableSourceSelection";
        Param["HideEurekaResults"] = "hideEurekaResults";
        Param["HideEurekaSuggestions"] = "hideEurekaSuggestions";
        Param["HideAutocompleteSuggestions"] = "hideAutocompleteSuggestions";
        Param["HideLiveboardHeader"] = "hideLiveboardHeader";
        Param["ShowLiveboardDescription"] = "showLiveboardDescription";
        Param["ShowLiveboardTitle"] = "showLiveboardTitle";
        Param["HiddenTabs"] = "hideTabs";
        Param["VisibleTabs"] = "visibleTabs";
        Param["HideTabPanel"] = "hideTabPanel";
        Param["HideSampleQuestions"] = "hideSampleQuestions";
        Param["WorksheetId"] = "worksheet";
        Param["Query"] = "query";
        Param["HideHomepageLeftNav"] = "hideHomepageLeftNav";
        Param["ModularHomeExperienceEnabled"] = "modularHomeExperience";
        Param["PendoTrackingKey"] = "additionalPendoKey";
        Param["LiveboardHeaderSticky"] = "isLiveboardHeaderSticky";
        Param["IsProductTour"] = "isProductTour";
        Param["HideSearchBarTitle"] = "hideSearchBarTitle";
        Param["HideSageAnswerHeader"] = "hideSageAnswerHeader";
        Param["HideSearchBar"] = "hideSearchBar";
        Param["ClientLogLevel"] = "clientLogLevel";
        Param["ExposeTranslationIDs"] = "exposeTranslationIDs";
        Param["OverrideNativeConsole"] = "overrideConsoleLogs";
        Param["enableAskSage"] = "enableAskSage";
        Param["CollapseSearchBarInitially"] = "collapseSearchBarInitially";
        Param["DataPanelCustomGroupsAccordionInitialState"] = "dataPanelCustomGroupsAccordionInitialState";
        Param["EnableCustomColumnGroups"] = "enableCustomColumnGroups";
        Param["DateFormatLocale"] = "dateFormatLocale";
        Param["NumberFormatLocale"] = "numberFormatLocale";
        Param["CurrencyFormat"] = "currencyFormat";
        Param["Enable2ColumnLayout"] = "enable2ColumnLayout";
        Param["IsFullAppEmbed"] = "isFullAppEmbed";
        Param["IsOnBeforeGetVizDataInterceptEnabled"] = "isOnBeforeGetVizDataInterceptEnabled";
        Param["FocusSearchBarOnRender"] = "focusSearchBarOnRender";
        Param["DisableRedirectionLinksInNewTab"] = "disableRedirectionLinksInNewTab";
        Param["HomePageSearchBarMode"] = "homePageSearchBarMode";
        Param["ShowLiveboardVerifiedBadge"] = "showLiveboardVerifiedBadge";
        Param["ShowLiveboardReverifyBanner"] = "showLiveboardReverifyBanner";
        Param["LiveboardHeaderV2"] = "isLiveboardHeaderV2Enabled";
        Param["HideIrrelevantFiltersInTab"] = "hideIrrelevantFiltersAtTabLevel";
        Param["SpotterEnabled"] = "isSpotterExperienceEnabled";
        Param["IsUnifiedSearchExperienceEnabled"] = "isUnifiedSearchExperienceEnabled";
        Param["OverrideOrgId"] = "orgId";
        Param["OauthPollingInterval"] = "oAuthPollingInterval";
        Param["IsForceRedirect"] = "isForceRedirect";
        Param["DataSourceId"] = "dataSourceId";
        Param["preAuthCache"] = "preAuthCache";
        Param["ShowSpotterLimitations"] = "showSpotterLimitations";
        Param["CoverAndFilterOptionInPDF"] = "coverAndFilterOptionInPDF";
        Param["PrimaryAction"] = "primaryAction";
        Param["isSpotterAgentEmbed"] = "isSpotterAgentEmbed";
    })(Param || (Param = {}));
    /**
     * ThoughtSpot application pages include actions and menu commands
     * for various user-initiated operations. These actions are represented
     * as enumeration members in the SDK. To show, hide, or disable
     * specific actions in the embedded view, define the Action
     * enumeration members in the `disabledActions`, `visibleActions`,
     * or `hiddenActions` array.
     * @example
     * ```js
     * const embed = new LiveboardEmbed('#embed-container', {
     *    ... // other options
     *    visibleActions: [Action.Save, Action.Edit, Action.Present, ActionAction.Explore],
     *    disabledActions: [Action.Download],
     *    //hiddenActions: [], // Set either this or visibleActions
     * })
     * ```
     * @example
     * ```js
     * const embed = new LiveboardEmbed('#embed-container', {
     *    ... // other options
     *    //visibleActions: [],
     *    disabledActions: [Action.Download],
     *    hiddenActions: [Action.Edit, ActionAction.Explore],
     * })
     * ```
     */
    // eslint-disable-next-line no-shadow
    exports.Action = void 0;
    (function (Action) {
        /**
         * The **Save** action on an Answer or Liveboard.
         * Allows users to save the changes.
         * @example
         * ```js
         * disabledActions: [Action.Save]
         * ```
         */
        Action["Save"] = "save";
        /**
         * @hidden
         */
        Action["Update"] = "update";
        /**
         * @hidden
         */
        Action["SaveUntitled"] = "saveUntitled";
        /**
         * The **Save as View** action on the Answer
         * page. Saves an Answer as a View object in the full
         * application embedding mode.
         * @example
         * ```js
         * disabledActions: [Action.SaveAsView]
         * ```
         */
        Action["SaveAsView"] = "saveAsView";
        /**
         * The **Make a copy** action on a Liveboard or Answer
         * page. Creates a copy of the Liveboard.
         * In LiveboardEmbed, the **Make a copy** action is not available for
         * visualizations in the embedded Liveboard view.
         * In AppEmbed, the **Make a copy** action is available on both
         * Liveboards and visualizations.
         * @example
         * ```js
         * disabledActions: [Action.MakeACopy]
         * ```
         */
        Action["MakeACopy"] = "makeACopy";
        /**
         * The **Copy and Edit** action on a Liveboard.
         * This action is now replaced with `Action.MakeACopy`.
         * @example
         * ```js
         * disabledActions: [Action.EditACopy]
         * ```
         */
        Action["EditACopy"] = "editACopy";
        /**
         * The **Copy link** menu action on a Liveboard visualization.
         * Copies the visualization URL
         * @example
         * ```js
         * disabledActions: [Action.CopyLink]
         * ```
         */
        Action["CopyLink"] = "embedDocument";
        /**
         * @hidden
         */
        Action["ResetLayout"] = "resetLayout";
        /**
         * The **Schedule** menu action on a Liveboard.
         * Allows scheduling a Liveboard job, for example,
         * sending periodic notifications.
         * @example
         * ```js
         * disabledActions: [Action.Schedule]
         * ```
         */
        Action["Schedule"] = "subscription";
        /**
         * The **Manage schedules** menu action on a Liveboard.
         * Allows users to manage scheduled Liveboard jobs.
         * @example
         * ```js
         * disabledActions: [Action.SchedulesList]
         * ```
         */
        Action["SchedulesList"] = "schedule-list";
        /**
         * The **Share** action on a Liveboard, Answer, or Worksheet.
         * Allows users to share an object with other users and groups.
         * @example
         * ```js
         * disabledActions: [Action.Share]
         * ```
         */
        Action["Share"] = "share";
        /**
         * The **Add filter** action on a Liveboard page.
         * Allows adding filters to visualizations on a Liveboard.
         * @example
         * ```js
         * disabledActions: [Action.AddFilter]
         * ```
         */
        Action["AddFilter"] = "addFilter";
        /**
         * The **Add Data Panel Objects** action on the data panel v2.
         * Allows to show action menu to add different objects (such as
         * formulas, Parameters) in data panel new experience.
         * @example
         * ```js
         * disabledActions: [Action.AddDataPanelObjects]
         * ```
         * @version SDK: 1.32.0 | ThoughtSpot: 10.0.0.cl, 10.1.0.sw
         */
        Action["AddDataPanelObjects"] = "addDataPanelObjects";
        /**
         * The filter configuration options for a Liveboard.
         * The configuration options are available when adding
         * filters on a Liveboard.
         *
         * @example
         * ```js
         * disabledActions: [Action.ConfigureFilter]
         * ```
         */
        Action["ConfigureFilter"] = "configureFilter";
        /**
        * The **Collapse data sources** icon on the Search page.
        * Collapses the panel showing data sources.
        *
        * @example
        * ```js
        * disabledActions: [Action.CollapseDataPanel]
        * ```
        * @version: SDK: 1.1.0 | ThoughtSpot Cloud: ts7.may.cl, 8.4.1.sw
        */
        Action["CollapseDataSources"] = "collapseDataSources";
        /**
        * The **Collapse data panel** icon on the Search page.
        * Collapses the data panel view.
        *
        * @version: SDK: 1.34.0 | ThoughtSpot Cloud: 10.3.0.cl
        *
        * @example
        * ```js
        * disabledActions: [Action.CollapseDataPanel]
        * ```
        */
        Action["CollapseDataPanel"] = "collapseDataPanel";
        /**
         * The **Choose sources** button on Search page.
         * Allows selecting data sources for search queries.
         * @example
         * ```js
         * disabledActions: [Action.ChooseDataSources]
         * ```
         */
        Action["ChooseDataSources"] = "chooseDataSources";
        /**
         * The **Create formula** action on a Search or Answer page.
         * Allows adding formulas to an Answer.
         * @example
         * ```js
         * disabledActions: [Action.AddFormula]
         * ```
         */
        Action["AddFormula"] = "addFormula";
        /**
         * The **Add parameter** action on a Liveboard or Answer.
         * Allows adding Parameters to a Liveboard or Answer.
         * @example
         * ```js
         * disabledActions: [Action.AddParameter]
         * ```
         */
        Action["AddParameter"] = "addParameter";
        /**
         * The **Add Column Set** action on a Answer.
         * Allows adding column sets to a Answer.
         * @example
         * ```js
         * disabledActions: [Action.AddColumnSet]
         * ```
         * @version SDK: 1.32.0 | ThoughtSpot: 10.0.0.cl, 10.1.0.sw
         */
        Action["AddColumnSet"] = "addSimpleCohort";
        /**
         * The **Add Query Set** action on a Answer.
         * Allows adding query sets to a Answer.
         * @example
         * ```js
         * disabledActions: [Action.AddQuerySet]
         * ```
         * @version SDK: 1.32.0 | ThoughtSpot: 10.0.0.cl, 10.1.0.sw
         */
        Action["AddQuerySet"] = "addAdvancedCohort";
        /**
         * @hidden
         */
        Action["SearchOnTop"] = "searchOnTop";
        /**
         * The **SpotIQ analyze** menu action on a visualization or
         * Answer page.
         * @example
         * ```js
         * disabledActions: [Action.SpotIQAnalyze]
         * ```
         */
        Action["SpotIQAnalyze"] = "spotIQAnalyze";
        /**
         * @hidden
         */
        Action["ExplainInsight"] = "explainInsight";
        /**
         * @hidden
         */
        Action["SpotIQFollow"] = "spotIQFollow";
        /**
         * The Share action for a Liveboard visualization.
         */
        Action["ShareViz"] = "shareViz";
        /**
         * @hidden
         */
        Action["ReplaySearch"] = "replaySearch";
        /**
         * The **Show underlying data** menu action on a
         * visualization or Answer page.
         * Displays detailed information and raw data
         * for a given visualization.
         * @example
         * ```js
         * disabledActions: [Action.ShowUnderlyingData]
         * ```
         */
        Action["ShowUnderlyingData"] = "showUnderlyingData";
        /**
         * The **Download** menu action on Liveboard
         * visualizations and Answers.
         * Allows downloading a visualization or Answer.
         * @example
         * ```js
         * disabledActions: [Action.DownloadAsPng]
         * ```
         */
        Action["Download"] = "download";
        /**
         * The **Download** > **PNG** menu action for charts on a Liveboard
         * or Answer page.
         * Downloads a visualization or Answer as a PNG file.
         * @example
         * ```js
         * disabledActions: [Action.DownloadAsPng]
         * ```
         */
        Action["DownloadAsPng"] = "downloadAsPng";
        /**
         *
         *The **Download PDF** action that downloads a Liveboard,
         * visualization, or Answer as a PDF file.
         *
         * **NOTE**: The **Download** > **PDF** option is available for
         * tables in visualizations and Answers.
         * @example
         * ```js
         * disabledActions: [Action.DownloadAsPdf]
         * ```
         */
        Action["DownloadAsPdf"] = "downloadAsPdf";
        /**
         * The **Download** > **CSV** menu action for tables on a Liveboard
         * or Answer page.
         * Downloads a visualization or Answer in the XLSX format.
         * @example
         * ```js
         * disabledActions: [Action.DownloadAsCsv]
         * ```
         */
        Action["DownloadAsCsv"] = "downloadAsCSV";
        /**
         * The **Download** > **XLSX** menu action for tables on a Liveboard
         * or Answer page.
         * Downloads a visualization or Answer in the XLSX format.
         * @example
         * ```js
         * disabledActions: [Action.DownloadAsXlsx]
         * ```
         */
        Action["DownloadAsXlsx"] = "downloadAsXLSX";
        /**
         * @hidden
         */
        Action["DownloadTrace"] = "downloadTrace";
        /**
         * The **Export TML** menu action on a Liveboard, Answer, and
         * the Data Workspace pages for data objects and connections.
         *
         * Allows exporting an object as a TML file.
         *
         * @example
         * ```js
         * disabledActions: [Action.ExportTML]
         * ```
         */
        Action["ExportTML"] = "exportTSL";
        /**
         * The **Import TML** menu action on the
         * *Data Workspace* > *Utilities* page.
         * Imports TML representation of ThoughtSpot objects.
         * @example
         * ```js
         * disabledActions: [Action.ImportTML]
         * ```
         */
        Action["ImportTML"] = "importTSL";
        /**
         * The **Update TML** menu action for Liveboards and Answers.
         * Updates TML representation of ThoughtSpot objects.
         * @example
         * ```js
         * disabledActions: [Action.UpdateTML]
         * ```
         */
        Action["UpdateTML"] = "updateTSL";
        /**
         * The **Edit TML** menu action for Liveboards and Answers.
         * Opens the TML editor.
         * @example
         * ```js
         * disabledActions: [Action.EditTML]
         * ```
         */
        Action["EditTML"] = "editTSL";
        /**
         * The **Present** menu action for Liveboards and Answers.
         * Allows presenting a Liveboard or visualization in
         * slideshow mode.
         * @example
         * ```js
         * disabledActions: [Action.Present]
         * ```
         */
        Action["Present"] = "present";
        /**
         * The visualization tile resize option.
         * Also available via More `...` options menu on a visualization.
         * Allows resizing visualization tiles and switching
         * between different preset layout option.
         *
         * @example
         * ```js
         * disabledActions: [Action.ToggleSize]
         * ```
         */
        Action["ToggleSize"] = "toggleSize";
        /**
         * The *Edit* action on the Liveboard page and in the
         * visualization menu.
         * Opens a Liveboard or visualization in edit mode.
         * @example
         * ```js
         * disabledActions: [Action.Edit]
         * ```
         */
        Action["Edit"] = "edit";
        /**
         * The text edit option for Liveboard and visualization titles.
         * @example
         * ```js
         * disabledActions: [Action.EditTitle]
         * ```
         */
        Action["EditTitle"] = "editTitle";
        /**
         * The **Delete** action on a Liveboard, *Liveboards* and
         * *Answers* list pages in full application embedding.
         *
         * @example
         * ```js
         * disabledActions: [Action.Remove]
         * ```
         */
        Action["Remove"] = "delete";
        /**
         * @hidden
         */
        Action["Ungroup"] = "ungroup";
        /**
         * @hidden
         */
        Action["Describe"] = "describe";
        /**
         * @hidden
         */
        Action["Relate"] = "relate";
        /**
         * @hidden
         */
        Action["CustomizeHeadlines"] = "customizeHeadlines";
        /**
         * @hidden
         */
        Action["PinboardInfo"] = "pinboardInfo";
        /**
         * The **Show Liveboard details** menu action on a Liveboard.
         * Displays details such as the name, description, and
         * author of the Liveboard, and timestamp of Liveboard creation
         * and update.
         * @example
         * ```js
         * disabledActions: [Action.LiveboardInfo]
         * ```
         */
        Action["LiveboardInfo"] = "pinboardInfo";
        /**
         * @hidden
         */
        Action["SendAnswerFeedback"] = "sendFeedback";
        /**
         * @hidden
         */
        Action["DownloadEmbraceQueries"] = "downloadEmbraceQueries";
        /**
         * The **Pin** menu action on an Answer or
         * Search results page.
         * @example
         * ```js
         * disabledActions: [Action.Pin]
         * ```
         */
        Action["Pin"] = "pin";
        /**
         * @hidden
         */
        Action["AnalysisInfo"] = "analysisInfo";
        /**
         * The **Schedule** menu action on a Liveboard.
         * Allows scheduling a Liveboard job.
         * @example
         * ```js
         * disabledActions: [Action.Subscription]
         * ```
         */
        Action["Subscription"] = "subscription";
        /**
         * The **Explore** action on Liveboard visualizations
         * @example
         * ```js
         * disabledActions: [Action.Explore]
         * ```
         */
        Action["Explore"] = "explore";
        /**
         * The contextual menu action to include a specific data point
         * when drilling down a table or chart on an Answer.
         *
         * @example
         * ```js
         * disabledActions: [Action.DrillInclude]
         * ```
         */
        Action["DrillInclude"] = "context-menu-item-include";
        /**
         * The contextual menu action to exclude a specific data point
         * when drilling down a table or chart on an Answer.
         * @example
         * ```js
         * disabledActions: [Action.DrillInclude]
         * ```
         */
        Action["DrillExclude"] = "context-menu-item-exclude";
        /**
         * The **Copy to clipboard** menu action on tables in an Answer
         * or Liveboard.
         * Copies the selected data point.
         * @example
         * ```js
         * disabledActions: [Action.CopyToClipboard]
         * ```
         */
        Action["CopyToClipboard"] = "context-menu-item-copy-to-clipboard";
        Action["CopyAndEdit"] = "context-menu-item-copy-and-edit";
        /**
         * @hidden
         */
        Action["DrillEdit"] = "context-menu-item-edit";
        Action["EditMeasure"] = "context-menu-item-edit-measure";
        Action["Separator"] = "context-menu-item-separator";
        /**
         * The **Drill down** menu action on Answers and Liveboard
         * visualizations.
         * Allows drilling down to a specific data point on a chart or table.
         * @example
         * ```js
         * disabledActions: [Action.DrillDown]
         * ```
         */
        Action["DrillDown"] = "DRILL";
        /**
         * The request access action on Liveboards.
         * Allows users with view permissions to request edit access to a Liveboard.
         * @example
         * ```js
         * disabledActions: [Action.RequestAccess]
         * ```
         */
        Action["RequestAccess"] = "requestAccess";
        /**
         * The **Query visualizer** and **Query SQL** buttons in
         * Query details panel of the Answer page.
         *
         * **Query visualizer** - Displays the tables
         * and filters used in a search query.
         * **Query SQL** - Displays the SQL statements used
         * in a search query to fetch data.
         * @example
         * ```js
         * disabledActions: [Action.QueryDetailsButtons]
         * ```
         */
        Action["QueryDetailsButtons"] = "queryDetailsButtons";
        /**
         * The **Delete** action for Answers in the full application
         * embedding mode.
         * @example
         * ```js
         * disabledActions: [Action.AnswerDelete]
         * ```
         * @version SDK: 1.9.0 | ThoughtSpot: 8.1.0.cl, 8.4.1.sw
         */
        Action["AnswerDelete"] = "onDeleteAnswer";
        /**
         * The chart switcher icon on Answer page and
         * visualizations in edit mode.
         * Allows switching to the table or chart mode
         * when editing a visualization.
         * @example
         * ```js
         * disabledActions: [Action.AnswerChartSwitcher]
         * ```
         * @version SDK: 1.9.0 | ThoughtSpot: 8.1.0.cl, 8.4.1.sw
         */
        Action["AnswerChartSwitcher"] = "answerChartSwitcher";
        /**
         * The Favorites icon (*) for Answers,
         * Liveboard, and data objects like Worksheet, Model,
         * Tables and Views.
         * Allows adding an object to the user’s favorites list.
         * @example
         * ```js
         * disabledActions: [Action.AddToFavorites]
         * ```
         * @version SDK: 1.9.0 | ThoughtSpot: 8.1.0.cl, 8.4.1.sw
         */
        Action["AddToFavorites"] = "addToFavorites";
        /**
         * The edit icon on Liveboards (Classic experience).
         * @example
         * ```js
         * disabledActions: [Action.EditDetails]
         * ```
         * @version SDK: 1.9.0 | ThoughtSpot: 8.1.0.cl, 8.4.1.sw
         */
        Action["EditDetails"] = "editDetails";
        /**
         * The *Create alert* action for KPI charts.
         * Allows users to schedule threshold-based alerts
         * for KPI charts.
         * @example
         * ```js
         * disabledActions: [Action.CreateMonitor]
         * ```
         * @version SDK: 1.11.0 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         */
        Action["CreateMonitor"] = "createMonitor";
        /**
         * @deprecated
         * Reports errors
         * @example
         * ```js
         * disabledActions: [Action.ReportError]
         * ```
         * @version SDK: 1.11.1 | ThoughtSpot: 8.3.0.cl, 8.4.1.sw
         */
        Action["ReportError"] = "reportError";
        /**
         * The **Sync to sheets** action on Answers and Liveboard visualizations.
         * Allows sending data to a Google Sheet.
         * @example
         * ```js
         * disabledActions: [Action.SyncToSheets]
         * ```
         * @version SDK: 1.18.0| ThoughtSpot: 8.10.0.cl, 9.0.1.sw
         */
        Action["SyncToSheets"] = "sync-to-sheets";
        /**
         * The **Sync to other apps** action on Answers and Liveboard visualizations.
         * Allows sending data to third-party apps like Slack, Salesforce,
         * Microsoft Teams, and so on.
         * @example
         * ```js
         * disabledActions: [Action.SyncToOtherApps]
         * ```
         * @version SDK: 1.18.0| ThoughtSpot: 8.10.0.cl, 9.0.1.sw
         */
        Action["SyncToOtherApps"] = "sync-to-other-apps";
        /**
         * The **Manage pipelines** action on Answers and Liveboard visualizations.
         * Allows users to manage data sync pipelines to third-party apps.
         * @example
         * ```js
         * disabledActions: [Action.ManagePipelines]
         * ```
         * @version SDK: 1.18.0| ThoughtSpot: 8.10.0.cl, 9.0.1.sw
         */
        Action["ManagePipelines"] = "manage-pipeline";
        /**
         * The **Filter** action on Liveboard visualizations.
         * Allows users to apply cross-filters on a Liveboard.
         * @example
         * ```js
         * disabledActions: [Action.CrossFilter]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.8.0.sw
         */
        Action["CrossFilter"] = "context-menu-item-cross-filter";
        /**
         * The **Sync to Slack** action on Liveboard visualizations.
         * Allows sending data to third-party apps Slack
         * @example
         * ```js
         * disabledActions: [Action.SyncToSlack]
         * ```
         * @version @version SDK : 1.32.0 | ThoughtSpot Cloud: 10.1.0.cl
         */
        Action["SyncToSlack"] = "syncToSlack";
        /**
         * The **Sync to Teams** action on Liveboard visualizations.
         * Allows sending data to third-party apps Team
         * @example
         * ```js
         * disabledActions: [Action.SyncToTeams]
         * ```
         * @version @version SDK : 1.32.0 | ThoughtSpot Cloud: 10.1.0.cl
         */
        Action["SyncToTeams"] = "syncToTeams";
        /**
         * The **Remove** action that appears when cross filters are applied
         * on a Liveboard.
         * Removes filters applied o a visualization.
         * @example
         * ```js
         * disabledActions: [Action.RemoveCrossFilter]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["RemoveCrossFilter"] = "context-menu-item-remove-cross-filter";
        /**
         * The **Aggregate** option in the chart axis or the
         * table column customization menu.
         * Provides aggregation options to analyze the data on a chart or table.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuAggregate]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuAggregate"] = "axisMenuAggregate";
        /**
         * The **Time bucket** option in the chart axis or table column
         * customization menu.
         * Allows defining time metric for date comparison.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuTimeBucket]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuTimeBucket"] = "axisMenuTimeBucket";
        /**
         * The **Filter** action in the chart axis or table column
         * customization menu.
         * Allows adding, editing, or removing filters.
         *
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuFilter]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuFilter"] = "axisMenuFilter";
        /**
         * The **Conditional formatting** action on chart or table.
         * Allows adding rules for conditional formatting of data
         * points on a chart or table.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuConditionalFormat]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuConditionalFormat"] = "axisMenuConditionalFormat";
        /**
         * The **Sort** menu action on a table or chart axis
         * Sorts data in ascending or descending order.
         * Allows adding, editing, or removing filters.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuConditionalFormat]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuSort"] = "axisMenuSort";
        /**
         * The **Group** option in the chart axis or table column
         * customization menu.
         * Allows grouping data points if the axes use the same
         * unit of measurement and a similar scale.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuGroup]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuGroup"] = "axisMenuGroup";
        /**
         * The **Position** option in the axis customization menu.
         * Allows changing the position of the axis to the
         * left or right side of the chart.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuPosition]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuPosition"] = "axisMenuPosition";
        /**
         * The **Rename** option in the chart axis or table column customization menu.
         * Renames the axis label on a chart or the column header on a table.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuRename]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuRename"] = "axisMenuRename";
        /**
         * The **Edit** action in the axis customization menu.
         * Allows editing the axis name, position, minimum and maximum values,
         * and format of a column.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuEdit]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuEdit"] = "axisMenuEdit";
        /**
         * The **Number format** action to customize the format of
         * the data labels on a chart or table.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuNumberFormat]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuNumberFormat"] = "axisMenuNumberFormat";
        /**
         * The **Text wrapping** action on a table.
         * Wraps or clips column text on a table.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuTextWrapping]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuTextWrapping"] = "axisMenuTextWrapping";
        /**
         * The **Remove** action in the chart axis or table column
         * customization menu.
         * Removes the data labels from a chart or the column of a
         * table visualization.
         * @example
         * ```js
         * disabledActions: [Action.AxisMenuRemove]
         * ```
         * @version SDK: 1.21.0 | ThoughtSpot: 9.2.0.cl, 9.5.1.sw
         */
        Action["AxisMenuRemove"] = "axisMenuRemove";
        /**
         * @hidden
         */
        Action["InsertInToSlide"] = "insertInToSlide";
        /**
         * The **Rename** menu action on Liveboards and visualizations.
         * Allows renaming a Liveboard or visualization.
         * @example
         * ```js
         * disabledActions: [Action.RenameModalTitleDescription]
         * ```
         * @version SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl, 9.8.0.sw
         */
        Action["RenameModalTitleDescription"] = "renameModalTitleDescription";
        /**
         * The *Request verification* action on a Liveboard.
         * Initiates a request for Liveboard verification.
         * @example
         * ```js
         * disabledActions: [Action.RequestVerification]
         * ```
         * @version SDK: 1.25.0 | ThoughtSpot: 9.6.0.cl, 10.1.0.sw
         */
        Action["RequestVerification"] = "requestVerification";
        /**
         *
         * Allows users to mark a Liveboard as verified.
         * @example
         * ```js
         * disabledActions: [Action.MarkAsVerified]
         * ```
         * @version SDK: 1.25.0 | ThoughtSpot: 9.6.0.cl, 10.1.0.sw
         */
        Action["MarkAsVerified"] = "markAsVerified";
        /**
         * The **Add Tab** action on a Liveboard.
         * Allows adding a new tab to a Liveboard view.
         * @example
         * ```js
         * disabledActions: [Action.AddTab]
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.7.0.cl, 9.8.0.sw
         */
        Action["AddTab"] = "addTab";
        /**
         *
         *Initiates contextual change analysis on KPI charts.
         * @example
         * ```js
         * disabledActions: [Action.EnableContextualChangeAnalysis]
         * ```
         * @version SDK: 1.25.0 | ThoughtSpot Cloud: 9.6.0.cl
         */
        Action["EnableContextualChangeAnalysis"] = "enableContextualChangeAnalysis";
        /**
         * Action ID to hide or disable Natural Language Search query.
         *
         * @example
         * ```js
         * disabledActions: [Action.ShowSageQuery]
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot Cloud: 9.7.0.cl
         */
        Action["ShowSageQuery"] = "showSageQuery";
        /**
         *
         * Action ID to hide or disable the edit option for the
         * results generated from the
         * Natural Language Search query.
         *
         * @example
         * ```js
         * disabledActions: [Action.EditSageAnswer]
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot Cloud: 9.7.0.cl
         */
        Action["EditSageAnswer"] = "editSageAnswer";
        /**
         * The feedback widget for AI-generated Answers.
         * Allows users to send feedback on the Answers generated
         * from a Natural Language Search query.
         *
         * @example
         * ```js
         * disabledActions: [Action.SageAnswerFeedback]
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.7.0.cl
         */
        Action["SageAnswerFeedback"] = "sageAnswerFeedback";
        /**
         *
         * @example
         * ```js
         * disabledActions: [Action.ModifySageAnswer]
         * ```
         * @version SDK: 1.26.0 | ThoughtSpot: 9.7.0.cl
         */
        Action["ModifySageAnswer"] = "modifySageAnswer";
        /**
         * The **Move to Tab** menu action on visualizations in Liveboard edit mode.
         * Allows moving a visualization to a different tab.
         * @example
         * ```js
         * disabledActions: [Action.MoveToTab]
         * ```
         */
        Action["MoveToTab"] = "onContainerMove";
        /**
         * The **Manage Alerts** menu action on KPI visualizations.
         * Allows creating, viewing, and editing monitor
         * alerts for a KPI chart.
         *
         * @example
         * ```js
         * disabledActions: [Action.ManageMonitor]
         * ```
         */
        Action["ManageMonitor"] = "manageMonitor";
        /**
         * The Liveboard Personalised Views dropdown.
         * Allows navigating to a personalized Liveboard View.
         *  @example
         * ```js
         * disabledActions: [Action.PersonalisedViewsDropdown]
         * ```
         *  @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 10.1.0.sw
         */
        Action["PersonalisedViewsDropdown"] = "personalisedViewsDropdown";
        /**
         * Action ID for show or hide the user details on a
         * Liveboard (Recently visited / social proof)
         *  @example
         * ```js
         * disabledActions: [Action.LiveboardUsers]
         * ```
         *  @version SDK : 1.26.0 | ThoughtSpot: 9.7.0.cl, 10.1.0.sw
         */
        Action["LiveboardUsers"] = "liveboardUsers";
        /**
         * Action ID for the Parent TML action
         * The parent action **TML** must be included to access TML-related options
         * within the cascading menu (specific to the Answer page)
         * @example
         * ```js
         * // to include specific TML actions
         * visibleActions: [Action.TML, Action.ExportTML, Action.EditTML]
         *
         * ```
         * @example
         * ```js
         * hiddenAction: [Action.TML] // hide all TML actions
         * disabledActions: [Action.TML] // to disable all TML actions
         * ```
         * @version SDK : 1.28.3 | ThoughtSpot: 9.12.0.cl, 10.1.0.sw
         */
        Action["TML"] = "tml";
        /**
         * The **Create Liveboard* action on
         * the Liveboards page and the Pin modal.
         * Allows users to create a Liveboard.
         *
         * @example
         * ```js
         * hiddenAction: [Action.CreateLiveboard]
         * disabledActions: [Action.CreateLiveboard]
         * ```
         * @version SDK: 1.32.0 | ThoughtSpot: 10.1.0.cl, 10.1.0.sw
         */
        Action["CreateLiveboard"] = "createLiveboard";
        /**
         * Action ID for to hide or disable the
         * Verified Liveboard banner.
         *  @example
         * ```js
         * hiddenAction: [Action.VerifiedLiveboard]
         * ```
         *  @version SDK: 1.29.0 | ThoughtSpot: 9.10.0.cl, 10.1.0.sw
         */
        Action["VerifiedLiveboard"] = "verifiedLiveboard";
        /**
         * Action ID for the *Ask Sage* In Natural Language Search embed,
         * *Spotter* in Liveboard, full app, and Spotter embed.
         *
         * Allows initiating a conversation with ThoughtSpot AI analyst.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.AskAi]
         * ```
         *  @version SDK: 1.29.0 | ThoughtSpot Cloud: 9.12.0.cl
         */
        Action["AskAi"] = "AskAi";
        /**
         * The **Add KPI to Watchlist** action on Home page watchlist.
         * Adds a KPI chart to the watchlist on the Home page.
         * @example
         * ```js
         * disabledActions: [Action.AddToWatchlist]
         * ```
         * @version SDK : 1.27.9 | ThoughtSpot Cloud: 9.12.5.cl
         */
        Action["AddToWatchlist"] = "addToWatchlist";
        /**
         * The **Remove from watchlist** menu action on KPI watchlist.
         * Removes a KPI chart from the watchlist on the Home page.
         * @example
         * ```js
         * disabledActions: [Action.RemoveFromWatchlist]
         * ```
         * @version SDK : 1.27.9 | ThoughtSpot: 9.12.5.cl
         */
        Action["RemoveFromWatchlist"] = "removeFromWatchlist";
        /**
         * The **Organize Favourites** action on Homepage
         * *Favorites* module.
         *
         * @example
         * ```js
         * disabledActions: [Action.OrganiseFavourites]
         * ```
         * @version SDK : 1.32.0 | ThoughtSpot: 10.0.0.cl
         */
        Action["OrganiseFavourites"] = "organiseFavourites";
        /**
         * The **AI Highlights** action on a Liveboard.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.AIHighlights]
         * ```
         *  @version SDK: 1.27.10 | ThoughtSpot Cloud: 9.12.5.cl
         */
        Action["AIHighlights"] = "AIHighlights";
        /**
         * The *Edit* action on the *Liveboard Schedules* page
         * (new Homepage experience).
         * Allows editing Liveboard schedules.
         *
         * @example
         * ```js
         * disabledActions: [Action.EditScheduleHomepage]
         * ```
         *  @version SDK: 1.34.0 | ThoughtSpot Cloud: 10.3.0.cl
         */
        Action["EditScheduleHomepage"] = "editScheduleHomepage";
        /**
         * The *Pause* action on the *Liveboard Schedules* page
         * Pauses a scheduled Liveboard job.
         * @example
         * ```js
         * disabledActions: [Action.PauseScheduleHomepage]
         * ```
         *  @version SDK: 1.34.0 | ThoughtSpot Cloud: 10.3.0.cl
         */
        Action["PauseScheduleHomepage"] = "pauseScheduleHomepage";
        /**
         * The **View run history** action **Liveboard Schedules** page.
         * Allows viewing schedule run history.
         * @example
         * ```js
         * disabledActions: [Action.ViewScheduleRunHomepage]
         * ```
         *  @version SDK: 1.34.0 | ThoughtSpot: 10.3.0.cl
         */
        Action["ViewScheduleRunHomepage"] = "viewScheduleRunHomepage";
        /**
         * Action ID to hide or disable the
         * unsubscribe option for Liveboard schedules.
         * @example
         * ```js
         * disabledActions: [Action.UnsubscribeScheduleHomepage]
         * ```
         *  @version SDK: 1.34.0 | ThoughtSpot: 10.3.0.cl
         */
        Action["UnsubscribeScheduleHomepage"] = "unsubscribeScheduleHomepage";
        /**
         * The **Manage Tags** action on Homepage Favourite Module.
         * @example
         * ```js
         * disabledActions: [Action.ManageTags]
         * ```
         * @version SDK : 1.34.0 | ThoughtSpot Cloud: 10.3.0.cl
         */
        Action["ManageTags"] = "manageTags";
        /**
         * The **Delete** action on the **Liveboard Schedules* page.
         * Deletes a Liveboard schedule.
         * @example
         * ```js
         * disabledActions: [Action.DeleteScheduleHomepage]
         * ```
         *  @version SDK: 1.34.0 | ThoughtSpot: 10.3.0.cl
         */
        Action["DeleteScheduleHomepage"] = "deleteScheduleHomepage";
        /**
         * The **Analyze CTA** action on KPI chart.
         * @example
         * ```js
         * disabledActions: [Action.KPIAnalysisCTA]
         * ```
         *  @version SDK: 1.34.0 | ThoughtSpot Cloud: 10.3.0.cl
         */
        Action["KPIAnalysisCTA"] = "kpiAnalysisCTA";
        /**
         * Action ID for disabling chip reorder in Answer and Liveboard
         * @example
         * ```js
         * const disabledActions = [Action.DisableChipReorder]
         * ```
         * @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["DisableChipReorder"] = "disableChipReorder";
        /**
         * Action ID to show, hide, or disable filters
         * in a Liveboard tab.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.ChangeFilterVisibilityInTab]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["ChangeFilterVisibilityInTab"] = "changeFilterVisibilityInTab";
        /**
         * The **Preview data** button on the Spotter interface.
         * Allows previewing the data used for Spotter queries.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.PreviewDataSpotter]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["PreviewDataSpotter"] = "previewDataSpotter";
        /**
         * The **Reset** link on the Spotter interface.
         * Resets the conversation with Spotter.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.ResetSpotterChat]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["ResetSpotterChat"] = "resetSpotterChat";
        /**
         * Action ID for hide or disable the
         * Spotter feedback widget.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.SpotterFeedback]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["SpotterFeedback"] = "spotterFeedback";
        /**
         * Action ID for hide or disable
         * the previous prompt edit option in Spotter.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.EditPreviousPrompt]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["EditPreviousPrompt"] = "editPreviousPrompt";
        /**
         * Action ID for hide or disable
         * the previous prompt deletion option in Spotter.
         *
         *  @example
         * ```js
         * hiddenAction: [Action.DeletePreviousPrompt]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["DeletePreviousPrompt"] = "deletePreviousPrompt";
        /**
         * Action ID for hide or disable editing tokens generated from
         * Spotter results.
         *  @example
         * ```js
         * hiddenAction: [Action.EditTokens]
         * ```
         *  @version SDK: 1.36.0 | ThoughtSpot Cloud: 10.6.0.cl
         */
        Action["EditTokens"] = "editTokens";
        /**
         * Action ID for hiding rename option for Column rename
         *  @example
         * ```js
         * hiddenAction: [Action.ColumnRename]
         * ```
         *  @version SDK: 1.37.0 | ThoughtSpot Cloud: 10.8.0.cl
         */
        Action["ColumnRename"] = "columnRename";
        /**
         * Action ID for hide checkboxes for include or exclude
         * cover and filter pages in the Liveboard PDF
         *  @example
         * ```js
         * hiddenAction: [Action.CoverAndFilterOptionInPDF]
         * ```
         *  @version SDK: 1.37.0 | ThoughtSpot Cloud: 10.8.0.cl
         */
        Action["CoverAndFilterOptionInPDF"] = "coverAndFilterOptionInPDF";
    })(exports.Action || (exports.Action = {}));
    exports.PrefetchFeatures = void 0;
    (function (PrefetchFeatures) {
        PrefetchFeatures["FullApp"] = "FullApp";
        PrefetchFeatures["SearchEmbed"] = "SearchEmbed";
        PrefetchFeatures["LiveboardEmbed"] = "LiveboardEmbed";
        PrefetchFeatures["VizEmbed"] = "VizEmbed";
    })(exports.PrefetchFeatures || (exports.PrefetchFeatures = {}));
    /**
     * Enum for options to change context trigger.
     * The `BOTH_CLICKS` option is available from 10.8.0.cl.
     */
    exports.ContextMenuTriggerOptions = void 0;
    (function (ContextMenuTriggerOptions) {
        ContextMenuTriggerOptions["LEFT_CLICK"] = "left-click";
        ContextMenuTriggerOptions["RIGHT_CLICK"] = "right-click";
        ContextMenuTriggerOptions["BOTH_CLICKS"] = "both-clicks";
    })(exports.ContextMenuTriggerOptions || (exports.ContextMenuTriggerOptions = {}));
    /**
     * Enum options to show or suppress Visual Embed SDK and
     * ThoughtSpot application logs in the console output.
     * This attribute doesn't support suppressing
     * browser warnings or errors.
     */
    exports.LogLevel = void 0;
    (function (LogLevel) {
        /**
         * No application or SDK-related logs will be logged
         * in the console output.
         * @example
         * ```js
         * init({
         *   ... // other options,
         *  logLevel: LogLevel.SILENT,
         * })
         * ```
         * @version SDK: 1.26.7 | ThoughtSpot Cloud: 9.10.0.cl
         */
        LogLevel["SILENT"] = "SILENT";
        /**
         * Log only errors in the console output.
         * @example
         * ```js
         * init({
         *   ... // other options,
         *  logLevel: LogLevel.ERROR,
         * })
         * ```
         * @version SDK: 1.26.7 | ThoughtSpot Cloud: 9.10.0.cl
         */
        LogLevel["ERROR"] = "ERROR";
        /**
         * Log only warnings and errors in the console output.
         * @example
         * ```js
         * init({
         *   ... // other options,
         *  logLevel: LogLevel.WARN,
         * })
         * ```
         * @version SDK: 1.26.7 | ThoughtSpot Cloud: 9.10.0.cl
         */
        LogLevel["WARN"] = "WARN";
        /**
         * Log only the information alerts, warnings, and errors
         * in the console output.
         * @example
         * ```js
         * init({
         *   ... // other options,
         *  logLevel: LogLevel.INFO,
         * })
         * ```
         * @version SDK: 1.26.7 | ThoughtSpot Cloud: 9.10.0.cl
         */
        LogLevel["INFO"] = "INFO";
        /**
         * Log debug messages, warnings, information alerts,
         * and errors in the console output.
         * @example
         * ```js
         * init({
         *   ... // other options,
         *  logLevel: LogLevel.DEBUG,
         * })
         * ```
         * @version SDK: 1.26.7 | ThoughtSpot Cloud: 9.10.0.cl
         */
        LogLevel["DEBUG"] = "DEBUG";
        /**
         * All logs will be logged in the browser console.
         * @example
         * ```js
         * init({
         *   ... // other options,
         *  logLevel: LogLevel.TRACE,
         * })
         * ```
         * @version SDK: 1.26.7 | ThoughtSpot Cloud: 9.10.0.cl
         */
        LogLevel["TRACE"] = "TRACE";
    })(exports.LogLevel || (exports.LogLevel = {}));

    const logFunctions = {
        [exports.LogLevel.SILENT]: () => undefined,
        [exports.LogLevel.ERROR]: console.error,
        [exports.LogLevel.WARN]: console.warn,
        [exports.LogLevel.INFO]: console.info,
        [exports.LogLevel.DEBUG]: console.debug,
        [exports.LogLevel.TRACE]: console.trace,
    };
    let globalLogLevelOverride = exports.LogLevel.TRACE;
    const setGlobalLogLevelOverride = (logLevel) => {
        globalLogLevelOverride = logLevel;
    };
    const logLevelToNumber = {
        [exports.LogLevel.SILENT]: 0,
        [exports.LogLevel.ERROR]: 1,
        [exports.LogLevel.WARN]: 2,
        [exports.LogLevel.INFO]: 3,
        [exports.LogLevel.DEBUG]: 4,
        [exports.LogLevel.TRACE]: 5,
    };
    const compareLogLevels = (logLevel1, logLevel2) => {
        const logLevel1Index = logLevelToNumber[logLevel1];
        const logLevel2Index = logLevelToNumber[logLevel2];
        return logLevel1Index - logLevel2Index;
    };
    class Logger {
        constructor() {
            this.logLevel = exports.LogLevel.ERROR;
            this.setLogLevel = (newLogLevel) => {
                this.logLevel = newLogLevel;
            };
            this.getLogLevel = () => this.logLevel;
        }
        canLog(logLevel) {
            if (logLevel === exports.LogLevel.SILENT)
                return false;
            if (!isUndefined$1(globalLogLevelOverride)) {
                return compareLogLevels(globalLogLevelOverride, logLevel) >= 0;
            }
            return compareLogLevels(this.logLevel, logLevel) >= 0;
        }
        logMessages(args, logLevel) {
            if (this.canLog(logLevel)) {
                const logFn = logFunctions[logLevel];
                if (logFn) {
                    logFn(...args);
                }
            }
        }
        log(...args) {
            this.info(args);
        }
        info(...args) {
            this.logMessages(args, exports.LogLevel.INFO);
        }
        debug(...args) {
            this.logMessages(args, exports.LogLevel.DEBUG);
        }
        trace(...args) {
            this.logMessages(args, exports.LogLevel.TRACE);
        }
        error(...args) {
            this.logMessages(args, exports.LogLevel.ERROR);
        }
        warn(...args) {
            this.logMessages(args, exports.LogLevel.WARN);
        }
    }
    const logger$3 = new Logger();

    /**
     * Removes all key-value entries from the list cache.
     *
     * @private
     * @name clear
     * @memberOf ListCache
     */
    function listCacheClear() {
      this.__data__ = [];
      this.size = 0;
    }

    var _listCacheClear = listCacheClear;

    /**
     * Performs a
     * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
     * comparison between two values to determine if they are equivalent.
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
     * @example
     *
     * var object = { 'a': 1 };
     * var other = { 'a': 1 };
     *
     * _.eq(object, object);
     * // => true
     *
     * _.eq(object, other);
     * // => false
     *
     * _.eq('a', 'a');
     * // => true
     *
     * _.eq('a', Object('a'));
     * // => false
     *
     * _.eq(NaN, NaN);
     * // => true
     */
    function eq(value, other) {
      return value === other || (value !== value && other !== other);
    }

    var eq_1 = eq;

    /**
     * Gets the index at which the `key` is found in `array` of key-value pairs.
     *
     * @private
     * @param {Array} array The array to inspect.
     * @param {*} key The key to search for.
     * @returns {number} Returns the index of the matched value, else `-1`.
     */
    function assocIndexOf(array, key) {
      var length = array.length;
      while (length--) {
        if (eq_1(array[length][0], key)) {
          return length;
        }
      }
      return -1;
    }

    var _assocIndexOf = assocIndexOf;

    /** Used for built-in method references. */
    var arrayProto = Array.prototype;

    /** Built-in value references. */
    var splice = arrayProto.splice;

    /**
     * Removes `key` and its value from the list cache.
     *
     * @private
     * @name delete
     * @memberOf ListCache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function listCacheDelete(key) {
      var data = this.__data__,
          index = _assocIndexOf(data, key);

      if (index < 0) {
        return false;
      }
      var lastIndex = data.length - 1;
      if (index == lastIndex) {
        data.pop();
      } else {
        splice.call(data, index, 1);
      }
      --this.size;
      return true;
    }

    var _listCacheDelete = listCacheDelete;

    /**
     * Gets the list cache value for `key`.
     *
     * @private
     * @name get
     * @memberOf ListCache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function listCacheGet(key) {
      var data = this.__data__,
          index = _assocIndexOf(data, key);

      return index < 0 ? undefined : data[index][1];
    }

    var _listCacheGet = listCacheGet;

    /**
     * Checks if a list cache value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf ListCache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function listCacheHas(key) {
      return _assocIndexOf(this.__data__, key) > -1;
    }

    var _listCacheHas = listCacheHas;

    /**
     * Sets the list cache `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf ListCache
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the list cache instance.
     */
    function listCacheSet(key, value) {
      var data = this.__data__,
          index = _assocIndexOf(data, key);

      if (index < 0) {
        ++this.size;
        data.push([key, value]);
      } else {
        data[index][1] = value;
      }
      return this;
    }

    var _listCacheSet = listCacheSet;

    /**
     * Creates an list cache object.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function ListCache(entries) {
      var index = -1,
          length = entries == null ? 0 : entries.length;

      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }

    // Add methods to `ListCache`.
    ListCache.prototype.clear = _listCacheClear;
    ListCache.prototype['delete'] = _listCacheDelete;
    ListCache.prototype.get = _listCacheGet;
    ListCache.prototype.has = _listCacheHas;
    ListCache.prototype.set = _listCacheSet;

    var _ListCache = ListCache;

    /**
     * Removes all key-value entries from the stack.
     *
     * @private
     * @name clear
     * @memberOf Stack
     */
    function stackClear() {
      this.__data__ = new _ListCache;
      this.size = 0;
    }

    var _stackClear = stackClear;

    /**
     * Removes `key` and its value from the stack.
     *
     * @private
     * @name delete
     * @memberOf Stack
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function stackDelete(key) {
      var data = this.__data__,
          result = data['delete'](key);

      this.size = data.size;
      return result;
    }

    var _stackDelete = stackDelete;

    /**
     * Gets the stack value for `key`.
     *
     * @private
     * @name get
     * @memberOf Stack
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function stackGet(key) {
      return this.__data__.get(key);
    }

    var _stackGet = stackGet;

    /**
     * Checks if a stack value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf Stack
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function stackHas(key) {
      return this.__data__.has(key);
    }

    var _stackHas = stackHas;

    var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

    function createCommonjsModule(fn) {
      var module = { exports: {} };
    	return fn(module, module.exports), module.exports;
    }

    /** Detect free variable `global` from Node.js. */

    var freeGlobal = typeof commonjsGlobal == 'object' && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;

    var _freeGlobal = freeGlobal;

    /** Detect free variable `self`. */
    var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

    /** Used as a reference to the global object. */
    var root = _freeGlobal || freeSelf || Function('return this')();

    var _root = root;

    /** Built-in value references. */
    var Symbol$1 = _root.Symbol;

    var _Symbol = Symbol$1;

    /** Used for built-in method references. */
    var objectProto$c = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$a = objectProto$c.hasOwnProperty;

    /**
     * Used to resolve the
     * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
     * of values.
     */
    var nativeObjectToString$1 = objectProto$c.toString;

    /** Built-in value references. */
    var symToStringTag$1 = _Symbol ? _Symbol.toStringTag : undefined;

    /**
     * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the raw `toStringTag`.
     */
    function getRawTag(value) {
      var isOwn = hasOwnProperty$a.call(value, symToStringTag$1),
          tag = value[symToStringTag$1];

      try {
        value[symToStringTag$1] = undefined;
        var unmasked = true;
      } catch (e) {}

      var result = nativeObjectToString$1.call(value);
      if (unmasked) {
        if (isOwn) {
          value[symToStringTag$1] = tag;
        } else {
          delete value[symToStringTag$1];
        }
      }
      return result;
    }

    var _getRawTag = getRawTag;

    /** Used for built-in method references. */
    var objectProto$b = Object.prototype;

    /**
     * Used to resolve the
     * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
     * of values.
     */
    var nativeObjectToString = objectProto$b.toString;

    /**
     * Converts `value` to a string using `Object.prototype.toString`.
     *
     * @private
     * @param {*} value The value to convert.
     * @returns {string} Returns the converted string.
     */
    function objectToString(value) {
      return nativeObjectToString.call(value);
    }

    var _objectToString = objectToString;

    /** `Object#toString` result references. */
    var nullTag$1 = '[object Null]',
        undefinedTag = '[object Undefined]';

    /** Built-in value references. */
    var symToStringTag = _Symbol ? _Symbol.toStringTag : undefined;

    /**
     * The base implementation of `getTag` without fallbacks for buggy environments.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the `toStringTag`.
     */
    function baseGetTag(value) {
      if (value == null) {
        return value === undefined ? undefinedTag : nullTag$1;
      }
      return (symToStringTag && symToStringTag in Object(value))
        ? _getRawTag(value)
        : _objectToString(value);
    }

    var _baseGetTag = baseGetTag;

    /**
     * Checks if `value` is the
     * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
     * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an object, else `false`.
     * @example
     *
     * _.isObject({});
     * // => true
     *
     * _.isObject([1, 2, 3]);
     * // => true
     *
     * _.isObject(_.noop);
     * // => true
     *
     * _.isObject(null);
     * // => false
     */
    function isObject(value) {
      var type = typeof value;
      return value != null && (type == 'object' || type == 'function');
    }

    var isObject_1 = isObject;

    /** `Object#toString` result references. */
    var asyncTag = '[object AsyncFunction]',
        funcTag$1 = '[object Function]',
        genTag = '[object GeneratorFunction]',
        proxyTag = '[object Proxy]';

    /**
     * Checks if `value` is classified as a `Function` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a function, else `false`.
     * @example
     *
     * _.isFunction(_);
     * // => true
     *
     * _.isFunction(/abc/);
     * // => false
     */
    function isFunction(value) {
      if (!isObject_1(value)) {
        return false;
      }
      // The use of `Object#toString` avoids issues with the `typeof` operator
      // in Safari 9 which returns 'object' for typed arrays and other constructors.
      var tag = _baseGetTag(value);
      return tag == funcTag$1 || tag == genTag || tag == asyncTag || tag == proxyTag;
    }

    var isFunction_1 = isFunction;

    /** Used to detect overreaching core-js shims. */
    var coreJsData = _root['__core-js_shared__'];

    var _coreJsData = coreJsData;

    /** Used to detect methods masquerading as native. */
    var maskSrcKey = (function() {
      var uid = /[^.]+$/.exec(_coreJsData && _coreJsData.keys && _coreJsData.keys.IE_PROTO || '');
      return uid ? ('Symbol(src)_1.' + uid) : '';
    }());

    /**
     * Checks if `func` has its source masked.
     *
     * @private
     * @param {Function} func The function to check.
     * @returns {boolean} Returns `true` if `func` is masked, else `false`.
     */
    function isMasked(func) {
      return !!maskSrcKey && (maskSrcKey in func);
    }

    var _isMasked = isMasked;

    /** Used for built-in method references. */
    var funcProto$1 = Function.prototype;

    /** Used to resolve the decompiled source of functions. */
    var funcToString$1 = funcProto$1.toString;

    /**
     * Converts `func` to its source code.
     *
     * @private
     * @param {Function} func The function to convert.
     * @returns {string} Returns the source code.
     */
    function toSource(func) {
      if (func != null) {
        try {
          return funcToString$1.call(func);
        } catch (e) {}
        try {
          return (func + '');
        } catch (e) {}
      }
      return '';
    }

    var _toSource = toSource;

    /**
     * Used to match `RegExp`
     * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
     */
    var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

    /** Used to detect host constructors (Safari). */
    var reIsHostCtor = /^\[object .+?Constructor\]$/;

    /** Used for built-in method references. */
    var funcProto = Function.prototype,
        objectProto$a = Object.prototype;

    /** Used to resolve the decompiled source of functions. */
    var funcToString = funcProto.toString;

    /** Used to check objects for own properties. */
    var hasOwnProperty$9 = objectProto$a.hasOwnProperty;

    /** Used to detect if a method is native. */
    var reIsNative = RegExp('^' +
      funcToString.call(hasOwnProperty$9).replace(reRegExpChar, '\\$&')
      .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
    );

    /**
     * The base implementation of `_.isNative` without bad shim checks.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a native function,
     *  else `false`.
     */
    function baseIsNative(value) {
      if (!isObject_1(value) || _isMasked(value)) {
        return false;
      }
      var pattern = isFunction_1(value) ? reIsNative : reIsHostCtor;
      return pattern.test(_toSource(value));
    }

    var _baseIsNative = baseIsNative;

    /**
     * Gets the value at `key` of `object`.
     *
     * @private
     * @param {Object} [object] The object to query.
     * @param {string} key The key of the property to get.
     * @returns {*} Returns the property value.
     */
    function getValue(object, key) {
      return object == null ? undefined : object[key];
    }

    var _getValue = getValue;

    /**
     * Gets the native function at `key` of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {string} key The key of the method to get.
     * @returns {*} Returns the function if it's native, else `undefined`.
     */
    function getNative(object, key) {
      var value = _getValue(object, key);
      return _baseIsNative(value) ? value : undefined;
    }

    var _getNative = getNative;

    /* Built-in method references that are verified to be native. */
    var Map$1 = _getNative(_root, 'Map');

    var _Map = Map$1;

    /* Built-in method references that are verified to be native. */
    var nativeCreate = _getNative(Object, 'create');

    var _nativeCreate = nativeCreate;

    /**
     * Removes all key-value entries from the hash.
     *
     * @private
     * @name clear
     * @memberOf Hash
     */
    function hashClear() {
      this.__data__ = _nativeCreate ? _nativeCreate(null) : {};
      this.size = 0;
    }

    var _hashClear = hashClear;

    /**
     * Removes `key` and its value from the hash.
     *
     * @private
     * @name delete
     * @memberOf Hash
     * @param {Object} hash The hash to modify.
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function hashDelete(key) {
      var result = this.has(key) && delete this.__data__[key];
      this.size -= result ? 1 : 0;
      return result;
    }

    var _hashDelete = hashDelete;

    /** Used to stand-in for `undefined` hash values. */
    var HASH_UNDEFINED$2 = '__lodash_hash_undefined__';

    /** Used for built-in method references. */
    var objectProto$9 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$8 = objectProto$9.hasOwnProperty;

    /**
     * Gets the hash value for `key`.
     *
     * @private
     * @name get
     * @memberOf Hash
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function hashGet(key) {
      var data = this.__data__;
      if (_nativeCreate) {
        var result = data[key];
        return result === HASH_UNDEFINED$2 ? undefined : result;
      }
      return hasOwnProperty$8.call(data, key) ? data[key] : undefined;
    }

    var _hashGet = hashGet;

    /** Used for built-in method references. */
    var objectProto$8 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$7 = objectProto$8.hasOwnProperty;

    /**
     * Checks if a hash value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf Hash
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function hashHas(key) {
      var data = this.__data__;
      return _nativeCreate ? (data[key] !== undefined) : hasOwnProperty$7.call(data, key);
    }

    var _hashHas = hashHas;

    /** Used to stand-in for `undefined` hash values. */
    var HASH_UNDEFINED$1 = '__lodash_hash_undefined__';

    /**
     * Sets the hash `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf Hash
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the hash instance.
     */
    function hashSet(key, value) {
      var data = this.__data__;
      this.size += this.has(key) ? 0 : 1;
      data[key] = (_nativeCreate && value === undefined) ? HASH_UNDEFINED$1 : value;
      return this;
    }

    var _hashSet = hashSet;

    /**
     * Creates a hash object.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function Hash(entries) {
      var index = -1,
          length = entries == null ? 0 : entries.length;

      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }

    // Add methods to `Hash`.
    Hash.prototype.clear = _hashClear;
    Hash.prototype['delete'] = _hashDelete;
    Hash.prototype.get = _hashGet;
    Hash.prototype.has = _hashHas;
    Hash.prototype.set = _hashSet;

    var _Hash = Hash;

    /**
     * Removes all key-value entries from the map.
     *
     * @private
     * @name clear
     * @memberOf MapCache
     */
    function mapCacheClear() {
      this.size = 0;
      this.__data__ = {
        'hash': new _Hash,
        'map': new (_Map || _ListCache),
        'string': new _Hash
      };
    }

    var _mapCacheClear = mapCacheClear;

    /**
     * Checks if `value` is suitable for use as unique object key.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
     */
    function isKeyable(value) {
      var type = typeof value;
      return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
        ? (value !== '__proto__')
        : (value === null);
    }

    var _isKeyable = isKeyable;

    /**
     * Gets the data for `map`.
     *
     * @private
     * @param {Object} map The map to query.
     * @param {string} key The reference key.
     * @returns {*} Returns the map data.
     */
    function getMapData(map, key) {
      var data = map.__data__;
      return _isKeyable(key)
        ? data[typeof key == 'string' ? 'string' : 'hash']
        : data.map;
    }

    var _getMapData = getMapData;

    /**
     * Removes `key` and its value from the map.
     *
     * @private
     * @name delete
     * @memberOf MapCache
     * @param {string} key The key of the value to remove.
     * @returns {boolean} Returns `true` if the entry was removed, else `false`.
     */
    function mapCacheDelete(key) {
      var result = _getMapData(this, key)['delete'](key);
      this.size -= result ? 1 : 0;
      return result;
    }

    var _mapCacheDelete = mapCacheDelete;

    /**
     * Gets the map value for `key`.
     *
     * @private
     * @name get
     * @memberOf MapCache
     * @param {string} key The key of the value to get.
     * @returns {*} Returns the entry value.
     */
    function mapCacheGet(key) {
      return _getMapData(this, key).get(key);
    }

    var _mapCacheGet = mapCacheGet;

    /**
     * Checks if a map value for `key` exists.
     *
     * @private
     * @name has
     * @memberOf MapCache
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function mapCacheHas(key) {
      return _getMapData(this, key).has(key);
    }

    var _mapCacheHas = mapCacheHas;

    /**
     * Sets the map `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf MapCache
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the map cache instance.
     */
    function mapCacheSet(key, value) {
      var data = _getMapData(this, key),
          size = data.size;

      data.set(key, value);
      this.size += data.size == size ? 0 : 1;
      return this;
    }

    var _mapCacheSet = mapCacheSet;

    /**
     * Creates a map cache object to store key-value pairs.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function MapCache(entries) {
      var index = -1,
          length = entries == null ? 0 : entries.length;

      this.clear();
      while (++index < length) {
        var entry = entries[index];
        this.set(entry[0], entry[1]);
      }
    }

    // Add methods to `MapCache`.
    MapCache.prototype.clear = _mapCacheClear;
    MapCache.prototype['delete'] = _mapCacheDelete;
    MapCache.prototype.get = _mapCacheGet;
    MapCache.prototype.has = _mapCacheHas;
    MapCache.prototype.set = _mapCacheSet;

    var _MapCache = MapCache;

    /** Used as the size to enable large array optimizations. */
    var LARGE_ARRAY_SIZE = 200;

    /**
     * Sets the stack `key` to `value`.
     *
     * @private
     * @name set
     * @memberOf Stack
     * @param {string} key The key of the value to set.
     * @param {*} value The value to set.
     * @returns {Object} Returns the stack cache instance.
     */
    function stackSet(key, value) {
      var data = this.__data__;
      if (data instanceof _ListCache) {
        var pairs = data.__data__;
        if (!_Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
          pairs.push([key, value]);
          this.size = ++data.size;
          return this;
        }
        data = this.__data__ = new _MapCache(pairs);
      }
      data.set(key, value);
      this.size = data.size;
      return this;
    }

    var _stackSet = stackSet;

    /**
     * Creates a stack cache object to store key-value pairs.
     *
     * @private
     * @constructor
     * @param {Array} [entries] The key-value pairs to cache.
     */
    function Stack(entries) {
      var data = this.__data__ = new _ListCache(entries);
      this.size = data.size;
    }

    // Add methods to `Stack`.
    Stack.prototype.clear = _stackClear;
    Stack.prototype['delete'] = _stackDelete;
    Stack.prototype.get = _stackGet;
    Stack.prototype.has = _stackHas;
    Stack.prototype.set = _stackSet;

    var _Stack = Stack;

    /** Used to stand-in for `undefined` hash values. */
    var HASH_UNDEFINED = '__lodash_hash_undefined__';

    /**
     * Adds `value` to the array cache.
     *
     * @private
     * @name add
     * @memberOf SetCache
     * @alias push
     * @param {*} value The value to cache.
     * @returns {Object} Returns the cache instance.
     */
    function setCacheAdd(value) {
      this.__data__.set(value, HASH_UNDEFINED);
      return this;
    }

    var _setCacheAdd = setCacheAdd;

    /**
     * Checks if `value` is in the array cache.
     *
     * @private
     * @name has
     * @memberOf SetCache
     * @param {*} value The value to search for.
     * @returns {number} Returns `true` if `value` is found, else `false`.
     */
    function setCacheHas(value) {
      return this.__data__.has(value);
    }

    var _setCacheHas = setCacheHas;

    /**
     *
     * Creates an array cache object to store unique values.
     *
     * @private
     * @constructor
     * @param {Array} [values] The values to cache.
     */
    function SetCache(values) {
      var index = -1,
          length = values == null ? 0 : values.length;

      this.__data__ = new _MapCache;
      while (++index < length) {
        this.add(values[index]);
      }
    }

    // Add methods to `SetCache`.
    SetCache.prototype.add = SetCache.prototype.push = _setCacheAdd;
    SetCache.prototype.has = _setCacheHas;

    var _SetCache = SetCache;

    /**
     * A specialized version of `_.some` for arrays without support for iteratee
     * shorthands.
     *
     * @private
     * @param {Array} [array] The array to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {boolean} Returns `true` if any element passes the predicate check,
     *  else `false`.
     */
    function arraySome(array, predicate) {
      var index = -1,
          length = array == null ? 0 : array.length;

      while (++index < length) {
        if (predicate(array[index], index, array)) {
          return true;
        }
      }
      return false;
    }

    var _arraySome = arraySome;

    /**
     * Checks if a `cache` value for `key` exists.
     *
     * @private
     * @param {Object} cache The cache to query.
     * @param {string} key The key of the entry to check.
     * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
     */
    function cacheHas(cache, key) {
      return cache.has(key);
    }

    var _cacheHas = cacheHas;

    /** Used to compose bitmasks for value comparisons. */
    var COMPARE_PARTIAL_FLAG$3 = 1,
        COMPARE_UNORDERED_FLAG$1 = 2;

    /**
     * A specialized version of `baseIsEqualDeep` for arrays with support for
     * partial deep comparisons.
     *
     * @private
     * @param {Array} array The array to compare.
     * @param {Array} other The other array to compare.
     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
     * @param {Function} customizer The function to customize comparisons.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Object} stack Tracks traversed `array` and `other` objects.
     * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
     */
    function equalArrays(array, other, bitmask, customizer, equalFunc, stack) {
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG$3,
          arrLength = array.length,
          othLength = other.length;

      if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
        return false;
      }
      // Check that cyclic values are equal.
      var arrStacked = stack.get(array);
      var othStacked = stack.get(other);
      if (arrStacked && othStacked) {
        return arrStacked == other && othStacked == array;
      }
      var index = -1,
          result = true,
          seen = (bitmask & COMPARE_UNORDERED_FLAG$1) ? new _SetCache : undefined;

      stack.set(array, other);
      stack.set(other, array);

      // Ignore non-index properties.
      while (++index < arrLength) {
        var arrValue = array[index],
            othValue = other[index];

        if (customizer) {
          var compared = isPartial
            ? customizer(othValue, arrValue, index, other, array, stack)
            : customizer(arrValue, othValue, index, array, other, stack);
        }
        if (compared !== undefined) {
          if (compared) {
            continue;
          }
          result = false;
          break;
        }
        // Recursively compare arrays (susceptible to call stack limits).
        if (seen) {
          if (!_arraySome(other, function(othValue, othIndex) {
                if (!_cacheHas(seen, othIndex) &&
                    (arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack))) {
                  return seen.push(othIndex);
                }
              })) {
            result = false;
            break;
          }
        } else if (!(
              arrValue === othValue ||
                equalFunc(arrValue, othValue, bitmask, customizer, stack)
            )) {
          result = false;
          break;
        }
      }
      stack['delete'](array);
      stack['delete'](other);
      return result;
    }

    var _equalArrays = equalArrays;

    /** Built-in value references. */
    var Uint8Array$1 = _root.Uint8Array;

    var _Uint8Array = Uint8Array$1;

    /**
     * Converts `map` to its key-value pairs.
     *
     * @private
     * @param {Object} map The map to convert.
     * @returns {Array} Returns the key-value pairs.
     */
    function mapToArray(map) {
      var index = -1,
          result = Array(map.size);

      map.forEach(function(value, key) {
        result[++index] = [key, value];
      });
      return result;
    }

    var _mapToArray = mapToArray;

    /**
     * Converts `set` to an array of its values.
     *
     * @private
     * @param {Object} set The set to convert.
     * @returns {Array} Returns the values.
     */
    function setToArray(set) {
      var index = -1,
          result = Array(set.size);

      set.forEach(function(value) {
        result[++index] = value;
      });
      return result;
    }

    var _setToArray = setToArray;

    /** Used to compose bitmasks for value comparisons. */
    var COMPARE_PARTIAL_FLAG$2 = 1,
        COMPARE_UNORDERED_FLAG = 2;

    /** `Object#toString` result references. */
    var boolTag$2 = '[object Boolean]',
        dateTag$1 = '[object Date]',
        errorTag$1 = '[object Error]',
        mapTag$3 = '[object Map]',
        numberTag$1 = '[object Number]',
        regexpTag$1 = '[object RegExp]',
        setTag$3 = '[object Set]',
        stringTag$1 = '[object String]',
        symbolTag = '[object Symbol]';

    var arrayBufferTag$1 = '[object ArrayBuffer]',
        dataViewTag$2 = '[object DataView]';

    /** Used to convert symbols to primitives and strings. */
    var symbolProto = _Symbol ? _Symbol.prototype : undefined,
        symbolValueOf = symbolProto ? symbolProto.valueOf : undefined;

    /**
     * A specialized version of `baseIsEqualDeep` for comparing objects of
     * the same `toStringTag`.
     *
     * **Note:** This function only supports comparing values with tags of
     * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
     *
     * @private
     * @param {Object} object The object to compare.
     * @param {Object} other The other object to compare.
     * @param {string} tag The `toStringTag` of the objects to compare.
     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
     * @param {Function} customizer The function to customize comparisons.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Object} stack Tracks traversed `object` and `other` objects.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack) {
      switch (tag) {
        case dataViewTag$2:
          if ((object.byteLength != other.byteLength) ||
              (object.byteOffset != other.byteOffset)) {
            return false;
          }
          object = object.buffer;
          other = other.buffer;

        case arrayBufferTag$1:
          if ((object.byteLength != other.byteLength) ||
              !equalFunc(new _Uint8Array(object), new _Uint8Array(other))) {
            return false;
          }
          return true;

        case boolTag$2:
        case dateTag$1:
        case numberTag$1:
          // Coerce booleans to `1` or `0` and dates to milliseconds.
          // Invalid dates are coerced to `NaN`.
          return eq_1(+object, +other);

        case errorTag$1:
          return object.name == other.name && object.message == other.message;

        case regexpTag$1:
        case stringTag$1:
          // Coerce regexes to strings and treat strings, primitives and objects,
          // as equal. See http://www.ecma-international.org/ecma-262/7.0/#sec-regexp.prototype.tostring
          // for more details.
          return object == (other + '');

        case mapTag$3:
          var convert = _mapToArray;

        case setTag$3:
          var isPartial = bitmask & COMPARE_PARTIAL_FLAG$2;
          convert || (convert = _setToArray);

          if (object.size != other.size && !isPartial) {
            return false;
          }
          // Assume cyclic values are equal.
          var stacked = stack.get(object);
          if (stacked) {
            return stacked == other;
          }
          bitmask |= COMPARE_UNORDERED_FLAG;

          // Recursively compare objects (susceptible to call stack limits).
          stack.set(object, other);
          var result = _equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack);
          stack['delete'](object);
          return result;

        case symbolTag:
          if (symbolValueOf) {
            return symbolValueOf.call(object) == symbolValueOf.call(other);
          }
      }
      return false;
    }

    var _equalByTag = equalByTag;

    /**
     * Appends the elements of `values` to `array`.
     *
     * @private
     * @param {Array} array The array to modify.
     * @param {Array} values The values to append.
     * @returns {Array} Returns `array`.
     */
    function arrayPush(array, values) {
      var index = -1,
          length = values.length,
          offset = array.length;

      while (++index < length) {
        array[offset + index] = values[index];
      }
      return array;
    }

    var _arrayPush = arrayPush;

    /**
     * Checks if `value` is classified as an `Array` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an array, else `false`.
     * @example
     *
     * _.isArray([1, 2, 3]);
     * // => true
     *
     * _.isArray(document.body.children);
     * // => false
     *
     * _.isArray('abc');
     * // => false
     *
     * _.isArray(_.noop);
     * // => false
     */
    var isArray = Array.isArray;

    var isArray_1 = isArray;

    /**
     * The base implementation of `getAllKeys` and `getAllKeysIn` which uses
     * `keysFunc` and `symbolsFunc` to get the enumerable property names and
     * symbols of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @param {Function} keysFunc The function to get the keys of `object`.
     * @param {Function} symbolsFunc The function to get the symbols of `object`.
     * @returns {Array} Returns the array of property names and symbols.
     */
    function baseGetAllKeys(object, keysFunc, symbolsFunc) {
      var result = keysFunc(object);
      return isArray_1(object) ? result : _arrayPush(result, symbolsFunc(object));
    }

    var _baseGetAllKeys = baseGetAllKeys;

    /**
     * A specialized version of `_.filter` for arrays without support for
     * iteratee shorthands.
     *
     * @private
     * @param {Array} [array] The array to iterate over.
     * @param {Function} predicate The function invoked per iteration.
     * @returns {Array} Returns the new filtered array.
     */
    function arrayFilter(array, predicate) {
      var index = -1,
          length = array == null ? 0 : array.length,
          resIndex = 0,
          result = [];

      while (++index < length) {
        var value = array[index];
        if (predicate(value, index, array)) {
          result[resIndex++] = value;
        }
      }
      return result;
    }

    var _arrayFilter = arrayFilter;

    /**
     * This method returns a new empty array.
     *
     * @static
     * @memberOf _
     * @since 4.13.0
     * @category Util
     * @returns {Array} Returns the new empty array.
     * @example
     *
     * var arrays = _.times(2, _.stubArray);
     *
     * console.log(arrays);
     * // => [[], []]
     *
     * console.log(arrays[0] === arrays[1]);
     * // => false
     */
    function stubArray() {
      return [];
    }

    var stubArray_1 = stubArray;

    /** Used for built-in method references. */
    var objectProto$7 = Object.prototype;

    /** Built-in value references. */
    var propertyIsEnumerable$1 = objectProto$7.propertyIsEnumerable;

    /* Built-in method references for those with the same name as other `lodash` methods. */
    var nativeGetSymbols = Object.getOwnPropertySymbols;

    /**
     * Creates an array of the own enumerable symbols of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of symbols.
     */
    var getSymbols = !nativeGetSymbols ? stubArray_1 : function(object) {
      if (object == null) {
        return [];
      }
      object = Object(object);
      return _arrayFilter(nativeGetSymbols(object), function(symbol) {
        return propertyIsEnumerable$1.call(object, symbol);
      });
    };

    var _getSymbols = getSymbols;

    /**
     * The base implementation of `_.times` without support for iteratee shorthands
     * or max array length checks.
     *
     * @private
     * @param {number} n The number of times to invoke `iteratee`.
     * @param {Function} iteratee The function invoked per iteration.
     * @returns {Array} Returns the array of results.
     */
    function baseTimes(n, iteratee) {
      var index = -1,
          result = Array(n);

      while (++index < n) {
        result[index] = iteratee(index);
      }
      return result;
    }

    var _baseTimes = baseTimes;

    /**
     * Checks if `value` is object-like. A value is object-like if it's not `null`
     * and has a `typeof` result of "object".
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
     * @example
     *
     * _.isObjectLike({});
     * // => true
     *
     * _.isObjectLike([1, 2, 3]);
     * // => true
     *
     * _.isObjectLike(_.noop);
     * // => false
     *
     * _.isObjectLike(null);
     * // => false
     */
    function isObjectLike(value) {
      return value != null && typeof value == 'object';
    }

    var isObjectLike_1 = isObjectLike;

    /** `Object#toString` result references. */
    var argsTag$2 = '[object Arguments]';

    /**
     * The base implementation of `_.isArguments`.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an `arguments` object,
     */
    function baseIsArguments(value) {
      return isObjectLike_1(value) && _baseGetTag(value) == argsTag$2;
    }

    var _baseIsArguments = baseIsArguments;

    /** Used for built-in method references. */
    var objectProto$6 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$6 = objectProto$6.hasOwnProperty;

    /** Built-in value references. */
    var propertyIsEnumerable = objectProto$6.propertyIsEnumerable;

    /**
     * Checks if `value` is likely an `arguments` object.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is an `arguments` object,
     *  else `false`.
     * @example
     *
     * _.isArguments(function() { return arguments; }());
     * // => true
     *
     * _.isArguments([1, 2, 3]);
     * // => false
     */
    var isArguments = _baseIsArguments(function() { return arguments; }()) ? _baseIsArguments : function(value) {
      return isObjectLike_1(value) && hasOwnProperty$6.call(value, 'callee') &&
        !propertyIsEnumerable.call(value, 'callee');
    };

    var isArguments_1 = isArguments;

    /**
     * This method returns `false`.
     *
     * @static
     * @memberOf _
     * @since 4.13.0
     * @category Util
     * @returns {boolean} Returns `false`.
     * @example
     *
     * _.times(2, _.stubFalse);
     * // => [false, false]
     */
    function stubFalse() {
      return false;
    }

    var stubFalse_1 = stubFalse;

    var isBuffer_1 = createCommonjsModule(function (module, exports) {
    /** Detect free variable `exports`. */
    var freeExports = exports && !exports.nodeType && exports;

    /** Detect free variable `module`. */
    var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;

    /** Detect the popular CommonJS extension `module.exports`. */
    var moduleExports = freeModule && freeModule.exports === freeExports;

    /** Built-in value references. */
    var Buffer = moduleExports ? _root.Buffer : undefined;

    /* Built-in method references for those with the same name as other `lodash` methods. */
    var nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined;

    /**
     * Checks if `value` is a buffer.
     *
     * @static
     * @memberOf _
     * @since 4.3.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
     * @example
     *
     * _.isBuffer(new Buffer(2));
     * // => true
     *
     * _.isBuffer(new Uint8Array(2));
     * // => false
     */
    var isBuffer = nativeIsBuffer || stubFalse_1;

    module.exports = isBuffer;
    });

    /** Used as references for various `Number` constants. */
    var MAX_SAFE_INTEGER$1 = 9007199254740991;

    /** Used to detect unsigned integer values. */
    var reIsUint = /^(?:0|[1-9]\d*)$/;

    /**
     * Checks if `value` is a valid array-like index.
     *
     * @private
     * @param {*} value The value to check.
     * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
     * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
     */
    function isIndex(value, length) {
      var type = typeof value;
      length = length == null ? MAX_SAFE_INTEGER$1 : length;

      return !!length &&
        (type == 'number' ||
          (type != 'symbol' && reIsUint.test(value))) &&
            (value > -1 && value % 1 == 0 && value < length);
    }

    var _isIndex = isIndex;

    /** Used as references for various `Number` constants. */
    var MAX_SAFE_INTEGER = 9007199254740991;

    /**
     * Checks if `value` is a valid array-like length.
     *
     * **Note:** This method is loosely based on
     * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
     * @example
     *
     * _.isLength(3);
     * // => true
     *
     * _.isLength(Number.MIN_VALUE);
     * // => false
     *
     * _.isLength(Infinity);
     * // => false
     *
     * _.isLength('3');
     * // => false
     */
    function isLength(value) {
      return typeof value == 'number' &&
        value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
    }

    var isLength_1 = isLength;

    /** `Object#toString` result references. */
    var argsTag$1 = '[object Arguments]',
        arrayTag$1 = '[object Array]',
        boolTag$1 = '[object Boolean]',
        dateTag = '[object Date]',
        errorTag = '[object Error]',
        funcTag = '[object Function]',
        mapTag$2 = '[object Map]',
        numberTag = '[object Number]',
        objectTag$2 = '[object Object]',
        regexpTag = '[object RegExp]',
        setTag$2 = '[object Set]',
        stringTag = '[object String]',
        weakMapTag$1 = '[object WeakMap]';

    var arrayBufferTag = '[object ArrayBuffer]',
        dataViewTag$1 = '[object DataView]',
        float32Tag = '[object Float32Array]',
        float64Tag = '[object Float64Array]',
        int8Tag = '[object Int8Array]',
        int16Tag = '[object Int16Array]',
        int32Tag = '[object Int32Array]',
        uint8Tag = '[object Uint8Array]',
        uint8ClampedTag = '[object Uint8ClampedArray]',
        uint16Tag = '[object Uint16Array]',
        uint32Tag = '[object Uint32Array]';

    /** Used to identify `toStringTag` values of typed arrays. */
    var typedArrayTags = {};
    typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
    typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
    typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
    typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
    typedArrayTags[uint32Tag] = true;
    typedArrayTags[argsTag$1] = typedArrayTags[arrayTag$1] =
    typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag$1] =
    typedArrayTags[dataViewTag$1] = typedArrayTags[dateTag] =
    typedArrayTags[errorTag] = typedArrayTags[funcTag] =
    typedArrayTags[mapTag$2] = typedArrayTags[numberTag] =
    typedArrayTags[objectTag$2] = typedArrayTags[regexpTag] =
    typedArrayTags[setTag$2] = typedArrayTags[stringTag] =
    typedArrayTags[weakMapTag$1] = false;

    /**
     * The base implementation of `_.isTypedArray` without Node.js optimizations.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
     */
    function baseIsTypedArray(value) {
      return isObjectLike_1(value) &&
        isLength_1(value.length) && !!typedArrayTags[_baseGetTag(value)];
    }

    var _baseIsTypedArray = baseIsTypedArray;

    /**
     * The base implementation of `_.unary` without support for storing metadata.
     *
     * @private
     * @param {Function} func The function to cap arguments for.
     * @returns {Function} Returns the new capped function.
     */
    function baseUnary(func) {
      return function(value) {
        return func(value);
      };
    }

    var _baseUnary = baseUnary;

    var _nodeUtil = createCommonjsModule(function (module, exports) {
    /** Detect free variable `exports`. */
    var freeExports = exports && !exports.nodeType && exports;

    /** Detect free variable `module`. */
    var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;

    /** Detect the popular CommonJS extension `module.exports`. */
    var moduleExports = freeModule && freeModule.exports === freeExports;

    /** Detect free variable `process` from Node.js. */
    var freeProcess = moduleExports && _freeGlobal.process;

    /** Used to access faster Node.js helpers. */
    var nodeUtil = (function() {
      try {
        // Use `util.types` for Node.js 10+.
        var types = freeModule && freeModule.require && freeModule.require('util').types;

        if (types) {
          return types;
        }

        // Legacy `process.binding('util')` for Node.js < 10.
        return freeProcess && freeProcess.binding && freeProcess.binding('util');
      } catch (e) {}
    }());

    module.exports = nodeUtil;
    });

    /* Node.js helper references. */
    var nodeIsTypedArray = _nodeUtil && _nodeUtil.isTypedArray;

    /**
     * Checks if `value` is classified as a typed array.
     *
     * @static
     * @memberOf _
     * @since 3.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
     * @example
     *
     * _.isTypedArray(new Uint8Array);
     * // => true
     *
     * _.isTypedArray([]);
     * // => false
     */
    var isTypedArray = nodeIsTypedArray ? _baseUnary(nodeIsTypedArray) : _baseIsTypedArray;

    var isTypedArray_1 = isTypedArray;

    /** Used for built-in method references. */
    var objectProto$5 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$5 = objectProto$5.hasOwnProperty;

    /**
     * Creates an array of the enumerable property names of the array-like `value`.
     *
     * @private
     * @param {*} value The value to query.
     * @param {boolean} inherited Specify returning inherited property names.
     * @returns {Array} Returns the array of property names.
     */
    function arrayLikeKeys(value, inherited) {
      var isArr = isArray_1(value),
          isArg = !isArr && isArguments_1(value),
          isBuff = !isArr && !isArg && isBuffer_1(value),
          isType = !isArr && !isArg && !isBuff && isTypedArray_1(value),
          skipIndexes = isArr || isArg || isBuff || isType,
          result = skipIndexes ? _baseTimes(value.length, String) : [],
          length = result.length;

      for (var key in value) {
        if ((inherited || hasOwnProperty$5.call(value, key)) &&
            !(skipIndexes && (
               // Safari 9 has enumerable `arguments.length` in strict mode.
               key == 'length' ||
               // Node.js 0.10 has enumerable non-index properties on buffers.
               (isBuff && (key == 'offset' || key == 'parent')) ||
               // PhantomJS 2 has enumerable non-index properties on typed arrays.
               (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
               // Skip index properties.
               _isIndex(key, length)
            ))) {
          result.push(key);
        }
      }
      return result;
    }

    var _arrayLikeKeys = arrayLikeKeys;

    /** Used for built-in method references. */
    var objectProto$4 = Object.prototype;

    /**
     * Checks if `value` is likely a prototype object.
     *
     * @private
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
     */
    function isPrototype(value) {
      var Ctor = value && value.constructor,
          proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto$4;

      return value === proto;
    }

    var _isPrototype = isPrototype;

    /**
     * Creates a unary function that invokes `func` with its argument transformed.
     *
     * @private
     * @param {Function} func The function to wrap.
     * @param {Function} transform The argument transform.
     * @returns {Function} Returns the new function.
     */
    function overArg(func, transform) {
      return function(arg) {
        return func(transform(arg));
      };
    }

    var _overArg = overArg;

    /* Built-in method references for those with the same name as other `lodash` methods. */
    var nativeKeys = _overArg(Object.keys, Object);

    var _nativeKeys = nativeKeys;

    /** Used for built-in method references. */
    var objectProto$3 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$4 = objectProto$3.hasOwnProperty;

    /**
     * The base implementation of `_.keys` which doesn't treat sparse arrays as dense.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     */
    function baseKeys(object) {
      if (!_isPrototype(object)) {
        return _nativeKeys(object);
      }
      var result = [];
      for (var key in Object(object)) {
        if (hasOwnProperty$4.call(object, key) && key != 'constructor') {
          result.push(key);
        }
      }
      return result;
    }

    var _baseKeys = baseKeys;

    /**
     * Checks if `value` is array-like. A value is considered array-like if it's
     * not a function and has a `value.length` that's an integer greater than or
     * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
     * @example
     *
     * _.isArrayLike([1, 2, 3]);
     * // => true
     *
     * _.isArrayLike(document.body.children);
     * // => true
     *
     * _.isArrayLike('abc');
     * // => true
     *
     * _.isArrayLike(_.noop);
     * // => false
     */
    function isArrayLike(value) {
      return value != null && isLength_1(value.length) && !isFunction_1(value);
    }

    var isArrayLike_1 = isArrayLike;

    /**
     * Creates an array of the own enumerable property names of `object`.
     *
     * **Note:** Non-object values are coerced to objects. See the
     * [ES spec](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
     * for more details.
     *
     * @static
     * @since 0.1.0
     * @memberOf _
     * @category Object
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     *   this.b = 2;
     * }
     *
     * Foo.prototype.c = 3;
     *
     * _.keys(new Foo);
     * // => ['a', 'b'] (iteration order is not guaranteed)
     *
     * _.keys('hi');
     * // => ['0', '1']
     */
    function keys(object) {
      return isArrayLike_1(object) ? _arrayLikeKeys(object) : _baseKeys(object);
    }

    var keys_1 = keys;

    /**
     * Creates an array of own enumerable property names and symbols of `object`.
     *
     * @private
     * @param {Object} object The object to query.
     * @returns {Array} Returns the array of property names and symbols.
     */
    function getAllKeys(object) {
      return _baseGetAllKeys(object, keys_1, _getSymbols);
    }

    var _getAllKeys = getAllKeys;

    /** Used to compose bitmasks for value comparisons. */
    var COMPARE_PARTIAL_FLAG$1 = 1;

    /** Used for built-in method references. */
    var objectProto$2 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$3 = objectProto$2.hasOwnProperty;

    /**
     * A specialized version of `baseIsEqualDeep` for objects with support for
     * partial deep comparisons.
     *
     * @private
     * @param {Object} object The object to compare.
     * @param {Object} other The other object to compare.
     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
     * @param {Function} customizer The function to customize comparisons.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Object} stack Tracks traversed `object` and `other` objects.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function equalObjects(object, other, bitmask, customizer, equalFunc, stack) {
      var isPartial = bitmask & COMPARE_PARTIAL_FLAG$1,
          objProps = _getAllKeys(object),
          objLength = objProps.length,
          othProps = _getAllKeys(other),
          othLength = othProps.length;

      if (objLength != othLength && !isPartial) {
        return false;
      }
      var index = objLength;
      while (index--) {
        var key = objProps[index];
        if (!(isPartial ? key in other : hasOwnProperty$3.call(other, key))) {
          return false;
        }
      }
      // Check that cyclic values are equal.
      var objStacked = stack.get(object);
      var othStacked = stack.get(other);
      if (objStacked && othStacked) {
        return objStacked == other && othStacked == object;
      }
      var result = true;
      stack.set(object, other);
      stack.set(other, object);

      var skipCtor = isPartial;
      while (++index < objLength) {
        key = objProps[index];
        var objValue = object[key],
            othValue = other[key];

        if (customizer) {
          var compared = isPartial
            ? customizer(othValue, objValue, key, other, object, stack)
            : customizer(objValue, othValue, key, object, other, stack);
        }
        // Recursively compare objects (susceptible to call stack limits).
        if (!(compared === undefined
              ? (objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack))
              : compared
            )) {
          result = false;
          break;
        }
        skipCtor || (skipCtor = key == 'constructor');
      }
      if (result && !skipCtor) {
        var objCtor = object.constructor,
            othCtor = other.constructor;

        // Non `Object` object instances with different constructors are not equal.
        if (objCtor != othCtor &&
            ('constructor' in object && 'constructor' in other) &&
            !(typeof objCtor == 'function' && objCtor instanceof objCtor &&
              typeof othCtor == 'function' && othCtor instanceof othCtor)) {
          result = false;
        }
      }
      stack['delete'](object);
      stack['delete'](other);
      return result;
    }

    var _equalObjects = equalObjects;

    /* Built-in method references that are verified to be native. */
    var DataView = _getNative(_root, 'DataView');

    var _DataView = DataView;

    /* Built-in method references that are verified to be native. */
    var Promise$1 = _getNative(_root, 'Promise');

    var _Promise = Promise$1;

    /* Built-in method references that are verified to be native. */
    var Set$1 = _getNative(_root, 'Set');

    var _Set = Set$1;

    /* Built-in method references that are verified to be native. */
    var WeakMap = _getNative(_root, 'WeakMap');

    var _WeakMap = WeakMap;

    /** `Object#toString` result references. */
    var mapTag$1 = '[object Map]',
        objectTag$1 = '[object Object]',
        promiseTag = '[object Promise]',
        setTag$1 = '[object Set]',
        weakMapTag = '[object WeakMap]';

    var dataViewTag = '[object DataView]';

    /** Used to detect maps, sets, and weakmaps. */
    var dataViewCtorString = _toSource(_DataView),
        mapCtorString = _toSource(_Map),
        promiseCtorString = _toSource(_Promise),
        setCtorString = _toSource(_Set),
        weakMapCtorString = _toSource(_WeakMap);

    /**
     * Gets the `toStringTag` of `value`.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the `toStringTag`.
     */
    var getTag = _baseGetTag;

    // Fallback for data views, maps, sets, and weak maps in IE 11 and promises in Node.js < 6.
    if ((_DataView && getTag(new _DataView(new ArrayBuffer(1))) != dataViewTag) ||
        (_Map && getTag(new _Map) != mapTag$1) ||
        (_Promise && getTag(_Promise.resolve()) != promiseTag) ||
        (_Set && getTag(new _Set) != setTag$1) ||
        (_WeakMap && getTag(new _WeakMap) != weakMapTag)) {
      getTag = function(value) {
        var result = _baseGetTag(value),
            Ctor = result == objectTag$1 ? value.constructor : undefined,
            ctorString = Ctor ? _toSource(Ctor) : '';

        if (ctorString) {
          switch (ctorString) {
            case dataViewCtorString: return dataViewTag;
            case mapCtorString: return mapTag$1;
            case promiseCtorString: return promiseTag;
            case setCtorString: return setTag$1;
            case weakMapCtorString: return weakMapTag;
          }
        }
        return result;
      };
    }

    var _getTag = getTag;

    /** Used to compose bitmasks for value comparisons. */
    var COMPARE_PARTIAL_FLAG = 1;

    /** `Object#toString` result references. */
    var argsTag = '[object Arguments]',
        arrayTag = '[object Array]',
        objectTag = '[object Object]';

    /** Used for built-in method references. */
    var objectProto$1 = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$2 = objectProto$1.hasOwnProperty;

    /**
     * A specialized version of `baseIsEqual` for arrays and objects which performs
     * deep comparisons and tracks traversed objects enabling objects with circular
     * references to be compared.
     *
     * @private
     * @param {Object} object The object to compare.
     * @param {Object} other The other object to compare.
     * @param {number} bitmask The bitmask flags. See `baseIsEqual` for more details.
     * @param {Function} customizer The function to customize comparisons.
     * @param {Function} equalFunc The function to determine equivalents of values.
     * @param {Object} [stack] Tracks traversed `object` and `other` objects.
     * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
     */
    function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack) {
      var objIsArr = isArray_1(object),
          othIsArr = isArray_1(other),
          objTag = objIsArr ? arrayTag : _getTag(object),
          othTag = othIsArr ? arrayTag : _getTag(other);

      objTag = objTag == argsTag ? objectTag : objTag;
      othTag = othTag == argsTag ? objectTag : othTag;

      var objIsObj = objTag == objectTag,
          othIsObj = othTag == objectTag,
          isSameTag = objTag == othTag;

      if (isSameTag && isBuffer_1(object)) {
        if (!isBuffer_1(other)) {
          return false;
        }
        objIsArr = true;
        objIsObj = false;
      }
      if (isSameTag && !objIsObj) {
        stack || (stack = new _Stack);
        return (objIsArr || isTypedArray_1(object))
          ? _equalArrays(object, other, bitmask, customizer, equalFunc, stack)
          : _equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack);
      }
      if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
        var objIsWrapped = objIsObj && hasOwnProperty$2.call(object, '__wrapped__'),
            othIsWrapped = othIsObj && hasOwnProperty$2.call(other, '__wrapped__');

        if (objIsWrapped || othIsWrapped) {
          var objUnwrapped = objIsWrapped ? object.value() : object,
              othUnwrapped = othIsWrapped ? other.value() : other;

          stack || (stack = new _Stack);
          return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack);
        }
      }
      if (!isSameTag) {
        return false;
      }
      stack || (stack = new _Stack);
      return _equalObjects(object, other, bitmask, customizer, equalFunc, stack);
    }

    var _baseIsEqualDeep = baseIsEqualDeep;

    /**
     * The base implementation of `_.isEqual` which supports partial comparisons
     * and tracks traversed objects.
     *
     * @private
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @param {boolean} bitmask The bitmask flags.
     *  1 - Unordered comparison
     *  2 - Partial comparison
     * @param {Function} [customizer] The function to customize comparisons.
     * @param {Object} [stack] Tracks traversed `value` and `other` objects.
     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
     */
    function baseIsEqual(value, other, bitmask, customizer, stack) {
      if (value === other) {
        return true;
      }
      if (value == null || other == null || (!isObjectLike_1(value) && !isObjectLike_1(other))) {
        return value !== value && other !== other;
      }
      return _baseIsEqualDeep(value, other, bitmask, customizer, baseIsEqual, stack);
    }

    var _baseIsEqual = baseIsEqual;

    /**
     * Performs a deep comparison between two values to determine if they are
     * equivalent.
     *
     * **Note:** This method supports comparing arrays, array buffers, booleans,
     * date objects, error objects, maps, numbers, `Object` objects, regexes,
     * sets, strings, symbols, and typed arrays. `Object` objects are compared
     * by their own, not inherited, enumerable properties. Functions and DOM
     * nodes are compared by strict equality, i.e. `===`.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to compare.
     * @param {*} other The other value to compare.
     * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
     * @example
     *
     * var object = { 'a': 1 };
     * var other = { 'a': 1 };
     *
     * _.isEqual(object, other);
     * // => true
     *
     * object === other;
     * // => false
     */
    function isEqual(value, other) {
      return _baseIsEqual(value, other);
    }

    var isEqual_1 = isEqual;

    /** `Object#toString` result references. */
    var mapTag = '[object Map]',
        setTag = '[object Set]';

    /** Used for built-in method references. */
    var objectProto = Object.prototype;

    /** Used to check objects for own properties. */
    var hasOwnProperty$1 = objectProto.hasOwnProperty;

    /**
     * Checks if `value` is an empty object, collection, map, or set.
     *
     * Objects are considered empty if they have no own enumerable string keyed
     * properties.
     *
     * Array-like values such as `arguments` objects, arrays, buffers, strings, or
     * jQuery-like collections are considered empty if they have a `length` of `0`.
     * Similarly, maps and sets are considered empty if they have a `size` of `0`.
     *
     * @static
     * @memberOf _
     * @since 0.1.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is empty, else `false`.
     * @example
     *
     * _.isEmpty(null);
     * // => true
     *
     * _.isEmpty(true);
     * // => true
     *
     * _.isEmpty(1);
     * // => true
     *
     * _.isEmpty([1, 2, 3]);
     * // => false
     *
     * _.isEmpty({ 'a': 1 });
     * // => false
     */
    function isEmpty$1(value) {
      if (value == null) {
        return true;
      }
      if (isArrayLike_1(value) &&
          (isArray_1(value) || typeof value == 'string' || typeof value.splice == 'function' ||
            isBuffer_1(value) || isTypedArray_1(value) || isArguments_1(value))) {
        return !value.length;
      }
      var tag = _getTag(value);
      if (tag == mapTag || tag == setTag) {
        return !value.size;
      }
      if (_isPrototype(value)) {
        return !_baseKeys(value).length;
      }
      for (var key in value) {
        if (hasOwnProperty$1.call(value, key)) {
          return false;
        }
      }
      return true;
    }

    var isEmpty_1 = isEmpty$1;

    const ERROR_MESSAGE = {
        INVALID_THOUGHTSPOT_HOST: 'Error parsing ThoughtSpot host. Please provide a valid URL.',
        SPOTTER_EMBED_WORKSHEED_ID_NOT_FOUND: 'Please select a worksheet to get started',
        LIVEBOARD_VIZ_ID_VALIDATION: 'Please select a Liveboard to embed.',
        TRIGGER_TIMED_OUT: 'Trigger timed-out in getting a response',
        SEARCHEMBED_BETA_WRANING_MESSAGE: 'SearchEmbed is in Beta in this release.',
        SAGE_EMBED_BETA_WARNING_MESSAGE: 'SageEmbed is in Beta in this release.',
        THIRD_PARTY_COOKIE_BLOCKED_ALERT: 'Third-party cookie access is blocked on this browser. Please allow third-party cookies for this to work properly. \nYou can use `suppressNoCookieAccessAlert` to suppress this message.',
        DUPLICATE_TOKEN_ERR: 'Duplicate token. Please issue a new token every time getAuthToken callback is called. See https://developers.thoughtspot.com/docs/?pageid=embed-auth#trusted-auth-embed for more details.',
        SDK_NOT_INITIALIZED: 'SDK not initialized',
        SESSION_INFO_FAILED: 'Failed to get session information',
        INVALID_TOKEN_ERROR: 'Received invalid token from getAuthToken callback or authToken endpoint.',
        MIXPANEL_TOKEN_NOT_FOUND: 'Mixpanel token not found in session info',
        PRERENDER_ID_MISSING: 'PreRender ID is required for preRender',
        SYNC_STYLE_CALLED_BEFORE_RENDER: 'PreRender should be called before using syncPreRenderStyle',
        CSP_VIOLATION_ALERT: 'CSP violation detected. Please check the console errors for more details.',
        CSP_FRAME_HOST_VIOLATION_LOG_MESSAGE: 'Please set up CSP correctly for the application to start working. For more information, see https://developers.thoughtspot.com/docs/security-settings#csp-viz-embed-hosts. \n If the issue persists, refer to https://developers.thoughtspot.com/docs/security-settings#csp-viz-embed-hosts',
        MISSING_REPORTING_OBSERVER: 'ReportingObserver not supported',
        RENDER_CALLED_BEFORE_INIT: 'Looks like render was called before calling init, the render won\'t start until init is called.\nFor more info check\n1. https://developers.thoughtspot.com/docs/Function_init#_init\n2.https://developers.thoughtspot.com/docs/getting-started#initSdk',
    };

    const EndPoints = {
        AUTH_VERIFICATION: '/callosum/v1/session/info',
        SESSION_INFO: '/callosum/v1/session/info',
        PREAUTH_INFO: '/prism/preauth/info',
        SAML_LOGIN_TEMPLATE: (targetUrl) => `/callosum/v1/saml/login?targetURLPath=${targetUrl}`,
        OIDC_LOGIN_TEMPLATE: (targetUrl) => `/callosum/v1/oidc/login?targetURLPath=${targetUrl}`,
        TOKEN_LOGIN: '/callosum/v1/session/login/token',
        BASIC_LOGIN: '/callosum/v1/session/login',
        LOGOUT: '/callosum/v1/session/logout',
        EXECUTE_TML: '/api/rest/2.0/metadata/tml/import',
        EXPORT_TML: '/api/rest/2.0/metadata/tml/export',
        IS_ACTIVE: '/callosum/v1/session/isactive',
    };
    /**
     *
     * @param url
     * @param options
     */
    function failureLoggedFetch(url, options = {}) {
        return fetch(url, options).then(async (r) => {
            var _a;
            if (!r.ok && r.type !== 'opaqueredirect' && r.type !== 'opaque') {
                logger$3.error('Failure', await ((_a = r.text) === null || _a === void 0 ? void 0 : _a.call(r)));
            }
            return r;
        });
    }
    /**
     * Service to validate a auth token against a ThoughtSpot host.
     * @param thoughtSpotHost : ThoughtSpot host to verify the token against.
     * @param authToken : Auth token to verify.
     */
    async function verifyTokenService(thoughtSpotHost, authToken) {
        const authVerificationUrl = `${thoughtSpotHost}${EndPoints.IS_ACTIVE}`;
        try {
            const res = await fetch(authVerificationUrl, {
                headers: {
                    Authorization: `Bearer ${authToken}`,
                    'x-requested-by': 'ThoughtSpot',
                },
                credentials: 'omit',
            });
            return res.ok;
        }
        catch (e) {
            logger$3.warn(`Token Verification Service failed : ${e.message}`);
        }
        return false;
    }
    /**
     *
     * @param authEndpoint
     */
    async function fetchAuthTokenService(authEndpoint) {
        return fetch(authEndpoint);
    }
    /**
     *
     * @param thoughtSpotHost
     * @param username
     * @param authToken
     */
    async function fetchAuthService(thoughtSpotHost, username, authToken) {
        const fetchUrlParams = username
            ? `username=${username}&auth_token=${authToken}`
            : `auth_token=${authToken}`;
        return failureLoggedFetch(`${thoughtSpotHost}${EndPoints.TOKEN_LOGIN}?${fetchUrlParams}`, {
            credentials: 'include',
            // We do not want to follow the redirect, as it starts giving a CORS
            // error
            redirect: 'manual',
        });
    }
    /**
     *
     * @param thoughtSpotHost
     * @param username
     * @param authToken
     */
    async function fetchAuthPostService(thoughtSpotHost, username, authToken) {
        const bodyPrams = username
            ? `username=${encodeURIComponent(username)}&auth_token=${encodeURIComponent(authToken)}`
            : `auth_token=${encodeURIComponent(authToken)}`;
        return failureLoggedFetch(`${thoughtSpotHost}${EndPoints.TOKEN_LOGIN}`, {
            method: 'POST',
            headers: {
                'content-type': 'application/x-www-form-urlencoded',
                'x-requested-by': 'ThoughtSpot',
            },
            body: bodyPrams,
            credentials: 'include',
            // We do not want to follow the redirect, as it starts giving a CORS
            // error
            redirect: 'manual',
        });
    }
    /**
     *
     * @param thoughtSpotHost
     * @param username
     * @param password
     */
    async function fetchBasicAuthService(thoughtSpotHost, username, password) {
        return failureLoggedFetch(`${thoughtSpotHost}${EndPoints.BASIC_LOGIN}`, {
            method: 'POST',
            headers: {
                'content-type': 'application/x-www-form-urlencoded',
                'x-requested-by': 'ThoughtSpot',
            },
            body: `username=${encodeURIComponent(username)}&password=${encodeURIComponent(password)}`,
            credentials: 'include',
        });
    }

    const cacheAuthTokenKey = 'cachedAuthToken';
    const getCacheAuthToken = () => getValueFromWindow(cacheAuthTokenKey);
    const storeAuthTokenInCache = (token) => {
        storeValueInWindow(cacheAuthTokenKey, token);
    };
    // This method can be used to get the authToken using the embedConfig
    /**
     *
     * @param embedConfig
     */
    async function getAuthenticationToken(embedConfig) {
        const cachedAuthToken = getCacheAuthToken();
        // Since we don't have token validation enabled , we cannot tell if the
        // cached token is valid or not. So we will always fetch a new token.
        if (cachedAuthToken && !embedConfig.disableTokenVerification) {
            let isCachedTokenStillValid;
            try {
                isCachedTokenStillValid = await validateAuthToken(embedConfig, cachedAuthToken, true);
            }
            catch {
                isCachedTokenStillValid = false;
            }
            if (isCachedTokenStillValid)
                return cachedAuthToken;
        }
        const { authEndpoint, getAuthToken } = embedConfig;
        let authToken = null;
        if (getAuthToken) {
            authToken = await getAuthToken();
        }
        else {
            const response = await fetchAuthTokenService(authEndpoint);
            authToken = await response.text();
        }
        try {
            // this will throw error if the token is not valid
            await validateAuthToken(embedConfig, authToken);
        }
        catch (e) {
            logger$3.error(`${ERROR_MESSAGE.INVALID_TOKEN_ERROR} Error : ${e.message}`);
            throw e;
        }
        storeAuthTokenInCache(authToken);
        return authToken;
    }
    const validateAuthToken = async (embedConfig, authToken, suppressAlert) => {
        const cachedAuthToken = getCacheAuthToken();
        if (embedConfig.disableTokenVerification) {
            logger$3.info('Token verification is disabled. Assuming token is valid.');
            return true;
        }
        try {
            const isTokenValid = await verifyTokenService(embedConfig.thoughtSpotHost, authToken);
            if (isTokenValid)
                return true;
        }
        catch {
            return false;
        }
        if (cachedAuthToken && cachedAuthToken === authToken) {
            if (!embedConfig.suppressErrorAlerts && !suppressAlert) {
                // eslint-disable-next-line no-alert
                alert(ERROR_MESSAGE.DUPLICATE_TOKEN_ERR);
            }
            throw new Error(ERROR_MESSAGE.DUPLICATE_TOKEN_ERR);
        }
        else {
            throw new Error(ERROR_MESSAGE.INVALID_TOKEN_ERROR);
        }
    };
    /**
     * Resets the auth token and a new token will be fetched on the next request.
     * @example
     * ```js
     * resetCachedAuthToken();
     * ```
     * @version SDK: 1.28.0 | ThoughtSpot: *
     * @group Authentication / Init
     */
    const resetCachedAuthToken = () => {
        storeAuthTokenInCache(null);
    };

    const configKey = 'embedConfig';
    /**
     * Gets the configuration embed was initialized with.
     * @returns {@link EmbedConfig} The configuration embed was initialized with.
     * @version SDK: 1.19.0 | ThoughtSpot: *
     * @group Global methods
     */
    const getEmbedConfig = () => getValueFromWindow(configKey) || {};
    /**
     * Sets the configuration embed was initialized with.
     * And returns the new configuration.
     * @param newConfig The configuration to set.
     * @version SDK: 1.27.0 | ThoughtSpot: *
     * @group Global methods
     */
    const setEmbedConfig = (newConfig) => {
        storeValueInWindow(configKey, newConfig);
        return getValueFromWindow(configKey);
    };

    /**
     * Fetch wrapper that adds the authentication token to the request.
     * Use this to call the ThoughtSpot APIs when using the visual embed sdk.
     * The interface for this method is the same as Web `Fetch`.
     * @param input
     * @param init
     * @example
     * ```js
     * tokenizedFetch("<TS_ORIGIN>/api/rest/2.0/auth/session/user", {
     *   // .. fetch options ..
     * });
     *```
     * @version SDK: 1.28.0
     * @group Global methods
     */
    const tokenizedFetch = async (input, init) => {
        const embedConfig = getEmbedConfig();
        if (embedConfig.authType !== exports.AuthType.TrustedAuthTokenCookieless) {
            return fetch(input, {
                // ensure cookies are included for the non cookie-less api calls.
                credentials: 'include',
                ...init,
            });
        }
        const req = new Request(input, init);
        const authToken = await getAuthenticationToken(embedConfig);
        if (authToken) {
            req.headers.append('Authorization', `Bearer ${authToken}`);
        }
        return fetch(req);
    };

    /**
     *
     * @param root0
     * @param root0.query
     * @param root0.variables
     * @param root0.thoughtSpotHost
     * @param root0.isCompositeQuery
     */
    async function graphqlQuery({ query, variables, thoughtSpotHost, isCompositeQuery = false, }) {
        const operationName = getOperationNameFromQuery(query);
        try {
            const response = await tokenizedFetch(`${thoughtSpotHost}/prism/?op=${operationName}`, {
                method: 'POST',
                headers: {
                    'content-type': 'application/json;charset=UTF-8',
                    'x-requested-by': 'ThoughtSpot',
                    accept: '*/*',
                    'accept-language': 'en-us',
                },
                body: JSON.stringify({
                    operationName,
                    query,
                    variables,
                }),
                credentials: 'include',
            });
            const result = await response.json();
            const dataValues = Object.values(result.data);
            return (isCompositeQuery) ? result.data : dataValues[0];
        }
        catch (error) {
            return error;
        }
    }

    const getSourceDetailQuery = `
    query GetSourceDetail($ids: [GUID!]!) {
        getSourceDetailById(ids: $ids, type: LOGICAL_TABLE) {
        id
        name
        description
        authorName
        authorDisplayName
        isExternal
        type
        created
        modified
        columns {
            id
            name
            author
            authorDisplayName
            description
            dataType
            type
            modified
            ownerName
            owner
            dataRecency
            sources {
            tableId
            tableName
            columnId
            columnName
            __typename
            }
            synonyms
            cohortAnswerId
            __typename
        }
        relationships
        destinationRelationships
        dataSourceId
        __typename
        }
    }  
`;
    const sourceDetailCache = new Map();
    /**
     *
     * @param thoughtSpotHost
     * @param sourceId
     */
    async function getSourceDetail(thoughtSpotHost, sourceId) {
        if (sourceDetailCache.get(sourceId)) {
            return sourceDetailCache.get(sourceId);
        }
        const details = await graphqlQuery({
            query: getSourceDetailQuery,
            variables: {
                ids: [sourceId],
            },
            thoughtSpotHost,
        });
        const souceDetails = details[0];
        if (souceDetails) {
            sourceDetailCache.set(sourceId, souceDetails);
        }
        return souceDetails;
    }

    const bachSessionId = `
id {
    sessionId
    genNo
    acSession {
        sessionId
        genNo
    }
}
`;
    const getUnaggregatedAnswerSession = `
mutation GetUnAggregatedAnswerSession($session: BachSessionIdInput!, $columns: [UserPointSelectionInput!]!) {
    Answer__getUnaggregatedAnswer(session: $session, columns: $columns) {
        ${bachSessionId}
        answer {
            visualizations {
                ... on TableViz {
                    columns {
                        column {
                            id
                            name
                            referencedColumns {
                                guid
                                displayName
                            }
                        }
                    }
                }
            }
        }
    }
}  
`;
    const removeColumns = `
mutation RemoveColumns($session: BachSessionIdInput!, $logicalColumnIds: [GUID!], $columnIds: [GUID!]) {
    Answer__removeColumns(
        session: $session
        logicalColumnIds: $logicalColumnIds
        columnIds: $columnIds
        ) {
            ${bachSessionId}
    }
}
    `;
    const addColumns = `
    mutation AddColumns($session: BachSessionIdInput!, $columns: [AnswerColumnInfo!]!) {
        Answer__addColumn(session: $session, columns: $columns) {
            ${bachSessionId}
        }
    }
    `;
    const addFilter = `
    mutation AddUpdateFilter($session: BachSessionIdInput!, $params: AddUpdateFilterInput!) {
        Answer__addUpdateFilter(session: $session, params: $params) {
            ${bachSessionId}
        }
    }
`;
    const getAnswer = `
    query GetAnswer($session: BachSessionIdInput!) {
        getAnswer(session: $session) {
            ${bachSessionId}
            answer {
                id
                name
                description
                displayMode
                sources {
                    header {
                        guid
                        displayName
                    }
                }
                filterGroups {
                    columnInfo {
                        name
                        referencedColumns {
                            guid
                            displayName
                        }
                    }
                    filters {
                        filterContent {
                            filterType
                            negate
                            value {
                                key
                            }
                        }
                    }
                }
                metadata {
                    author
                    authorId
                    createdAt
                    isDiscoverable
                    isHidden
                    modifiedAt
                }
                visualizations {
                    ... on TableViz {
                        id
                        columns {
                            column {
                                id
                                name
                                referencedColumns {
                                    guid
                                    displayName
                                }
                            }
                        }
                    }
                    ... on ChartViz {
                        id
                    }
                }
            }
        }
    }

`;
    const getAnswerData = `
    query GetTableWithHeadlineData($session: BachSessionIdInput!, $deadline: Int!, $dataPaginationParams: DataPaginationParamsInput!) {
        getAnswer(session: $session) {
            ${bachSessionId}
            answer {
                id
                visualizations {
                    id
                    ... on TableViz {
                        columns {
                            column {
                                id
                                name
                                type
                                aggregationType
                                dataType
                            }
                        }
                        data(deadline: $deadline, pagination: $dataPaginationParams)
                    }          
                }
            }
        }
    }
`;
    const addVizToLiveboard = `
    mutation AddVizToLiveboard(liveboardId: GUID!, session: BachSessionIdInput!, tabId: GUID, vizId: GUID!) {
        Answer__addVizToPinboard(
            pinboardId: liveboardId

            session: $session

            tabId: $tabId

            vizId: $vizId
        ) {
            ${bachSessionId}
        }
    }
`;
    const getSQLQuery = `
    mutation GetSQLQuery($session: BachSessionIdInput!) {
        Answer__getQuery(session: $session) {
            ${bachSessionId}
            sql
        }
    }
`;
    const getAnswerTML = `
mutation GetUnsavedAnswerTML($session: BachSessionIdInput!, $exportDependencies: Boolean, $formatType:  EDocFormatType, $exportPermissions: Boolean, $exportFqn: Boolean) {
  UnsavedAnswer_getTML(
    session: $session
    exportDependencies: $exportDependencies
    formatType: $formatType
    exportPermissions: $exportPermissions
    exportFqn: $exportFqn
  ) {
    zipFile
    object {
      edoc
      name
      type
      __typename
    }
    __typename
  }
}`;

    // import YAML from 'yaml';
    // eslint-disable-next-line no-shadow
    var OperationType;
    (function (OperationType) {
        OperationType["GetChartWithData"] = "GetChartWithData";
        OperationType["GetTableWithHeadlineData"] = "GetTableWithHeadlineData";
    })(OperationType || (OperationType = {}));
    /**
     * AnswerService provides a simple way to work with ThoughtSpot Answers.
     *
     * This service allows you to interact with ThoughtSpot Answers programmatically,
     * making it easy to customize visualizations, filter data, and extract insights
     * directly from your application.
     *
     * You can use this service to:
     * - Add or remove columns from Answers (`addColumns`, `removeColumns`, `addColumnsByName`)
     * - Apply filters to Answers (`addFilter`)
     * - Get data from Answers in different formats (JSON, CSV, PNG) (`fetchData`, `fetchCSVBlob`, `fetchPNGBlob`)
     * - Get data for specific points in visualizations (`getUnderlyingDataForPoint`)
     * - Run custom queries (`executeQuery`)
     * - Add visualizations to liveboards (`addDisplayedVizToLiveboard`)
     *
     * @example
     * ```js
     * // Get the answer service
     * embed.on(EmbedEvent.Data, async (e) => {
     *     const service = await embed.getAnswerService();
     *
     *     // Add columns to the answer
     *     await service.addColumnsByName(["Sales", "Region"]);
     *
     *     // Get the data
     *     const data = await service.fetchData();
     *     console.log(data);
     * });
     * ```
     *
     * @example
     * ```js
     * // Get data for a point in a visualization
     * embed.on(EmbedEvent.CustomAction, async (e) => {
     *     const underlying = await e.answerService.getUnderlyingDataForPoint([
     *       'Product Name',
     *       'Sales Amount'
     *     ]);
     *
     *     const data = await underlying.fetchData(0, 100);
     *     console.log(data);
     * });
     * ```
     *
     * @version SDK: 1.25.0| ThoughtSpot: 9.10.0.cl
     * @group Events
     */
    class AnswerService {
        /**
         * Should not need to be called directly.
         * @param session
         * @param answer
         * @param thoughtSpotHost
         * @param selectedPoints
         */
        constructor(session, answer, thoughtSpotHost, selectedPoints) {
            this.session = session;
            this.thoughtSpotHost = thoughtSpotHost;
            this.selectedPoints = selectedPoints;
            this.tmlOverride = {};
            this.session = removeTypename(session);
            this.answer = answer;
        }
        /**
         * Get the details about the source used in the answer.
         * This can be used to get the list of all columns in the data source for example.
         */
        async getSourceDetail() {
            const sourceId = (await this.getAnswer()).sources[0].header.guid;
            return getSourceDetail(this.thoughtSpotHost, sourceId);
        }
        /**
         * Remove columnIds and return updated answer session.
         * @param columnIds
         * @returns
         */
        async removeColumns(columnIds) {
            return this.executeQuery(removeColumns, {
                logicalColumnIds: columnIds,
            });
        }
        /**
         * Add columnIds and return updated answer session.
         * @param columnIds
         * @returns
         */
        async addColumns(columnIds) {
            return this.executeQuery(addColumns, {
                columns: columnIds.map((colId) => ({ logicalColumnId: colId })),
            });
        }
        /**
         * Add columns by names and return updated answer session.
         * @param columnNames
         * @returns
         * @example
         * ```js
         * embed.on(EmbedEvent.Data, async (e) => {
         *    const service = await embed.getAnswerService();
         *    await service.addColumnsByName([
         *      "col name 1",
         *      "col name 2"
         *    ]);
         *    console.log(await service.fetchData());
         * });
         */
        async addColumnsByName(columnNames) {
            const sourceDetail = await this.getSourceDetail();
            const columnGuids = getGuidsFromColumnNames(sourceDetail, columnNames);
            return this.addColumns([...columnGuids]);
        }
        /**
         * Add a filter to the answer.
         * @param columnName
         * @param operator
         * @param values
         * @returns
         */
        async addFilter(columnName, operator, values) {
            const sourceDetail = await this.getSourceDetail();
            const columnGuids = getGuidsFromColumnNames(sourceDetail, [columnName]);
            return this.executeQuery(addFilter, {
                params: {
                    filterContent: [{
                            filterType: operator,
                            value: values.map((v) => {
                                const [type, prefix] = getTypeFromValue(v);
                                return {
                                    type: type.toUpperCase(),
                                    [`${prefix}Value`]: v,
                                };
                            }),
                        }],
                    filterGroupId: {
                        logicalColumnId: columnGuids.values().next().value,
                    },
                },
            });
        }
        async getSQLQuery() {
            const { sql } = await this.executeQuery(getSQLQuery, {});
            return sql;
        }
        /**
         * Fetch data from the answer.
         * @param offset
         * @param size
         * @returns
         */
        async fetchData(offset = 0, size = 1000) {
            const { answer } = await this.executeQuery(getAnswerData, {
                deadline: 0,
                dataPaginationParams: {
                    isClientPaginated: true,
                    offset,
                    size,
                },
            });
            const { columns, data } = answer.visualizations.find((viz) => !!viz.data) || {};
            return {
                columns,
                data,
            };
        }
        /**
         * Fetch the data for the answer as a CSV blob. This might be
         * quicker for larger data.
         * @param userLocale
         * @param includeInfo Include the CSV header in the output
         * @returns Response
         */
        async fetchCSVBlob(userLocale = 'en-us', includeInfo = false) {
            const fetchUrl = this.getFetchCSVBlobUrl(userLocale, includeInfo);
            return tokenizedFetch(fetchUrl, {
                credentials: 'include',
            });
        }
        /**
         * Fetch the data for the answer as a PNG blob. This might be
         * quicker for larger data.
         * @param userLocale
         * @param includeInfo
         * @param omitBackground Omit the background in the PNG
         * @param deviceScaleFactor The scale factor for the PNG
         * @return Response
         */
        async fetchPNGBlob(userLocale = 'en-us', omitBackground = false, deviceScaleFactor = 2) {
            const fetchUrl = this.getFetchPNGBlobUrl(userLocale, omitBackground, deviceScaleFactor);
            return tokenizedFetch(fetchUrl, {
                credentials: 'include',
            });
        }
        /**
         * Just get the internal URL for this answer's data
         * as a CSV blob.
         * @param userLocale
         * @param includeInfo
         * @returns
         */
        getFetchCSVBlobUrl(userLocale = 'en-us', includeInfo = false) {
            return `${this.thoughtSpotHost}/prism/download/answer/csv?sessionId=${this.session.sessionId}&genNo=${this.session.genNo}&userLocale=${userLocale}&exportFileName=data&hideCsvHeader=${!includeInfo}`;
        }
        /**
         * Just get the internal URL for this answer's data
         * as a PNG blob.
         * @param userLocale
         * @param omitBackground
         * @param deviceScaleFactor
         */
        getFetchPNGBlobUrl(userLocale = 'en-us', omitBackground = false, deviceScaleFactor = 2) {
            return `${this.thoughtSpotHost}/prism/download/answer/png?sessionId=${this.session.sessionId}&deviceScaleFactor=${deviceScaleFactor}&omitBackground=${omitBackground}&genNo=${this.session.genNo}&userLocale=${userLocale}&exportFileName=data`;
        }
        /**
         * Get underlying data given a point and the output column names.
         * In case of a context menu action, the selectedPoints are
         * automatically passed.
         * @param outputColumnNames
         * @param selectedPoints
         * @example
         * ```js
         *  embed.on(EmbedEvent.CustomAction, e => {
         *     const underlying = await e.answerService.getUnderlyingDataForPoint([
         *       'col name 1' // The column should exist in the data source.
         *     ]);
         *     const data = await underlying.fetchData(0, 100);
         *  })
         * ```
         * @version SDK: 1.25.0| ThoughtSpot: 9.10.0.cl
         */
        async getUnderlyingDataForPoint(outputColumnNames, selectedPoints) {
            if (!selectedPoints && !this.selectedPoints) {
                throw new Error('Needs to be triggered in context of a point');
            }
            if (!selectedPoints) {
                selectedPoints = getSelectedPointsForUnderlyingDataQuery(this.selectedPoints);
            }
            const sourceDetail = await this.getSourceDetail();
            const ouputColumnGuids = getGuidsFromColumnNames(sourceDetail, outputColumnNames);
            const unAggAnswer = await graphqlQuery({
                query: getUnaggregatedAnswerSession,
                variables: {
                    session: this.session,
                    columns: selectedPoints,
                },
                thoughtSpotHost: this.thoughtSpotHost,
            });
            const unaggAnswerSession = new AnswerService(unAggAnswer.id, unAggAnswer.answer, this.thoughtSpotHost);
            const currentColumns = new Set(unAggAnswer.answer.visualizations[0].columns
                .map((c) => c.column.referencedColumns[0].guid));
            const columnsToAdd = [...ouputColumnGuids].filter((col) => !currentColumns.has(col));
            if (columnsToAdd.length) {
                await unaggAnswerSession.addColumns(columnsToAdd);
            }
            const columnsToRemove = [...currentColumns].filter((col) => !ouputColumnGuids.has(col));
            if (columnsToRemove.length) {
                await unaggAnswerSession.removeColumns(columnsToRemove);
            }
            return unaggAnswerSession;
        }
        /**
         * Execute a custom graphql query in the context of the answer.
         * @param query graphql query
         * @param variables graphql variables
         * @returns
         */
        async executeQuery(query, variables) {
            const data = await graphqlQuery({
                query,
                variables: {
                    session: this.session,
                    ...variables,
                },
                thoughtSpotHost: this.thoughtSpotHost,
                isCompositeQuery: false,
            });
            this.session = deepMerge(this.session, (data === null || data === void 0 ? void 0 : data.id) || {});
            return data;
        }
        /**
         * Get the internal session details for the answer.
         * @returns
         */
        getSession() {
            return this.session;
        }
        async getAnswer() {
            if (this.answer) {
                return this.answer;
            }
            this.answer = this.executeQuery(getAnswer, {}).then((data) => data === null || data === void 0 ? void 0 : data.answer);
            return this.answer;
        }
        async getTML() {
            const { object } = await this.executeQuery(getAnswerTML, {});
            const edoc = object[0].edoc;
            const YAML = await Promise.resolve().then(function () { return index; });
            const parsedDoc = YAML.parse(edoc);
            return {
                answer: {
                    ...parsedDoc.answer,
                    ...this.tmlOverride,
                },
            };
        }
        async addDisplayedVizToLiveboard(liveboardId) {
            const { displayMode, visualizations } = await this.getAnswer();
            const viz = getDisplayedViz(visualizations, displayMode);
            return this.executeQuery(addVizToLiveboard, {
                liveboardId,
                vizId: viz.id,
            });
        }
        setTMLOverride(override) {
            this.tmlOverride = override;
        }
    }
    /**
     *
     * @param sourceDetail
     * @param colNames
     */
    function getGuidsFromColumnNames(sourceDetail, colNames) {
        const cols = sourceDetail.columns.reduce((colSet, col) => {
            colSet[col.name.toLowerCase()] = col;
            return colSet;
        }, {});
        return new Set(colNames.map((colName) => {
            const col = cols[colName.toLowerCase()];
            return col.id;
        }));
    }
    /**
     *
     * @param selectedPoints
     */
    function getSelectedPointsForUnderlyingDataQuery(selectedPoints) {
        const underlyingDataPoint = [];
        /**
         *
         * @param colVal
         */
        function addPointFromColVal(colVal) {
            var _a;
            const dataType = colVal.column.dataType;
            colVal.column.id;
            let dataValue;
            if (dataType === 'DATE') {
                if (Number.isFinite(colVal.value)) {
                    dataValue = [{
                            epochRange: {
                                startEpoch: colVal.value,
                            },
                        }];
                    // Case for custom calendar.
                }
                else if ((_a = colVal.value) === null || _a === void 0 ? void 0 : _a.v) {
                    dataValue = [{
                            epochRange: {
                                startEpoch: colVal.value.v.s,
                                endEpoch: colVal.value.v.e,
                            },
                        }];
                }
            }
            else {
                dataValue = [{ value: colVal.value }];
            }
            underlyingDataPoint.push({
                columnId: colVal.column.id,
                dataValue,
            });
        }
        selectedPoints.forEach((p) => {
            p.selectedAttributes.forEach(addPointFromColVal);
        });
        return underlyingDataPoint;
    }
    /**
     *
     * @param visualizations
     * @param displayMode
     */
    function getDisplayedViz(visualizations, displayMode) {
        if (displayMode === 'CHART_MODE') {
            return visualizations.find(
            // eslint-disable-next-line no-underscore-dangle
            (viz) => viz.__typename === 'ChartViz');
        }
        return visualizations.find(
        // eslint-disable-next-line no-underscore-dangle
        (viz) => viz.__typename === 'TableViz');
    }

    /**
     * Copyright (c) 2023
     *
     * Utilities related to reading configuration objects
     * @summary Config-related utils
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    const urlRegex = new RegExp([
        '(^(https?:)//)?',
        '(([^:/?#]*)(?::([0-9]+))?)',
        '(/{0,1}[^?#]*)',
        '(\\?[^#]*|)',
        '(#.*|)$', // hash
    ].join(''));
    /**
     * Parse and construct the ThoughtSpot hostname or IP address
     * from the embed configuration object.
     * @param config
     */
    const getThoughtSpotHost = (config) => {
        if (!config.thoughtSpotHost) {
            throw new Error(ERROR_MESSAGE.INVALID_THOUGHTSPOT_HOST);
        }
        const urlParts = config.thoughtSpotHost.match(urlRegex);
        if (!urlParts) {
            throw new Error(ERROR_MESSAGE.INVALID_THOUGHTSPOT_HOST);
        }
        const protocol = urlParts[2] || window.location.protocol;
        const host = urlParts[3];
        let path = urlParts[6];
        // Lose the trailing / if any
        if (path.charAt(path.length - 1) === '/') {
            path = path.substring(0, path.length - 1);
        }
        // const urlParams = urlParts[7];
        // const hash = urlParts[8];
        return `${protocol}//${host}${path}`;
    };
    const getV2BasePath = (config) => {
        if (config.basepath) {
            return config.basepath;
        }
        const tsHost = getThoughtSpotHost(config);
        // This is to handle when e2e's. Search is run on pods for
        // comp-blink-test-pipeline with baseUrl=https://localhost:8443.
        // This is to handle when the developer is developing in their local
        // environment.
        if (tsHost.includes('://localhost') && !tsHost.includes(':8443')) {
            return '';
        }
        return 'v2';
    };
    /**
     * It is a good idea to keep URLs under 2000 chars.
     * If this is ever breached, since we pass view configuration through
     * URL params, we would like to log a warning.
     * Reference: https://stackoverflow.com/questions/417142/what-is-the-maximum-length-of-a-url-in-different-browsers
     */
    const URL_MAX_LENGTH = 2000;
    /**
     * The default CSS dimensions of the embedded app
     */
    const DEFAULT_EMBED_WIDTH = '100%';
    const DEFAULT_EMBED_HEIGHT = '100%';

    var Config = {
        DEBUG: false,
        LIB_VERSION: '2.47.0'
    };

    // since es6 imports are static and we run unit tests from the console, window won't be defined when importing this file
    var window$1;
    if (typeof(window) === 'undefined') {
        var loc = {
            hostname: ''
        };
        window$1 = {
            navigator: { userAgent: '' },
            document: {
                location: loc,
                referrer: ''
            },
            screen: { width: 0, height: 0 },
            location: loc
        };
    } else {
        window$1 = window;
    }

    /*
     * Saved references to long variable names, so that closure compiler can
     * minimize file size.
     */

    var ArrayProto = Array.prototype;
    var FuncProto = Function.prototype;
    var ObjProto = Object.prototype;
    var slice = ArrayProto.slice;
    var toString = ObjProto.toString;
    var hasOwnProperty = ObjProto.hasOwnProperty;
    var windowConsole = window$1.console;
    var navigator = window$1.navigator;
    var document$1 = window$1.document;
    var windowOpera = window$1.opera;
    var screen = window$1.screen;
    var userAgent = navigator.userAgent;
    var nativeBind = FuncProto.bind;
    var nativeForEach = ArrayProto.forEach;
    var nativeIndexOf = ArrayProto.indexOf;
    var nativeMap = ArrayProto.map;
    var nativeIsArray = Array.isArray;
    var breaker = {};
    var _ = {
        trim: function(str) {
            // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/Trim#Polyfill
            return str.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, '');
        }
    };

    // Console override
    var console$1 = {
        /** @type {function(...*)} */
        log: function() {
            if (Config.DEBUG && !_.isUndefined(windowConsole) && windowConsole) {
                try {
                    windowConsole.log.apply(windowConsole, arguments);
                } catch (err) {
                    _.each(arguments, function(arg) {
                        windowConsole.log(arg);
                    });
                }
            }
        },
        /** @type {function(...*)} */
        warn: function() {
            if (Config.DEBUG && !_.isUndefined(windowConsole) && windowConsole) {
                var args = ['Mixpanel warning:'].concat(_.toArray(arguments));
                try {
                    windowConsole.warn.apply(windowConsole, args);
                } catch (err) {
                    _.each(args, function(arg) {
                        windowConsole.warn(arg);
                    });
                }
            }
        },
        /** @type {function(...*)} */
        error: function() {
            if (Config.DEBUG && !_.isUndefined(windowConsole) && windowConsole) {
                var args = ['Mixpanel error:'].concat(_.toArray(arguments));
                try {
                    windowConsole.error.apply(windowConsole, args);
                } catch (err) {
                    _.each(args, function(arg) {
                        windowConsole.error(arg);
                    });
                }
            }
        },
        /** @type {function(...*)} */
        critical: function() {
            if (!_.isUndefined(windowConsole) && windowConsole) {
                var args = ['Mixpanel error:'].concat(_.toArray(arguments));
                try {
                    windowConsole.error.apply(windowConsole, args);
                } catch (err) {
                    _.each(args, function(arg) {
                        windowConsole.error(arg);
                    });
                }
            }
        }
    };

    var log_func_with_prefix = function(func, prefix) {
        return function() {
            arguments[0] = '[' + prefix + '] ' + arguments[0];
            return func.apply(console$1, arguments);
        };
    };
    var console_with_prefix = function(prefix) {
        return {
            log: log_func_with_prefix(console$1.log, prefix),
            error: log_func_with_prefix(console$1.error, prefix),
            critical: log_func_with_prefix(console$1.critical, prefix)
        };
    };


    // UNDERSCORE
    // Embed part of the Underscore Library
    _.bind = function(func, context) {
        var args, bound;
        if (nativeBind && func.bind === nativeBind) {
            return nativeBind.apply(func, slice.call(arguments, 1));
        }
        if (!_.isFunction(func)) {
            throw new TypeError();
        }
        args = slice.call(arguments, 2);
        bound = function() {
            if (!(this instanceof bound)) {
                return func.apply(context, args.concat(slice.call(arguments)));
            }
            var ctor = {};
            ctor.prototype = func.prototype;
            var self = new ctor();
            ctor.prototype = null;
            var result = func.apply(self, args.concat(slice.call(arguments)));
            if (Object(result) === result) {
                return result;
            }
            return self;
        };
        return bound;
    };

    /**
     * @param {*=} obj
     * @param {function(...*)=} iterator
     * @param {Object=} context
     */
    _.each = function(obj, iterator, context) {
        if (obj === null || obj === undefined) {
            return;
        }
        if (nativeForEach && obj.forEach === nativeForEach) {
            obj.forEach(iterator, context);
        } else if (obj.length === +obj.length) {
            for (var i = 0, l = obj.length; i < l; i++) {
                if (i in obj && iterator.call(context, obj[i], i, obj) === breaker) {
                    return;
                }
            }
        } else {
            for (var key in obj) {
                if (hasOwnProperty.call(obj, key)) {
                    if (iterator.call(context, obj[key], key, obj) === breaker) {
                        return;
                    }
                }
            }
        }
    };

    _.extend = function(obj) {
        _.each(slice.call(arguments, 1), function(source) {
            for (var prop in source) {
                if (source[prop] !== void 0) {
                    obj[prop] = source[prop];
                }
            }
        });
        return obj;
    };

    _.isArray = nativeIsArray || function(obj) {
        return toString.call(obj) === '[object Array]';
    };

    // from a comment on http://dbj.org/dbj/?p=286
    // fails on only one very rare and deliberate custom object:
    // var bomb = { toString : undefined, valueOf: function(o) { return "function BOMBA!"; }};
    _.isFunction = function(f) {
        try {
            return /^\s*\bfunction\b/.test(f);
        } catch (x) {
            return false;
        }
    };

    _.isArguments = function(obj) {
        return !!(obj && hasOwnProperty.call(obj, 'callee'));
    };

    _.toArray = function(iterable) {
        if (!iterable) {
            return [];
        }
        if (iterable.toArray) {
            return iterable.toArray();
        }
        if (_.isArray(iterable)) {
            return slice.call(iterable);
        }
        if (_.isArguments(iterable)) {
            return slice.call(iterable);
        }
        return _.values(iterable);
    };

    _.map = function(arr, callback, context) {
        if (nativeMap && arr.map === nativeMap) {
            return arr.map(callback, context);
        } else {
            var results = [];
            _.each(arr, function(item) {
                results.push(callback.call(context, item));
            });
            return results;
        }
    };

    _.keys = function(obj) {
        var results = [];
        if (obj === null) {
            return results;
        }
        _.each(obj, function(value, key) {
            results[results.length] = key;
        });
        return results;
    };

    _.values = function(obj) {
        var results = [];
        if (obj === null) {
            return results;
        }
        _.each(obj, function(value) {
            results[results.length] = value;
        });
        return results;
    };

    _.include = function(obj, target) {
        var found = false;
        if (obj === null) {
            return found;
        }
        if (nativeIndexOf && obj.indexOf === nativeIndexOf) {
            return obj.indexOf(target) != -1;
        }
        _.each(obj, function(value) {
            if (found || (found = (value === target))) {
                return breaker;
            }
        });
        return found;
    };

    _.includes = function(str, needle) {
        return str.indexOf(needle) !== -1;
    };

    // Underscore Addons
    _.inherit = function(subclass, superclass) {
        subclass.prototype = new superclass();
        subclass.prototype.constructor = subclass;
        subclass.superclass = superclass.prototype;
        return subclass;
    };

    _.isObject = function(obj) {
        return (obj === Object(obj) && !_.isArray(obj));
    };

    _.isEmptyObject = function(obj) {
        if (_.isObject(obj)) {
            for (var key in obj) {
                if (hasOwnProperty.call(obj, key)) {
                    return false;
                }
            }
            return true;
        }
        return false;
    };

    _.isUndefined = function(obj) {
        return obj === void 0;
    };

    _.isString = function(obj) {
        return toString.call(obj) == '[object String]';
    };

    _.isDate = function(obj) {
        return toString.call(obj) == '[object Date]';
    };

    _.isNumber = function(obj) {
        return toString.call(obj) == '[object Number]';
    };

    _.isElement = function(obj) {
        return !!(obj && obj.nodeType === 1);
    };

    _.encodeDates = function(obj) {
        _.each(obj, function(v, k) {
            if (_.isDate(v)) {
                obj[k] = _.formatDate(v);
            } else if (_.isObject(v)) {
                obj[k] = _.encodeDates(v); // recurse
            }
        });
        return obj;
    };

    _.timestamp = function() {
        Date.now = Date.now || function() {
            return +new Date;
        };
        return Date.now();
    };

    _.formatDate = function(d) {
        // YYYY-MM-DDTHH:MM:SS in UTC
        function pad(n) {
            return n < 10 ? '0' + n : n;
        }
        return d.getUTCFullYear() + '-' +
            pad(d.getUTCMonth() + 1) + '-' +
            pad(d.getUTCDate()) + 'T' +
            pad(d.getUTCHours()) + ':' +
            pad(d.getUTCMinutes()) + ':' +
            pad(d.getUTCSeconds());
    };

    _.strip_empty_properties = function(p) {
        var ret = {};
        _.each(p, function(v, k) {
            if (_.isString(v) && v.length > 0) {
                ret[k] = v;
            }
        });
        return ret;
    };

    /*
     * this function returns a copy of object after truncating it.  If
     * passed an Array or Object it will iterate through obj and
     * truncate all the values recursively.
     */
    _.truncate = function(obj, length) {
        var ret;

        if (typeof(obj) === 'string') {
            ret = obj.slice(0, length);
        } else if (_.isArray(obj)) {
            ret = [];
            _.each(obj, function(val) {
                ret.push(_.truncate(val, length));
            });
        } else if (_.isObject(obj)) {
            ret = {};
            _.each(obj, function(val, key) {
                ret[key] = _.truncate(val, length);
            });
        } else {
            ret = obj;
        }

        return ret;
    };

    _.JSONEncode = (function() {
        return function(mixed_val) {
            var value = mixed_val;
            var quote = function(string) {
                var escapable = /[\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g; // eslint-disable-line no-control-regex
                var meta = { // table of character substitutions
                    '\b': '\\b',
                    '\t': '\\t',
                    '\n': '\\n',
                    '\f': '\\f',
                    '\r': '\\r',
                    '"': '\\"',
                    '\\': '\\\\'
                };

                escapable.lastIndex = 0;
                return escapable.test(string) ?
                    '"' + string.replace(escapable, function(a) {
                        var c = meta[a];
                        return typeof c === 'string' ? c :
                            '\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
                    }) + '"' :
                    '"' + string + '"';
            };

            var str = function(key, holder) {
                var gap = '';
                var indent = '    ';
                var i = 0; // The loop counter.
                var k = ''; // The member key.
                var v = ''; // The member value.
                var length = 0;
                var mind = gap;
                var partial = [];
                var value = holder[key];

                // If the value has a toJSON method, call it to obtain a replacement value.
                if (value && typeof value === 'object' &&
                    typeof value.toJSON === 'function') {
                    value = value.toJSON(key);
                }

                // What happens next depends on the value's type.
                switch (typeof value) {
                    case 'string':
                        return quote(value);

                    case 'number':
                        // JSON numbers must be finite. Encode non-finite numbers as null.
                        return isFinite(value) ? String(value) : 'null';

                    case 'boolean':
                    case 'null':
                        // If the value is a boolean or null, convert it to a string. Note:
                        // typeof null does not produce 'null'. The case is included here in
                        // the remote chance that this gets fixed someday.

                        return String(value);

                    case 'object':
                        // If the type is 'object', we might be dealing with an object or an array or
                        // null.
                        // Due to a specification blunder in ECMAScript, typeof null is 'object',
                        // so watch out for that case.
                        if (!value) {
                            return 'null';
                        }

                        // Make an array to hold the partial results of stringifying this object value.
                        gap += indent;
                        partial = [];

                        // Is the value an array?
                        if (toString.apply(value) === '[object Array]') {
                            // The value is an array. Stringify every element. Use null as a placeholder
                            // for non-JSON values.

                            length = value.length;
                            for (i = 0; i < length; i += 1) {
                                partial[i] = str(i, value) || 'null';
                            }

                            // Join all of the elements together, separated with commas, and wrap them in
                            // brackets.
                            v = partial.length === 0 ? '[]' :
                                gap ? '[\n' + gap +
                                partial.join(',\n' + gap) + '\n' +
                                mind + ']' :
                                    '[' + partial.join(',') + ']';
                            gap = mind;
                            return v;
                        }

                        // Iterate through all of the keys in the object.
                        for (k in value) {
                            if (hasOwnProperty.call(value, k)) {
                                v = str(k, value);
                                if (v) {
                                    partial.push(quote(k) + (gap ? ': ' : ':') + v);
                                }
                            }
                        }

                        // Join all of the member texts together, separated with commas,
                        // and wrap them in braces.
                        v = partial.length === 0 ? '{}' :
                            gap ? '{' + partial.join(',') + '' +
                            mind + '}' : '{' + partial.join(',') + '}';
                        gap = mind;
                        return v;
                }
            };

            // Make a fake root object containing our value under the key of ''.
            // Return the result of stringifying the value.
            return str('', {
                '': value
            });
        };
    })();

    /**
     * From https://github.com/douglascrockford/JSON-js/blob/master/json_parse.js
     * Slightly modified to throw a real Error rather than a POJO
     */
    _.JSONDecode = (function() {
        var at, // The index of the current character
            ch, // The current character
            escapee = {
                '"': '"',
                '\\': '\\',
                '/': '/',
                'b': '\b',
                'f': '\f',
                'n': '\n',
                'r': '\r',
                't': '\t'
            },
            text,
            error = function(m) {
                var e = new SyntaxError(m);
                e.at = at;
                e.text = text;
                throw e;
            },
            next = function(c) {
                // If a c parameter is provided, verify that it matches the current character.
                if (c && c !== ch) {
                    error('Expected \'' + c + '\' instead of \'' + ch + '\'');
                }
                // Get the next character. When there are no more characters,
                // return the empty string.
                ch = text.charAt(at);
                at += 1;
                return ch;
            },
            number = function() {
                // Parse a number value.
                var number,
                    string = '';

                if (ch === '-') {
                    string = '-';
                    next('-');
                }
                while (ch >= '0' && ch <= '9') {
                    string += ch;
                    next();
                }
                if (ch === '.') {
                    string += '.';
                    while (next() && ch >= '0' && ch <= '9') {
                        string += ch;
                    }
                }
                if (ch === 'e' || ch === 'E') {
                    string += ch;
                    next();
                    if (ch === '-' || ch === '+') {
                        string += ch;
                        next();
                    }
                    while (ch >= '0' && ch <= '9') {
                        string += ch;
                        next();
                    }
                }
                number = +string;
                if (!isFinite(number)) {
                    error('Bad number');
                } else {
                    return number;
                }
            },

            string = function() {
                // Parse a string value.
                var hex,
                    i,
                    string = '',
                    uffff;
                // When parsing for string values, we must look for " and \ characters.
                if (ch === '"') {
                    while (next()) {
                        if (ch === '"') {
                            next();
                            return string;
                        }
                        if (ch === '\\') {
                            next();
                            if (ch === 'u') {
                                uffff = 0;
                                for (i = 0; i < 4; i += 1) {
                                    hex = parseInt(next(), 16);
                                    if (!isFinite(hex)) {
                                        break;
                                    }
                                    uffff = uffff * 16 + hex;
                                }
                                string += String.fromCharCode(uffff);
                            } else if (typeof escapee[ch] === 'string') {
                                string += escapee[ch];
                            } else {
                                break;
                            }
                        } else {
                            string += ch;
                        }
                    }
                }
                error('Bad string');
            },
            white = function() {
                // Skip whitespace.
                while (ch && ch <= ' ') {
                    next();
                }
            },
            word = function() {
                // true, false, or null.
                switch (ch) {
                    case 't':
                        next('t');
                        next('r');
                        next('u');
                        next('e');
                        return true;
                    case 'f':
                        next('f');
                        next('a');
                        next('l');
                        next('s');
                        next('e');
                        return false;
                    case 'n':
                        next('n');
                        next('u');
                        next('l');
                        next('l');
                        return null;
                }
                error('Unexpected "' + ch + '"');
            },
            value, // Placeholder for the value function.
            array = function() {
                // Parse an array value.
                var array = [];

                if (ch === '[') {
                    next('[');
                    white();
                    if (ch === ']') {
                        next(']');
                        return array; // empty array
                    }
                    while (ch) {
                        array.push(value());
                        white();
                        if (ch === ']') {
                            next(']');
                            return array;
                        }
                        next(',');
                        white();
                    }
                }
                error('Bad array');
            },
            object = function() {
                // Parse an object value.
                var key,
                    object = {};

                if (ch === '{') {
                    next('{');
                    white();
                    if (ch === '}') {
                        next('}');
                        return object; // empty object
                    }
                    while (ch) {
                        key = string();
                        white();
                        next(':');
                        if (Object.hasOwnProperty.call(object, key)) {
                            error('Duplicate key "' + key + '"');
                        }
                        object[key] = value();
                        white();
                        if (ch === '}') {
                            next('}');
                            return object;
                        }
                        next(',');
                        white();
                    }
                }
                error('Bad object');
            };

        value = function() {
            // Parse a JSON value. It could be an object, an array, a string,
            // a number, or a word.
            white();
            switch (ch) {
                case '{':
                    return object();
                case '[':
                    return array();
                case '"':
                    return string();
                case '-':
                    return number();
                default:
                    return ch >= '0' && ch <= '9' ? number() : word();
            }
        };

        // Return the json_parse function. It will have access to all of the
        // above functions and variables.
        return function(source) {
            var result;

            text = source;
            at = 0;
            ch = ' ';
            result = value();
            white();
            if (ch) {
                error('Syntax error');
            }

            return result;
        };
    })();

    _.base64Encode = function(data) {
        var b64 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';
        var o1, o2, o3, h1, h2, h3, h4, bits, i = 0,
            ac = 0,
            enc = '',
            tmp_arr = [];

        if (!data) {
            return data;
        }

        data = _.utf8Encode(data);

        do { // pack three octets into four hexets
            o1 = data.charCodeAt(i++);
            o2 = data.charCodeAt(i++);
            o3 = data.charCodeAt(i++);

            bits = o1 << 16 | o2 << 8 | o3;

            h1 = bits >> 18 & 0x3f;
            h2 = bits >> 12 & 0x3f;
            h3 = bits >> 6 & 0x3f;
            h4 = bits & 0x3f;

            // use hexets to index into b64, and append result to encoded string
            tmp_arr[ac++] = b64.charAt(h1) + b64.charAt(h2) + b64.charAt(h3) + b64.charAt(h4);
        } while (i < data.length);

        enc = tmp_arr.join('');

        switch (data.length % 3) {
            case 1:
                enc = enc.slice(0, -2) + '==';
                break;
            case 2:
                enc = enc.slice(0, -1) + '=';
                break;
        }

        return enc;
    };

    _.utf8Encode = function(string) {
        string = (string + '').replace(/\r\n/g, '\n').replace(/\r/g, '\n');

        var utftext = '',
            start,
            end;
        var stringl = 0,
            n;

        start = end = 0;
        stringl = string.length;

        for (n = 0; n < stringl; n++) {
            var c1 = string.charCodeAt(n);
            var enc = null;

            if (c1 < 128) {
                end++;
            } else if ((c1 > 127) && (c1 < 2048)) {
                enc = String.fromCharCode((c1 >> 6) | 192, (c1 & 63) | 128);
            } else {
                enc = String.fromCharCode((c1 >> 12) | 224, ((c1 >> 6) & 63) | 128, (c1 & 63) | 128);
            }
            if (enc !== null) {
                if (end > start) {
                    utftext += string.substring(start, end);
                }
                utftext += enc;
                start = end = n + 1;
            }
        }

        if (end > start) {
            utftext += string.substring(start, string.length);
        }

        return utftext;
    };

    _.UUID = (function() {

        // Time-based entropy
        var T = function() {
            var time = 1 * new Date(); // cross-browser version of Date.now()
            var ticks;
            if (window$1.performance && window$1.performance.now) {
                ticks = window$1.performance.now();
            } else {
                // fall back to busy loop
                ticks = 0;

                // this while loop figures how many browser ticks go by
                // before 1*new Date() returns a new number, ie the amount
                // of ticks that go by per millisecond
                while (time == 1 * new Date()) {
                    ticks++;
                }
            }
            return time.toString(16) + Math.floor(ticks).toString(16);
        };

        // Math.Random entropy
        var R = function() {
            return Math.random().toString(16).replace('.', '');
        };

        // User agent entropy
        // This function takes the user agent string, and then xors
        // together each sequence of 8 bytes.  This produces a final
        // sequence of 8 bytes which it returns as hex.
        var UA = function() {
            var ua = userAgent,
                i, ch, buffer = [],
                ret = 0;

            function xor(result, byte_array) {
                var j, tmp = 0;
                for (j = 0; j < byte_array.length; j++) {
                    tmp |= (buffer[j] << j * 8);
                }
                return result ^ tmp;
            }

            for (i = 0; i < ua.length; i++) {
                ch = ua.charCodeAt(i);
                buffer.unshift(ch & 0xFF);
                if (buffer.length >= 4) {
                    ret = xor(ret, buffer);
                    buffer = [];
                }
            }

            if (buffer.length > 0) {
                ret = xor(ret, buffer);
            }

            return ret.toString(16);
        };

        return function() {
            var se = (screen.height * screen.width).toString(16);
            return (T() + '-' + R() + '-' + UA() + '-' + se + '-' + T());
        };
    })();

    // _.isBlockedUA()
    // This is to block various web spiders from executing our JS and
    // sending false tracking data
    var BLOCKED_UA_STRS = [
        'ahrefsbot',
        'baiduspider',
        'bingbot',
        'bingpreview',
        'facebookexternal',
        'petalbot',
        'pinterest',
        'screaming frog',
        'yahoo! slurp',
        'yandexbot',

        // a whole bunch of goog-specific crawlers
        // https://developers.google.com/search/docs/advanced/crawling/overview-google-crawlers
        'adsbot-google',
        'apis-google',
        'duplexweb-google',
        'feedfetcher-google',
        'google favicon',
        'google web preview',
        'google-read-aloud',
        'googlebot',
        'googleweblight',
        'mediapartners-google',
        'storebot-google'
    ];
    _.isBlockedUA = function(ua) {
        var i;
        ua = ua.toLowerCase();
        for (i = 0; i < BLOCKED_UA_STRS.length; i++) {
            if (ua.indexOf(BLOCKED_UA_STRS[i]) !== -1) {
                return true;
            }
        }
        return false;
    };

    /**
     * @param {Object=} formdata
     * @param {string=} arg_separator
     */
    _.HTTPBuildQuery = function(formdata, arg_separator) {
        var use_val, use_key, tmp_arr = [];

        if (_.isUndefined(arg_separator)) {
            arg_separator = '&';
        }

        _.each(formdata, function(val, key) {
            use_val = encodeURIComponent(val.toString());
            use_key = encodeURIComponent(key);
            tmp_arr[tmp_arr.length] = use_key + '=' + use_val;
        });

        return tmp_arr.join(arg_separator);
    };

    _.getQueryParam = function(url, param) {
        // Expects a raw URL

        param = param.replace(/[[]/, '\\[').replace(/[\]]/, '\\]');
        var regexS = '[\\?&]' + param + '=([^&#]*)',
            regex = new RegExp(regexS),
            results = regex.exec(url);
        if (results === null || (results && typeof(results[1]) !== 'string' && results[1].length)) {
            return '';
        } else {
            var result = results[1];
            try {
                result = decodeURIComponent(result);
            } catch(err) {
                console$1.error('Skipping decoding for malformed query param: ' + result);
            }
            return result.replace(/\+/g, ' ');
        }
    };


    // _.cookie
    // Methods partially borrowed from quirksmode.org/js/cookies.html
    _.cookie = {
        get: function(name) {
            var nameEQ = name + '=';
            var ca = document$1.cookie.split(';');
            for (var i = 0; i < ca.length; i++) {
                var c = ca[i];
                while (c.charAt(0) == ' ') {
                    c = c.substring(1, c.length);
                }
                if (c.indexOf(nameEQ) === 0) {
                    return decodeURIComponent(c.substring(nameEQ.length, c.length));
                }
            }
            return null;
        },

        parse: function(name) {
            var cookie;
            try {
                cookie = _.JSONDecode(_.cookie.get(name)) || {};
            } catch (err) {
                // noop
            }
            return cookie;
        },

        set_seconds: function(name, value, seconds, is_cross_subdomain, is_secure, is_cross_site, domain_override) {
            var cdomain = '',
                expires = '',
                secure = '';

            if (domain_override) {
                cdomain = '; domain=' + domain_override;
            } else if (is_cross_subdomain) {
                var domain = extract_domain(document$1.location.hostname);
                cdomain = domain ? '; domain=.' + domain : '';
            }

            if (seconds) {
                var date = new Date();
                date.setTime(date.getTime() + (seconds * 1000));
                expires = '; expires=' + date.toGMTString();
            }

            if (is_cross_site) {
                is_secure = true;
                secure = '; SameSite=None';
            }
            if (is_secure) {
                secure += '; secure';
            }

            document$1.cookie = name + '=' + encodeURIComponent(value) + expires + '; path=/' + cdomain + secure;
        },

        set: function(name, value, days, is_cross_subdomain, is_secure, is_cross_site, domain_override) {
            var cdomain = '', expires = '', secure = '';

            if (domain_override) {
                cdomain = '; domain=' + domain_override;
            } else if (is_cross_subdomain) {
                var domain = extract_domain(document$1.location.hostname);
                cdomain = domain ? '; domain=.' + domain : '';
            }

            if (days) {
                var date = new Date();
                date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
                expires = '; expires=' + date.toGMTString();
            }

            if (is_cross_site) {
                is_secure = true;
                secure = '; SameSite=None';
            }
            if (is_secure) {
                secure += '; secure';
            }

            var new_cookie_val = name + '=' + encodeURIComponent(value) + expires + '; path=/' + cdomain + secure;
            document$1.cookie = new_cookie_val;
            return new_cookie_val;
        },

        remove: function(name, is_cross_subdomain, domain_override) {
            _.cookie.set(name, '', -1, is_cross_subdomain, false, false, domain_override);
        }
    };

    var _localStorageSupported = null;
    var localStorageSupported = function(storage, forceCheck) {
        if (_localStorageSupported !== null && !forceCheck) {
            return _localStorageSupported;
        }

        var supported = true;
        try {
            storage = storage || window.localStorage;
            var key = '__mplss_' + cheap_guid(8),
                val = 'xyz';
            storage.setItem(key, val);
            if (storage.getItem(key) !== val) {
                supported = false;
            }
            storage.removeItem(key);
        } catch (err) {
            supported = false;
        }

        _localStorageSupported = supported;
        return supported;
    };

    // _.localStorage
    _.localStorage = {
        is_supported: function(force_check) {
            var supported = localStorageSupported(null, force_check);
            if (!supported) {
                console$1.error('localStorage unsupported; falling back to cookie store');
            }
            return supported;
        },

        error: function(msg) {
            console$1.error('localStorage error: ' + msg);
        },

        get: function(name) {
            try {
                return window.localStorage.getItem(name);
            } catch (err) {
                _.localStorage.error(err);
            }
            return null;
        },

        parse: function(name) {
            try {
                return _.JSONDecode(_.localStorage.get(name)) || {};
            } catch (err) {
                // noop
            }
            return null;
        },

        set: function(name, value) {
            try {
                window.localStorage.setItem(name, value);
            } catch (err) {
                _.localStorage.error(err);
            }
        },

        remove: function(name) {
            try {
                window.localStorage.removeItem(name);
            } catch (err) {
                _.localStorage.error(err);
            }
        }
    };

    _.register_event = (function() {
        // written by Dean Edwards, 2005
        // with input from Tino Zijdel - crisp@xs4all.nl
        // with input from Carl Sverre - mail@carlsverre.com
        // with input from Mixpanel
        // http://dean.edwards.name/weblog/2005/10/add-event/
        // https://gist.github.com/1930440

        /**
         * @param {Object} element
         * @param {string} type
         * @param {function(...*)} handler
         * @param {boolean=} oldSchool
         * @param {boolean=} useCapture
         */
        var register_event = function(element, type, handler, oldSchool, useCapture) {
            if (!element) {
                console$1.error('No valid element provided to register_event');
                return;
            }

            if (element.addEventListener && !oldSchool) {
                element.addEventListener(type, handler, !!useCapture);
            } else {
                var ontype = 'on' + type;
                var old_handler = element[ontype]; // can be undefined
                element[ontype] = makeHandler(element, handler, old_handler);
            }
        };

        function makeHandler(element, new_handler, old_handlers) {
            var handler = function(event) {
                event = event || fixEvent(window.event);

                // this basically happens in firefox whenever another script
                // overwrites the onload callback and doesn't pass the event
                // object to previously defined callbacks.  All the browsers
                // that don't define window.event implement addEventListener
                // so the dom_loaded handler will still be fired as usual.
                if (!event) {
                    return undefined;
                }

                var ret = true;
                var old_result, new_result;

                if (_.isFunction(old_handlers)) {
                    old_result = old_handlers(event);
                }
                new_result = new_handler.call(element, event);

                if ((false === old_result) || (false === new_result)) {
                    ret = false;
                }

                return ret;
            };

            return handler;
        }

        function fixEvent(event) {
            if (event) {
                event.preventDefault = fixEvent.preventDefault;
                event.stopPropagation = fixEvent.stopPropagation;
            }
            return event;
        }
        fixEvent.preventDefault = function() {
            this.returnValue = false;
        };
        fixEvent.stopPropagation = function() {
            this.cancelBubble = true;
        };

        return register_event;
    })();


    var TOKEN_MATCH_REGEX = new RegExp('^(\\w*)\\[(\\w+)([=~\\|\\^\\$\\*]?)=?"?([^\\]"]*)"?\\]$');

    _.dom_query = (function() {
        /* document.getElementsBySelector(selector)
        - returns an array of element objects from the current document
        matching the CSS selector. Selectors can contain element names,
        class names and ids and can be nested. For example:

        elements = document.getElementsBySelector('div#main p a.external')

        Will return an array of all 'a' elements with 'external' in their
        class attribute that are contained inside 'p' elements that are
        contained inside the 'div' element which has id="main"

        New in version 0.4: Support for CSS2 and CSS3 attribute selectors:
        See http://www.w3.org/TR/css3-selectors/#attribute-selectors

        Version 0.4 - Simon Willison, March 25th 2003
        -- Works in Phoenix 0.5, Mozilla 1.3, Opera 7, Internet Explorer 6, Internet Explorer 5 on Windows
        -- Opera 7 fails

        Version 0.5 - Carl Sverre, Jan 7th 2013
        -- Now uses jQuery-esque `hasClass` for testing class name
        equality.  This fixes a bug related to '-' characters being
        considered not part of a 'word' in regex.
        */

        function getAllChildren(e) {
            // Returns all children of element. Workaround required for IE5/Windows. Ugh.
            return e.all ? e.all : e.getElementsByTagName('*');
        }

        var bad_whitespace = /[\t\r\n]/g;

        function hasClass(elem, selector) {
            var className = ' ' + selector + ' ';
            return ((' ' + elem.className + ' ').replace(bad_whitespace, ' ').indexOf(className) >= 0);
        }

        function getElementsBySelector(selector) {
            // Attempt to fail gracefully in lesser browsers
            if (!document$1.getElementsByTagName) {
                return [];
            }
            // Split selector in to tokens
            var tokens = selector.split(' ');
            var token, bits, tagName, found, foundCount, i, j, k, elements, currentContextIndex;
            var currentContext = [document$1];
            for (i = 0; i < tokens.length; i++) {
                token = tokens[i].replace(/^\s+/, '').replace(/\s+$/, '');
                if (token.indexOf('#') > -1) {
                    // Token is an ID selector
                    bits = token.split('#');
                    tagName = bits[0];
                    var id = bits[1];
                    var element = document$1.getElementById(id);
                    if (!element || (tagName && element.nodeName.toLowerCase() != tagName)) {
                        // element not found or tag with that ID not found, return false
                        return [];
                    }
                    // Set currentContext to contain just this element
                    currentContext = [element];
                    continue; // Skip to next token
                }
                if (token.indexOf('.') > -1) {
                    // Token contains a class selector
                    bits = token.split('.');
                    tagName = bits[0];
                    var className = bits[1];
                    if (!tagName) {
                        tagName = '*';
                    }
                    // Get elements matching tag, filter them for class selector
                    found = [];
                    foundCount = 0;
                    for (j = 0; j < currentContext.length; j++) {
                        if (tagName == '*') {
                            elements = getAllChildren(currentContext[j]);
                        } else {
                            elements = currentContext[j].getElementsByTagName(tagName);
                        }
                        for (k = 0; k < elements.length; k++) {
                            found[foundCount++] = elements[k];
                        }
                    }
                    currentContext = [];
                    currentContextIndex = 0;
                    for (j = 0; j < found.length; j++) {
                        if (found[j].className &&
                            _.isString(found[j].className) && // some SVG elements have classNames which are not strings
                            hasClass(found[j], className)
                        ) {
                            currentContext[currentContextIndex++] = found[j];
                        }
                    }
                    continue; // Skip to next token
                }
                // Code to deal with attribute selectors
                var token_match = token.match(TOKEN_MATCH_REGEX);
                if (token_match) {
                    tagName = token_match[1];
                    var attrName = token_match[2];
                    var attrOperator = token_match[3];
                    var attrValue = token_match[4];
                    if (!tagName) {
                        tagName = '*';
                    }
                    // Grab all of the tagName elements within current context
                    found = [];
                    foundCount = 0;
                    for (j = 0; j < currentContext.length; j++) {
                        if (tagName == '*') {
                            elements = getAllChildren(currentContext[j]);
                        } else {
                            elements = currentContext[j].getElementsByTagName(tagName);
                        }
                        for (k = 0; k < elements.length; k++) {
                            found[foundCount++] = elements[k];
                        }
                    }
                    currentContext = [];
                    currentContextIndex = 0;
                    var checkFunction; // This function will be used to filter the elements
                    switch (attrOperator) {
                        case '=': // Equality
                            checkFunction = function(e) {
                                return (e.getAttribute(attrName) == attrValue);
                            };
                            break;
                        case '~': // Match one of space seperated words
                            checkFunction = function(e) {
                                return (e.getAttribute(attrName).match(new RegExp('\\b' + attrValue + '\\b')));
                            };
                            break;
                        case '|': // Match start with value followed by optional hyphen
                            checkFunction = function(e) {
                                return (e.getAttribute(attrName).match(new RegExp('^' + attrValue + '-?')));
                            };
                            break;
                        case '^': // Match starts with value
                            checkFunction = function(e) {
                                return (e.getAttribute(attrName).indexOf(attrValue) === 0);
                            };
                            break;
                        case '$': // Match ends with value - fails with "Warning" in Opera 7
                            checkFunction = function(e) {
                                return (e.getAttribute(attrName).lastIndexOf(attrValue) == e.getAttribute(attrName).length - attrValue.length);
                            };
                            break;
                        case '*': // Match ends with value
                            checkFunction = function(e) {
                                return (e.getAttribute(attrName).indexOf(attrValue) > -1);
                            };
                            break;
                        default:
                            // Just test for existence of attribute
                            checkFunction = function(e) {
                                return e.getAttribute(attrName);
                            };
                    }
                    currentContext = [];
                    currentContextIndex = 0;
                    for (j = 0; j < found.length; j++) {
                        if (checkFunction(found[j])) {
                            currentContext[currentContextIndex++] = found[j];
                        }
                    }
                    // alert('Attribute Selector: '+tagName+' '+attrName+' '+attrOperator+' '+attrValue);
                    continue; // Skip to next token
                }
                // If we get here, token is JUST an element (not a class or ID selector)
                tagName = token;
                found = [];
                foundCount = 0;
                for (j = 0; j < currentContext.length; j++) {
                    elements = currentContext[j].getElementsByTagName(tagName);
                    for (k = 0; k < elements.length; k++) {
                        found[foundCount++] = elements[k];
                    }
                }
                currentContext = found;
            }
            return currentContext;
        }

        return function(query) {
            if (_.isElement(query)) {
                return [query];
            } else if (_.isObject(query) && !_.isUndefined(query.length)) {
                return query;
            } else {
                return getElementsBySelector.call(this, query);
            }
        };
    })();

    var CAMPAIGN_KEYWORDS = ['utm_source', 'utm_medium', 'utm_campaign', 'utm_content', 'utm_term'];
    var CLICK_IDS = ['dclid', 'fbclid', 'gclid', 'ko_click_id', 'li_fat_id', 'msclkid', 'ttclid', 'twclid', 'wbraid'];

    _.info = {
        campaignParams: function(default_value) {
            var kw = '',
                params = {};
            _.each(CAMPAIGN_KEYWORDS, function(kwkey) {
                kw = _.getQueryParam(document$1.URL, kwkey);
                if (kw.length) {
                    params[kwkey] = kw;
                } else if (default_value !== undefined) {
                    params[kwkey] = default_value;
                }
            });

            return params;
        },

        clickParams: function() {
            var id = '',
                params = {};
            _.each(CLICK_IDS, function(idkey) {
                id = _.getQueryParam(document$1.URL, idkey);
                if (id.length) {
                    params[idkey] = id;
                }
            });

            return params;
        },

        marketingParams: function() {
            return _.extend(_.info.campaignParams(), _.info.clickParams());
        },

        searchEngine: function(referrer) {
            if (referrer.search('https?://(.*)google.([^/?]*)') === 0) {
                return 'google';
            } else if (referrer.search('https?://(.*)bing.com') === 0) {
                return 'bing';
            } else if (referrer.search('https?://(.*)yahoo.com') === 0) {
                return 'yahoo';
            } else if (referrer.search('https?://(.*)duckduckgo.com') === 0) {
                return 'duckduckgo';
            } else {
                return null;
            }
        },

        searchInfo: function(referrer) {
            var search = _.info.searchEngine(referrer),
                param = (search != 'yahoo') ? 'q' : 'p',
                ret = {};

            if (search !== null) {
                ret['$search_engine'] = search;

                var keyword = _.getQueryParam(referrer, param);
                if (keyword.length) {
                    ret['mp_keyword'] = keyword;
                }
            }

            return ret;
        },

        /**
         * This function detects which browser is running this script.
         * The order of the checks are important since many user agents
         * include key words used in later checks.
         */
        browser: function(user_agent, vendor, opera) {
            vendor = vendor || ''; // vendor is undefined for at least IE9
            if (opera || _.includes(user_agent, ' OPR/')) {
                if (_.includes(user_agent, 'Mini')) {
                    return 'Opera Mini';
                }
                return 'Opera';
            } else if (/(BlackBerry|PlayBook|BB10)/i.test(user_agent)) {
                return 'BlackBerry';
            } else if (_.includes(user_agent, 'IEMobile') || _.includes(user_agent, 'WPDesktop')) {
                return 'Internet Explorer Mobile';
            } else if (_.includes(user_agent, 'SamsungBrowser/')) {
                // https://developer.samsung.com/internet/user-agent-string-format
                return 'Samsung Internet';
            } else if (_.includes(user_agent, 'Edge') || _.includes(user_agent, 'Edg/')) {
                return 'Microsoft Edge';
            } else if (_.includes(user_agent, 'FBIOS')) {
                return 'Facebook Mobile';
            } else if (_.includes(user_agent, 'Chrome')) {
                return 'Chrome';
            } else if (_.includes(user_agent, 'CriOS')) {
                return 'Chrome iOS';
            } else if (_.includes(user_agent, 'UCWEB') || _.includes(user_agent, 'UCBrowser')) {
                return 'UC Browser';
            } else if (_.includes(user_agent, 'FxiOS')) {
                return 'Firefox iOS';
            } else if (_.includes(vendor, 'Apple')) {
                if (_.includes(user_agent, 'Mobile')) {
                    return 'Mobile Safari';
                }
                return 'Safari';
            } else if (_.includes(user_agent, 'Android')) {
                return 'Android Mobile';
            } else if (_.includes(user_agent, 'Konqueror')) {
                return 'Konqueror';
            } else if (_.includes(user_agent, 'Firefox')) {
                return 'Firefox';
            } else if (_.includes(user_agent, 'MSIE') || _.includes(user_agent, 'Trident/')) {
                return 'Internet Explorer';
            } else if (_.includes(user_agent, 'Gecko')) {
                return 'Mozilla';
            } else {
                return '';
            }
        },

        /**
         * This function detects which browser version is running this script,
         * parsing major and minor version (e.g., 42.1). User agent strings from:
         * http://www.useragentstring.com/pages/useragentstring.php
         */
        browserVersion: function(userAgent, vendor, opera) {
            var browser = _.info.browser(userAgent, vendor, opera);
            var versionRegexs = {
                'Internet Explorer Mobile': /rv:(\d+(\.\d+)?)/,
                'Microsoft Edge': /Edge?\/(\d+(\.\d+)?)/,
                'Chrome': /Chrome\/(\d+(\.\d+)?)/,
                'Chrome iOS': /CriOS\/(\d+(\.\d+)?)/,
                'UC Browser' : /(UCBrowser|UCWEB)\/(\d+(\.\d+)?)/,
                'Safari': /Version\/(\d+(\.\d+)?)/,
                'Mobile Safari': /Version\/(\d+(\.\d+)?)/,
                'Opera': /(Opera|OPR)\/(\d+(\.\d+)?)/,
                'Firefox': /Firefox\/(\d+(\.\d+)?)/,
                'Firefox iOS': /FxiOS\/(\d+(\.\d+)?)/,
                'Konqueror': /Konqueror:(\d+(\.\d+)?)/,
                'BlackBerry': /BlackBerry (\d+(\.\d+)?)/,
                'Android Mobile': /android\s(\d+(\.\d+)?)/,
                'Samsung Internet': /SamsungBrowser\/(\d+(\.\d+)?)/,
                'Internet Explorer': /(rv:|MSIE )(\d+(\.\d+)?)/,
                'Mozilla': /rv:(\d+(\.\d+)?)/
            };
            var regex = versionRegexs[browser];
            if (regex === undefined) {
                return null;
            }
            var matches = userAgent.match(regex);
            if (!matches) {
                return null;
            }
            return parseFloat(matches[matches.length - 2]);
        },

        os: function() {
            var a = userAgent;
            if (/Windows/i.test(a)) {
                if (/Phone/.test(a) || /WPDesktop/.test(a)) {
                    return 'Windows Phone';
                }
                return 'Windows';
            } else if (/(iPhone|iPad|iPod)/.test(a)) {
                return 'iOS';
            } else if (/Android/.test(a)) {
                return 'Android';
            } else if (/(BlackBerry|PlayBook|BB10)/i.test(a)) {
                return 'BlackBerry';
            } else if (/Mac/i.test(a)) {
                return 'Mac OS X';
            } else if (/Linux/.test(a)) {
                return 'Linux';
            } else if (/CrOS/.test(a)) {
                return 'Chrome OS';
            } else {
                return '';
            }
        },

        device: function(user_agent) {
            if (/Windows Phone/i.test(user_agent) || /WPDesktop/.test(user_agent)) {
                return 'Windows Phone';
            } else if (/iPad/.test(user_agent)) {
                return 'iPad';
            } else if (/iPod/.test(user_agent)) {
                return 'iPod Touch';
            } else if (/iPhone/.test(user_agent)) {
                return 'iPhone';
            } else if (/(BlackBerry|PlayBook|BB10)/i.test(user_agent)) {
                return 'BlackBerry';
            } else if (/Android/.test(user_agent)) {
                return 'Android';
            } else {
                return '';
            }
        },

        referringDomain: function(referrer) {
            var split = referrer.split('/');
            if (split.length >= 3) {
                return split[2];
            }
            return '';
        },

        properties: function() {
            return _.extend(_.strip_empty_properties({
                '$os': _.info.os(),
                '$browser': _.info.browser(userAgent, navigator.vendor, windowOpera),
                '$referrer': document$1.referrer,
                '$referring_domain': _.info.referringDomain(document$1.referrer),
                '$device': _.info.device(userAgent)
            }), {
                '$current_url': window$1.location.href,
                '$browser_version': _.info.browserVersion(userAgent, navigator.vendor, windowOpera),
                '$screen_height': screen.height,
                '$screen_width': screen.width,
                'mp_lib': 'web',
                '$lib_version': Config.LIB_VERSION,
                '$insert_id': cheap_guid(),
                'time': _.timestamp() / 1000 // epoch time in seconds
            });
        },

        people_properties: function() {
            return _.extend(_.strip_empty_properties({
                '$os': _.info.os(),
                '$browser': _.info.browser(userAgent, navigator.vendor, windowOpera)
            }), {
                '$browser_version': _.info.browserVersion(userAgent, navigator.vendor, windowOpera)
            });
        },

        mpPageViewProperties: function() {
            return _.strip_empty_properties({
                'current_page_title': document$1.title,
                'current_domain': window$1.location.hostname,
                'current_url_path': window$1.location.pathname,
                'current_url_protocol': window$1.location.protocol,
                'current_url_search': window$1.location.search
            });
        }
    };

    var cheap_guid = function(maxlen) {
        var guid = Math.random().toString(36).substring(2, 10) + Math.random().toString(36).substring(2, 10);
        return maxlen ? guid.substring(0, maxlen) : guid;
    };

    // naive way to extract domain name (example.com) from full hostname (my.sub.example.com)
    var SIMPLE_DOMAIN_MATCH_REGEX = /[a-z0-9][a-z0-9-]*\.[a-z]+$/i;
    // this next one attempts to account for some ccSLDs, e.g. extracting oxford.ac.uk from www.oxford.ac.uk
    var DOMAIN_MATCH_REGEX = /[a-z0-9][a-z0-9-]+\.[a-z.]{2,6}$/i;
    /**
     * Attempts to extract main domain name from full hostname, using a few blunt heuristics. For
     * common TLDs like .com/.org that always have a simple SLD.TLD structure (example.com), we
     * simply extract the last two .-separated parts of the hostname (SIMPLE_DOMAIN_MATCH_REGEX).
     * For others, we attempt to account for short ccSLD+TLD combos (.ac.uk) with the legacy
     * DOMAIN_MATCH_REGEX (kept to maintain backwards compatibility with existing Mixpanel
     * integrations). The only _reliable_ way to extract domain from hostname is with an up-to-date
     * list like at https://publicsuffix.org/ so for cases that this helper fails at, the SDK
     * offers the 'cookie_domain' config option to set it explicitly.
     * @example
     * extract_domain('my.sub.example.com')
     * // 'example.com'
     */
    var extract_domain = function(hostname) {
        var domain_regex = DOMAIN_MATCH_REGEX;
        var parts = hostname.split('.');
        var tld = parts[parts.length - 1];
        if (tld.length > 4 || tld === 'com' || tld === 'org') {
            domain_regex = SIMPLE_DOMAIN_MATCH_REGEX;
        }
        var matches = hostname.match(domain_regex);
        return matches ? matches[0] : '';
    };

    var JSONStringify = null;
    var JSONParse = null;
    if (typeof JSON !== 'undefined') {
        JSONStringify = JSON.stringify;
        JSONParse = JSON.parse;
    }
    JSONStringify = JSONStringify || _.JSONEncode;
    JSONParse = JSONParse || _.JSONDecode;

    // EXPORTS (for closure compiler)
    _['toArray']                = _.toArray;
    _['isObject']               = _.isObject;
    _['JSONEncode']             = _.JSONEncode;
    _['JSONDecode']             = _.JSONDecode;
    _['isBlockedUA']            = _.isBlockedUA;
    _['isEmptyObject']          = _.isEmptyObject;
    _['info']                   = _.info;
    _['info']['device']         = _.info.device;
    _['info']['browser']        = _.info.browser;
    _['info']['browserVersion'] = _.info.browserVersion;
    _['info']['properties']     = _.info.properties;

    /**
     * DomTracker Object
     * @constructor
     */
    var DomTracker = function() {};


    // interface
    DomTracker.prototype.create_properties = function() {};
    DomTracker.prototype.event_handler = function() {};
    DomTracker.prototype.after_track_handler = function() {};

    DomTracker.prototype.init = function(mixpanel_instance) {
        this.mp = mixpanel_instance;
        return this;
    };

    /**
     * @param {Object|string} query
     * @param {string} event_name
     * @param {Object=} properties
     * @param {function=} user_callback
     */
    DomTracker.prototype.track = function(query, event_name, properties, user_callback) {
        var that = this;
        var elements = _.dom_query(query);

        if (elements.length === 0) {
            console$1.error('The DOM query (' + query + ') returned 0 elements');
            return;
        }

        _.each(elements, function(element) {
            _.register_event(element, this.override_event, function(e) {
                var options = {};
                var props = that.create_properties(properties, this);
                var timeout = that.mp.get_config('track_links_timeout');

                that.event_handler(e, this, options);

                // in case the mixpanel servers don't get back to us in time
                window.setTimeout(that.track_callback(user_callback, props, options, true), timeout);

                // fire the tracking event
                that.mp.track(event_name, props, that.track_callback(user_callback, props, options));
            });
        }, this);

        return true;
    };

    /**
     * @param {function} user_callback
     * @param {Object} props
     * @param {boolean=} timeout_occured
     */
    DomTracker.prototype.track_callback = function(user_callback, props, options, timeout_occured) {
        timeout_occured = timeout_occured || false;
        var that = this;

        return function() {
            // options is referenced from both callbacks, so we can have
            // a 'lock' of sorts to ensure only one fires
            if (options.callback_fired) { return; }
            options.callback_fired = true;

            if (user_callback && user_callback(timeout_occured, props) === false) {
                // user can prevent the default functionality by
                // returning false from their callback
                return;
            }

            that.after_track_handler(props, options, timeout_occured);
        };
    };

    DomTracker.prototype.create_properties = function(properties, element) {
        var props;

        if (typeof(properties) === 'function') {
            props = properties(element);
        } else {
            props = _.extend({}, properties);
        }

        return props;
    };

    /**
     * LinkTracker Object
     * @constructor
     * @extends DomTracker
     */
    var LinkTracker = function() {
        this.override_event = 'click';
    };
    _.inherit(LinkTracker, DomTracker);

    LinkTracker.prototype.create_properties = function(properties, element) {
        var props = LinkTracker.superclass.create_properties.apply(this, arguments);

        if (element.href) { props['url'] = element.href; }

        return props;
    };

    LinkTracker.prototype.event_handler = function(evt, element, options) {
        options.new_tab = (
            evt.which === 2 ||
            evt.metaKey ||
            evt.ctrlKey ||
            element.target === '_blank'
        );
        options.href = element.href;

        if (!options.new_tab) {
            evt.preventDefault();
        }
    };

    LinkTracker.prototype.after_track_handler = function(props, options) {
        if (options.new_tab) { return; }

        setTimeout(function() {
            window.location = options.href;
        }, 0);
    };

    /**
     * FormTracker Object
     * @constructor
     * @extends DomTracker
     */
    var FormTracker = function() {
        this.override_event = 'submit';
    };
    _.inherit(FormTracker, DomTracker);

    FormTracker.prototype.event_handler = function(evt, element, options) {
        options.element = element;
        evt.preventDefault();
    };

    FormTracker.prototype.after_track_handler = function(props, options) {
        setTimeout(function() {
            options.element.submit();
        }, 0);
    };

    // eslint-disable-line camelcase

    var logger$2 = console_with_prefix('lock');

    /**
     * SharedLock: a mutex built on HTML5 localStorage, to ensure that only one browser
     * window/tab at a time will be able to access shared resources.
     *
     * Based on the Alur and Taubenfeld fast lock
     * (http://www.cs.rochester.edu/research/synchronization/pseudocode/fastlock.html)
     * with an added timeout to ensure there will be eventual progress in the event
     * that a window is closed in the middle of the callback.
     *
     * Implementation based on the original version by David Wolever (https://github.com/wolever)
     * at https://gist.github.com/wolever/5fd7573d1ef6166e8f8c4af286a69432.
     *
     * @example
     * const myLock = new SharedLock('some-key');
     * myLock.withLock(function() {
     *   console.log('I hold the mutex!');
     * });
     *
     * @constructor
     */
    var SharedLock = function(key, options) {
        options = options || {};

        this.storageKey = key;
        this.storage = options.storage || window.localStorage;
        this.pollIntervalMS = options.pollIntervalMS || 100;
        this.timeoutMS = options.timeoutMS || 2000;
    };

    // pass in a specific pid to test contention scenarios; otherwise
    // it is chosen randomly for each acquisition attempt
    SharedLock.prototype.withLock = function(lockedCB, errorCB, pid) {
        if (!pid && typeof errorCB !== 'function') {
            pid = errorCB;
            errorCB = null;
        }

        var i = pid || (new Date().getTime() + '|' + Math.random());
        var startTime = new Date().getTime();

        var key = this.storageKey;
        var pollIntervalMS = this.pollIntervalMS;
        var timeoutMS = this.timeoutMS;
        var storage = this.storage;

        var keyX = key + ':X';
        var keyY = key + ':Y';
        var keyZ = key + ':Z';

        var reportError = function(err) {
            errorCB && errorCB(err);
        };

        var delay = function(cb) {
            if (new Date().getTime() - startTime > timeoutMS) {
                logger$2.error('Timeout waiting for mutex on ' + key + '; clearing lock. [' + i + ']');
                storage.removeItem(keyZ);
                storage.removeItem(keyY);
                loop();
                return;
            }
            setTimeout(function() {
                try {
                    cb();
                } catch(err) {
                    reportError(err);
                }
            }, pollIntervalMS * (Math.random() + 0.1));
        };

        var waitFor = function(predicate, cb) {
            if (predicate()) {
                cb();
            } else {
                delay(function() {
                    waitFor(predicate, cb);
                });
            }
        };

        var getSetY = function() {
            var valY = storage.getItem(keyY);
            if (valY && valY !== i) { // if Y == i then this process already has the lock (useful for test cases)
                return false;
            } else {
                storage.setItem(keyY, i);
                if (storage.getItem(keyY) === i) {
                    return true;
                } else {
                    if (!localStorageSupported(storage, true)) {
                        throw new Error('localStorage support dropped while acquiring lock');
                    }
                    return false;
                }
            }
        };

        var loop = function() {
            storage.setItem(keyX, i);

            waitFor(getSetY, function() {
                if (storage.getItem(keyX) === i) {
                    criticalSection();
                    return;
                }

                delay(function() {
                    if (storage.getItem(keyY) !== i) {
                        loop();
                        return;
                    }
                    waitFor(function() {
                        return !storage.getItem(keyZ);
                    }, criticalSection);
                });
            });
        };

        var criticalSection = function() {
            storage.setItem(keyZ, '1');
            try {
                lockedCB();
            } finally {
                storage.removeItem(keyZ);
                if (storage.getItem(keyY) === i) {
                    storage.removeItem(keyY);
                }
                if (storage.getItem(keyX) === i) {
                    storage.removeItem(keyX);
                }
            }
        };

        try {
            if (localStorageSupported(storage, true)) {
                loop();
            } else {
                throw new Error('localStorage support check failed');
            }
        } catch(err) {
            reportError(err);
        }
    };

    // eslint-disable-line camelcase

    var logger$1 = console_with_prefix('batch');

    /**
     * RequestQueue: queue for batching API requests with localStorage backup for retries.
     * Maintains an in-memory queue which represents the source of truth for the current
     * page, but also writes all items out to a copy in the browser's localStorage, which
     * can be read on subsequent pageloads and retried. For batchability, all the request
     * items in the queue should be of the same type (events, people updates, group updates)
     * so they can be sent in a single request to the same API endpoint.
     *
     * LocalStorage keying and locking: In order for reloads and subsequent pageloads of
     * the same site to access the same persisted data, they must share the same localStorage
     * key (for instance based on project token and queue type). Therefore access to the
     * localStorage entry is guarded by an asynchronous mutex (SharedLock) to prevent
     * simultaneously open windows/tabs from overwriting each other's data (which would lead
     * to data loss in some situations).
     * @constructor
     */
    var RequestQueue = function(storageKey, options) {
        options = options || {};
        this.storageKey = storageKey;
        this.storage = options.storage || window.localStorage;
        this.reportError = options.errorReporter || _.bind(logger$1.error, logger$1);
        this.lock = new SharedLock(storageKey, {storage: this.storage});

        this.pid = options.pid || null; // pass pid to test out storage lock contention scenarios

        this.memQueue = [];
    };

    /**
     * Add one item to queues (memory and localStorage). The queued entry includes
     * the given item along with an auto-generated ID and a "flush-after" timestamp.
     * It is expected that the item will be sent over the network and dequeued
     * before the flush-after time; if this doesn't happen it is considered orphaned
     * (e.g., the original tab where it was enqueued got closed before it could be
     * sent) and the item can be sent by any tab that finds it in localStorage.
     *
     * The final callback param is called with a param indicating success or
     * failure of the enqueue operation; it is asynchronous because the localStorage
     * lock is asynchronous.
     */
    RequestQueue.prototype.enqueue = function(item, flushInterval, cb) {
        var queueEntry = {
            'id': cheap_guid(),
            'flushAfter': new Date().getTime() + flushInterval * 2,
            'payload': item
        };

        this.lock.withLock(_.bind(function lockAcquired() {
            var succeeded;
            try {
                var storedQueue = this.readFromStorage();
                storedQueue.push(queueEntry);
                succeeded = this.saveToStorage(storedQueue);
                if (succeeded) {
                    // only add to in-memory queue when storage succeeds
                    this.memQueue.push(queueEntry);
                }
            } catch(err) {
                this.reportError('Error enqueueing item', item);
                succeeded = false;
            }
            if (cb) {
                cb(succeeded);
            }
        }, this), _.bind(function lockFailure(err) {
            this.reportError('Error acquiring storage lock', err);
            if (cb) {
                cb(false);
            }
        }, this), this.pid);
    };

    /**
     * Read out the given number of queue entries. If this.memQueue
     * has fewer than batchSize items, then look for "orphaned" items
     * in the persisted queue (items where the 'flushAfter' time has
     * already passed).
     */
    RequestQueue.prototype.fillBatch = function(batchSize) {
        var batch = this.memQueue.slice(0, batchSize);
        if (batch.length < batchSize) {
            // don't need lock just to read events; localStorage is thread-safe
            // and the worst that could happen is a duplicate send of some
            // orphaned events, which will be deduplicated on the server side
            var storedQueue = this.readFromStorage();
            if (storedQueue.length) {
                // item IDs already in batch; don't duplicate out of storage
                var idsInBatch = {}; // poor man's Set
                _.each(batch, function(item) { idsInBatch[item['id']] = true; });

                for (var i = 0; i < storedQueue.length; i++) {
                    var item = storedQueue[i];
                    if (new Date().getTime() > item['flushAfter'] && !idsInBatch[item['id']]) {
                        item.orphaned = true;
                        batch.push(item);
                        if (batch.length >= batchSize) {
                            break;
                        }
                    }
                }
            }
        }
        return batch;
    };

    /**
     * Remove items with matching 'id' from array (immutably)
     * also remove any item without a valid id (e.g., malformed
     * storage entries).
     */
    var filterOutIDsAndInvalid = function(items, idSet) {
        var filteredItems = [];
        _.each(items, function(item) {
            if (item['id'] && !idSet[item['id']]) {
                filteredItems.push(item);
            }
        });
        return filteredItems;
    };

    /**
     * Remove items with matching IDs from both in-memory queue
     * and persisted queue
     */
    RequestQueue.prototype.removeItemsByID = function(ids, cb) {
        var idSet = {}; // poor man's Set
        _.each(ids, function(id) { idSet[id] = true; });

        this.memQueue = filterOutIDsAndInvalid(this.memQueue, idSet);

        var removeFromStorage = _.bind(function() {
            var succeeded;
            try {
                var storedQueue = this.readFromStorage();
                storedQueue = filterOutIDsAndInvalid(storedQueue, idSet);
                succeeded = this.saveToStorage(storedQueue);

                // an extra check: did storage report success but somehow
                // the items are still there?
                if (succeeded) {
                    storedQueue = this.readFromStorage();
                    for (var i = 0; i < storedQueue.length; i++) {
                        var item = storedQueue[i];
                        if (item['id'] && !!idSet[item['id']]) {
                            this.reportError('Item not removed from storage');
                            return false;
                        }
                    }
                }
            } catch(err) {
                this.reportError('Error removing items', ids);
                succeeded = false;
            }
            return succeeded;
        }, this);

        this.lock.withLock(function lockAcquired() {
            var succeeded = removeFromStorage();
            if (cb) {
                cb(succeeded);
            }
        }, _.bind(function lockFailure(err) {
            var succeeded = false;
            this.reportError('Error acquiring storage lock', err);
            if (!localStorageSupported(this.storage, true)) {
                // Looks like localStorage writes have stopped working sometime after
                // initialization (probably full), and so nobody can acquire locks
                // anymore. Consider it temporarily safe to remove items without the
                // lock, since nobody's writing successfully anyway.
                succeeded = removeFromStorage();
                if (!succeeded) {
                    // OK, we couldn't even write out the smaller queue. Try clearing it
                    // entirely.
                    try {
                        this.storage.removeItem(this.storageKey);
                    } catch(err) {
                        this.reportError('Error clearing queue', err);
                    }
                }
            }
            if (cb) {
                cb(succeeded);
            }
        }, this), this.pid);
    };

    // internal helper for RequestQueue.updatePayloads
    var updatePayloads = function(existingItems, itemsToUpdate) {
        var newItems = [];
        _.each(existingItems, function(item) {
            var id = item['id'];
            if (id in itemsToUpdate) {
                var newPayload = itemsToUpdate[id];
                if (newPayload !== null) {
                    item['payload'] = newPayload;
                    newItems.push(item);
                }
            } else {
                // no update
                newItems.push(item);
            }
        });
        return newItems;
    };

    /**
     * Update payloads of given items in both in-memory queue and
     * persisted queue. Items set to null are removed from queues.
     */
    RequestQueue.prototype.updatePayloads = function(itemsToUpdate, cb) {
        this.memQueue = updatePayloads(this.memQueue, itemsToUpdate);
        this.lock.withLock(_.bind(function lockAcquired() {
            var succeeded;
            try {
                var storedQueue = this.readFromStorage();
                storedQueue = updatePayloads(storedQueue, itemsToUpdate);
                succeeded = this.saveToStorage(storedQueue);
            } catch(err) {
                this.reportError('Error updating items', itemsToUpdate);
                succeeded = false;
            }
            if (cb) {
                cb(succeeded);
            }
        }, this), _.bind(function lockFailure(err) {
            this.reportError('Error acquiring storage lock', err);
            if (cb) {
                cb(false);
            }
        }, this), this.pid);
    };

    /**
     * Read and parse items array from localStorage entry, handling
     * malformed/missing data if necessary.
     */
    RequestQueue.prototype.readFromStorage = function() {
        var storageEntry;
        try {
            storageEntry = this.storage.getItem(this.storageKey);
            if (storageEntry) {
                storageEntry = JSONParse(storageEntry);
                if (!_.isArray(storageEntry)) {
                    this.reportError('Invalid storage entry:', storageEntry);
                    storageEntry = null;
                }
            }
        } catch (err) {
            this.reportError('Error retrieving queue', err);
            storageEntry = null;
        }
        return storageEntry || [];
    };

    /**
     * Serialize the given items array to localStorage.
     */
    RequestQueue.prototype.saveToStorage = function(queue) {
        try {
            this.storage.setItem(this.storageKey, JSONStringify(queue));
            return true;
        } catch (err) {
            this.reportError('Error saving queue', err);
            return false;
        }
    };

    /**
     * Clear out queues (memory and localStorage).
     */
    RequestQueue.prototype.clear = function() {
        this.memQueue = [];
        this.storage.removeItem(this.storageKey);
    };

    // eslint-disable-line camelcase

    // maximum interval between request retries after exponential backoff
    var MAX_RETRY_INTERVAL_MS = 10 * 60 * 1000; // 10 minutes

    var logger = console_with_prefix('batch');

    /**
     * RequestBatcher: manages the queueing, flushing, retry etc of requests of one
     * type (events, people, groups).
     * Uses RequestQueue to manage the backing store.
     * @constructor
     */
    var RequestBatcher = function(storageKey, options) {
        this.errorReporter = options.errorReporter;
        this.queue = new RequestQueue(storageKey, {
            errorReporter: _.bind(this.reportError, this),
            storage: options.storage
        });

        this.libConfig = options.libConfig;
        this.sendRequest = options.sendRequestFunc;
        this.beforeSendHook = options.beforeSendHook;
        this.stopAllBatching = options.stopAllBatchingFunc;

        // seed variable batch size + flush interval with configured values
        this.batchSize = this.libConfig['batch_size'];
        this.flushInterval = this.libConfig['batch_flush_interval_ms'];

        this.stopped = !this.libConfig['batch_autostart'];
        this.consecutiveRemovalFailures = 0;

        // extra client-side dedupe
        this.itemIdsSentSuccessfully = {};
    };

    /**
     * Add one item to queue.
     */
    RequestBatcher.prototype.enqueue = function(item, cb) {
        this.queue.enqueue(item, this.flushInterval, cb);
    };

    /**
     * Start flushing batches at the configured time interval. Must call
     * this method upon SDK init in order to send anything over the network.
     */
    RequestBatcher.prototype.start = function() {
        this.stopped = false;
        this.consecutiveRemovalFailures = 0;
        this.flush();
    };

    /**
     * Stop flushing batches. Can be restarted by calling start().
     */
    RequestBatcher.prototype.stop = function() {
        this.stopped = true;
        if (this.timeoutID) {
            clearTimeout(this.timeoutID);
            this.timeoutID = null;
        }
    };

    /**
     * Clear out queue.
     */
    RequestBatcher.prototype.clear = function() {
        this.queue.clear();
    };

    /**
     * Restore batch size configuration to whatever is set in the main SDK.
     */
    RequestBatcher.prototype.resetBatchSize = function() {
        this.batchSize = this.libConfig['batch_size'];
    };

    /**
     * Restore flush interval time configuration to whatever is set in the main SDK.
     */
    RequestBatcher.prototype.resetFlush = function() {
        this.scheduleFlush(this.libConfig['batch_flush_interval_ms']);
    };

    /**
     * Schedule the next flush in the given number of milliseconds.
     */
    RequestBatcher.prototype.scheduleFlush = function(flushMS) {
        this.flushInterval = flushMS;
        if (!this.stopped) { // don't schedule anymore if batching has been stopped
            this.timeoutID = setTimeout(_.bind(this.flush, this), this.flushInterval);
        }
    };

    /**
     * Flush one batch to network. Depending on success/failure modes, it will either
     * remove the batch from the queue or leave it in for retry, and schedule the next
     * flush. In cases of most network or API failures, it will back off exponentially
     * when retrying.
     * @param {Object} [options]
     * @param {boolean} [options.sendBeacon] - whether to send batch with
     * navigator.sendBeacon (only useful for sending batches before page unloads, as
     * sendBeacon offers no callbacks or status indications)
     */
    RequestBatcher.prototype.flush = function(options) {
        try {

            if (this.requestInProgress) {
                logger.log('Flush: Request already in progress');
                return;
            }

            options = options || {};
            var timeoutMS = this.libConfig['batch_request_timeout_ms'];
            var startTime = new Date().getTime();
            var currentBatchSize = this.batchSize;
            var batch = this.queue.fillBatch(currentBatchSize);
            var dataForRequest = [];
            var transformedItems = {};
            _.each(batch, function(item) {
                var payload = item['payload'];
                if (this.beforeSendHook && !item.orphaned) {
                    payload = this.beforeSendHook(payload);
                }
                if (payload) {
                    // mp_sent_by_lib_version prop captures which lib version actually
                    // sends each event (regardless of which version originally queued
                    // it for sending)
                    if (payload['event'] && payload['properties']) {
                        payload['properties'] = _.extend(
                            {},
                            payload['properties'],
                            {'mp_sent_by_lib_version': Config.LIB_VERSION}
                        );
                    }
                    var addPayload = true;
                    var itemId = item['id'];
                    if (itemId) {
                        if ((this.itemIdsSentSuccessfully[itemId] || 0) > 5) {
                            this.reportError('[dupe] item ID sent too many times, not sending', {
                                item: item,
                                batchSize: batch.length,
                                timesSent: this.itemIdsSentSuccessfully[itemId]
                            });
                            addPayload = false;
                        }
                    } else {
                        this.reportError('[dupe] found item with no ID', {item: item});
                    }

                    if (addPayload) {
                        dataForRequest.push(payload);
                    }
                }
                transformedItems[item['id']] = payload;
            }, this);
            if (dataForRequest.length < 1) {
                this.resetFlush();
                return; // nothing to do
            }

            this.requestInProgress = true;

            var batchSendCallback = _.bind(function(res) {
                this.requestInProgress = false;

                try {

                    // handle API response in a try-catch to make sure we can reset the
                    // flush operation if something goes wrong

                    var removeItemsFromQueue = false;
                    if (options.unloading) {
                        // update persisted data to include hook transformations
                        this.queue.updatePayloads(transformedItems);
                    } else if (
                        _.isObject(res) &&
                        res.error === 'timeout' &&
                        new Date().getTime() - startTime >= timeoutMS
                    ) {
                        this.reportError('Network timeout; retrying');
                        this.flush();
                    } else if (
                        _.isObject(res) &&
                        res.xhr_req &&
                        (res.xhr_req['status'] >= 500 || res.xhr_req['status'] === 429 || res.error === 'timeout')
                    ) {
                        // network or API error, or 429 Too Many Requests, retry
                        var retryMS = this.flushInterval * 2;
                        var headers = res.xhr_req['responseHeaders'];
                        if (headers) {
                            var retryAfter = headers['Retry-After'];
                            if (retryAfter) {
                                retryMS = (parseInt(retryAfter, 10) * 1000) || retryMS;
                            }
                        }
                        retryMS = Math.min(MAX_RETRY_INTERVAL_MS, retryMS);
                        this.reportError('Error; retry in ' + retryMS + ' ms');
                        this.scheduleFlush(retryMS);
                    } else if (_.isObject(res) && res.xhr_req && res.xhr_req['status'] === 413) {
                        // 413 Payload Too Large
                        if (batch.length > 1) {
                            var halvedBatchSize = Math.max(1, Math.floor(currentBatchSize / 2));
                            this.batchSize = Math.min(this.batchSize, halvedBatchSize, batch.length - 1);
                            this.reportError('413 response; reducing batch size to ' + this.batchSize);
                            this.resetFlush();
                        } else {
                            this.reportError('Single-event request too large; dropping', batch);
                            this.resetBatchSize();
                            removeItemsFromQueue = true;
                        }
                    } else {
                        // successful network request+response; remove each item in batch from queue
                        // (even if it was e.g. a 400, in which case retrying won't help)
                        removeItemsFromQueue = true;
                    }

                    if (removeItemsFromQueue) {
                        this.queue.removeItemsByID(
                            _.map(batch, function(item) { return item['id']; }),
                            _.bind(function(succeeded) {
                                if (succeeded) {
                                    this.consecutiveRemovalFailures = 0;
                                    this.flush(); // handle next batch if the queue isn't empty
                                } else {
                                    this.reportError('Failed to remove items from queue');
                                    if (++this.consecutiveRemovalFailures > 5) {
                                        this.reportError('Too many queue failures; disabling batching system.');
                                        this.stopAllBatching();
                                    } else {
                                        this.resetFlush();
                                    }
                                }
                            }, this)
                        );

                        // client-side dedupe
                        _.each(batch, _.bind(function(item) {
                            var itemId = item['id'];
                            if (itemId) {
                                this.itemIdsSentSuccessfully[itemId] = this.itemIdsSentSuccessfully[itemId] || 0;
                                this.itemIdsSentSuccessfully[itemId]++;
                                if (this.itemIdsSentSuccessfully[itemId] > 5) {
                                    this.reportError('[dupe] item ID sent too many times', {
                                        item: item,
                                        batchSize: batch.length,
                                        timesSent: this.itemIdsSentSuccessfully[itemId]
                                    });
                                }
                            } else {
                                this.reportError('[dupe] found item with no ID while removing', {item: item});
                            }
                        }, this));
                    }

                } catch(err) {
                    this.reportError('Error handling API response', err);
                    this.resetFlush();
                }
            }, this);
            var requestOptions = {
                method: 'POST',
                verbose: true,
                ignore_json_errors: true, // eslint-disable-line camelcase
                timeout_ms: timeoutMS // eslint-disable-line camelcase
            };
            if (options.unloading) {
                requestOptions.transport = 'sendBeacon';
            }
            logger.log('MIXPANEL REQUEST:', dataForRequest);
            this.sendRequest(dataForRequest, requestOptions, batchSendCallback);

        } catch(err) {
            this.reportError('Error flushing request queue', err);
            this.resetFlush();
        }
    };

    /**
     * Log error to global logger and optional user-defined logger.
     */
    RequestBatcher.prototype.reportError = function(msg, err) {
        logger.error.apply(logger.error, arguments);
        if (this.errorReporter) {
            try {
                if (!(err instanceof Error)) {
                    err = new Error(msg);
                }
                this.errorReporter(msg, err);
            } catch(err) {
                logger.error(err);
            }
        }
    };

    /**
     * A function used to track a Mixpanel event (e.g. MixpanelLib.track)
     * @callback trackFunction
     * @param {String} event_name The name of the event. This can be anything the user does - 'Button Click', 'Sign Up', 'Item Purchased', etc.
     * @param {Object} [properties] A set of properties to include with the event you're sending. These describe the user who did the event or details about the event itself.
     * @param {Function} [callback] If provided, the callback function will be called after tracking the event.
     */

    /** Public **/

    var GDPR_DEFAULT_PERSISTENCE_PREFIX = '__mp_opt_in_out_';

    /**
     * Opt the user in to data tracking and cookies/localstorage for the given token
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {trackFunction} [options.track] - function used for tracking a Mixpanel event to record the opt-in action
     * @param {string} [options.trackEventName] - event name to be used for tracking the opt-in action
     * @param {Object} [options.trackProperties] - set of properties to be tracked along with the opt-in action
     * @param {string} [options.persistenceType] Persistence mechanism used - cookie or localStorage
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookieExpiration] - number of days until the opt-in cookie expires
     * @param {string} [options.cookieDomain] - custom cookie domain
     * @param {boolean} [options.crossSiteCookie] - whether the opt-in cookie is set as cross-site-enabled
     * @param {boolean} [options.crossSubdomainCookie] - whether the opt-in cookie is set as cross-subdomain or not
     * @param {boolean} [options.secureCookie] - whether the opt-in cookie is set as secure or not
     */
    function optIn(token, options) {
        _optInOut(true, token, options);
    }

    /**
     * Opt the user out of data tracking and cookies/localstorage for the given token
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {string} [options.persistenceType] Persistence mechanism used - cookie or localStorage
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookieExpiration] - number of days until the opt-out cookie expires
     * @param {string} [options.cookieDomain] - custom cookie domain
     * @param {boolean} [options.crossSiteCookie] - whether the opt-in cookie is set as cross-site-enabled
     * @param {boolean} [options.crossSubdomainCookie] - whether the opt-out cookie is set as cross-subdomain or not
     * @param {boolean} [options.secureCookie] - whether the opt-out cookie is set as secure or not
     */
    function optOut(token, options) {
        _optInOut(false, token, options);
    }

    /**
     * Check whether the user has opted in to data tracking and cookies/localstorage for the given token
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {string} [options.persistenceType] Persistence mechanism used - cookie or localStorage
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @returns {boolean} whether the user has opted in to the given opt type
     */
    function hasOptedIn(token, options) {
        return _getStorageValue(token, options) === '1';
    }

    /**
     * Check whether the user has opted out of data tracking and cookies/localstorage for the given token
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {string} [options.persistenceType] Persistence mechanism used - cookie or localStorage
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @param {boolean} [options.ignoreDnt] - flag to ignore browser DNT settings and always return false
     * @returns {boolean} whether the user has opted out of the given opt type
     */
    function hasOptedOut(token, options) {
        if (_hasDoNotTrackFlagOn(options)) {
            console$1.warn('This browser has "Do Not Track" enabled. This will prevent the Mixpanel SDK from sending any data. To ignore the "Do Not Track" browser setting, initialize the Mixpanel instance with the config "ignore_dnt: true"');
            return true;
        }
        var optedOut = _getStorageValue(token, options) === '0';
        if (optedOut) {
            console$1.warn('You are opted out of Mixpanel tracking. This will prevent the Mixpanel SDK from sending any data.');
        }
        return optedOut;
    }

    /**
     * Wrap a MixpanelLib method with a check for whether the user is opted out of data tracking and cookies/localstorage for the given token
     * If the user has opted out, return early instead of executing the method.
     * If a callback argument was provided, execute it passing the 0 error code.
     * @param {function} method - wrapped method to be executed if the user has not opted out
     * @returns {*} the result of executing method OR undefined if the user has opted out
     */
    function addOptOutCheckMixpanelLib(method) {
        return _addOptOutCheck(method, function(name) {
            return this.get_config(name);
        });
    }

    /**
     * Wrap a MixpanelPeople method with a check for whether the user is opted out of data tracking and cookies/localstorage for the given token
     * If the user has opted out, return early instead of executing the method.
     * If a callback argument was provided, execute it passing the 0 error code.
     * @param {function} method - wrapped method to be executed if the user has not opted out
     * @returns {*} the result of executing method OR undefined if the user has opted out
     */
    function addOptOutCheckMixpanelPeople(method) {
        return _addOptOutCheck(method, function(name) {
            return this._get_config(name);
        });
    }

    /**
     * Wrap a MixpanelGroup method with a check for whether the user is opted out of data tracking and cookies/localstorage for the given token
     * If the user has opted out, return early instead of executing the method.
     * If a callback argument was provided, execute it passing the 0 error code.
     * @param {function} method - wrapped method to be executed if the user has not opted out
     * @returns {*} the result of executing method OR undefined if the user has opted out
     */
    function addOptOutCheckMixpanelGroup(method) {
        return _addOptOutCheck(method, function(name) {
            return this._get_config(name);
        });
    }

    /**
     * Clear the user's opt in/out status of data tracking and cookies/localstorage for the given token
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {string} [options.persistenceType] Persistence mechanism used - cookie or localStorage
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookieExpiration] - number of days until the opt-in cookie expires
     * @param {string} [options.cookieDomain] - custom cookie domain
     * @param {boolean} [options.crossSiteCookie] - whether the opt-in cookie is set as cross-site-enabled
     * @param {boolean} [options.crossSubdomainCookie] - whether the opt-in cookie is set as cross-subdomain or not
     * @param {boolean} [options.secureCookie] - whether the opt-in cookie is set as secure or not
     */
    function clearOptInOut(token, options) {
        options = options || {};
        _getStorage(options).remove(
            _getStorageKey(token, options), !!options.crossSubdomainCookie, options.cookieDomain
        );
    }

    /** Private **/

    /**
     * Get storage util
     * @param {Object} [options]
     * @param {string} [options.persistenceType]
     * @returns {object} either _.cookie or _.localstorage
     */
    function _getStorage(options) {
        options = options || {};
        return options.persistenceType === 'localStorage' ? _.localStorage : _.cookie;
    }

    /**
     * Get the name of the cookie that is used for the given opt type (tracking, cookie, etc.)
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @returns {string} the name of the cookie for the given opt type
     */
    function _getStorageKey(token, options) {
        options = options || {};
        return (options.persistencePrefix || GDPR_DEFAULT_PERSISTENCE_PREFIX) + token;
    }

    /**
     * Get the value of the cookie that is used for the given opt type (tracking, cookie, etc.)
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @returns {string} the value of the cookie for the given opt type
     */
    function _getStorageValue(token, options) {
        return _getStorage(options).get(_getStorageKey(token, options));
    }

    /**
     * Check whether the user has set the DNT/doNotTrack setting to true in their browser
     * @param {Object} [options]
     * @param {string} [options.window] - alternate window object to check; used to force various DNT settings in browser tests
     * @param {boolean} [options.ignoreDnt] - flag to ignore browser DNT settings and always return false
     * @returns {boolean} whether the DNT setting is true
     */
    function _hasDoNotTrackFlagOn(options) {
        if (options && options.ignoreDnt) {
            return false;
        }
        var win = (options && options.window) || window$1;
        var nav = win['navigator'] || {};
        var hasDntOn = false;

        _.each([
            nav['doNotTrack'], // standard
            nav['msDoNotTrack'],
            win['doNotTrack']
        ], function(dntValue) {
            if (_.includes([true, 1, '1', 'yes'], dntValue)) {
                hasDntOn = true;
            }
        });

        return hasDntOn;
    }

    /**
     * Set cookie/localstorage for the user indicating that they are opted in or out for the given opt type
     * @param {boolean} optValue - whether to opt the user in or out for the given opt type
     * @param {string} token - Mixpanel project tracking token
     * @param {Object} [options]
     * @param {trackFunction} [options.track] - function used for tracking a Mixpanel event to record the opt-in action
     * @param {string} [options.trackEventName] - event name to be used for tracking the opt-in action
     * @param {Object} [options.trackProperties] - set of properties to be tracked along with the opt-in action
     * @param {string} [options.persistencePrefix=__mp_opt_in_out] - custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookieExpiration] - number of days until the opt-in cookie expires
     * @param {string} [options.cookieDomain] - custom cookie domain
     * @param {boolean} [options.crossSiteCookie] - whether the opt-in cookie is set as cross-site-enabled
     * @param {boolean} [options.crossSubdomainCookie] - whether the opt-in cookie is set as cross-subdomain or not
     * @param {boolean} [options.secureCookie] - whether the opt-in cookie is set as secure or not
     */
    function _optInOut(optValue, token, options) {
        if (!_.isString(token) || !token.length) {
            console$1.error('gdpr.' + (optValue ? 'optIn' : 'optOut') + ' called with an invalid token');
            return;
        }

        options = options || {};

        _getStorage(options).set(
            _getStorageKey(token, options),
            optValue ? 1 : 0,
            _.isNumber(options.cookieExpiration) ? options.cookieExpiration : null,
            !!options.crossSubdomainCookie,
            !!options.secureCookie,
            !!options.crossSiteCookie,
            options.cookieDomain
        );

        if (options.track && optValue) { // only track event if opting in (optValue=true)
            options.track(options.trackEventName || '$opt_in', options.trackProperties, {
                'send_immediately': true
            });
        }
    }

    /**
     * Wrap a method with a check for whether the user is opted out of data tracking and cookies/localstorage for the given token
     * If the user has opted out, return early instead of executing the method.
     * If a callback argument was provided, execute it passing the 0 error code.
     * @param {function} method - wrapped method to be executed if the user has not opted out
     * @param {function} getConfigValue - getter function for the Mixpanel API token and other options to be used with opt-out check
     * @returns {*} the result of executing method OR undefined if the user has opted out
     */
    function _addOptOutCheck(method, getConfigValue) {
        return function() {
            var optedOut = false;

            try {
                var token = getConfigValue.call(this, 'token');
                var ignoreDnt = getConfigValue.call(this, 'ignore_dnt');
                var persistenceType = getConfigValue.call(this, 'opt_out_tracking_persistence_type');
                var persistencePrefix = getConfigValue.call(this, 'opt_out_tracking_cookie_prefix');
                var win = getConfigValue.call(this, 'window'); // used to override window during browser tests

                if (token) { // if there was an issue getting the token, continue method execution as normal
                    optedOut = hasOptedOut(token, {
                        ignoreDnt: ignoreDnt,
                        persistenceType: persistenceType,
                        persistencePrefix: persistencePrefix,
                        window: win
                    });
                }
            } catch(err) {
                console$1.error('Unexpected error when checking tracking opt-out status: ' + err);
            }

            if (!optedOut) {
                return method.apply(this, arguments);
            }

            var callback = arguments[arguments.length - 1];
            if (typeof(callback) === 'function') {
                callback(0);
            }

            return;
        };
    }

    /** @const */ var SET_ACTION      = '$set';
    /** @const */ var SET_ONCE_ACTION = '$set_once';
    /** @const */ var UNSET_ACTION    = '$unset';
    /** @const */ var ADD_ACTION      = '$add';
    /** @const */ var APPEND_ACTION   = '$append';
    /** @const */ var UNION_ACTION    = '$union';
    /** @const */ var REMOVE_ACTION   = '$remove';
    /** @const */ var DELETE_ACTION   = '$delete';

    // Common internal methods for mixpanel.people and mixpanel.group APIs.
    // These methods shouldn't involve network I/O.
    var apiActions = {
        set_action: function(prop, to) {
            var data = {};
            var $set = {};
            if (_.isObject(prop)) {
                _.each(prop, function(v, k) {
                    if (!this._is_reserved_property(k)) {
                        $set[k] = v;
                    }
                }, this);
            } else {
                $set[prop] = to;
            }

            data[SET_ACTION] = $set;
            return data;
        },

        unset_action: function(prop) {
            var data = {};
            var $unset = [];
            if (!_.isArray(prop)) {
                prop = [prop];
            }

            _.each(prop, function(k) {
                if (!this._is_reserved_property(k)) {
                    $unset.push(k);
                }
            }, this);

            data[UNSET_ACTION] = $unset;
            return data;
        },

        set_once_action: function(prop, to) {
            var data = {};
            var $set_once = {};
            if (_.isObject(prop)) {
                _.each(prop, function(v, k) {
                    if (!this._is_reserved_property(k)) {
                        $set_once[k] = v;
                    }
                }, this);
            } else {
                $set_once[prop] = to;
            }
            data[SET_ONCE_ACTION] = $set_once;
            return data;
        },

        union_action: function(list_name, values) {
            var data = {};
            var $union = {};
            if (_.isObject(list_name)) {
                _.each(list_name, function(v, k) {
                    if (!this._is_reserved_property(k)) {
                        $union[k] = _.isArray(v) ? v : [v];
                    }
                }, this);
            } else {
                $union[list_name] = _.isArray(values) ? values : [values];
            }
            data[UNION_ACTION] = $union;
            return data;
        },

        append_action: function(list_name, value) {
            var data = {};
            var $append = {};
            if (_.isObject(list_name)) {
                _.each(list_name, function(v, k) {
                    if (!this._is_reserved_property(k)) {
                        $append[k] = v;
                    }
                }, this);
            } else {
                $append[list_name] = value;
            }
            data[APPEND_ACTION] = $append;
            return data;
        },

        remove_action: function(list_name, value) {
            var data = {};
            var $remove = {};
            if (_.isObject(list_name)) {
                _.each(list_name, function(v, k) {
                    if (!this._is_reserved_property(k)) {
                        $remove[k] = v;
                    }
                }, this);
            } else {
                $remove[list_name] = value;
            }
            data[REMOVE_ACTION] = $remove;
            return data;
        },

        delete_action: function() {
            var data = {};
            data[DELETE_ACTION] = '';
            return data;
        }
    };

    /**
     * Mixpanel Group Object
     * @constructor
     */
    var MixpanelGroup = function() {};

    _.extend(MixpanelGroup.prototype, apiActions);

    MixpanelGroup.prototype._init = function(mixpanel_instance, group_key, group_id) {
        this._mixpanel = mixpanel_instance;
        this._group_key = group_key;
        this._group_id = group_id;
    };

    /**
     * Set properties on a group.
     *
     * ### Usage:
     *
     *     mixpanel.get_group('company', 'mixpanel').set('Location', '405 Howard');
     *
     *     // or set multiple properties at once
     *     mixpanel.get_group('company', 'mixpanel').set({
     *          'Location': '405 Howard',
     *          'Founded' : 2009,
     *     });
     *     // properties can be strings, integers, dates, or lists
     *
     * @param {Object|String} prop If a string, this is the name of the property. If an object, this is an associative array of names and values.
     * @param {*} [to] A value to set on the given property name
     * @param {Function} [callback] If provided, the callback will be called after the tracking event
     */
    MixpanelGroup.prototype.set = addOptOutCheckMixpanelGroup(function(prop, to, callback) {
        var data = this.set_action(prop, to);
        if (_.isObject(prop)) {
            callback = to;
        }
        return this._send_request(data, callback);
    });

    /**
     * Set properties on a group, only if they do not yet exist.
     * This will not overwrite previous group property values, unlike
     * group.set().
     *
     * ### Usage:
     *
     *     mixpanel.get_group('company', 'mixpanel').set_once('Location', '405 Howard');
     *
     *     // or set multiple properties at once
     *     mixpanel.get_group('company', 'mixpanel').set_once({
     *          'Location': '405 Howard',
     *          'Founded' : 2009,
     *     });
     *     // properties can be strings, integers, lists or dates
     *
     * @param {Object|String} prop If a string, this is the name of the property. If an object, this is an associative array of names and values.
     * @param {*} [to] A value to set on the given property name
     * @param {Function} [callback] If provided, the callback will be called after the tracking event
     */
    MixpanelGroup.prototype.set_once = addOptOutCheckMixpanelGroup(function(prop, to, callback) {
        var data = this.set_once_action(prop, to);
        if (_.isObject(prop)) {
            callback = to;
        }
        return this._send_request(data, callback);
    });

    /**
     * Unset properties on a group permanently.
     *
     * ### Usage:
     *
     *     mixpanel.get_group('company', 'mixpanel').unset('Founded');
     *
     * @param {String} prop The name of the property.
     * @param {Function} [callback] If provided, the callback will be called after the tracking event
     */
    MixpanelGroup.prototype.unset = addOptOutCheckMixpanelGroup(function(prop, callback) {
        var data = this.unset_action(prop);
        return this._send_request(data, callback);
    });

    /**
     * Merge a given list with a list-valued group property, excluding duplicate values.
     *
     * ### Usage:
     *
     *     // merge a value to a list, creating it if needed
     *     mixpanel.get_group('company', 'mixpanel').union('Location', ['San Francisco', 'London']);
     *
     * @param {String} list_name Name of the property.
     * @param {Array} values Values to merge with the given property
     * @param {Function} [callback] If provided, the callback will be called after the tracking event
     */
    MixpanelGroup.prototype.union = addOptOutCheckMixpanelGroup(function(list_name, values, callback) {
        if (_.isObject(list_name)) {
            callback = values;
        }
        var data = this.union_action(list_name, values);
        return this._send_request(data, callback);
    });

    /**
     * Permanently delete a group.
     *
     * ### Usage:
     *
     *     mixpanel.get_group('company', 'mixpanel').delete();
     *
     * @param {Function} [callback] If provided, the callback will be called after the tracking event
     */
    MixpanelGroup.prototype['delete'] = addOptOutCheckMixpanelGroup(function(callback) {
        // bracket notation above prevents a minification error related to reserved words
        var data = this.delete_action();
        return this._send_request(data, callback);
    });

    /**
     * Remove a property from a group. The value will be ignored if doesn't exist.
     *
     * ### Usage:
     *
     *     mixpanel.get_group('company', 'mixpanel').remove('Location', 'London');
     *
     * @param {String} list_name Name of the property.
     * @param {Object} value Value to remove from the given group property
     * @param {Function} [callback] If provided, the callback will be called after the tracking event
     */
    MixpanelGroup.prototype.remove = addOptOutCheckMixpanelGroup(function(list_name, value, callback) {
        var data = this.remove_action(list_name, value);
        return this._send_request(data, callback);
    });

    MixpanelGroup.prototype._send_request = function(data, callback) {
        data['$group_key'] = this._group_key;
        data['$group_id'] = this._group_id;
        data['$token'] = this._get_config('token');

        var date_encoded_data = _.encodeDates(data);
        return this._mixpanel._track_or_batch({
            type: 'groups',
            data: date_encoded_data,
            endpoint: this._get_config('api_host') + '/groups/',
            batcher: this._mixpanel.request_batchers.groups
        }, callback);
    };

    MixpanelGroup.prototype._is_reserved_property = function(prop) {
        return prop === '$group_key' || prop === '$group_id';
    };

    MixpanelGroup.prototype._get_config = function(conf) {
        return this._mixpanel.get_config(conf);
    };

    MixpanelGroup.prototype.toString = function() {
        return this._mixpanel.toString() + '.group.' + this._group_key + '.' + this._group_id;
    };

    // MixpanelGroup Exports
    MixpanelGroup.prototype['remove']   = MixpanelGroup.prototype.remove;
    MixpanelGroup.prototype['set']      = MixpanelGroup.prototype.set;
    MixpanelGroup.prototype['set_once'] = MixpanelGroup.prototype.set_once;
    MixpanelGroup.prototype['union']    = MixpanelGroup.prototype.union;
    MixpanelGroup.prototype['unset']    = MixpanelGroup.prototype.unset;
    MixpanelGroup.prototype['toString'] = MixpanelGroup.prototype.toString;

    /**
     * Mixpanel People Object
     * @constructor
     */
    var MixpanelPeople = function() {};

    _.extend(MixpanelPeople.prototype, apiActions);

    MixpanelPeople.prototype._init = function(mixpanel_instance) {
        this._mixpanel = mixpanel_instance;
    };

    /*
    * Set properties on a user record.
    *
    * ### Usage:
    *
    *     mixpanel.people.set('gender', 'm');
    *
    *     // or set multiple properties at once
    *     mixpanel.people.set({
    *         'Company': 'Acme',
    *         'Plan': 'Premium',
    *         'Upgrade date': new Date()
    *     });
    *     // properties can be strings, integers, dates, or lists
    *
    * @param {Object|String} prop If a string, this is the name of the property. If an object, this is an associative array of names and values.
    * @param {*} [to] A value to set on the given property name
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.set = addOptOutCheckMixpanelPeople(function(prop, to, callback) {
        var data = this.set_action(prop, to);
        if (_.isObject(prop)) {
            callback = to;
        }
        // make sure that the referrer info has been updated and saved
        if (this._get_config('save_referrer')) {
            this._mixpanel['persistence'].update_referrer_info(document.referrer);
        }

        // update $set object with default people properties
        data[SET_ACTION] = _.extend(
            {},
            _.info.people_properties(),
            this._mixpanel['persistence'].get_referrer_info(),
            data[SET_ACTION]
        );
        return this._send_request(data, callback);
    });

    /*
    * Set properties on a user record, only if they do not yet exist.
    * This will not overwrite previous people property values, unlike
    * people.set().
    *
    * ### Usage:
    *
    *     mixpanel.people.set_once('First Login Date', new Date());
    *
    *     // or set multiple properties at once
    *     mixpanel.people.set_once({
    *         'First Login Date': new Date(),
    *         'Starting Plan': 'Premium'
    *     });
    *
    *     // properties can be strings, integers or dates
    *
    * @param {Object|String} prop If a string, this is the name of the property. If an object, this is an associative array of names and values.
    * @param {*} [to] A value to set on the given property name
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.set_once = addOptOutCheckMixpanelPeople(function(prop, to, callback) {
        var data = this.set_once_action(prop, to);
        if (_.isObject(prop)) {
            callback = to;
        }
        return this._send_request(data, callback);
    });

    /*
    * Unset properties on a user record (permanently removes the properties and their values from a profile).
    *
    * ### Usage:
    *
    *     mixpanel.people.unset('gender');
    *
    *     // or unset multiple properties at once
    *     mixpanel.people.unset(['gender', 'Company']);
    *
    * @param {Array|String} prop If a string, this is the name of the property. If an array, this is a list of property names.
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.unset = addOptOutCheckMixpanelPeople(function(prop, callback) {
        var data = this.unset_action(prop);
        return this._send_request(data, callback);
    });

    /*
    * Increment/decrement numeric people analytics properties.
    *
    * ### Usage:
    *
    *     mixpanel.people.increment('page_views', 1);
    *
    *     // or, for convenience, if you're just incrementing a counter by
    *     // 1, you can simply do
    *     mixpanel.people.increment('page_views');
    *
    *     // to decrement a counter, pass a negative number
    *     mixpanel.people.increment('credits_left', -1);
    *
    *     // like mixpanel.people.set(), you can increment multiple
    *     // properties at once:
    *     mixpanel.people.increment({
    *         counter1: 1,
    *         counter2: 6
    *     });
    *
    * @param {Object|String} prop If a string, this is the name of the property. If an object, this is an associative array of names and numeric values.
    * @param {Number} [by] An amount to increment the given property
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.increment = addOptOutCheckMixpanelPeople(function(prop, by, callback) {
        var data = {};
        var $add = {};
        if (_.isObject(prop)) {
            _.each(prop, function(v, k) {
                if (!this._is_reserved_property(k)) {
                    if (isNaN(parseFloat(v))) {
                        console$1.error('Invalid increment value passed to mixpanel.people.increment - must be a number');
                        return;
                    } else {
                        $add[k] = v;
                    }
                }
            }, this);
            callback = by;
        } else {
            // convenience: mixpanel.people.increment('property'); will
            // increment 'property' by 1
            if (_.isUndefined(by)) {
                by = 1;
            }
            $add[prop] = by;
        }
        data[ADD_ACTION] = $add;

        return this._send_request(data, callback);
    });

    /*
    * Append a value to a list-valued people analytics property.
    *
    * ### Usage:
    *
    *     // append a value to a list, creating it if needed
    *     mixpanel.people.append('pages_visited', 'homepage');
    *
    *     // like mixpanel.people.set(), you can append multiple
    *     // properties at once:
    *     mixpanel.people.append({
    *         list1: 'bob',
    *         list2: 123
    *     });
    *
    * @param {Object|String} list_name If a string, this is the name of the property. If an object, this is an associative array of names and values.
    * @param {*} [value] value An item to append to the list
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.append = addOptOutCheckMixpanelPeople(function(list_name, value, callback) {
        if (_.isObject(list_name)) {
            callback = value;
        }
        var data = this.append_action(list_name, value);
        return this._send_request(data, callback);
    });

    /*
    * Remove a value from a list-valued people analytics property.
    *
    * ### Usage:
    *
    *     mixpanel.people.remove('School', 'UCB');
    *
    * @param {Object|String} list_name If a string, this is the name of the property. If an object, this is an associative array of names and values.
    * @param {*} [value] value Item to remove from the list
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.remove = addOptOutCheckMixpanelPeople(function(list_name, value, callback) {
        if (_.isObject(list_name)) {
            callback = value;
        }
        var data = this.remove_action(list_name, value);
        return this._send_request(data, callback);
    });

    /*
    * Merge a given list with a list-valued people analytics property,
    * excluding duplicate values.
    *
    * ### Usage:
    *
    *     // merge a value to a list, creating it if needed
    *     mixpanel.people.union('pages_visited', 'homepage');
    *
    *     // like mixpanel.people.set(), you can append multiple
    *     // properties at once:
    *     mixpanel.people.union({
    *         list1: 'bob',
    *         list2: 123
    *     });
    *
    *     // like mixpanel.people.append(), you can append multiple
    *     // values to the same list:
    *     mixpanel.people.union({
    *         list1: ['bob', 'billy']
    *     });
    *
    * @param {Object|String} list_name If a string, this is the name of the property. If an object, this is an associative array of names and values.
    * @param {*} [value] Value / values to merge with the given property
    * @param {Function} [callback] If provided, the callback will be called after tracking the event.
    */
    MixpanelPeople.prototype.union = addOptOutCheckMixpanelPeople(function(list_name, values, callback) {
        if (_.isObject(list_name)) {
            callback = values;
        }
        var data = this.union_action(list_name, values);
        return this._send_request(data, callback);
    });

    /*
     * Record that you have charged the current user a certain amount
     * of money. Charges recorded with track_charge() will appear in the
     * Mixpanel revenue report.
     *
     * ### Usage:
     *
     *     // charge a user $50
     *     mixpanel.people.track_charge(50);
     *
     *     // charge a user $30.50 on the 2nd of january
     *     mixpanel.people.track_charge(30.50, {
     *         '$time': new Date('jan 1 2012')
     *     });
     *
     * @param {Number} amount The amount of money charged to the current user
     * @param {Object} [properties] An associative array of properties associated with the charge
     * @param {Function} [callback] If provided, the callback will be called when the server responds
     * @deprecated
     */
    MixpanelPeople.prototype.track_charge = addOptOutCheckMixpanelPeople(function(amount, properties, callback) {
        if (!_.isNumber(amount)) {
            amount = parseFloat(amount);
            if (isNaN(amount)) {
                console$1.error('Invalid value passed to mixpanel.people.track_charge - must be a number');
                return;
            }
        }

        return this.append('$transactions', _.extend({
            '$amount': amount
        }, properties), callback);
    });

    /*
     * Permanently clear all revenue report transactions from the
     * current user's people analytics profile.
     *
     * ### Usage:
     *
     *     mixpanel.people.clear_charges();
     *
     * @param {Function} [callback] If provided, the callback will be called after tracking the event.
     * @deprecated
     */
    MixpanelPeople.prototype.clear_charges = function(callback) {
        return this.set('$transactions', [], callback);
    };

    /*
    * Permanently deletes the current people analytics profile from
    * Mixpanel (using the current distinct_id).
    *
    * ### Usage:
    *
    *     // remove the all data you have stored about the current user
    *     mixpanel.people.delete_user();
    *
    */
    MixpanelPeople.prototype.delete_user = function() {
        if (!this._identify_called()) {
            console$1.error('mixpanel.people.delete_user() requires you to call identify() first');
            return;
        }
        var data = {'$delete': this._mixpanel.get_distinct_id()};
        return this._send_request(data);
    };

    MixpanelPeople.prototype.toString = function() {
        return this._mixpanel.toString() + '.people';
    };

    MixpanelPeople.prototype._send_request = function(data, callback) {
        data['$token'] = this._get_config('token');
        data['$distinct_id'] = this._mixpanel.get_distinct_id();
        var device_id = this._mixpanel.get_property('$device_id');
        var user_id = this._mixpanel.get_property('$user_id');
        var had_persisted_distinct_id = this._mixpanel.get_property('$had_persisted_distinct_id');
        if (device_id) {
            data['$device_id'] = device_id;
        }
        if (user_id) {
            data['$user_id'] = user_id;
        }
        if (had_persisted_distinct_id) {
            data['$had_persisted_distinct_id'] = had_persisted_distinct_id;
        }

        var date_encoded_data = _.encodeDates(data);

        if (!this._identify_called()) {
            this._enqueue(data);
            if (!_.isUndefined(callback)) {
                if (this._get_config('verbose')) {
                    callback({status: -1, error: null});
                } else {
                    callback(-1);
                }
            }
            return _.truncate(date_encoded_data, 255);
        }

        return this._mixpanel._track_or_batch({
            type: 'people',
            data: date_encoded_data,
            endpoint: this._get_config('api_host') + '/engage/',
            batcher: this._mixpanel.request_batchers.people
        }, callback);
    };

    MixpanelPeople.prototype._get_config = function(conf_var) {
        return this._mixpanel.get_config(conf_var);
    };

    MixpanelPeople.prototype._identify_called = function() {
        return this._mixpanel._flags.identify_called === true;
    };

    // Queue up engage operations if identify hasn't been called yet.
    MixpanelPeople.prototype._enqueue = function(data) {
        if (SET_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(SET_ACTION, data);
        } else if (SET_ONCE_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(SET_ONCE_ACTION, data);
        } else if (UNSET_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(UNSET_ACTION, data);
        } else if (ADD_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(ADD_ACTION, data);
        } else if (APPEND_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(APPEND_ACTION, data);
        } else if (REMOVE_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(REMOVE_ACTION, data);
        } else if (UNION_ACTION in data) {
            this._mixpanel['persistence']._add_to_people_queue(UNION_ACTION, data);
        } else {
            console$1.error('Invalid call to _enqueue():', data);
        }
    };

    MixpanelPeople.prototype._flush_one_queue = function(action, action_method, callback, queue_to_params_fn) {
        var _this = this;
        var queued_data = _.extend({}, this._mixpanel['persistence']._get_queue(action));
        var action_params = queued_data;

        if (!_.isUndefined(queued_data) && _.isObject(queued_data) && !_.isEmptyObject(queued_data)) {
            _this._mixpanel['persistence']._pop_from_people_queue(action, queued_data);
            if (queue_to_params_fn) {
                action_params = queue_to_params_fn(queued_data);
            }
            action_method.call(_this, action_params, function(response, data) {
                // on bad response, we want to add it back to the queue
                if (response === 0) {
                    _this._mixpanel['persistence']._add_to_people_queue(action, queued_data);
                }
                if (!_.isUndefined(callback)) {
                    callback(response, data);
                }
            });
        }
    };

    // Flush queued engage operations - order does not matter,
    // and there are network level race conditions anyway
    MixpanelPeople.prototype._flush = function(
        _set_callback, _add_callback, _append_callback, _set_once_callback, _union_callback, _unset_callback, _remove_callback
    ) {
        var _this = this;
        var $append_queue = this._mixpanel['persistence']._get_queue(APPEND_ACTION);
        var $remove_queue = this._mixpanel['persistence']._get_queue(REMOVE_ACTION);

        this._flush_one_queue(SET_ACTION, this.set, _set_callback);
        this._flush_one_queue(SET_ONCE_ACTION, this.set_once, _set_once_callback);
        this._flush_one_queue(UNSET_ACTION, this.unset, _unset_callback, function(queue) { return _.keys(queue); });
        this._flush_one_queue(ADD_ACTION, this.increment, _add_callback);
        this._flush_one_queue(UNION_ACTION, this.union, _union_callback);

        // we have to fire off each $append individually since there is
        // no concat method server side
        if (!_.isUndefined($append_queue) && _.isArray($append_queue) && $append_queue.length) {
            var $append_item;
            var append_callback = function(response, data) {
                if (response === 0) {
                    _this._mixpanel['persistence']._add_to_people_queue(APPEND_ACTION, $append_item);
                }
                if (!_.isUndefined(_append_callback)) {
                    _append_callback(response, data);
                }
            };
            for (var i = $append_queue.length - 1; i >= 0; i--) {
                $append_item = $append_queue.pop();
                if (!_.isEmptyObject($append_item)) {
                    _this.append($append_item, append_callback);
                }
            }
            // Save the shortened append queue
            _this._mixpanel['persistence'].save();
        }

        // same for $remove
        if (!_.isUndefined($remove_queue) && _.isArray($remove_queue) && $remove_queue.length) {
            var $remove_item;
            var remove_callback = function(response, data) {
                if (response === 0) {
                    _this._mixpanel['persistence']._add_to_people_queue(REMOVE_ACTION, $remove_item);
                }
                if (!_.isUndefined(_remove_callback)) {
                    _remove_callback(response, data);
                }
            };
            for (var j = $remove_queue.length - 1; j >= 0; j--) {
                $remove_item = $remove_queue.pop();
                if (!_.isEmptyObject($remove_item)) {
                    _this.remove($remove_item, remove_callback);
                }
            }
            _this._mixpanel['persistence'].save();
        }
    };

    MixpanelPeople.prototype._is_reserved_property = function(prop) {
        return prop === '$distinct_id' || prop === '$token' || prop === '$device_id' || prop === '$user_id' || prop === '$had_persisted_distinct_id';
    };

    // MixpanelPeople Exports
    MixpanelPeople.prototype['set']           = MixpanelPeople.prototype.set;
    MixpanelPeople.prototype['set_once']      = MixpanelPeople.prototype.set_once;
    MixpanelPeople.prototype['unset']         = MixpanelPeople.prototype.unset;
    MixpanelPeople.prototype['increment']     = MixpanelPeople.prototype.increment;
    MixpanelPeople.prototype['append']        = MixpanelPeople.prototype.append;
    MixpanelPeople.prototype['remove']        = MixpanelPeople.prototype.remove;
    MixpanelPeople.prototype['union']         = MixpanelPeople.prototype.union;
    MixpanelPeople.prototype['track_charge']  = MixpanelPeople.prototype.track_charge;
    MixpanelPeople.prototype['clear_charges'] = MixpanelPeople.prototype.clear_charges;
    MixpanelPeople.prototype['delete_user']   = MixpanelPeople.prototype.delete_user;
    MixpanelPeople.prototype['toString']      = MixpanelPeople.prototype.toString;

    /*
     * Constants
     */
    /** @const */ var SET_QUEUE_KEY          = '__mps';
    /** @const */ var SET_ONCE_QUEUE_KEY     = '__mpso';
    /** @const */ var UNSET_QUEUE_KEY        = '__mpus';
    /** @const */ var ADD_QUEUE_KEY          = '__mpa';
    /** @const */ var APPEND_QUEUE_KEY       = '__mpap';
    /** @const */ var REMOVE_QUEUE_KEY       = '__mpr';
    /** @const */ var UNION_QUEUE_KEY        = '__mpu';
    // This key is deprecated, but we want to check for it to see whether aliasing is allowed.
    /** @const */ var PEOPLE_DISTINCT_ID_KEY = '$people_distinct_id';
    /** @const */ var ALIAS_ID_KEY           = '__alias';
    /** @const */ var EVENT_TIMERS_KEY       = '__timers';
    /** @const */ var RESERVED_PROPERTIES = [
        SET_QUEUE_KEY,
        SET_ONCE_QUEUE_KEY,
        UNSET_QUEUE_KEY,
        ADD_QUEUE_KEY,
        APPEND_QUEUE_KEY,
        REMOVE_QUEUE_KEY,
        UNION_QUEUE_KEY,
        PEOPLE_DISTINCT_ID_KEY,
        ALIAS_ID_KEY,
        EVENT_TIMERS_KEY
    ];

    /**
     * Mixpanel Persistence Object
     * @constructor
     */
    var MixpanelPersistence = function(config) {
        this['props'] = {};
        this.campaign_params_saved = false;

        if (config['persistence_name']) {
            this.name = 'mp_' + config['persistence_name'];
        } else {
            this.name = 'mp_' + config['token'] + '_mixpanel';
        }

        var storage_type = config['persistence'];
        if (storage_type !== 'cookie' && storage_type !== 'localStorage') {
            console$1.critical('Unknown persistence type ' + storage_type + '; falling back to cookie');
            storage_type = config['persistence'] = 'cookie';
        }

        if (storage_type === 'localStorage' && _.localStorage.is_supported()) {
            this.storage = _.localStorage;
        } else {
            this.storage = _.cookie;
        }

        this.load();
        this.update_config(config);
        this.upgrade(config);
        this.save();
    };

    MixpanelPersistence.prototype.properties = function() {
        var p = {};
        // Filter out reserved properties
        _.each(this['props'], function(v, k) {
            if (!_.include(RESERVED_PROPERTIES, k)) {
                p[k] = v;
            }
        });
        return p;
    };

    MixpanelPersistence.prototype.load = function() {
        if (this.disabled) { return; }

        var entry = this.storage.parse(this.name);

        if (entry) {
            this['props'] = _.extend({}, entry);
        }
    };

    MixpanelPersistence.prototype.upgrade = function(config) {
        var upgrade_from_old_lib = config['upgrade'],
            old_cookie_name,
            old_cookie;

        if (upgrade_from_old_lib) {
            old_cookie_name = 'mp_super_properties';
            // Case where they had a custom cookie name before.
            if (typeof(upgrade_from_old_lib) === 'string') {
                old_cookie_name = upgrade_from_old_lib;
            }

            old_cookie = this.storage.parse(old_cookie_name);

            // remove the cookie
            this.storage.remove(old_cookie_name);
            this.storage.remove(old_cookie_name, true);

            if (old_cookie) {
                this['props'] = _.extend(
                    this['props'],
                    old_cookie['all'],
                    old_cookie['events']
                );
            }
        }

        if (!config['cookie_name'] && config['name'] !== 'mixpanel') {
            // special case to handle people with cookies of the form
            // mp_TOKEN_INSTANCENAME from the first release of this library
            old_cookie_name = 'mp_' + config['token'] + '_' + config['name'];
            old_cookie = this.storage.parse(old_cookie_name);

            if (old_cookie) {
                this.storage.remove(old_cookie_name);
                this.storage.remove(old_cookie_name, true);

                // Save the prop values that were in the cookie from before -
                // this should only happen once as we delete the old one.
                this.register_once(old_cookie);
            }
        }

        if (this.storage === _.localStorage) {
            old_cookie = _.cookie.parse(this.name);

            _.cookie.remove(this.name);
            _.cookie.remove(this.name, true);

            if (old_cookie) {
                this.register_once(old_cookie);
            }
        }
    };

    MixpanelPersistence.prototype.save = function() {
        if (this.disabled) { return; }
        this.storage.set(
            this.name,
            _.JSONEncode(this['props']),
            this.expire_days,
            this.cross_subdomain,
            this.secure,
            this.cross_site,
            this.cookie_domain
        );
    };

    MixpanelPersistence.prototype.remove = function() {
        // remove both domain and subdomain cookies
        this.storage.remove(this.name, false, this.cookie_domain);
        this.storage.remove(this.name, true, this.cookie_domain);
    };

    // removes the storage entry and deletes all loaded data
    // forced name for tests
    MixpanelPersistence.prototype.clear = function() {
        this.remove();
        this['props'] = {};
    };

    /**
    * @param {Object} props
    * @param {*=} default_value
    * @param {number=} days
    */
    MixpanelPersistence.prototype.register_once = function(props, default_value, days) {
        if (_.isObject(props)) {
            if (typeof(default_value) === 'undefined') { default_value = 'None'; }
            this.expire_days = (typeof(days) === 'undefined') ? this.default_expiry : days;

            _.each(props, function(val, prop) {
                if (!this['props'].hasOwnProperty(prop) || this['props'][prop] === default_value) {
                    this['props'][prop] = val;
                }
            }, this);

            this.save();

            return true;
        }
        return false;
    };

    /**
    * @param {Object} props
    * @param {number=} days
    */
    MixpanelPersistence.prototype.register = function(props, days) {
        if (_.isObject(props)) {
            this.expire_days = (typeof(days) === 'undefined') ? this.default_expiry : days;

            _.extend(this['props'], props);

            this.save();

            return true;
        }
        return false;
    };

    MixpanelPersistence.prototype.unregister = function(prop) {
        if (prop in this['props']) {
            delete this['props'][prop];
            this.save();
        }
    };

    MixpanelPersistence.prototype.update_search_keyword = function(referrer) {
        this.register(_.info.searchInfo(referrer));
    };

    // EXPORTED METHOD, we test this directly.
    MixpanelPersistence.prototype.update_referrer_info = function(referrer) {
        // If referrer doesn't exist, we want to note the fact that it was type-in traffic.
        this.register_once({
            '$initial_referrer': referrer || '$direct',
            '$initial_referring_domain': _.info.referringDomain(referrer) || '$direct'
        }, '');
    };

    MixpanelPersistence.prototype.get_referrer_info = function() {
        return _.strip_empty_properties({
            '$initial_referrer': this['props']['$initial_referrer'],
            '$initial_referring_domain': this['props']['$initial_referring_domain']
        });
    };

    // safely fills the passed in object with stored properties,
    // does not override any properties defined in both
    // returns the passed in object
    MixpanelPersistence.prototype.safe_merge = function(props) {
        _.each(this['props'], function(val, prop) {
            if (!(prop in props)) {
                props[prop] = val;
            }
        });

        return props;
    };

    MixpanelPersistence.prototype.update_config = function(config) {
        this.default_expiry = this.expire_days = config['cookie_expiration'];
        this.set_disabled(config['disable_persistence']);
        this.set_cookie_domain(config['cookie_domain']);
        this.set_cross_site(config['cross_site_cookie']);
        this.set_cross_subdomain(config['cross_subdomain_cookie']);
        this.set_secure(config['secure_cookie']);
    };

    MixpanelPersistence.prototype.set_disabled = function(disabled) {
        this.disabled = disabled;
        if (this.disabled) {
            this.remove();
        } else {
            this.save();
        }
    };

    MixpanelPersistence.prototype.set_cookie_domain = function(cookie_domain) {
        if (cookie_domain !== this.cookie_domain) {
            this.remove();
            this.cookie_domain = cookie_domain;
            this.save();
        }
    };

    MixpanelPersistence.prototype.set_cross_site = function(cross_site) {
        if (cross_site !== this.cross_site) {
            this.cross_site = cross_site;
            this.remove();
            this.save();
        }
    };

    MixpanelPersistence.prototype.set_cross_subdomain = function(cross_subdomain) {
        if (cross_subdomain !== this.cross_subdomain) {
            this.cross_subdomain = cross_subdomain;
            this.remove();
            this.save();
        }
    };

    MixpanelPersistence.prototype.get_cross_subdomain = function() {
        return this.cross_subdomain;
    };

    MixpanelPersistence.prototype.set_secure = function(secure) {
        if (secure !== this.secure) {
            this.secure = secure ? true : false;
            this.remove();
            this.save();
        }
    };

    MixpanelPersistence.prototype._add_to_people_queue = function(queue, data) {
        var q_key = this._get_queue_key(queue),
            q_data = data[queue],
            set_q = this._get_or_create_queue(SET_ACTION),
            set_once_q = this._get_or_create_queue(SET_ONCE_ACTION),
            unset_q = this._get_or_create_queue(UNSET_ACTION),
            add_q = this._get_or_create_queue(ADD_ACTION),
            union_q = this._get_or_create_queue(UNION_ACTION),
            remove_q = this._get_or_create_queue(REMOVE_ACTION, []),
            append_q = this._get_or_create_queue(APPEND_ACTION, []);

        if (q_key === SET_QUEUE_KEY) {
            // Update the set queue - we can override any existing values
            _.extend(set_q, q_data);
            // if there was a pending increment, override it
            // with the set.
            this._pop_from_people_queue(ADD_ACTION, q_data);
            // if there was a pending union, override it
            // with the set.
            this._pop_from_people_queue(UNION_ACTION, q_data);
            this._pop_from_people_queue(UNSET_ACTION, q_data);
        } else if (q_key === SET_ONCE_QUEUE_KEY) {
            // only queue the data if there is not already a set_once call for it.
            _.each(q_data, function(v, k) {
                if (!(k in set_once_q)) {
                    set_once_q[k] = v;
                }
            });
            this._pop_from_people_queue(UNSET_ACTION, q_data);
        } else if (q_key === UNSET_QUEUE_KEY) {
            _.each(q_data, function(prop) {

                // undo previously-queued actions on this key
                _.each([set_q, set_once_q, add_q, union_q], function(enqueued_obj) {
                    if (prop in enqueued_obj) {
                        delete enqueued_obj[prop];
                    }
                });
                _.each(append_q, function(append_obj) {
                    if (prop in append_obj) {
                        delete append_obj[prop];
                    }
                });

                unset_q[prop] = true;

            });
        } else if (q_key === ADD_QUEUE_KEY) {
            _.each(q_data, function(v, k) {
                // If it exists in the set queue, increment
                // the value
                if (k in set_q) {
                    set_q[k] += v;
                } else {
                    // If it doesn't exist, update the add
                    // queue
                    if (!(k in add_q)) {
                        add_q[k] = 0;
                    }
                    add_q[k] += v;
                }
            }, this);
            this._pop_from_people_queue(UNSET_ACTION, q_data);
        } else if (q_key === UNION_QUEUE_KEY) {
            _.each(q_data, function(v, k) {
                if (_.isArray(v)) {
                    if (!(k in union_q)) {
                        union_q[k] = [];
                    }
                    // We may send duplicates, the server will dedup them.
                    union_q[k] = union_q[k].concat(v);
                }
            });
            this._pop_from_people_queue(UNSET_ACTION, q_data);
        } else if (q_key === REMOVE_QUEUE_KEY) {
            remove_q.push(q_data);
            this._pop_from_people_queue(APPEND_ACTION, q_data);
        } else if (q_key === APPEND_QUEUE_KEY) {
            append_q.push(q_data);
            this._pop_from_people_queue(UNSET_ACTION, q_data);
        }

        console$1.log('MIXPANEL PEOPLE REQUEST (QUEUED, PENDING IDENTIFY):');
        console$1.log(data);

        this.save();
    };

    MixpanelPersistence.prototype._pop_from_people_queue = function(queue, data) {
        var q = this._get_queue(queue);
        if (!_.isUndefined(q)) {
            _.each(data, function(v, k) {
                if (queue === APPEND_ACTION || queue === REMOVE_ACTION) {
                    // list actions: only remove if both k+v match
                    // e.g. remove should not override append in a case like
                    // append({foo: 'bar'}); remove({foo: 'qux'})
                    _.each(q, function(queued_action) {
                        if (queued_action[k] === v) {
                            delete queued_action[k];
                        }
                    });
                } else {
                    delete q[k];
                }
            }, this);

            this.save();
        }
    };

    MixpanelPersistence.prototype._get_queue_key = function(queue) {
        if (queue === SET_ACTION) {
            return SET_QUEUE_KEY;
        } else if (queue === SET_ONCE_ACTION) {
            return SET_ONCE_QUEUE_KEY;
        } else if (queue === UNSET_ACTION) {
            return UNSET_QUEUE_KEY;
        } else if (queue === ADD_ACTION) {
            return ADD_QUEUE_KEY;
        } else if (queue === APPEND_ACTION) {
            return APPEND_QUEUE_KEY;
        } else if (queue === REMOVE_ACTION) {
            return REMOVE_QUEUE_KEY;
        } else if (queue === UNION_ACTION) {
            return UNION_QUEUE_KEY;
        } else {
            console$1.error('Invalid queue:', queue);
        }
    };

    MixpanelPersistence.prototype._get_queue = function(queue) {
        return this['props'][this._get_queue_key(queue)];
    };
    MixpanelPersistence.prototype._get_or_create_queue = function(queue, default_val) {
        var key = this._get_queue_key(queue);
        default_val = _.isUndefined(default_val) ? {} : default_val;

        return this['props'][key] || (this['props'][key] = default_val);
    };

    MixpanelPersistence.prototype.set_event_timer = function(event_name, timestamp) {
        var timers = this['props'][EVENT_TIMERS_KEY] || {};
        timers[event_name] = timestamp;
        this['props'][EVENT_TIMERS_KEY] = timers;
        this.save();
    };

    MixpanelPersistence.prototype.remove_event_timer = function(event_name) {
        var timers = this['props'][EVENT_TIMERS_KEY] || {};
        var timestamp = timers[event_name];
        if (!_.isUndefined(timestamp)) {
            delete this['props'][EVENT_TIMERS_KEY][event_name];
            this.save();
        }
        return timestamp;
    };

    /*
     * Mixpanel JS Library
     *
     * Copyright 2012, Mixpanel, Inc. All Rights Reserved
     * http://mixpanel.com/
     *
     * Includes portions of Underscore.js
     * http://documentcloud.github.com/underscore/
     * (c) 2011 Jeremy Ashkenas, DocumentCloud Inc.
     * Released under the MIT License.
     */

    // ==ClosureCompiler==
    // @compilation_level ADVANCED_OPTIMIZATIONS
    // @output_file_name mixpanel-2.8.min.js
    // ==/ClosureCompiler==

    /*
    SIMPLE STYLE GUIDE:

    this.x === public function
    this._x === internal - only use within this file
    this.__x === private - only use within the class

    Globals should be all caps
    */

    var init_type;       // MODULE or SNIPPET loader
    var mixpanel_master; // main mixpanel instance / object
    var INIT_MODULE  = 0;
    var INIT_SNIPPET = 1;

    var IDENTITY_FUNC = function(x) {return x;};
    var NOOP_FUNC = function() {};

    /** @const */ var PRIMARY_INSTANCE_NAME = 'mixpanel';
    /** @const */ var PAYLOAD_TYPE_BASE64   = 'base64';
    /** @const */ var PAYLOAD_TYPE_JSON     = 'json';
    /** @const */ var DEVICE_ID_PREFIX      = '$device:';


    /*
     * Dynamic... constants? Is that an oxymoron?
     */
    // http://hacks.mozilla.org/2009/07/cross-site-xmlhttprequest-with-cors/
    // https://developer.mozilla.org/en-US/docs/DOM/XMLHttpRequest#withCredentials
    var USE_XHR = (window$1.XMLHttpRequest && 'withCredentials' in new XMLHttpRequest());

    // IE<10 does not support cross-origin XHR's but script tags
    // with defer won't block window.onload; ENQUEUE_REQUESTS
    // should only be true for Opera<12
    var ENQUEUE_REQUESTS = !USE_XHR && (userAgent.indexOf('MSIE') === -1) && (userAgent.indexOf('Mozilla') === -1);

    // save reference to navigator.sendBeacon so it can be minified
    var sendBeacon = null;
    if (navigator['sendBeacon']) {
        sendBeacon = function() {
            // late reference to navigator.sendBeacon to allow patching/spying
            return navigator['sendBeacon'].apply(navigator, arguments);
        };
    }

    /*
     * Module-level globals
     */
    var DEFAULT_CONFIG = {
        'api_host':                          'https://api-js.mixpanel.com',
        'api_method':                        'POST',
        'api_transport':                     'XHR',
        'api_payload_format':                PAYLOAD_TYPE_BASE64,
        'app_host':                          'https://mixpanel.com',
        'cdn':                               'https://cdn.mxpnl.com',
        'cross_site_cookie':                 false,
        'cross_subdomain_cookie':            true,
        'error_reporter':                    NOOP_FUNC,
        'persistence':                       'cookie',
        'persistence_name':                  '',
        'cookie_domain':                     '',
        'cookie_name':                       '',
        'loaded':                            NOOP_FUNC,
        'track_marketing':                   true,
        'track_pageview':                    false,
        'skip_first_touch_marketing':        false,
        'store_google':                      true,
        'save_referrer':                     true,
        'test':                              false,
        'verbose':                           false,
        'img':                               false,
        'debug':                             false,
        'track_links_timeout':               300,
        'cookie_expiration':                 365,
        'upgrade':                           false,
        'disable_persistence':               false,
        'disable_cookie':                    false,
        'secure_cookie':                     false,
        'ip':                                true,
        'opt_out_tracking_by_default':       false,
        'opt_out_persistence_by_default':    false,
        'opt_out_tracking_persistence_type': 'localStorage',
        'opt_out_tracking_cookie_prefix':    null,
        'property_blacklist':                [],
        'xhr_headers':                       {}, // { header: value, header2: value }
        'ignore_dnt':                        false,
        'batch_requests':                    true,
        'batch_size':                        50,
        'batch_flush_interval_ms':           5000,
        'batch_request_timeout_ms':          90000,
        'batch_autostart':                   true,
        'hooks':                             {}
    };

    var DOM_LOADED = false;

    /**
     * Mixpanel Library Object
     * @constructor
     */
    var MixpanelLib = function() {};


    /**
     * create_mplib(token:string, config:object, name:string)
     *
     * This function is used by the init method of MixpanelLib objects
     * as well as the main initializer at the end of the JSLib (that
     * initializes document.mixpanel as well as any additional instances
     * declared before this file has loaded).
     */
    var create_mplib = function(token, config, name) {
        var instance,
            target = (name === PRIMARY_INSTANCE_NAME) ? mixpanel_master : mixpanel_master[name];

        if (target && init_type === INIT_MODULE) {
            instance = target;
        } else {
            if (target && !_.isArray(target)) {
                console$1.error('You have already initialized ' + name);
                return;
            }
            instance = new MixpanelLib();
        }

        instance._cached_groups = {}; // cache groups in a pool

        instance._init(token, config, name);

        instance['people'] = new MixpanelPeople();
        instance['people']._init(instance);

        if (!instance.get_config('skip_first_touch_marketing')) {
            // We need null UTM params in the object because
            // UTM parameters act as a tuple. If any UTM param
            // is present, then we set all UTM params including
            // empty ones together
            var utm_params = _.info.campaignParams(null);
            var initial_utm_params = {};
            var has_utm = false;
            _.each(utm_params, function(utm_value, utm_key) {
                initial_utm_params['initial_' + utm_key] = utm_value;
                if (utm_value) {
                    has_utm = true;
                }
            });
            if (has_utm) {
                instance['people'].set_once(initial_utm_params);
            }
        }

        // if any instance on the page has debug = true, we set the
        // global debug to be true
        Config.DEBUG = Config.DEBUG || instance.get_config('debug');

        // if target is not defined, we called init after the lib already
        // loaded, so there won't be an array of things to execute
        if (!_.isUndefined(target) && _.isArray(target)) {
            // Crunch through the people queue first - we queue this data up &
            // flush on identify, so it's better to do all these operations first
            instance._execute_array.call(instance['people'], target['people']);
            instance._execute_array(target);
        }

        return instance;
    };

    // Initialization methods

    /**
     * This function initializes a new instance of the Mixpanel tracking object.
     * All new instances are added to the main mixpanel object as sub properties (such as
     * mixpanel.library_name) and also returned by this function. To define a
     * second instance on the page, you would call:
     *
     *     mixpanel.init('new token', { your: 'config' }, 'library_name');
     *
     * and use it like so:
     *
     *     mixpanel.library_name.track(...);
     *
     * @param {String} token   Your Mixpanel API token
     * @param {Object} [config]  A dictionary of config options to override. <a href="https://github.com/mixpanel/mixpanel-js/blob/v2.46.0/src/mixpanel-core.js#L88-L127">See a list of default config options</a>.
     * @param {String} [name]    The name for the new mixpanel instance that you want created
     */
    MixpanelLib.prototype.init = function (token, config, name) {
        if (_.isUndefined(name)) {
            this.report_error('You must name your new library: init(token, config, name)');
            return;
        }
        if (name === PRIMARY_INSTANCE_NAME) {
            this.report_error('You must initialize the main mixpanel object right after you include the Mixpanel js snippet');
            return;
        }

        var instance = create_mplib(token, config, name);
        mixpanel_master[name] = instance;
        instance._loaded();

        return instance;
    };

    // mixpanel._init(token:string, config:object, name:string)
    //
    // This function sets up the current instance of the mixpanel
    // library.  The difference between this method and the init(...)
    // method is this one initializes the actual instance, whereas the
    // init(...) method sets up a new library and calls _init on it.
    //
    MixpanelLib.prototype._init = function(token, config, name) {
        config = config || {};

        this['__loaded'] = true;
        this['config'] = {};

        var variable_features = {};

        // default to JSON payload for standard mixpanel.com API hosts
        if (!('api_payload_format' in config)) {
            var api_host = config['api_host'] || DEFAULT_CONFIG['api_host'];
            if (api_host.match(/\.mixpanel\.com/)) {
                variable_features['api_payload_format'] = PAYLOAD_TYPE_JSON;
            }
        }

        this.set_config(_.extend({}, DEFAULT_CONFIG, variable_features, config, {
            'name': name,
            'token': token,
            'callback_fn': ((name === PRIMARY_INSTANCE_NAME) ? name : PRIMARY_INSTANCE_NAME + '.' + name) + '._jsc'
        }));

        this['_jsc'] = NOOP_FUNC;

        this.__dom_loaded_queue = [];
        this.__request_queue = [];
        this.__disabled_events = [];
        this._flags = {
            'disable_all_events': false,
            'identify_called': false
        };

        // set up request queueing/batching
        this.request_batchers = {};
        this._batch_requests = this.get_config('batch_requests');
        if (this._batch_requests) {
            if (!_.localStorage.is_supported(true) || !USE_XHR) {
                this._batch_requests = false;
                console$1.log('Turning off Mixpanel request-queueing; needs XHR and localStorage support');
            } else {
                this.init_batchers();
                if (sendBeacon && window$1.addEventListener) {
                    // Before page closes or hides (user tabs away etc), attempt to flush any events
                    // queued up via navigator.sendBeacon. Since sendBeacon doesn't report success/failure,
                    // events will not be removed from the persistent store; if the site is loaded again,
                    // the events will be flushed again on startup and deduplicated on the Mixpanel server
                    // side.
                    // There is no reliable way to capture only page close events, so we lean on the
                    // visibilitychange and pagehide events as recommended at
                    // https://developer.mozilla.org/en-US/docs/Web/API/Window/unload_event#usage_notes.
                    // These events fire when the user clicks away from the current page/tab, so will occur
                    // more frequently than page unload, but are the only mechanism currently for capturing
                    // this scenario somewhat reliably.
                    var flush_on_unload = _.bind(function() {
                        if (!this.request_batchers.events.stopped) {
                            this.request_batchers.events.flush({unloading: true});
                        }
                    }, this);
                    window$1.addEventListener('pagehide', function(ev) {
                        if (ev['persisted']) {
                            flush_on_unload();
                        }
                    });
                    window$1.addEventListener('visibilitychange', function() {
                        if (document$1['visibilityState'] === 'hidden') {
                            flush_on_unload();
                        }
                    });
                }
            }
        }

        this['persistence'] = this['cookie'] = new MixpanelPersistence(this['config']);
        this.unpersisted_superprops = {};
        this._gdpr_init();

        var uuid = _.UUID();
        if (!this.get_distinct_id()) {
            // There is no need to set the distinct id
            // or the device id if something was already stored
            // in the persitence
            this.register_once({
                'distinct_id': DEVICE_ID_PREFIX + uuid,
                '$device_id': uuid
            }, '');
        }

        if (this.get_config('track_pageview')) {
            this.track_pageview();
        }
    };

    // Private methods

    MixpanelLib.prototype._loaded = function() {
        this.get_config('loaded')(this);
        this._set_default_superprops();
    };

    // update persistence with info on referrer, UTM params, etc
    MixpanelLib.prototype._set_default_superprops = function() {
        this['persistence'].update_search_keyword(document$1.referrer);
        if (this.get_config('store_google')) {
            this.register(_.info.campaignParams(), {persistent: false});
        }
        if (this.get_config('save_referrer')) {
            this['persistence'].update_referrer_info(document$1.referrer);
        }
    };

    MixpanelLib.prototype._dom_loaded = function() {
        _.each(this.__dom_loaded_queue, function(item) {
            this._track_dom.apply(this, item);
        }, this);

        if (!this.has_opted_out_tracking()) {
            _.each(this.__request_queue, function(item) {
                this._send_request.apply(this, item);
            }, this);
        }

        delete this.__dom_loaded_queue;
        delete this.__request_queue;
    };

    MixpanelLib.prototype._track_dom = function(DomClass, args) {
        if (this.get_config('img')) {
            this.report_error('You can\'t use DOM tracking functions with img = true.');
            return false;
        }

        if (!DOM_LOADED) {
            this.__dom_loaded_queue.push([DomClass, args]);
            return false;
        }

        var dt = new DomClass().init(this);
        return dt.track.apply(dt, args);
    };

    /**
     * _prepare_callback() should be called by callers of _send_request for use
     * as the callback argument.
     *
     * If there is no callback, this returns null.
     * If we are going to make XHR/XDR requests, this returns a function.
     * If we are going to use script tags, this returns a string to use as the
     * callback GET param.
     */
    MixpanelLib.prototype._prepare_callback = function(callback, data) {
        if (_.isUndefined(callback)) {
            return null;
        }

        if (USE_XHR) {
            var callback_function = function(response) {
                callback(response, data);
            };
            return callback_function;
        } else {
            // if the user gives us a callback, we store as a random
            // property on this instances jsc function and update our
            // callback string to reflect that.
            var jsc = this['_jsc'];
            var randomized_cb = '' + Math.floor(Math.random() * 100000000);
            var callback_string = this.get_config('callback_fn') + '[' + randomized_cb + ']';
            jsc[randomized_cb] = function(response) {
                delete jsc[randomized_cb];
                callback(response, data);
            };
            return callback_string;
        }
    };

    MixpanelLib.prototype._send_request = function(url, data, options, callback) {
        var succeeded = true;

        if (ENQUEUE_REQUESTS) {
            this.__request_queue.push(arguments);
            return succeeded;
        }

        var DEFAULT_OPTIONS = {
            method: this.get_config('api_method'),
            transport: this.get_config('api_transport'),
            verbose: this.get_config('verbose')
        };
        var body_data = null;

        if (!callback && (_.isFunction(options) || typeof options === 'string')) {
            callback = options;
            options = null;
        }
        options = _.extend(DEFAULT_OPTIONS, options || {});
        if (!USE_XHR) {
            options.method = 'GET';
        }
        var use_post = options.method === 'POST';
        var use_sendBeacon = sendBeacon && use_post && options.transport.toLowerCase() === 'sendbeacon';

        // needed to correctly format responses
        var verbose_mode = options.verbose;
        if (data['verbose']) { verbose_mode = true; }

        if (this.get_config('test')) { data['test'] = 1; }
        if (verbose_mode) { data['verbose'] = 1; }
        if (this.get_config('img')) { data['img'] = 1; }
        if (!USE_XHR) {
            if (callback) {
                data['callback'] = callback;
            } else if (verbose_mode || this.get_config('test')) {
                // Verbose output (from verbose mode, or an error in test mode) is a json blob,
                // which by itself is not valid javascript. Without a callback, this verbose output will
                // cause an error when returned via jsonp, so we force a no-op callback param.
                // See the ECMA script spec: http://www.ecma-international.org/ecma-262/5.1/#sec-12.4
                data['callback'] = '(function(){})';
            }
        }

        data['ip'] = this.get_config('ip')?1:0;
        data['_'] = new Date().getTime().toString();

        if (use_post) {
            body_data = 'data=' + encodeURIComponent(data['data']);
            delete data['data'];
        }

        url += '?' + _.HTTPBuildQuery(data);

        var lib = this;
        if ('img' in data) {
            var img = document$1.createElement('img');
            img.src = url;
            document$1.body.appendChild(img);
        } else if (use_sendBeacon) {
            try {
                succeeded = sendBeacon(url, body_data);
            } catch (e) {
                lib.report_error(e);
                succeeded = false;
            }
            try {
                if (callback) {
                    callback(succeeded ? 1 : 0);
                }
            } catch (e) {
                lib.report_error(e);
            }
        } else if (USE_XHR) {
            try {
                var req = new XMLHttpRequest();
                req.open(options.method, url, true);

                var headers = this.get_config('xhr_headers');
                if (use_post) {
                    headers['Content-Type'] = 'application/x-www-form-urlencoded';
                }
                _.each(headers, function(headerValue, headerName) {
                    req.setRequestHeader(headerName, headerValue);
                });

                if (options.timeout_ms && typeof req.timeout !== 'undefined') {
                    req.timeout = options.timeout_ms;
                    var start_time = new Date().getTime();
                }

                // send the mp_optout cookie
                // withCredentials cannot be modified until after calling .open on Android and Mobile Safari
                req.withCredentials = true;
                req.onreadystatechange = function () {
                    if (req.readyState === 4) { // XMLHttpRequest.DONE == 4, except in safari 4
                        if (req.status === 200) {
                            if (callback) {
                                if (verbose_mode) {
                                    var response;
                                    try {
                                        response = _.JSONDecode(req.responseText);
                                    } catch (e) {
                                        lib.report_error(e);
                                        if (options.ignore_json_errors) {
                                            response = req.responseText;
                                        } else {
                                            return;
                                        }
                                    }
                                    callback(response);
                                } else {
                                    callback(Number(req.responseText));
                                }
                            }
                        } else {
                            var error;
                            if (
                                req.timeout &&
                                !req.status &&
                                new Date().getTime() - start_time >= req.timeout
                            ) {
                                error = 'timeout';
                            } else {
                                error = 'Bad HTTP status: ' + req.status + ' ' + req.statusText;
                            }
                            lib.report_error(error);
                            if (callback) {
                                if (verbose_mode) {
                                    callback({status: 0, error: error, xhr_req: req});
                                } else {
                                    callback(0);
                                }
                            }
                        }
                    }
                };
                req.send(body_data);
            } catch (e) {
                lib.report_error(e);
                succeeded = false;
            }
        } else {
            var script = document$1.createElement('script');
            script.type = 'text/javascript';
            script.async = true;
            script.defer = true;
            script.src = url;
            var s = document$1.getElementsByTagName('script')[0];
            s.parentNode.insertBefore(script, s);
        }

        return succeeded;
    };

    /**
     * _execute_array() deals with processing any mixpanel function
     * calls that were called before the Mixpanel library were loaded
     * (and are thus stored in an array so they can be called later)
     *
     * Note: we fire off all the mixpanel function calls && user defined
     * functions BEFORE we fire off mixpanel tracking calls. This is so
     * identify/register/set_config calls can properly modify early
     * tracking calls.
     *
     * @param {Array} array
     */
    MixpanelLib.prototype._execute_array = function(array) {
        var fn_name, alias_calls = [], other_calls = [], tracking_calls = [];
        _.each(array, function(item) {
            if (item) {
                fn_name = item[0];
                if (_.isArray(fn_name)) {
                    tracking_calls.push(item); // chained call e.g. mixpanel.get_group().set()
                } else if (typeof(item) === 'function') {
                    item.call(this);
                } else if (_.isArray(item) && fn_name === 'alias') {
                    alias_calls.push(item);
                } else if (_.isArray(item) && fn_name.indexOf('track') !== -1 && typeof(this[fn_name]) === 'function') {
                    tracking_calls.push(item);
                } else {
                    other_calls.push(item);
                }
            }
        }, this);

        var execute = function(calls, context) {
            _.each(calls, function(item) {
                if (_.isArray(item[0])) {
                    // chained call
                    var caller = context;
                    _.each(item, function(call) {
                        caller = caller[call[0]].apply(caller, call.slice(1));
                    });
                } else {
                    this[item[0]].apply(this, item.slice(1));
                }
            }, context);
        };

        execute(alias_calls, this);
        execute(other_calls, this);
        execute(tracking_calls, this);
    };

    // request queueing utils

    MixpanelLib.prototype.are_batchers_initialized = function() {
        return !!this.request_batchers.events;
    };

    MixpanelLib.prototype.init_batchers = function() {
        var token = this.get_config('token');
        if (!this.are_batchers_initialized()) {
            var batcher_for = _.bind(function(attrs) {
                return new RequestBatcher(
                    '__mpq_' + token + attrs.queue_suffix,
                    {
                        libConfig: this['config'],
                        sendRequestFunc: _.bind(function(data, options, cb) {
                            this._send_request(
                                this.get_config('api_host') + attrs.endpoint,
                                this._encode_data_for_request(data),
                                options,
                                this._prepare_callback(cb, data)
                            );
                        }, this),
                        beforeSendHook: _.bind(function(item) {
                            return this._run_hook('before_send_' + attrs.type, item);
                        }, this),
                        errorReporter: this.get_config('error_reporter'),
                        stopAllBatchingFunc: _.bind(this.stop_batch_senders, this)
                    }
                );
            }, this);
            this.request_batchers = {
                events: batcher_for({type: 'events', endpoint: '/track/', queue_suffix: '_ev'}),
                people: batcher_for({type: 'people', endpoint: '/engage/', queue_suffix: '_pp'}),
                groups: batcher_for({type: 'groups', endpoint: '/groups/', queue_suffix: '_gr'})
            };
        }
        if (this.get_config('batch_autostart')) {
            this.start_batch_senders();
        }
    };

    MixpanelLib.prototype.start_batch_senders = function() {
        if (this.are_batchers_initialized()) {
            this._batch_requests = true;
            _.each(this.request_batchers, function(batcher) {
                batcher.start();
            });
        }
    };

    MixpanelLib.prototype.stop_batch_senders = function() {
        this._batch_requests = false;
        _.each(this.request_batchers, function(batcher) {
            batcher.stop();
            batcher.clear();
        });
    };

    /**
     * push() keeps the standard async-array-push
     * behavior around after the lib is loaded.
     * This is only useful for external integrations that
     * do not wish to rely on our convenience methods
     * (created in the snippet).
     *
     * ### Usage:
     *     mixpanel.push(['register', { a: 'b' }]);
     *
     * @param {Array} item A [function_name, args...] array to be executed
     */
    MixpanelLib.prototype.push = function(item) {
        this._execute_array([item]);
    };

    /**
     * Disable events on the Mixpanel object. If passed no arguments,
     * this function disables tracking of any event. If passed an
     * array of event names, those events will be disabled, but other
     * events will continue to be tracked.
     *
     * Note: this function does not stop other mixpanel functions from
     * firing, such as register() or people.set().
     *
     * @param {Array} [events] An array of event names to disable
     */
    MixpanelLib.prototype.disable = function(events) {
        if (typeof(events) === 'undefined') {
            this._flags.disable_all_events = true;
        } else {
            this.__disabled_events = this.__disabled_events.concat(events);
        }
    };

    MixpanelLib.prototype._encode_data_for_request = function(data) {
        var encoded_data = _.JSONEncode(data);
        if (this.get_config('api_payload_format') === PAYLOAD_TYPE_BASE64) {
            encoded_data = _.base64Encode(encoded_data);
        }
        return {'data': encoded_data};
    };

    // internal method for handling track vs batch-enqueue logic
    MixpanelLib.prototype._track_or_batch = function(options, callback) {
        var truncated_data = _.truncate(options.data, 255);
        var endpoint = options.endpoint;
        var batcher = options.batcher;
        var should_send_immediately = options.should_send_immediately;
        var send_request_options = options.send_request_options || {};
        callback = callback || NOOP_FUNC;

        var request_enqueued_or_initiated = true;
        var send_request_immediately = _.bind(function() {
            if (!send_request_options.skip_hooks) {
                truncated_data = this._run_hook('before_send_' + options.type, truncated_data);
            }
            if (truncated_data) {
                console$1.log('MIXPANEL REQUEST:');
                console$1.log(truncated_data);
                return this._send_request(
                    endpoint,
                    this._encode_data_for_request(truncated_data),
                    send_request_options,
                    this._prepare_callback(callback, truncated_data)
                );
            } else {
                return null;
            }
        }, this);

        if (this._batch_requests && !should_send_immediately) {
            batcher.enqueue(truncated_data, function(succeeded) {
                if (succeeded) {
                    callback(1, truncated_data);
                } else {
                    send_request_immediately();
                }
            });
        } else {
            request_enqueued_or_initiated = send_request_immediately();
        }

        return request_enqueued_or_initiated && truncated_data;
    };

    /**
     * Track an event. This is the most important and
     * frequently used Mixpanel function.
     *
     * ### Usage:
     *
     *     // track an event named 'Registered'
     *     mixpanel.track('Registered', {'Gender': 'Male', 'Age': 21});
     *
     *     // track an event using navigator.sendBeacon
     *     mixpanel.track('Left page', {'duration_seconds': 35}, {transport: 'sendBeacon'});
     *
     * To track link clicks or form submissions, see track_links() or track_forms().
     *
     * @param {String} event_name The name of the event. This can be anything the user does - 'Button Click', 'Sign Up', 'Item Purchased', etc.
     * @param {Object} [properties] A set of properties to include with the event you're sending. These describe the user who did the event or details about the event itself.
     * @param {Object} [options] Optional configuration for this track request.
     * @param {String} [options.transport] Transport method for network request ('xhr' or 'sendBeacon').
     * @param {Boolean} [options.send_immediately] Whether to bypass batching/queueing and send track request immediately.
     * @param {Function} [callback] If provided, the callback function will be called after tracking the event.
     * @returns {Boolean|Object} If the tracking request was successfully initiated/queued, an object
     * with the tracking payload sent to the API server is returned; otherwise false.
     */
    MixpanelLib.prototype.track = addOptOutCheckMixpanelLib(function(event_name, properties, options, callback) {
        if (!callback && typeof options === 'function') {
            callback = options;
            options = null;
        }
        options = options || {};
        var transport = options['transport']; // external API, don't minify 'transport' prop
        if (transport) {
            options.transport = transport; // 'transport' prop name can be minified internally
        }
        var should_send_immediately = options['send_immediately'];
        if (typeof callback !== 'function') {
            callback = NOOP_FUNC;
        }

        if (_.isUndefined(event_name)) {
            this.report_error('No event name provided to mixpanel.track');
            return;
        }

        if (this._event_is_disabled(event_name)) {
            callback(0);
            return;
        }

        // set defaults
        properties = properties || {};
        properties['token'] = this.get_config('token');

        // set $duration if time_event was previously called for this event
        var start_timestamp = this['persistence'].remove_event_timer(event_name);
        if (!_.isUndefined(start_timestamp)) {
            var duration_in_ms = new Date().getTime() - start_timestamp;
            properties['$duration'] = parseFloat((duration_in_ms / 1000).toFixed(3));
        }

        this._set_default_superprops();

        var marketing_properties = this.get_config('track_marketing')
            ? _.info.marketingParams()
            : {};

        // note: extend writes to the first object, so lets make sure we
        // don't write to the persistence properties object and info
        // properties object by passing in a new object

        // update properties with pageview info and super-properties
        properties = _.extend(
            {},
            _.info.properties(),
            marketing_properties,
            this['persistence'].properties(),
            this.unpersisted_superprops,
            properties
        );

        var property_blacklist = this.get_config('property_blacklist');
        if (_.isArray(property_blacklist)) {
            _.each(property_blacklist, function(blacklisted_prop) {
                delete properties[blacklisted_prop];
            });
        } else {
            this.report_error('Invalid value for property_blacklist config: ' + property_blacklist);
        }

        var data = {
            'event': event_name,
            'properties': properties
        };
        var ret = this._track_or_batch({
            type: 'events',
            data: data,
            endpoint: this.get_config('api_host') + '/track/',
            batcher: this.request_batchers.events,
            should_send_immediately: should_send_immediately,
            send_request_options: options
        }, callback);

        return ret;
    });

    /**
     * Register the current user into one/many groups.
     *
     * ### Usage:
     *
     *      mixpanel.set_group('company', ['mixpanel', 'google']) // an array of IDs
     *      mixpanel.set_group('company', 'mixpanel')
     *      mixpanel.set_group('company', 128746312)
     *
     * @param {String} group_key Group key
     * @param {Array|String|Number} group_ids An array of group IDs, or a singular group ID
     * @param {Function} [callback] If provided, the callback will be called after tracking the event.
     *
     */
    MixpanelLib.prototype.set_group = addOptOutCheckMixpanelLib(function(group_key, group_ids, callback) {
        if (!_.isArray(group_ids)) {
            group_ids = [group_ids];
        }
        var prop = {};
        prop[group_key] = group_ids;
        this.register(prop);
        return this['people'].set(group_key, group_ids, callback);
    });

    /**
     * Add a new group for this user.
     *
     * ### Usage:
     *
     *      mixpanel.add_group('company', 'mixpanel')
     *
     * @param {String} group_key Group key
     * @param {*} group_id A valid Mixpanel property type
     * @param {Function} [callback] If provided, the callback will be called after tracking the event.
     */
    MixpanelLib.prototype.add_group = addOptOutCheckMixpanelLib(function(group_key, group_id, callback) {
        var old_values = this.get_property(group_key);
        if (old_values === undefined) {
            var prop = {};
            prop[group_key] = [group_id];
            this.register(prop);
        } else {
            if (old_values.indexOf(group_id) === -1) {
                old_values.push(group_id);
                this.register(prop);
            }
        }
        return this['people'].union(group_key, group_id, callback);
    });

    /**
     * Remove a group from this user.
     *
     * ### Usage:
     *
     *      mixpanel.remove_group('company', 'mixpanel')
     *
     * @param {String} group_key Group key
     * @param {*} group_id A valid Mixpanel property type
     * @param {Function} [callback] If provided, the callback will be called after tracking the event.
     */
    MixpanelLib.prototype.remove_group = addOptOutCheckMixpanelLib(function(group_key, group_id, callback) {
        var old_value = this.get_property(group_key);
        // if the value doesn't exist, the persistent store is unchanged
        if (old_value !== undefined) {
            var idx = old_value.indexOf(group_id);
            if (idx > -1) {
                old_value.splice(idx, 1);
                this.register({group_key: old_value});
            }
            if (old_value.length === 0) {
                this.unregister(group_key);
            }
        }
        return this['people'].remove(group_key, group_id, callback);
    });

    /**
     * Track an event with specific groups.
     *
     * ### Usage:
     *
     *      mixpanel.track_with_groups('purchase', {'product': 'iphone'}, {'University': ['UCB', 'UCLA']})
     *
     * @param {String} event_name The name of the event (see `mixpanel.track()`)
     * @param {Object=} properties A set of properties to include with the event you're sending (see `mixpanel.track()`)
     * @param {Object=} groups An object mapping group name keys to one or more values
     * @param {Function} [callback] If provided, the callback will be called after tracking the event.
     */
    MixpanelLib.prototype.track_with_groups = addOptOutCheckMixpanelLib(function(event_name, properties, groups, callback) {
        var tracking_props = _.extend({}, properties || {});
        _.each(groups, function(v, k) {
            if (v !== null && v !== undefined) {
                tracking_props[k] = v;
            }
        });
        return this.track(event_name, tracking_props, callback);
    });

    MixpanelLib.prototype._create_map_key = function (group_key, group_id) {
        return group_key + '_' + JSON.stringify(group_id);
    };

    MixpanelLib.prototype._remove_group_from_cache = function (group_key, group_id) {
        delete this._cached_groups[this._create_map_key(group_key, group_id)];
    };

    /**
     * Look up reference to a Mixpanel group
     *
     * ### Usage:
     *
     *       mixpanel.get_group(group_key, group_id)
     *
     * @param {String} group_key Group key
     * @param {Object} group_id A valid Mixpanel property type
     * @returns {Object} A MixpanelGroup identifier
     */
    MixpanelLib.prototype.get_group = function (group_key, group_id) {
        var map_key = this._create_map_key(group_key, group_id);
        var group = this._cached_groups[map_key];
        if (group === undefined || group._group_key !== group_key || group._group_id !== group_id) {
            group = new MixpanelGroup();
            group._init(this, group_key, group_id);
            this._cached_groups[map_key] = group;
        }
        return group;
    };

    /**
     * Track a default Mixpanel page view event, which includes extra default event properties to
     * improve page view data. The `config.track_pageview` option for <a href="#mixpanelinit">mixpanel.init()</a>
     * may be turned on for tracking page loads automatically.
     *
     * ### Usage
     *
     *     // track a default $mp_web_page_view event
     *     mixpanel.track_pageview();
     *
     *     // track a page view event with additional event properties
     *     mixpanel.track_pageview({'ab_test_variant': 'card-layout-b'});
     *
     *     // example approach to track page views on different page types as event properties
     *     mixpanel.track_pageview({'page': 'pricing'});
     *     mixpanel.track_pageview({'page': 'homepage'});
     *
     *     // UNCOMMON: Tracking a page view event with a custom event_name option. NOT expected to be used for
     *     // individual pages on the same site or product. Use cases for custom event_name may be page
     *     // views on different products or internal applications that are considered completely separate
     *     mixpanel.track_pageview({'page': 'customer-search'}, {'event_name': '[internal] Admin Page View'});
     *
     * @param {Object} [properties] An optional set of additional properties to send with the page view event
     * @param {Object} [options] Page view tracking options
     * @param {String} [options.event_name] - Alternate name for the tracking event
     * @returns {Boolean|Object} If the tracking request was successfully initiated/queued, an object
     * with the tracking payload sent to the API server is returned; otherwise false.
     */
    MixpanelLib.prototype.track_pageview = addOptOutCheckMixpanelLib(function(properties, options) {
        if (typeof properties !== 'object') {
            properties = {};
        }
        options = options || {};
        var event_name = options['event_name'] || '$mp_web_page_view';

        var default_page_properties = _.extend(
            _.info.mpPageViewProperties(),
            _.info.campaignParams(),
            _.info.clickParams()
        );

        var event_properties = _.extend(
            {},
            default_page_properties,
            properties
        );

        return this.track(event_name, event_properties);
    });

    /**
     * Track clicks on a set of document elements. Selector must be a
     * valid query. Elements must exist on the page at the time track_links is called.
     *
     * ### Usage:
     *
     *     // track click for link id #nav
     *     mixpanel.track_links('#nav', 'Clicked Nav Link');
     *
     * ### Notes:
     *
     * This function will wait up to 300 ms for the Mixpanel
     * servers to respond. If they have not responded by that time
     * it will head to the link without ensuring that your event
     * has been tracked.  To configure this timeout please see the
     * set_config() documentation below.
     *
     * If you pass a function in as the properties argument, the
     * function will receive the DOMElement that triggered the
     * event as an argument.  You are expected to return an object
     * from the function; any properties defined on this object
     * will be sent to mixpanel as event properties.
     *
     * @type {Function}
     * @param {Object|String} query A valid DOM query, element or jQuery-esque list
     * @param {String} event_name The name of the event to track
     * @param {Object|Function} [properties] A properties object or function that returns a dictionary of properties when passed a DOMElement
     */
    MixpanelLib.prototype.track_links = function() {
        return this._track_dom.call(this, LinkTracker, arguments);
    };

    /**
     * Track form submissions. Selector must be a valid query.
     *
     * ### Usage:
     *
     *     // track submission for form id 'register'
     *     mixpanel.track_forms('#register', 'Created Account');
     *
     * ### Notes:
     *
     * This function will wait up to 300 ms for the mixpanel
     * servers to respond, if they have not responded by that time
     * it will head to the link without ensuring that your event
     * has been tracked.  To configure this timeout please see the
     * set_config() documentation below.
     *
     * If you pass a function in as the properties argument, the
     * function will receive the DOMElement that triggered the
     * event as an argument.  You are expected to return an object
     * from the function; any properties defined on this object
     * will be sent to mixpanel as event properties.
     *
     * @type {Function}
     * @param {Object|String} query A valid DOM query, element or jQuery-esque list
     * @param {String} event_name The name of the event to track
     * @param {Object|Function} [properties] This can be a set of properties, or a function that returns a set of properties after being passed a DOMElement
     */
    MixpanelLib.prototype.track_forms = function() {
        return this._track_dom.call(this, FormTracker, arguments);
    };

    /**
     * Time an event by including the time between this call and a
     * later 'track' call for the same event in the properties sent
     * with the event.
     *
     * ### Usage:
     *
     *     // time an event named 'Registered'
     *     mixpanel.time_event('Registered');
     *     mixpanel.track('Registered', {'Gender': 'Male', 'Age': 21});
     *
     * When called for a particular event name, the next track call for that event
     * name will include the elapsed time between the 'time_event' and 'track'
     * calls. This value is stored as seconds in the '$duration' property.
     *
     * @param {String} event_name The name of the event.
     */
    MixpanelLib.prototype.time_event = function(event_name) {
        if (_.isUndefined(event_name)) {
            this.report_error('No event name provided to mixpanel.time_event');
            return;
        }

        if (this._event_is_disabled(event_name)) {
            return;
        }

        this['persistence'].set_event_timer(event_name,  new Date().getTime());
    };

    var REGISTER_DEFAULTS = {
        'persistent': true
    };
    /**
     * Helper to parse options param for register methods, maintaining
     * legacy support for plain "days" param instead of options object
     * @param {Number|Object} [days_or_options] 'days' option (Number), or Options object for register methods
     * @returns {Object} options object
     */
    var options_for_register = function(days_or_options) {
        var options;
        if (_.isObject(days_or_options)) {
            options = days_or_options;
        } else if (!_.isUndefined(days_or_options)) {
            options = {'days': days_or_options};
        } else {
            options = {};
        }
        return _.extend({}, REGISTER_DEFAULTS, options);
    };

    /**
     * Register a set of super properties, which are included with all
     * events. This will overwrite previous super property values.
     *
     * ### Usage:
     *
     *     // register 'Gender' as a super property
     *     mixpanel.register({'Gender': 'Female'});
     *
     *     // register several super properties when a user signs up
     *     mixpanel.register({
     *         'Email': 'jdoe@example.com',
     *         'Account Type': 'Free'
     *     });
     *
     *     // register only for the current pageload
     *     mixpanel.register({'Name': 'Pat'}, {persistent: false});
     *
     * @param {Object} properties An associative array of properties to store about the user
     * @param {Number|Object} [days_or_options] Options object or number of days since the user's last visit to store the super properties (only valid for persisted props)
     * @param {boolean} [days_or_options.days] - number of days since the user's last visit to store the super properties (only valid for persisted props)
     * @param {boolean} [days_or_options.persistent=true] - whether to put in persistent storage (cookie/localStorage)
     */
    MixpanelLib.prototype.register = function(props, days_or_options) {
        var options = options_for_register(days_or_options);
        if (options['persistent']) {
            this['persistence'].register(props, options['days']);
        } else {
            _.extend(this.unpersisted_superprops, props);
        }
    };

    /**
     * Register a set of super properties only once. This will not
     * overwrite previous super property values, unlike register().
     *
     * ### Usage:
     *
     *     // register a super property for the first time only
     *     mixpanel.register_once({
     *         'First Login Date': new Date().toISOString()
     *     });
     *
     *     // register once, only for the current pageload
     *     mixpanel.register_once({
     *         'First interaction time': new Date().toISOString()
     *     }, 'None', {persistent: false});
     *
     * ### Notes:
     *
     * If default_value is specified, current super properties
     * with that value will be overwritten.
     *
     * @param {Object} properties An associative array of properties to store about the user
     * @param {*} [default_value] Value to override if already set in super properties (ex: 'False') Default: 'None'
     * @param {Number|Object} [days_or_options] Options object or number of days since the user's last visit to store the super properties (only valid for persisted props)
     * @param {boolean} [days_or_options.days] - number of days since the user's last visit to store the super properties (only valid for persisted props)
     * @param {boolean} [days_or_options.persistent=true] - whether to put in persistent storage (cookie/localStorage)
     */
    MixpanelLib.prototype.register_once = function(props, default_value, days_or_options) {
        var options = options_for_register(days_or_options);
        if (options['persistent']) {
            this['persistence'].register_once(props, default_value, options['days']);
        } else {
            if (typeof(default_value) === 'undefined') {
                default_value = 'None';
            }
            _.each(props, function(val, prop) {
                if (!this.unpersisted_superprops.hasOwnProperty(prop) || this.unpersisted_superprops[prop] === default_value) {
                    this.unpersisted_superprops[prop] = val;
                }
            }, this);
        }
    };

    /**
     * Delete a super property stored with the current user.
     *
     * @param {String} property The name of the super property to remove
     * @param {Object} [options]
     * @param {boolean} [options.persistent=true] - whether to look in persistent storage (cookie/localStorage)
     */
    MixpanelLib.prototype.unregister = function(property, options) {
        options = options_for_register(options);
        if (options['persistent']) {
            this['persistence'].unregister(property);
        } else {
            delete this.unpersisted_superprops[property];
        }
    };

    MixpanelLib.prototype._register_single = function(prop, value) {
        var props = {};
        props[prop] = value;
        this.register(props);
    };

    /**
     * Identify a user with a unique ID to track user activity across
     * devices, tie a user to their events, and create a user profile.
     * If you never call this method, unique visitors are tracked using
     * a UUID generated the first time they visit the site.
     *
     * Call identify when you know the identity of the current user,
     * typically after login or signup. We recommend against using
     * identify for anonymous visitors to your site.
     *
     * ### Notes:
     * If your project has
     * <a href="https://help.mixpanel.com/hc/en-us/articles/360039133851">ID Merge</a>
     * enabled, the identify method will connect pre- and
     * post-authentication events when appropriate.
     *
     * If your project does not have ID Merge enabled, identify will
     * change the user's local distinct_id to the unique ID you pass.
     * Events tracked prior to authentication will not be connected
     * to the same user identity. If ID Merge is disabled, alias can
     * be used to connect pre- and post-registration events.
     *
     * @param {String} [unique_id] A string that uniquely identifies a user. If not provided, the distinct_id currently in the persistent store (cookie or localStorage) will be used.
     */
    MixpanelLib.prototype.identify = function(
        new_distinct_id, _set_callback, _add_callback, _append_callback, _set_once_callback, _union_callback, _unset_callback, _remove_callback
    ) {
        // Optional Parameters
        //  _set_callback:function  A callback to be run if and when the People set queue is flushed
        //  _add_callback:function  A callback to be run if and when the People add queue is flushed
        //  _append_callback:function  A callback to be run if and when the People append queue is flushed
        //  _set_once_callback:function  A callback to be run if and when the People set_once queue is flushed
        //  _union_callback:function  A callback to be run if and when the People union queue is flushed
        //  _unset_callback:function  A callback to be run if and when the People unset queue is flushed

        var previous_distinct_id = this.get_distinct_id();
        if (new_distinct_id && previous_distinct_id !== new_distinct_id) {
            // we allow the following condition if previous distinct_id is same as new_distinct_id
            // so that you can force flush people updates for anonymous profiles.
            if (typeof new_distinct_id === 'string' && new_distinct_id.indexOf(DEVICE_ID_PREFIX) === 0) {
                this.report_error('distinct_id cannot have $device: prefix');
                return -1;
            }
            this.register({'$user_id': new_distinct_id});
        }

        if (!this.get_property('$device_id')) {
            // The persisted distinct id might not actually be a device id at all
            // it might be a distinct id of the user from before
            var device_id = previous_distinct_id;
            this.register_once({
                '$had_persisted_distinct_id': true,
                '$device_id': device_id
            }, '');
        }

        // identify only changes the distinct id if it doesn't match either the existing or the alias;
        // if it's new, blow away the alias as well.
        if (new_distinct_id !== previous_distinct_id && new_distinct_id !== this.get_property(ALIAS_ID_KEY)) {
            this.unregister(ALIAS_ID_KEY);
            this.register({'distinct_id': new_distinct_id});
        }
        this._flags.identify_called = true;
        // Flush any queued up people requests
        this['people']._flush(_set_callback, _add_callback, _append_callback, _set_once_callback, _union_callback, _unset_callback, _remove_callback);

        // send an $identify event any time the distinct_id is changing - logic on the server
        // will determine whether or not to do anything with it.
        if (new_distinct_id !== previous_distinct_id) {
            this.track('$identify', {
                'distinct_id': new_distinct_id,
                '$anon_distinct_id': previous_distinct_id
            }, {skip_hooks: true});
        }
    };

    /**
     * Clears super properties and generates a new random distinct_id for this instance.
     * Useful for clearing data when a user logs out.
     */
    MixpanelLib.prototype.reset = function() {
        this['persistence'].clear();
        this._flags.identify_called = false;
        var uuid = _.UUID();
        this.register_once({
            'distinct_id': DEVICE_ID_PREFIX + uuid,
            '$device_id': uuid
        }, '');
    };

    /**
     * Returns the current distinct id of the user. This is either the id automatically
     * generated by the library or the id that has been passed by a call to identify().
     *
     * ### Notes:
     *
     * get_distinct_id() can only be called after the Mixpanel library has finished loading.
     * init() has a loaded function available to handle this automatically. For example:
     *
     *     // set distinct_id after the mixpanel library has loaded
     *     mixpanel.init('YOUR PROJECT TOKEN', {
     *         loaded: function(mixpanel) {
     *             distinct_id = mixpanel.get_distinct_id();
     *         }
     *     });
     */
    MixpanelLib.prototype.get_distinct_id = function() {
        return this.get_property('distinct_id');
    };

    /**
     * The alias method creates an alias which Mixpanel will use to
     * remap one id to another. Multiple aliases can point to the
     * same identifier.
     *
     * The following is a valid use of alias:
     *
     *     mixpanel.alias('new_id', 'existing_id');
     *     // You can add multiple id aliases to the existing ID
     *     mixpanel.alias('newer_id', 'existing_id');
     *
     * Aliases can also be chained - the following is a valid example:
     *
     *     mixpanel.alias('new_id', 'existing_id');
     *     // chain newer_id - new_id - existing_id
     *     mixpanel.alias('newer_id', 'new_id');
     *
     * Aliases cannot point to multiple identifiers - the following
     * example will not work:
     *
     *     mixpanel.alias('new_id', 'existing_id');
     *     // this is invalid as 'new_id' already points to 'existing_id'
     *     mixpanel.alias('new_id', 'newer_id');
     *
     * ### Notes:
     *
     * If your project does not have
     * <a href="https://help.mixpanel.com/hc/en-us/articles/360039133851">ID Merge</a>
     * enabled, the best practice is to call alias once when a unique
     * ID is first created for a user (e.g., when a user first registers
     * for an account). Do not use alias multiple times for a single
     * user without ID Merge enabled.
     *
     * @param {String} alias A unique identifier that you want to use for this user in the future.
     * @param {String} [original] The current identifier being used for this user.
     */
    MixpanelLib.prototype.alias = function(alias, original) {
        // If the $people_distinct_id key exists in persistence, there has been a previous
        // mixpanel.people.identify() call made for this user. It is VERY BAD to make an alias with
        // this ID, as it will duplicate users.
        if (alias === this.get_property(PEOPLE_DISTINCT_ID_KEY)) {
            this.report_error('Attempting to create alias for existing People user - aborting.');
            return -2;
        }

        var _this = this;
        if (_.isUndefined(original)) {
            original = this.get_distinct_id();
        }
        if (alias !== original) {
            this._register_single(ALIAS_ID_KEY, alias);
            return this.track('$create_alias', {
                'alias': alias,
                'distinct_id': original
            }, {
                skip_hooks: true
            }, function() {
                // Flush the people queue
                _this.identify(alias);
            });
        } else {
            this.report_error('alias matches current distinct_id - skipping api call.');
            this.identify(alias);
            return -1;
        }
    };

    /**
     * Provide a string to recognize the user by. The string passed to
     * this method will appear in the Mixpanel Streams product rather
     * than an automatically generated name. Name tags do not have to
     * be unique.
     *
     * This value will only be included in Streams data.
     *
     * @param {String} name_tag A human readable name for the user
     * @deprecated
     */
    MixpanelLib.prototype.name_tag = function(name_tag) {
        this._register_single('mp_name_tag', name_tag);
    };

    /**
     * Update the configuration of a mixpanel library instance.
     *
     * The default config is:
     *
     *     {
     *       // HTTP method for tracking requests
     *       api_method: 'POST'
     *
     *       // transport for sending requests ('XHR' or 'sendBeacon')
     *       // NB: sendBeacon should only be used for scenarios such as
     *       // page unload where a "best-effort" attempt to send is
     *       // acceptable; the sendBeacon API does not support callbacks
     *       // or any way to know the result of the request. Mixpanel
     *       // tracking via sendBeacon will not support any event-
     *       // batching or retry mechanisms.
     *       api_transport: 'XHR'
     *
     *       // request-batching/queueing/retry
     *       batch_requests: true,
     *
     *       // maximum number of events/updates to send in a single
     *       // network request
     *       batch_size: 50,
     *
     *       // milliseconds to wait between sending batch requests
     *       batch_flush_interval_ms: 5000,
     *
     *       // milliseconds to wait for network responses to batch requests
     *       // before they are considered timed-out and retried
     *       batch_request_timeout_ms: 90000,
     *
     *       // override value for cookie domain, only useful for ensuring
     *       // correct cross-subdomain cookies on unusual domains like
     *       // subdomain.mainsite.avocat.fr; NB this cannot be used to
     *       // set cookies on a different domain than the current origin
     *       cookie_domain: ''
     *
     *       // super properties cookie expiration (in days)
     *       cookie_expiration: 365
     *
     *       // if true, cookie will be set with SameSite=None; Secure
     *       // this is only useful in special situations, like embedded
     *       // 3rd-party iframes that set up a Mixpanel instance
     *       cross_site_cookie: false
     *
     *       // super properties span subdomains
     *       cross_subdomain_cookie: true
     *
     *       // debug mode
     *       debug: false
     *
     *       // if this is true, the mixpanel cookie or localStorage entry
     *       // will be deleted, and no user persistence will take place
     *       disable_persistence: false
     *
     *       // if this is true, Mixpanel will automatically determine
     *       // City, Region and Country data using the IP address of
     *       //the client
     *       ip: true
     *
     *       // opt users out of tracking by this Mixpanel instance by default
     *       opt_out_tracking_by_default: false
     *
     *       // opt users out of browser data storage by this Mixpanel instance by default
     *       opt_out_persistence_by_default: false
     *
     *       // persistence mechanism used by opt-in/opt-out methods - cookie
     *       // or localStorage - falls back to cookie if localStorage is unavailable
     *       opt_out_tracking_persistence_type: 'localStorage'
     *
     *       // customize the name of cookie/localStorage set by opt-in/opt-out methods
     *       opt_out_tracking_cookie_prefix: null
     *
     *       // type of persistent store for super properties (cookie/
     *       // localStorage) if set to 'localStorage', any existing
     *       // mixpanel cookie value with the same persistence_name
     *       // will be transferred to localStorage and deleted
     *       persistence: 'cookie'
     *
     *       // name for super properties persistent store
     *       persistence_name: ''
     *
     *       // names of properties/superproperties which should never
     *       // be sent with track() calls
     *       property_blacklist: []
     *
     *       // if this is true, mixpanel cookies will be marked as
     *       // secure, meaning they will only be transmitted over https
     *       secure_cookie: false
     *
     *       // disables enriching user profiles with first touch marketing data
     *       skip_first_touch_marketing: false
     *
     *       // the amount of time track_links will
     *       // wait for Mixpanel's servers to respond
     *       track_links_timeout: 300
     *
     *       // adds any UTM parameters and click IDs present on the page to any events fired
     *       track_marketing: true
     *
     *       // enables automatic page view tracking using default page view events through
     *       // the track_pageview() method
     *       track_pageview: false
     *
     *       // if you set upgrade to be true, the library will check for
     *       // a cookie from our old js library and import super
     *       // properties from it, then the old cookie is deleted
     *       // The upgrade config option only works in the initialization,
     *       // so make sure you set it when you create the library.
     *       upgrade: false
     *
     *       // extra HTTP request headers to set for each API request, in
     *       // the format {'Header-Name': value}
     *       xhr_headers: {}
     *
     *       // whether to ignore or respect the web browser's Do Not Track setting
     *       ignore_dnt: false
     *     }
     *
     *
     * @param {Object} config A dictionary of new configuration values to update
     */
    MixpanelLib.prototype.set_config = function(config) {
        if (_.isObject(config)) {
            _.extend(this['config'], config);

            var new_batch_size = config['batch_size'];
            if (new_batch_size) {
                _.each(this.request_batchers, function(batcher) {
                    batcher.resetBatchSize();
                });
            }

            if (!this.get_config('persistence_name')) {
                this['config']['persistence_name'] = this['config']['cookie_name'];
            }
            if (!this.get_config('disable_persistence')) {
                this['config']['disable_persistence'] = this['config']['disable_cookie'];
            }

            if (this['persistence']) {
                this['persistence'].update_config(this['config']);
            }
            Config.DEBUG = Config.DEBUG || this.get_config('debug');
        }
    };

    /**
     * returns the current config object for the library.
     */
    MixpanelLib.prototype.get_config = function(prop_name) {
        return this['config'][prop_name];
    };

    /**
     * Fetch a hook function from config, with safe default, and run it
     * against the given arguments
     * @param {string} hook_name which hook to retrieve
     * @returns {any|null} return value of user-provided hook, or null if nothing was returned
     */
    MixpanelLib.prototype._run_hook = function(hook_name) {
        var ret = (this['config']['hooks'][hook_name] || IDENTITY_FUNC).apply(this, slice.call(arguments, 1));
        if (typeof ret === 'undefined') {
            this.report_error(hook_name + ' hook did not return a value');
            ret = null;
        }
        return ret;
    };

    /**
     * Returns the value of the super property named property_name. If no such
     * property is set, get_property() will return the undefined value.
     *
     * ### Notes:
     *
     * get_property() can only be called after the Mixpanel library has finished loading.
     * init() has a loaded function available to handle this automatically. For example:
     *
     *     // grab value for 'user_id' after the mixpanel library has loaded
     *     mixpanel.init('YOUR PROJECT TOKEN', {
     *         loaded: function(mixpanel) {
     *             user_id = mixpanel.get_property('user_id');
     *         }
     *     });
     *
     * @param {String} property_name The name of the super property you want to retrieve
     */
    MixpanelLib.prototype.get_property = function(property_name) {
        return this['persistence']['props'][property_name];
    };

    MixpanelLib.prototype.toString = function() {
        var name = this.get_config('name');
        if (name !== PRIMARY_INSTANCE_NAME) {
            name = PRIMARY_INSTANCE_NAME + '.' + name;
        }
        return name;
    };

    MixpanelLib.prototype._event_is_disabled = function(event_name) {
        return _.isBlockedUA(userAgent) ||
            this._flags.disable_all_events ||
            _.include(this.__disabled_events, event_name);
    };

    // perform some housekeeping around GDPR opt-in/out state
    MixpanelLib.prototype._gdpr_init = function() {
        var is_localStorage_requested = this.get_config('opt_out_tracking_persistence_type') === 'localStorage';

        // try to convert opt-in/out cookies to localStorage if possible
        if (is_localStorage_requested && _.localStorage.is_supported()) {
            if (!this.has_opted_in_tracking() && this.has_opted_in_tracking({'persistence_type': 'cookie'})) {
                this.opt_in_tracking({'enable_persistence': false});
            }
            if (!this.has_opted_out_tracking() && this.has_opted_out_tracking({'persistence_type': 'cookie'})) {
                this.opt_out_tracking({'clear_persistence': false});
            }
            this.clear_opt_in_out_tracking({
                'persistence_type': 'cookie',
                'enable_persistence': false
            });
        }

        // check whether the user has already opted out - if so, clear & disable persistence
        if (this.has_opted_out_tracking()) {
            this._gdpr_update_persistence({'clear_persistence': true});

        // check whether we should opt out by default
        // note: we don't clear persistence here by default since opt-out default state is often
        //       used as an initial state while GDPR information is being collected
        } else if (!this.has_opted_in_tracking() && (
            this.get_config('opt_out_tracking_by_default') || _.cookie.get('mp_optout')
        )) {
            _.cookie.remove('mp_optout');
            this.opt_out_tracking({
                'clear_persistence': this.get_config('opt_out_persistence_by_default')
            });
        }
    };

    /**
     * Enable or disable persistence based on options
     * only enable/disable if persistence is not already in this state
     * @param {boolean} [options.clear_persistence] If true, will delete all data stored by the sdk in persistence and disable it
     * @param {boolean} [options.enable_persistence] If true, will re-enable sdk persistence
     */
    MixpanelLib.prototype._gdpr_update_persistence = function(options) {
        var disabled;
        if (options && options['clear_persistence']) {
            disabled = true;
        } else if (options && options['enable_persistence']) {
            disabled = false;
        } else {
            return;
        }

        if (!this.get_config('disable_persistence') && this['persistence'].disabled !== disabled) {
            this['persistence'].set_disabled(disabled);
        }

        if (disabled) {
            _.each(this.request_batchers, function(batcher) {
                batcher.clear();
            });
        }
    };

    // call a base gdpr function after constructing the appropriate token and options args
    MixpanelLib.prototype._gdpr_call_func = function(func, options) {
        options = _.extend({
            'track': _.bind(this.track, this),
            'persistence_type': this.get_config('opt_out_tracking_persistence_type'),
            'cookie_prefix': this.get_config('opt_out_tracking_cookie_prefix'),
            'cookie_expiration': this.get_config('cookie_expiration'),
            'cross_site_cookie': this.get_config('cross_site_cookie'),
            'cross_subdomain_cookie': this.get_config('cross_subdomain_cookie'),
            'cookie_domain': this.get_config('cookie_domain'),
            'secure_cookie': this.get_config('secure_cookie'),
            'ignore_dnt': this.get_config('ignore_dnt')
        }, options);

        // check if localStorage can be used for recording opt out status, fall back to cookie if not
        if (!_.localStorage.is_supported()) {
            options['persistence_type'] = 'cookie';
        }

        return func(this.get_config('token'), {
            track: options['track'],
            trackEventName: options['track_event_name'],
            trackProperties: options['track_properties'],
            persistenceType: options['persistence_type'],
            persistencePrefix: options['cookie_prefix'],
            cookieDomain: options['cookie_domain'],
            cookieExpiration: options['cookie_expiration'],
            crossSiteCookie: options['cross_site_cookie'],
            crossSubdomainCookie: options['cross_subdomain_cookie'],
            secureCookie: options['secure_cookie'],
            ignoreDnt: options['ignore_dnt']
        });
    };

    /**
     * Opt the user in to data tracking and cookies/localstorage for this Mixpanel instance
     *
     * ### Usage
     *
     *     // opt user in
     *     mixpanel.opt_in_tracking();
     *
     *     // opt user in with specific event name, properties, cookie configuration
     *     mixpanel.opt_in_tracking({
     *         track_event_name: 'User opted in',
     *         track_event_properties: {
     *             'Email': 'jdoe@example.com'
     *         },
     *         cookie_expiration: 30,
     *         secure_cookie: true
     *     });
     *
     * @param {Object} [options] A dictionary of config options to override
     * @param {function} [options.track] Function used for tracking a Mixpanel event to record the opt-in action (default is this Mixpanel instance's track method)
     * @param {string} [options.track_event_name=$opt_in] Event name to be used for tracking the opt-in action
     * @param {Object} [options.track_properties] Set of properties to be tracked along with the opt-in action
     * @param {boolean} [options.enable_persistence=true] If true, will re-enable sdk persistence
     * @param {string} [options.persistence_type=localStorage] Persistence mechanism used - cookie or localStorage - falls back to cookie if localStorage is unavailable
     * @param {string} [options.cookie_prefix=__mp_opt_in_out] Custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookie_expiration] Number of days until the opt-in cookie expires (overrides value specified in this Mixpanel instance's config)
     * @param {string} [options.cookie_domain] Custom cookie domain (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.cross_site_cookie] Whether the opt-in cookie is set as cross-site-enabled (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.cross_subdomain_cookie] Whether the opt-in cookie is set as cross-subdomain or not (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.secure_cookie] Whether the opt-in cookie is set as secure or not (overrides value specified in this Mixpanel instance's config)
     */
    MixpanelLib.prototype.opt_in_tracking = function(options) {
        options = _.extend({
            'enable_persistence': true
        }, options);

        this._gdpr_call_func(optIn, options);
        this._gdpr_update_persistence(options);
    };

    /**
     * Opt the user out of data tracking and cookies/localstorage for this Mixpanel instance
     *
     * ### Usage
     *
     *     // opt user out
     *     mixpanel.opt_out_tracking();
     *
     *     // opt user out with different cookie configuration from Mixpanel instance
     *     mixpanel.opt_out_tracking({
     *         cookie_expiration: 30,
     *         secure_cookie: true
     *     });
     *
     * @param {Object} [options] A dictionary of config options to override
     * @param {boolean} [options.delete_user=true] If true, will delete the currently identified user's profile and clear all charges after opting the user out
     * @param {boolean} [options.clear_persistence=true] If true, will delete all data stored by the sdk in persistence
     * @param {string} [options.persistence_type=localStorage] Persistence mechanism used - cookie or localStorage - falls back to cookie if localStorage is unavailable
     * @param {string} [options.cookie_prefix=__mp_opt_in_out] Custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookie_expiration] Number of days until the opt-in cookie expires (overrides value specified in this Mixpanel instance's config)
     * @param {string} [options.cookie_domain] Custom cookie domain (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.cross_site_cookie] Whether the opt-in cookie is set as cross-site-enabled (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.cross_subdomain_cookie] Whether the opt-in cookie is set as cross-subdomain or not (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.secure_cookie] Whether the opt-in cookie is set as secure or not (overrides value specified in this Mixpanel instance's config)
     */
    MixpanelLib.prototype.opt_out_tracking = function(options) {
        options = _.extend({
            'clear_persistence': true,
            'delete_user': true
        }, options);

        // delete user and clear charges since these methods may be disabled by opt-out
        if (options['delete_user'] && this['people'] && this['people']._identify_called()) {
            this['people'].delete_user();
            this['people'].clear_charges();
        }

        this._gdpr_call_func(optOut, options);
        this._gdpr_update_persistence(options);
    };

    /**
     * Check whether the user has opted in to data tracking and cookies/localstorage for this Mixpanel instance
     *
     * ### Usage
     *
     *     var has_opted_in = mixpanel.has_opted_in_tracking();
     *     // use has_opted_in value
     *
     * @param {Object} [options] A dictionary of config options to override
     * @param {string} [options.persistence_type=localStorage] Persistence mechanism used - cookie or localStorage - falls back to cookie if localStorage is unavailable
     * @param {string} [options.cookie_prefix=__mp_opt_in_out] Custom prefix to be used in the cookie/localstorage name
     * @returns {boolean} current opt-in status
     */
    MixpanelLib.prototype.has_opted_in_tracking = function(options) {
        return this._gdpr_call_func(hasOptedIn, options);
    };

    /**
     * Check whether the user has opted out of data tracking and cookies/localstorage for this Mixpanel instance
     *
     * ### Usage
     *
     *     var has_opted_out = mixpanel.has_opted_out_tracking();
     *     // use has_opted_out value
     *
     * @param {Object} [options] A dictionary of config options to override
     * @param {string} [options.persistence_type=localStorage] Persistence mechanism used - cookie or localStorage - falls back to cookie if localStorage is unavailable
     * @param {string} [options.cookie_prefix=__mp_opt_in_out] Custom prefix to be used in the cookie/localstorage name
     * @returns {boolean} current opt-out status
     */
    MixpanelLib.prototype.has_opted_out_tracking = function(options) {
        return this._gdpr_call_func(hasOptedOut, options);
    };

    /**
     * Clear the user's opt in/out status of data tracking and cookies/localstorage for this Mixpanel instance
     *
     * ### Usage
     *
     *     // clear user's opt-in/out status
     *     mixpanel.clear_opt_in_out_tracking();
     *
     *     // clear user's opt-in/out status with specific cookie configuration - should match
     *     // configuration used when opt_in_tracking/opt_out_tracking methods were called.
     *     mixpanel.clear_opt_in_out_tracking({
     *         cookie_expiration: 30,
     *         secure_cookie: true
     *     });
     *
     * @param {Object} [options] A dictionary of config options to override
     * @param {boolean} [options.enable_persistence=true] If true, will re-enable sdk persistence
     * @param {string} [options.persistence_type=localStorage] Persistence mechanism used - cookie or localStorage - falls back to cookie if localStorage is unavailable
     * @param {string} [options.cookie_prefix=__mp_opt_in_out] Custom prefix to be used in the cookie/localstorage name
     * @param {Number} [options.cookie_expiration] Number of days until the opt-in cookie expires (overrides value specified in this Mixpanel instance's config)
     * @param {string} [options.cookie_domain] Custom cookie domain (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.cross_site_cookie] Whether the opt-in cookie is set as cross-site-enabled (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.cross_subdomain_cookie] Whether the opt-in cookie is set as cross-subdomain or not (overrides value specified in this Mixpanel instance's config)
     * @param {boolean} [options.secure_cookie] Whether the opt-in cookie is set as secure or not (overrides value specified in this Mixpanel instance's config)
     */
    MixpanelLib.prototype.clear_opt_in_out_tracking = function(options) {
        options = _.extend({
            'enable_persistence': true
        }, options);

        this._gdpr_call_func(clearOptInOut, options);
        this._gdpr_update_persistence(options);
    };

    MixpanelLib.prototype.report_error = function(msg, err) {
        console$1.error.apply(console$1.error, arguments);
        try {
            if (!err && !(msg instanceof Error)) {
                msg = new Error(msg);
            }
            this.get_config('error_reporter')(msg, err);
        } catch(err) {
            console$1.error(err);
        }
    };

    // EXPORTS (for closure compiler)

    // MixpanelLib Exports
    MixpanelLib.prototype['init']                               = MixpanelLib.prototype.init;
    MixpanelLib.prototype['reset']                              = MixpanelLib.prototype.reset;
    MixpanelLib.prototype['disable']                            = MixpanelLib.prototype.disable;
    MixpanelLib.prototype['time_event']                         = MixpanelLib.prototype.time_event;
    MixpanelLib.prototype['track']                              = MixpanelLib.prototype.track;
    MixpanelLib.prototype['track_links']                        = MixpanelLib.prototype.track_links;
    MixpanelLib.prototype['track_forms']                        = MixpanelLib.prototype.track_forms;
    MixpanelLib.prototype['track_pageview']                     = MixpanelLib.prototype.track_pageview;
    MixpanelLib.prototype['register']                           = MixpanelLib.prototype.register;
    MixpanelLib.prototype['register_once']                      = MixpanelLib.prototype.register_once;
    MixpanelLib.prototype['unregister']                         = MixpanelLib.prototype.unregister;
    MixpanelLib.prototype['identify']                           = MixpanelLib.prototype.identify;
    MixpanelLib.prototype['alias']                              = MixpanelLib.prototype.alias;
    MixpanelLib.prototype['name_tag']                           = MixpanelLib.prototype.name_tag;
    MixpanelLib.prototype['set_config']                         = MixpanelLib.prototype.set_config;
    MixpanelLib.prototype['get_config']                         = MixpanelLib.prototype.get_config;
    MixpanelLib.prototype['get_property']                       = MixpanelLib.prototype.get_property;
    MixpanelLib.prototype['get_distinct_id']                    = MixpanelLib.prototype.get_distinct_id;
    MixpanelLib.prototype['toString']                           = MixpanelLib.prototype.toString;
    MixpanelLib.prototype['opt_out_tracking']                   = MixpanelLib.prototype.opt_out_tracking;
    MixpanelLib.prototype['opt_in_tracking']                    = MixpanelLib.prototype.opt_in_tracking;
    MixpanelLib.prototype['has_opted_out_tracking']             = MixpanelLib.prototype.has_opted_out_tracking;
    MixpanelLib.prototype['has_opted_in_tracking']              = MixpanelLib.prototype.has_opted_in_tracking;
    MixpanelLib.prototype['clear_opt_in_out_tracking']          = MixpanelLib.prototype.clear_opt_in_out_tracking;
    MixpanelLib.prototype['get_group']                          = MixpanelLib.prototype.get_group;
    MixpanelLib.prototype['set_group']                          = MixpanelLib.prototype.set_group;
    MixpanelLib.prototype['add_group']                          = MixpanelLib.prototype.add_group;
    MixpanelLib.prototype['remove_group']                       = MixpanelLib.prototype.remove_group;
    MixpanelLib.prototype['track_with_groups']                  = MixpanelLib.prototype.track_with_groups;
    MixpanelLib.prototype['start_batch_senders']                = MixpanelLib.prototype.start_batch_senders;
    MixpanelLib.prototype['stop_batch_senders']                 = MixpanelLib.prototype.stop_batch_senders;

    // MixpanelPersistence Exports
    MixpanelPersistence.prototype['properties']            = MixpanelPersistence.prototype.properties;
    MixpanelPersistence.prototype['update_search_keyword'] = MixpanelPersistence.prototype.update_search_keyword;
    MixpanelPersistence.prototype['update_referrer_info']  = MixpanelPersistence.prototype.update_referrer_info;
    MixpanelPersistence.prototype['get_cross_subdomain']   = MixpanelPersistence.prototype.get_cross_subdomain;
    MixpanelPersistence.prototype['clear']                 = MixpanelPersistence.prototype.clear;


    var instances = {};
    var extend_mp = function() {
        // add all the sub mixpanel instances
        _.each(instances, function(instance, name) {
            if (name !== PRIMARY_INSTANCE_NAME) { mixpanel_master[name] = instance; }
        });

        // add private functions as _
        mixpanel_master['_'] = _;
    };

    var override_mp_init_func = function() {
        // we override the snippets init function to handle the case where a
        // user initializes the mixpanel library after the script loads & runs
        mixpanel_master['init'] = function(token, config, name) {
            if (name) {
                // initialize a sub library
                if (!mixpanel_master[name]) {
                    mixpanel_master[name] = instances[name] = create_mplib(token, config, name);
                    mixpanel_master[name]._loaded();
                }
                return mixpanel_master[name];
            } else {
                var instance = mixpanel_master;

                if (instances[PRIMARY_INSTANCE_NAME]) {
                    // main mixpanel lib already initialized
                    instance = instances[PRIMARY_INSTANCE_NAME];
                } else if (token) {
                    // intialize the main mixpanel lib
                    instance = create_mplib(token, config, PRIMARY_INSTANCE_NAME);
                    instance._loaded();
                    instances[PRIMARY_INSTANCE_NAME] = instance;
                }

                mixpanel_master = instance;
                if (init_type === INIT_SNIPPET) {
                    window$1[PRIMARY_INSTANCE_NAME] = mixpanel_master;
                }
                extend_mp();
            }
        };
    };

    var add_dom_loaded_handler = function() {
        // Cross browser DOM Loaded support
        function dom_loaded_handler() {
            // function flag since we only want to execute this once
            if (dom_loaded_handler.done) { return; }
            dom_loaded_handler.done = true;

            DOM_LOADED = true;
            ENQUEUE_REQUESTS = false;

            _.each(instances, function(inst) {
                inst._dom_loaded();
            });
        }

        function do_scroll_check() {
            try {
                document$1.documentElement.doScroll('left');
            } catch(e) {
                setTimeout(do_scroll_check, 1);
                return;
            }

            dom_loaded_handler();
        }

        if (document$1.addEventListener) {
            if (document$1.readyState === 'complete') {
                // safari 4 can fire the DOMContentLoaded event before loading all
                // external JS (including this file). you will see some copypasta
                // on the internet that checks for 'complete' and 'loaded', but
                // 'loaded' is an IE thing
                dom_loaded_handler();
            } else {
                document$1.addEventListener('DOMContentLoaded', dom_loaded_handler, false);
            }
        } else if (document$1.attachEvent) {
            // IE
            document$1.attachEvent('onreadystatechange', dom_loaded_handler);

            // check to make sure we arn't in a frame
            var toplevel = false;
            try {
                toplevel = window$1.frameElement === null;
            } catch(e) {
                // noop
            }

            if (document$1.documentElement.doScroll && toplevel) {
                do_scroll_check();
            }
        }

        // fallback handler, always will work
        _.register_event(window$1, 'load', dom_loaded_handler, true);
    };

    function init_as_module() {
        init_type = INIT_MODULE;
        mixpanel_master = new MixpanelLib();

        override_mp_init_func();
        mixpanel_master['init']();
        add_dom_loaded_handler();

        return mixpanel_master;
    }

    var mixpanel = init_as_module();

    var mixpanel_cjs = mixpanel;

    var mixpanel$1 = /*#__PURE__*/_mergeNamespaces({
        __proto__: null,
        default: mixpanel_cjs
    }, [mixpanel_cjs]);

    // Needed to avoid error in CJS builds on some bundlers.
    const mixpanelLib = mixpanel_cjs || mixpanel$1;
    let mixpanelInstance;
    /**
     * Enum of mixpanel events
     * @hidden
     */
    const MIXPANEL_EVENT = {
        VISUAL_SDK_RENDER_START: 'visual-sdk-render-start',
        VISUAL_SDK_CALLED_INIT: 'visual-sdk-called-init',
        VISUAL_SDK_RENDER_COMPLETE: 'visual-sdk-render-complete',
        VISUAL_SDK_RENDER_FAILED: 'visual-sdk-render-failed',
        VISUAL_SDK_TRIGGER: 'visual-sdk-trigger',
        VISUAL_SDK_ON: 'visual-sdk-on',
        VISUAL_SDK_IFRAME_LOAD_PERFORMANCE: 'visual-sdk-iframe-load-performance',
        VISUAL_SDK_EMBED_CREATE: 'visual-sdk-embed-create',
        VERCEL_INTEGRATION_COMPLETED: 'vercel-integration-completed',
    };
    let isMixpanelInitialized = false;
    let eventQueue = [];
    /**
     * Pushes the event with its Property key-value map to mixpanel.
     * @param eventId
     * @param eventProps
     */
    function uploadMixpanelEvent(eventId, eventProps = {}) {
        if (!isMixpanelInitialized) {
            eventQueue.push({ eventId, eventProps });
            return;
        }
        mixpanelInstance.track(eventId, eventProps);
    }
    /**
     *
     */
    function emptyQueue() {
        if (!isMixpanelInitialized) {
            return;
        }
        eventQueue.forEach((event) => {
            uploadMixpanelEvent(event.eventId, event.eventProps);
        });
        eventQueue = [];
    }
    /**
     *
     * @param sessionInfo
     */
    function initMixpanel(sessionInfo) {
        var _a;
        if (!sessionInfo || !sessionInfo.mixpanelToken) {
            logger$3.error(ERROR_MESSAGE.MIXPANEL_TOKEN_NOT_FOUND);
            return;
        }
        // On a public cluster the user is anonymous, so don't set the identify to
        // userGUID
        const isPublicCluster = !!sessionInfo.isPublicUser;
        const token = sessionInfo.mixpanelToken;
        try {
            if (token) {
                mixpanelInstance = mixpanelLib.init(token, undefined, 'tsEmbed');
                if (!isPublicCluster) {
                    mixpanelInstance.identify(sessionInfo.userGUID);
                }
                mixpanelInstance.register_once({
                    clusterId: sessionInfo.clusterId,
                    clusterName: sessionInfo.clusterName,
                    releaseVersion: sessionInfo.releaseVersion,
                    hostAppUrl: ((_a = window === null || window === void 0 ? void 0 : window.location) === null || _a === void 0 ? void 0 : _a.host) || '',
                });
                isMixpanelInitialized = true;
                emptyQueue();
            }
        }
        catch (e) {
            logger$3.error('Error initializing mixpanel', e);
        }
    }

    var eventemitter3 = createCommonjsModule(function (module) {

    var has = Object.prototype.hasOwnProperty
      , prefix = '~';

    /**
     * Constructor to create a storage for our `EE` objects.
     * An `Events` instance is a plain object whose properties are event names.
     *
     * @constructor
     * @private
     */
    function Events() {}

    //
    // We try to not inherit from `Object.prototype`. In some engines creating an
    // instance in this way is faster than calling `Object.create(null)` directly.
    // If `Object.create(null)` is not supported we prefix the event names with a
    // character to make sure that the built-in object properties are not
    // overridden or used as an attack vector.
    //
    if (Object.create) {
      Events.prototype = Object.create(null);

      //
      // This hack is needed because the `__proto__` property is still inherited in
      // some old browsers like Android 4, iPhone 5.1, Opera 11 and Safari 5.
      //
      if (!new Events().__proto__) prefix = false;
    }

    /**
     * Representation of a single event listener.
     *
     * @param {Function} fn The listener function.
     * @param {*} context The context to invoke the listener with.
     * @param {Boolean} [once=false] Specify if the listener is a one-time listener.
     * @constructor
     * @private
     */
    function EE(fn, context, once) {
      this.fn = fn;
      this.context = context;
      this.once = once || false;
    }

    /**
     * Add a listener for a given event.
     *
     * @param {EventEmitter} emitter Reference to the `EventEmitter` instance.
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn The listener function.
     * @param {*} context The context to invoke the listener with.
     * @param {Boolean} once Specify if the listener is a one-time listener.
     * @returns {EventEmitter}
     * @private
     */
    function addListener(emitter, event, fn, context, once) {
      if (typeof fn !== 'function') {
        throw new TypeError('The listener must be a function');
      }

      var listener = new EE(fn, context || emitter, once)
        , evt = prefix ? prefix + event : event;

      if (!emitter._events[evt]) emitter._events[evt] = listener, emitter._eventsCount++;
      else if (!emitter._events[evt].fn) emitter._events[evt].push(listener);
      else emitter._events[evt] = [emitter._events[evt], listener];

      return emitter;
    }

    /**
     * Clear event by name.
     *
     * @param {EventEmitter} emitter Reference to the `EventEmitter` instance.
     * @param {(String|Symbol)} evt The Event name.
     * @private
     */
    function clearEvent(emitter, evt) {
      if (--emitter._eventsCount === 0) emitter._events = new Events();
      else delete emitter._events[evt];
    }

    /**
     * Minimal `EventEmitter` interface that is molded against the Node.js
     * `EventEmitter` interface.
     *
     * @constructor
     * @public
     */
    function EventEmitter() {
      this._events = new Events();
      this._eventsCount = 0;
    }

    /**
     * Return an array listing the events for which the emitter has registered
     * listeners.
     *
     * @returns {Array}
     * @public
     */
    EventEmitter.prototype.eventNames = function eventNames() {
      var names = []
        , events
        , name;

      if (this._eventsCount === 0) return names;

      for (name in (events = this._events)) {
        if (has.call(events, name)) names.push(prefix ? name.slice(1) : name);
      }

      if (Object.getOwnPropertySymbols) {
        return names.concat(Object.getOwnPropertySymbols(events));
      }

      return names;
    };

    /**
     * Return the listeners registered for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @returns {Array} The registered listeners.
     * @public
     */
    EventEmitter.prototype.listeners = function listeners(event) {
      var evt = prefix ? prefix + event : event
        , handlers = this._events[evt];

      if (!handlers) return [];
      if (handlers.fn) return [handlers.fn];

      for (var i = 0, l = handlers.length, ee = new Array(l); i < l; i++) {
        ee[i] = handlers[i].fn;
      }

      return ee;
    };

    /**
     * Return the number of listeners listening to a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @returns {Number} The number of listeners.
     * @public
     */
    EventEmitter.prototype.listenerCount = function listenerCount(event) {
      var evt = prefix ? prefix + event : event
        , listeners = this._events[evt];

      if (!listeners) return 0;
      if (listeners.fn) return 1;
      return listeners.length;
    };

    /**
     * Calls each of the listeners registered for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @returns {Boolean} `true` if the event had listeners, else `false`.
     * @public
     */
    EventEmitter.prototype.emit = function emit(event, a1, a2, a3, a4, a5) {
      var evt = prefix ? prefix + event : event;

      if (!this._events[evt]) return false;

      var listeners = this._events[evt]
        , len = arguments.length
        , args
        , i;

      if (listeners.fn) {
        if (listeners.once) this.removeListener(event, listeners.fn, undefined, true);

        switch (len) {
          case 1: return listeners.fn.call(listeners.context), true;
          case 2: return listeners.fn.call(listeners.context, a1), true;
          case 3: return listeners.fn.call(listeners.context, a1, a2), true;
          case 4: return listeners.fn.call(listeners.context, a1, a2, a3), true;
          case 5: return listeners.fn.call(listeners.context, a1, a2, a3, a4), true;
          case 6: return listeners.fn.call(listeners.context, a1, a2, a3, a4, a5), true;
        }

        for (i = 1, args = new Array(len -1); i < len; i++) {
          args[i - 1] = arguments[i];
        }

        listeners.fn.apply(listeners.context, args);
      } else {
        var length = listeners.length
          , j;

        for (i = 0; i < length; i++) {
          if (listeners[i].once) this.removeListener(event, listeners[i].fn, undefined, true);

          switch (len) {
            case 1: listeners[i].fn.call(listeners[i].context); break;
            case 2: listeners[i].fn.call(listeners[i].context, a1); break;
            case 3: listeners[i].fn.call(listeners[i].context, a1, a2); break;
            case 4: listeners[i].fn.call(listeners[i].context, a1, a2, a3); break;
            default:
              if (!args) for (j = 1, args = new Array(len -1); j < len; j++) {
                args[j - 1] = arguments[j];
              }

              listeners[i].fn.apply(listeners[i].context, args);
          }
        }
      }

      return true;
    };

    /**
     * Add a listener for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn The listener function.
     * @param {*} [context=this] The context to invoke the listener with.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.on = function on(event, fn, context) {
      return addListener(this, event, fn, context, false);
    };

    /**
     * Add a one-time listener for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn The listener function.
     * @param {*} [context=this] The context to invoke the listener with.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.once = function once(event, fn, context) {
      return addListener(this, event, fn, context, true);
    };

    /**
     * Remove the listeners of a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn Only remove the listeners that match this function.
     * @param {*} context Only remove the listeners that have this context.
     * @param {Boolean} once Only remove one-time listeners.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.removeListener = function removeListener(event, fn, context, once) {
      var evt = prefix ? prefix + event : event;

      if (!this._events[evt]) return this;
      if (!fn) {
        clearEvent(this, evt);
        return this;
      }

      var listeners = this._events[evt];

      if (listeners.fn) {
        if (
          listeners.fn === fn &&
          (!once || listeners.once) &&
          (!context || listeners.context === context)
        ) {
          clearEvent(this, evt);
        }
      } else {
        for (var i = 0, events = [], length = listeners.length; i < length; i++) {
          if (
            listeners[i].fn !== fn ||
            (once && !listeners[i].once) ||
            (context && listeners[i].context !== context)
          ) {
            events.push(listeners[i]);
          }
        }

        //
        // Reset the array, or remove it completely if we have no more listeners.
        //
        if (events.length) this._events[evt] = events.length === 1 ? events[0] : events;
        else clearEvent(this, evt);
      }

      return this;
    };

    /**
     * Remove all listeners, or those of the specified event.
     *
     * @param {(String|Symbol)} [event] The event name.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.removeAllListeners = function removeAllListeners(event) {
      var evt;

      if (event) {
        evt = prefix ? prefix + event : event;
        if (this._events[evt]) clearEvent(this, evt);
      } else {
        this._events = new Events();
        this._eventsCount = 0;
      }

      return this;
    };

    //
    // Alias methods names because people roll like that.
    //
    EventEmitter.prototype.off = EventEmitter.prototype.removeListener;
    EventEmitter.prototype.addListener = EventEmitter.prototype.on;

    //
    // Expose the prefix.
    //
    EventEmitter.prefixed = prefix;

    //
    // Allow `EventEmitter` to be imported as module namespace.
    //
    EventEmitter.EventEmitter = EventEmitter;

    //
    // Expose the module.
    //
    {
      module.exports = EventEmitter;
    }
    });

    var ReportType;
    (function (ReportType) {
        ReportType["CSP_VIOLATION"] = "csp-violation";
        ReportType["DEPRECATION"] = "deprecation";
        ReportType["INTERVENTION"] = "intervention";
    })(ReportType || (ReportType = {}));
    let globalObserver = null;
    /**
     * Register a global ReportingObserver to capture all unhandled errors
     * @param overrideExisting boolean to override existing observer
     * @returns ReportingObserver | null
     */
    function registerReportingObserver(overrideExisting = false) {
        if (!(window.ReportingObserver)) {
            logger$3.warn(ERROR_MESSAGE.MISSING_REPORTING_OBSERVER);
            return null;
        }
        if (overrideExisting) {
            resetGlobalReportingObserver();
        }
        if (globalObserver) {
            return globalObserver;
        }
        const embedConfig = getEmbedConfig();
        globalObserver = new ReportingObserver((reports) => {
            reports.forEach((report) => {
                const { type, url, body } = report;
                const reportBody = body;
                const isThoughtSpotHost = url
                    && url.startsWith(embedConfig.thoughtSpotHost);
                const isFrameHostError = type === ReportType.CSP_VIOLATION
                    && reportBody.effectiveDirective === 'frame-ancestors';
                if (isThoughtSpotHost && isFrameHostError) {
                    if (!embedConfig.suppressErrorAlerts) {
                        alert(ERROR_MESSAGE.CSP_VIOLATION_ALERT);
                    }
                    logger$3.error(ERROR_MESSAGE.CSP_FRAME_HOST_VIOLATION_LOG_MESSAGE);
                }
            });
        }, { buffered: true });
        globalObserver.observe();
        return globalObserver;
    }
    /**
     * Resets the global ReportingObserver
     */
    function resetGlobalReportingObserver() {
        if (globalObserver)
            globalObserver.disconnect();
        globalObserver = null;
    }

    /**
     *
     * @param url
     * @param options
     */
    function tokenizedFailureLoggedFetch(url, options = {}) {
        return tokenizedFetch(url, options).then(async (r) => {
            var _a;
            if (!r.ok && r.type !== 'opaqueredirect' && r.type !== 'opaque') {
                logger$3.error(`Failed to fetch ${url}`, await ((_a = r.text) === null || _a === void 0 ? void 0 : _a.call(r)));
            }
            return r;
        });
    }
    /**
     * Fetches the session info from the ThoughtSpot server.
     * @param thoughtspotHost
     * @returns {Promise<any>}
     * @example
     * ```js
     *  const response = await sessionInfoService();
     * ```
     */
    async function fetchPreauthInfoService(thoughtspotHost) {
        const sessionInfoPath = `${thoughtspotHost}${EndPoints.PREAUTH_INFO}`;
        const handleError = (e) => {
            const error = new Error(`Failed to fetch auth info: ${e.message || e.statusText}`);
            error.status = e.status; // Attach the status code to the error object
            throw error;
        };
        try {
            const response = await tokenizedFailureLoggedFetch(sessionInfoPath);
            return response;
        }
        catch (e) {
            handleError(e);
            return null;
        }
    }
    /**
     * Fetches the session info from the ThoughtSpot server.
     * @param thoughtspotHost
     * @returns {Promise<any>}
     * @example
     * ```js
     *  const response = await sessionInfoService();
     * ```
     */
    async function fetchSessionInfoService(thoughtspotHost) {
        const sessionInfoPath = `${thoughtspotHost}${EndPoints.SESSION_INFO}`;
        const response = await tokenizedFailureLoggedFetch(sessionInfoPath);
        if (!response.ok) {
            throw new Error(`Failed to fetch session info: ${response.statusText}`);
        }
        const data = await response.json();
        return data;
    }
    /**
     *
     * @param thoughtSpotHost
     */
    async function fetchLogoutService(thoughtSpotHost) {
        return tokenizedFailureLoggedFetch(`${thoughtSpotHost}${EndPoints.LOGOUT}`, {
            credentials: 'include',
            method: 'POST',
            headers: {
                'x-requested-by': 'ThoughtSpot',
            },
        });
    }
    /**
     * Is active service to check if the user is logged in.
     * @param thoughtSpotHost
     * @version SDK: 1.28.4 | ThoughtSpot: *
     */
    async function isActiveService(thoughtSpotHost) {
        const isActiveUrl = `${thoughtSpotHost}${EndPoints.IS_ACTIVE}`;
        try {
            const res = await tokenizedFetch(isActiveUrl, {
                credentials: 'include',
            });
            return res.ok;
        }
        catch (e) {
            logger$3.warn(`Is Logged In Service failed : ${e.message}`);
        }
        return false;
    }

    let sessionInfo = null;
    let preauthInfo = null;
    /**
     * Processes the session info response and returns the session info object.
     *  @param preauthInfoResp {any} Response from the session info API.
     *  @returns {PreauthInfo} The session info object.
     *  @example ```js
     *  const preauthInfoResp = await fetch(sessionInfoPath);
     *  const sessionInfo = await formatPreauthInfo(preauthInfoResp);
     *  console.log(sessionInfo);
     *  ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     */
    const formatPreauthInfo = async (preauthInfoResp) => {
        var _a;
        try {
            // Convert Headers to a plain object
            const headers = {};
            (_a = preauthInfoResp === null || preauthInfoResp === void 0 ? void 0 : preauthInfoResp.headers) === null || _a === void 0 ? void 0 : _a.forEach((value, key) => {
                headers[key] = value;
            });
            const data = await preauthInfoResp.json();
            return {
                ...data,
                status: 200,
                headers,
            };
        }
        catch (error) {
            return null;
        }
    };
    /**
     * Returns the session info object and caches it for future use.
     * Once fetched the session info object is cached and returned from the cache on
     * subsequent calls.
     * @example ```js
     * const preauthInfo = await getPreauthInfo();
     * console.log(preauthInfo);
     * ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     * @returns {Promise<SessionInfo>} The session info object.
     */
    async function getPreauthInfo(allowCache = true) {
        if (!allowCache || !preauthInfo) {
            try {
                const host = getEmbedConfig().thoughtSpotHost;
                const sessionResponse = await fetchPreauthInfoService(host);
                const processedPreauthInfo = await formatPreauthInfo(sessionResponse);
                preauthInfo = processedPreauthInfo;
            }
            catch (error) {
                return null;
            }
        }
        return preauthInfo;
    }
    /**
     * Returns the cached session info object and caches it for future use.
     * Once fetched the session info object is cached and returned from the cache on
     * subsequent calls.
     * This cache is cleared when inti is called OR resetCachedSessionInfo is called.
     * @example ```js
     * const sessionInfo = await getSessionInfo();
     * console.log(sessionInfo);
     * ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     * @returns {Promise<SessionInfo>} The session info object.
     */
    async function getSessionInfo() {
        if (!sessionInfo) {
            const host = getEmbedConfig().thoughtSpotHost;
            const sessionResponse = await fetchSessionInfoService(host);
            const processedSessionInfo = getSessionDetails(sessionResponse);
            sessionInfo = processedSessionInfo;
        }
        return sessionInfo;
    }
    /**
     * Processes the session info response and returns the session info object.
     *  @param sessionInfoResp {any} Response from the session info API.
     *  @returns {SessionInfo} The session info object.
     *  @example ```js
     *  const sessionInfoResp = await fetch(sessionInfoPath);
     *  const sessionInfo = getSessionDetails(sessionInfoResp);
     *  console.log(sessionInfo);
     *  ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     */
    const getSessionDetails = (sessionInfoResp) => {
        const devMixpanelToken = sessionInfoResp.configInfo.mixpanelConfig.devSdkKey;
        const prodMixpanelToken = sessionInfoResp.configInfo.mixpanelConfig.prodSdkKey;
        const mixpanelToken = sessionInfoResp.configInfo.mixpanelConfig.production
            ? prodMixpanelToken
            : devMixpanelToken;
        return {
            userGUID: sessionInfoResp.userGUID,
            mixpanelToken,
            isPublicUser: sessionInfoResp.configInfo.isPublicUser,
            releaseVersion: sessionInfoResp.releaseVersion,
            clusterId: sessionInfoResp.configInfo.selfClusterId,
            clusterName: sessionInfoResp.configInfo.selfClusterName,
            ...sessionInfoResp,
        };
    };
    /**
     * Resets the cached session info object and forces a new fetch on the next call.
     * @example ```js
     * resetCachedSessionInfo();
     * const sessionInfo = await getSessionInfo();
     * console.log(sessionInfo);
     * ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     * @returns {void}
     */
    function resetCachedSessionInfo() {
        sessionInfo = null;
    }
    /**
     * Resets the cached preauth info object and forces a new fetch on the next call.
     * @example ```js
     * resetCachedPreauthInfo();
     * const preauthInfo = await getPreauthInfo();
     * console.log(preauthInfo);
     * ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     * @returns {void}
     */
    function resetCachedPreauthInfo() {
        preauthInfo = null;
    }

    /**
     * This function resets all the services that are cached in the SDK.
     * This is to be called when the user logs out of the application and also
     * when init is called again.
     * @version SDK: 1.30.2 | ThoughtSpot: *
     */
    function resetAllCachedServices() {
        resetCachedAuthToken();
        resetCachedSessionInfo();
        resetCachedPreauthInfo();
    }

    // eslint-disable-next-line import/no-mutable-exports
    let loggedInStatus = false;
    // eslint-disable-next-line import/no-mutable-exports
    let samlAuthWindow = null;
    // eslint-disable-next-line import/no-mutable-exports
    let samlCompletionPromise = null;
    let releaseVersion = '';
    const SSO_REDIRECTION_MARKER_GUID = '5e16222e-ef02-43e9-9fbd-24226bf3ce5b';
    /**
     * Enum for auth failure types. This is the parameter passed to the listner
     * of {@link AuthStatus.FAILURE}.
     * @group Authentication / Init
     */
    exports.AuthFailureType = void 0;
    (function (AuthFailureType) {
        AuthFailureType["SDK"] = "SDK";
        AuthFailureType["NO_COOKIE_ACCESS"] = "NO_COOKIE_ACCESS";
        AuthFailureType["EXPIRY"] = "EXPIRY";
        AuthFailureType["OTHER"] = "OTHER";
        AuthFailureType["IDLE_SESSION_TIMEOUT"] = "IDLE_SESSION_TIMEOUT";
        AuthFailureType["UNAUTHENTICATED_FAILURE"] = "UNAUTHENTICATED_FAILURE";
    })(exports.AuthFailureType || (exports.AuthFailureType = {}));
    /**
     * Enum for auth status emitted by the emitter returned from {@link init}.
     * @group Authentication / Init
     */
    exports.AuthStatus = void 0;
    (function (AuthStatus) {
        /**
         * Emits when the SDK fails to authenticate
         */
        AuthStatus["FAILURE"] = "FAILURE";
        /**
         * Emits when the SDK authenticates successfully
         */
        AuthStatus["SDK_SUCCESS"] = "SDK_SUCCESS";
        /**
         * @hidden
         * Emits when iframe is loaded and session info is available
         */
        AuthStatus["SESSION_INFO_SUCCESS"] = "SESSION_INFO_SUCCESS";
        /**
         * Emits when the app sends an authentication success message
         */
        AuthStatus["SUCCESS"] = "SUCCESS";
        /**
         * Emits when a user logs out
         */
        AuthStatus["LOGOUT"] = "LOGOUT";
        /**
         * Emitted when inPopup is true in the SAMLRedirect flow and the
         * popup is waiting to be triggered either programmatically
         * or by the trigger button.
         * @version SDK: 1.19.0
         */
        AuthStatus["WAITING_FOR_POPUP"] = "WAITING_FOR_POPUP";
        /**
         * Emitted when the SAML popup is closed without authentication
         */
        AuthStatus["SAML_POPUP_CLOSED_NO_AUTH"] = "SAML_POPUP_CLOSED_NO_AUTH";
    })(exports.AuthStatus || (exports.AuthStatus = {}));
    /**
     * Events which can be triggered on the emitter returned from {@link init}.
     * @group Authentication / Init
     */
    exports.AuthEvent = void 0;
    (function (AuthEvent) {
        /**
         * Manually trigger the SSO popup. This is useful when
         * authStatus is SAMLRedirect/OIDCRedirect and inPopup is set to true
         */
        AuthEvent["TRIGGER_SSO_POPUP"] = "TRIGGER_SSO_POPUP";
    })(exports.AuthEvent || (exports.AuthEvent = {}));
    let authEE;
    /**
     *
     * @param eventEmitter
     */
    function setAuthEE(eventEmitter) {
        authEE = eventEmitter;
    }
    /**
     *
     */
    function notifyAuthSDKSuccess() {
        if (!authEE) {
            logger$3.error(ERROR_MESSAGE.SDK_NOT_INITIALIZED);
            return;
        }
        authEE.emit(exports.AuthStatus.SDK_SUCCESS);
    }
    /**
     *
     */
    async function notifyAuthSuccess() {
        if (!authEE) {
            logger$3.error(ERROR_MESSAGE.SDK_NOT_INITIALIZED);
            return;
        }
        try {
            getPreauthInfo();
            const sessionInfo = await getSessionInfo();
            authEE.emit(exports.AuthStatus.SUCCESS, sessionInfo);
        }
        catch (e) {
            logger$3.error(ERROR_MESSAGE.SESSION_INFO_FAILED);
        }
    }
    /**
     *
     * @param failureType
     */
    function notifyAuthFailure(failureType) {
        if (!authEE) {
            logger$3.error(ERROR_MESSAGE.SDK_NOT_INITIALIZED);
            return;
        }
        authEE.emit(exports.AuthStatus.FAILURE, failureType);
    }
    /**
     *
     */
    function notifyLogout() {
        if (!authEE) {
            logger$3.error(ERROR_MESSAGE.SDK_NOT_INITIALIZED);
            return;
        }
        authEE.emit(exports.AuthStatus.LOGOUT);
    }
    /**
     * Check if we are logged into the ThoughtSpot cluster
     * @param thoughtSpotHost The ThoughtSpot cluster hostname or IP
     */
    async function isLoggedIn(thoughtSpotHost) {
        try {
            const response = await isActiveService(thoughtSpotHost);
            return response;
        }
        catch (e) {
            return false;
        }
    }
    /**
     * Services to be called after the login is successful,
     * This should be called after the cookie is set for cookie auth or
     * after the token is set for cookieless.
     * @return {Promise<void>}
     * @example
     * ```js
     * await postLoginService();
     * ```
     * @version SDK: 1.28.3 | ThoughtSpot: *
     */
    async function postLoginService() {
        try {
            getPreauthInfo();
            const sessionInfo = await getSessionInfo();
            releaseVersion = sessionInfo.releaseVersion;
            const embedConfig = getEmbedConfig();
            if (!embedConfig.disableSDKTracking) {
                initMixpanel(sessionInfo);
            }
        }
        catch (e) {
            logger$3.error('Post login services failed.', e.message, e);
        }
    }
    /**
     * Return releaseVersion if available
     */
    function getReleaseVersion() {
        return releaseVersion;
    }
    /**
     * Check if we are stuck at the SSO redirect URL
     */
    function isAtSSORedirectUrl() {
        return window.location.href.indexOf(getSSOMarker(SSO_REDIRECTION_MARKER_GUID)) >= 0;
    }
    /**
     * Remove the SSO redirect URL marker
     */
    function removeSSORedirectUrlMarker() {
        // Note (sunny): This will leave a # around even if it was not in the URL
        // to begin with. Trying to remove the hash by changing window.location will
        // reload the page which we don't want. We'll live with adding an
        // unnecessary hash to the parent page URL until we find any use case where
        // that creates an issue.
        // Replace any occurences of ?ssoMarker=guid or &ssoMarker=guid.
        let updatedHash = window.location.hash.replace(`?${getSSOMarker(SSO_REDIRECTION_MARKER_GUID)}`, '');
        updatedHash = updatedHash.replace(`&${getSSOMarker(SSO_REDIRECTION_MARKER_GUID)}`, '');
        window.location.hash = updatedHash;
    }
    /**
     * Perform token based authentication
     * @param embedConfig The embed configuration
     */
    const doTokenAuth = async (embedConfig) => {
        const { thoughtSpotHost, username, authEndpoint, getAuthToken, } = embedConfig;
        if (!authEndpoint && !getAuthToken) {
            throw new Error('Either auth endpoint or getAuthToken function must be provided');
        }
        loggedInStatus = await isLoggedIn(thoughtSpotHost);
        if (!loggedInStatus) {
            let authToken;
            try {
                authToken = await getAuthenticationToken(embedConfig);
            }
            catch (e) {
                loggedInStatus = false;
                throw e;
            }
            let resp;
            try {
                resp = await fetchAuthPostService(thoughtSpotHost, username, authToken);
            }
            catch (e) {
                resp = await fetchAuthService(thoughtSpotHost, username, authToken);
            }
            // token login issues a 302 when successful
            loggedInStatus = resp.ok || resp.type === 'opaqueredirect';
            if (loggedInStatus && embedConfig.detectCookieAccessSlow) {
                // When 3rd party cookie access is blocked, this will fail because
                // cookies will not be sent with the call.
                loggedInStatus = await isLoggedIn(thoughtSpotHost);
            }
        }
        return loggedInStatus;
    };
    /**
     * Validate embedConfig parameters required for cookielessTokenAuth
     * @param embedConfig The embed configuration
     */
    const doCookielessTokenAuth = async (embedConfig) => {
        const { authEndpoint, getAuthToken } = embedConfig;
        if (!authEndpoint && !getAuthToken) {
            throw new Error('Either auth endpoint or getAuthToken function must be provided');
        }
        let authSuccess = false;
        try {
            const authToken = await getAuthenticationToken(embedConfig);
            if (authToken) {
                authSuccess = true;
            }
        }
        catch {
            authSuccess = false;
        }
        return authSuccess;
    };
    /**
     * Perform basic authentication to the ThoughtSpot cluster using the cluster
     * credentials.
     *
     * Warning: This feature is primarily intended for developer testing. It is
     * strongly advised not to use this authentication method in production.
     * @param embedConfig The embed configuration
     */
    const doBasicAuth = async (embedConfig) => {
        const { thoughtSpotHost, username, password } = embedConfig;
        const loggedIn = await isLoggedIn(thoughtSpotHost);
        if (!loggedIn) {
            const response = await fetchBasicAuthService(thoughtSpotHost, username, password);
            loggedInStatus = response.ok;
            if (embedConfig.detectCookieAccessSlow) {
                loggedInStatus = await isLoggedIn(thoughtSpotHost);
            }
        }
        else {
            loggedInStatus = true;
        }
        return loggedInStatus;
    };
    /**
     *
     * @param ssoURL
     * @param triggerContainer
     * @param triggerText
     */
    async function samlPopupFlow(ssoURL, triggerContainer, triggerText) {
        let popupClosedCheck;
        const openPopup = () => {
            if (samlAuthWindow === null || samlAuthWindow.closed) {
                samlAuthWindow = window.open(ssoURL, '_blank', 'location=no,height=570,width=520,scrollbars=yes,status=yes');
                if (samlAuthWindow) {
                    popupClosedCheck = setInterval(() => {
                        if (samlAuthWindow.closed) {
                            clearInterval(popupClosedCheck);
                            if (samlCompletionPromise && !samlCompletionResolved) {
                                authEE === null || authEE === void 0 ? void 0 : authEE.emit(exports.AuthStatus.SAML_POPUP_CLOSED_NO_AUTH);
                            }
                        }
                    }, 500);
                }
            }
            else {
                samlAuthWindow.focus();
            }
        };
        let samlCompletionResolved = false;
        authEE === null || authEE === void 0 ? void 0 : authEE.emit(exports.AuthStatus.WAITING_FOR_POPUP);
        const containerEl = getDOMNode(triggerContainer);
        if (containerEl) {
            containerEl.innerHTML = '<button id="ts-auth-btn" class="ts-auth-btn" style="margin: auto;"></button>';
            const authElem = document.getElementById('ts-auth-btn');
            authElem.textContent = triggerText;
            authElem.addEventListener('click', openPopup, { once: true });
        }
        samlCompletionPromise = samlCompletionPromise || new Promise((resolve, reject) => {
            window.addEventListener('message', (e) => {
                if (e.data.type === exports.EmbedEvent.SAMLComplete) {
                    samlCompletionResolved = true;
                    if (popupClosedCheck) {
                        clearInterval(popupClosedCheck);
                    }
                    e.source.close();
                    resolve();
                }
            });
        });
        authEE === null || authEE === void 0 ? void 0 : authEE.once(exports.AuthEvent.TRIGGER_SSO_POPUP, openPopup);
        return samlCompletionPromise;
    }
    /**
     * Perform SAML authentication
     * @param embedConfig The embed configuration
     * @param ssoEndPoint
     */
    const doSSOAuth = async (embedConfig, ssoEndPoint) => {
        const { thoughtSpotHost } = embedConfig;
        const loggedIn = await isLoggedIn(thoughtSpotHost);
        if (loggedIn) {
            if (isAtSSORedirectUrl()) {
                removeSSORedirectUrlMarker();
            }
            loggedInStatus = true;
            return;
        }
        // we have already tried authentication and it did not succeed, restore
        // the current URL to the original one and invoke the callback.
        if (isAtSSORedirectUrl()) {
            removeSSORedirectUrlMarker();
            loggedInStatus = false;
            return;
        }
        const ssoURL = `${thoughtSpotHost}${ssoEndPoint}`;
        if (embedConfig.inPopup) {
            await samlPopupFlow(ssoURL, embedConfig.authTriggerContainer, embedConfig.authTriggerText);
            loggedInStatus = await isLoggedIn(thoughtSpotHost);
            return;
        }
        window.location.href = ssoURL;
    };
    const doSamlAuth = async (embedConfig) => {
        const { thoughtSpotHost } = embedConfig;
        // redirect for SSO, when the SSO authentication is done, this page will be
        // loaded again and the same JS will execute again.
        const ssoRedirectUrl = embedConfig.inPopup
            ? `${thoughtSpotHost}/v2/#/embed/saml-complete`
            : getRedirectUrl(window.location.href, SSO_REDIRECTION_MARKER_GUID, embedConfig.redirectPath);
        // bring back the page to the same URL
        const ssoEndPoint = `${EndPoints.SAML_LOGIN_TEMPLATE(encodeURIComponent(ssoRedirectUrl))}`;
        await doSSOAuth(embedConfig, ssoEndPoint);
        return loggedInStatus;
    };
    const doOIDCAuth = async (embedConfig) => {
        const { thoughtSpotHost } = embedConfig;
        // redirect for SSO, when the SSO authentication is done, this page will be
        // loaded again and the same JS will execute again.
        const ssoRedirectUrl = embedConfig.noRedirect || embedConfig.inPopup
            ? `${thoughtSpotHost}/v2/#/embed/saml-complete`
            : getRedirectUrl(window.location.href, SSO_REDIRECTION_MARKER_GUID, embedConfig.redirectPath);
        // bring back the page to the same URL
        const baseEndpoint = `${EndPoints.OIDC_LOGIN_TEMPLATE(encodeURIComponent(ssoRedirectUrl))}`;
        const ssoEndPoint = `${baseEndpoint}${baseEndpoint.includes('?') ? '&' : '?'}forceSAMLAutoRedirect=true`;
        await doSSOAuth(embedConfig, ssoEndPoint);
        return loggedInStatus;
    };
    const logout$1 = async (embedConfig) => {
        const { thoughtSpotHost } = embedConfig;
        await fetchLogoutService(thoughtSpotHost);
        resetAllCachedServices();
        const thoughtspotIframes = document.querySelectorAll("[data-ts-iframe='true']");
        if (thoughtspotIframes === null || thoughtspotIframes === void 0 ? void 0 : thoughtspotIframes.length) {
            thoughtspotIframes.forEach((el) => {
                el.parentElement.innerHTML = embedConfig.loginFailedMessage;
            });
        }
        loggedInStatus = false;
        return loggedInStatus;
    };
    /**
     * Perform authentication on the ThoughtSpot cluster
     * @param embedConfig The embed configuration
     */
    const authenticate = async (embedConfig) => {
        const { authType } = embedConfig;
        switch (authType) {
            case exports.AuthType.SSO:
            case exports.AuthType.SAMLRedirect:
            case exports.AuthType.SAML:
                return doSamlAuth(embedConfig);
            case exports.AuthType.OIDC:
            case exports.AuthType.OIDCRedirect:
                return doOIDCAuth(embedConfig);
            case exports.AuthType.AuthServer:
            case exports.AuthType.TrustedAuthToken:
                return doTokenAuth(embedConfig);
            case exports.AuthType.TrustedAuthTokenCookieless:
                return doCookielessTokenAuth(embedConfig);
            case exports.AuthType.Basic:
                return doBasicAuth(embedConfig);
            default:
                return Promise.resolve(true);
        }
    };

    if (typeof Promise.withResolvers === 'undefined') {
        Promise.withResolvers = () => {
            let resolve;
            let reject;
            const promise = new Promise((res, rej) => {
                resolve = res;
                reject = rej;
            });
            return { promise, resolve, reject };
        };
    }

    /* eslint-disable camelcase */
    /* eslint-disable import/no-mutable-exports */
    /**
     * Copyright (c) 2022
     *
     * Base classes
     * @summary Base classes
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    const CONFIG_DEFAULTS = {
        loginFailedMessage: 'Not logged in',
        authTriggerText: 'Authorize',
        authType: exports.AuthType.None,
        logLevel: exports.LogLevel.ERROR,
    };
    let authPromise;
    const getAuthPromise = () => authPromise;
    /**
     * Perform authentication on the ThoughtSpot app as applicable.
     */
    const handleAuth = () => {
        authPromise = authenticate(getEmbedConfig());
        authPromise.then((isLoggedIn) => {
            if (!isLoggedIn) {
                notifyAuthFailure(exports.AuthFailureType.SDK);
            }
            else {
                // Post login service is called after successful login.
                postLoginService();
                notifyAuthSDKSuccess();
            }
        }, () => {
            notifyAuthFailure(exports.AuthFailureType.SDK);
        });
        return authPromise;
    };
    const hostUrlToFeatureUrl = {
        [exports.PrefetchFeatures.SearchEmbed]: (url, flags) => `${url}v2/?${flags}#/embed/answer`,
        [exports.PrefetchFeatures.LiveboardEmbed]: (url, flags) => `${url}?${flags}`,
        [exports.PrefetchFeatures.FullApp]: (url, flags) => `${url}?${flags}`,
        [exports.PrefetchFeatures.VizEmbed]: (url, flags) => `${url}?${flags}`,
    };
    /**
     * Prefetches static resources from the specified URL. Web browsers can then cache the
     * prefetched resources and serve them from the user's local disk to provide faster access
     * to your app.
     * @param url The URL provided for prefetch
     * @param prefetchFeatures Specify features which needs to be prefetched.
     * @param additionalFlags This can be used to add any URL flag.
     * @version SDK: 1.4.0 | ThoughtSpot: ts7.sep.cl, 7.2.1
     * @group Global methods
     */
    const prefetch = (url, prefetchFeatures, additionalFlags) => {
        var _a;
        if (url === '') {
            // eslint-disable-next-line no-console
            logger$3.warn('The prefetch method does not have a valid URL');
        }
        else {
            const features = prefetchFeatures || [exports.PrefetchFeatures.FullApp];
            let hostUrl = url || getEmbedConfig().thoughtSpotHost;
            const prefetchFlags = {
                [Param.EmbedApp]: true,
                ...(_a = getEmbedConfig()) === null || _a === void 0 ? void 0 : _a.additionalFlags,
                ...additionalFlags,
            };
            hostUrl = hostUrl[hostUrl.length - 1] === '/' ? hostUrl : `${hostUrl}/`;
            Array.from(new Set(features
                .map((feature) => hostUrlToFeatureUrl[feature](hostUrl, getQueryParamString(prefetchFlags)))))
                .forEach((prefetchUrl, index) => {
                const iFrame = document.createElement('iframe');
                iFrame.src = prefetchUrl;
                iFrame.style.width = '0';
                iFrame.style.height = '0';
                iFrame.style.border = '0';
                // Make it 'fixed' to keep it in a different stacking context.
                //   This should solve the focus behaviours inside the iframe from
                //   interfering with main body.
                iFrame.style.position = 'fixed';
                // Push it out of viewport.
                iFrame.style.top = '100vh';
                iFrame.style.left = '100vw';
                iFrame.classList.add('prefetchIframe');
                iFrame.classList.add(`prefetchIframeNum-${index}`);
                document.body.appendChild(iFrame);
            });
        }
    };
    /**
     *
     * @param embedConfig
     */
    function sanity(embedConfig) {
        if (embedConfig.thoughtSpotHost === undefined) {
            throw new Error('ThoughtSpot host not provided');
        }
        if (embedConfig.authType === exports.AuthType.TrustedAuthToken) {
            if (!embedConfig.authEndpoint && typeof embedConfig.getAuthToken !== 'function') {
                throw new Error('Trusted auth should provide either authEndpoint or getAuthToken');
            }
        }
    }
    /**
     *
     * @param embedConfig
     */
    function backwardCompat(embedConfig) {
        const newConfig = { ...embedConfig };
        if (embedConfig.noRedirect !== undefined && embedConfig.inPopup === undefined) {
            newConfig.inPopup = embedConfig.noRedirect;
        }
        return newConfig;
    }
    const initFlagKey = 'initFlagKey';
    const createAndSetInitPromise = () => {
        const { promise: initPromise, resolve: initPromiseResolve,
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
         } = Promise.withResolvers();
        const initFlagStore = {
            initPromise,
            isInitCalled: false,
            initPromiseResolve,
        };
        storeValueInWindow(initFlagKey, initFlagStore, {
            // In case of diff imports the promise might be already set
            ignoreIfAlreadyExists: true,
        });
    };
    createAndSetInitPromise();
    const getInitPromise = () => { var _a; return (_a = getValueFromWindow(initFlagKey)) === null || _a === void 0 ? void 0 : _a.initPromise; };
    const getIsInitCalled = () => { var _a; return !!((_a = getValueFromWindow(initFlagKey)) === null || _a === void 0 ? void 0 : _a.isInitCalled); };
    /**
     * Initializes the Visual Embed SDK globally and perform
     * authentication if applicable. This function needs to be called before any ThoughtSpot
     * component like Liveboard etc can be embedded. But need not wait for AuthEvent.SUCCESS
     * to actually embed. That is handled internally.
     * @param embedConfig The configuration object containing ThoughtSpot host,
     * authentication mechanism and so on.
     * @example
     * ```js
     *   const authStatus = init({
     *     thoughtSpotHost: 'https://my.thoughtspot.cloud',
     *     authType: AuthType.None,
     *   });
     *   authStatus.on(AuthStatus.FAILURE, (reason) => { // do something here });
     * ```
     * @returns {@link AuthEventEmitter} event emitter which emits events on authentication success,
     *      failure and logout. See {@link AuthStatus}
     * @version SDK: 1.0.0 | ThoughtSpot ts7.april.cl, 7.2.1
     * @group Authentication / Init
     */
    const init = (embedConfig) => {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
        sanity(embedConfig);
        resetAllCachedServices();
        embedConfig = setEmbedConfig(backwardCompat({
            ...CONFIG_DEFAULTS,
            ...embedConfig,
            thoughtSpotHost: getThoughtSpotHost(embedConfig),
        }));
        setGlobalLogLevelOverride(embedConfig.logLevel);
        registerReportingObserver();
        const authEE = new eventemitter3();
        setAuthEE(authEE);
        handleAuth();
        const { password, ...configToTrack } = getEmbedConfig();
        uploadMixpanelEvent(MIXPANEL_EVENT.VISUAL_SDK_CALLED_INIT, {
            ...configToTrack,
            usedCustomizationSheet: ((_b = (_a = embedConfig.customizations) === null || _a === void 0 ? void 0 : _a.style) === null || _b === void 0 ? void 0 : _b.customCSSUrl) != null,
            usedCustomizationVariables: ((_e = (_d = (_c = embedConfig.customizations) === null || _c === void 0 ? void 0 : _c.style) === null || _d === void 0 ? void 0 : _d.customCSS) === null || _e === void 0 ? void 0 : _e.variables) != null,
            usedCustomizationRules: ((_h = (_g = (_f = embedConfig.customizations) === null || _f === void 0 ? void 0 : _f.style) === null || _g === void 0 ? void 0 : _g.customCSS) === null || _h === void 0 ? void 0 : _h.rules_UNSTABLE) != null,
            usedCustomizationStrings: !!((_k = (_j = embedConfig.customizations) === null || _j === void 0 ? void 0 : _j.content) === null || _k === void 0 ? void 0 : _k.strings),
            usedCustomizationIconSprite: !!((_l = embedConfig.customizations) === null || _l === void 0 ? void 0 : _l.iconSpriteUrl),
        });
        if (getEmbedConfig().callPrefetch) {
            prefetch(getEmbedConfig().thoughtSpotHost);
        }
        // Resolves the promise created in the initPromiseKey
        getValueFromWindow(initFlagKey).initPromiseResolve(authEE);
        getValueFromWindow(initFlagKey).isInitCalled = true;
        return authEE;
    };
    /**
     *
     */
    function disableAutoLogin() {
        getEmbedConfig().autoLogin = false;
    }
    /**
     * Logs out from ThoughtSpot. This also sets the autoLogin flag to false, to
     * prevent the SDK from automatically logging in again.
     *
     * You can call the `init` method again to re login, if autoLogin is set to
     * true in this second call it will be honored.
     * @param doNotDisableAutoLogin This flag when passed will not disable autoLogin
     * @returns Promise which resolves when logout completes.
     * @version SDK: 1.10.1 | ThoughtSpot: 8.2.0.cl, 8.4.1-sw
     * @group Global methods
     */
    const logout = (doNotDisableAutoLogin = false) => {
        if (!doNotDisableAutoLogin) {
            disableAutoLogin();
        }
        return logout$1(getEmbedConfig()).then((isLoggedIn) => {
            notifyLogout();
            return isLoggedIn;
        });
    };
    let renderQueue = Promise.resolve();
    /**
     * Renders functions in a queue, resolves to next function only after the callback next
     * is called
     * @param fn The function being registered
     */
    const renderInQueue = (fn) => {
        const { queueMultiRenders = false } = getEmbedConfig();
        if (queueMultiRenders) {
            renderQueue = renderQueue.then(() => new Promise((res) => fn(res)));
            return renderQueue;
        }
        // Sending an empty function to keep it consistent with the above usage.
        return fn(() => { }); // eslint-disable-line @typescript-eslint/no-empty-function
    };
    /**
     * Imports TML representation of the metadata objects into ThoughtSpot.
     * @param data
     * @returns imports TML data into ThoughtSpot
     * @example
     * ```js
     *  executeTML({
     * //Array of metadata Tmls in string format
     *      metadata_tmls: [
     *          "'\''{\"guid\":\"9bd202f5-d431-44bf-9a07-b4f7be372125\",
     *          \"liveboard\":{\"name\":\"Parameters Liveboard\"}}'\''"
     *      ],
     *      import_policy: 'PARTIAL', // Specifies the import policy for the TML import.
     *      create_new: false, // If selected, creates TML objects with new GUIDs.
     *  }).then(result => {
     *      console.log(result);
     *  }).catch(error => {
     *      console.error(error);
     *  });
     *```
     * @version SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl
     * @group Global methods
     */
    const executeTML = async (data) => {
        try {
            sanity(getEmbedConfig());
        }
        catch (err) {
            return Promise.reject(err);
        }
        const { thoughtSpotHost, authType } = getEmbedConfig();
        const headers = {
            'Content-Type': 'application/json',
            'x-requested-by': 'ThoughtSpot',
        };
        const payload = {
            metadata_tmls: data.metadata_tmls,
            import_policy: data.import_policy || 'PARTIAL',
            create_new: data.create_new || false,
        };
        return tokenizedFetch(`${thoughtSpotHost}${EndPoints.EXECUTE_TML}`, {
            method: 'POST',
            headers,
            body: JSON.stringify(payload),
            credentials: 'include',
        })
            .then((response) => {
            if (!response.ok) {
                throw new Error(`Failed to import TML data: ${response.status} - ${response.statusText}`);
            }
            return response.json();
        })
            .catch((error) => {
            throw error;
        });
    };
    /**
     * Exports TML representation of the metadata objects from ThoughtSpot in JSON or YAML
     * format.
     * @param data
     * @returns exports TML data
     * @example
     * ```js
     * exportTML({
     *   metadata: [
     *     {
     *       type: "LIVEBOARD", //Metadata Type
     *       identifier: "9bd202f5-d431-44bf-9a07-b4f7be372125" //Metadata Id
     *     }
     *   ],
     *   export_associated: false,//indicates whether to export associated metadata objects
     *   export_fqn: false, //Adds FQNs of the referenced objects.For example, if you are
     *                      //exporting a Liveboard and its associated objects, the API
     *                      //returns the Liveboard TML data with the FQNs of the referenced
     *                      //worksheet. If the exported TML data includes FQNs, you don't need
     *                      //to manually add FQNs of the referenced objects during TML import.
     *   edoc_format: "JSON" //It takes JSON or YAML value
     * }).then(result => {
     *   console.log(result);
     * }).catch(error => {
     *   console.error(error);
     * });
     * ```
     * @version SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl
     * @group Global methods
     */
    const exportTML = async (data) => {
        const { thoughtSpotHost, authType } = getEmbedConfig();
        try {
            sanity(getEmbedConfig());
        }
        catch (err) {
            return Promise.reject(err);
        }
        const payload = {
            metadata: data.metadata,
            export_associated: data.export_associated || false,
            export_fqn: data.export_fqn || false,
            edoc_format: data.edoc_format || 'YAML',
        };
        const headers = {
            'Content-Type': 'application/json',
            'x-requested-by': 'ThoughtSpot',
        };
        return tokenizedFetch(`${thoughtSpotHost}${EndPoints.EXPORT_TML}`, {
            method: 'POST',
            headers,
            body: JSON.stringify(payload),
            credentials: 'include',
        })
            .then((response) => {
            if (!response.ok) {
                throw new Error(`Failed to export TML: ${response.status} - ${response.statusText}`);
            }
            return response.json();
        })
            .catch((error) => {
            throw error;
        });
    };

    /**
     *
     * @param e
     * @param thoughtSpotHost
     */
    function processCustomAction(e, thoughtSpotHost) {
        const { session, embedAnswerData, contextMenuPoints } = e.data;
        const answerService = new AnswerService(session, embedAnswerData || {}, thoughtSpotHost, contextMenuPoints === null || contextMenuPoints === void 0 ? void 0 : contextMenuPoints.selectedPoints);
        return {
            ...e,
            answerService,
        };
    }
    /**
     * Responds to AuthInit sent from host signifying successful authentication in host.
     * @param e
     * @returns {any}
     */
    function processAuthInit(e) {
        var _a, _b;
        notifyAuthSuccess();
        // Expose only allowed details (eg: userGUID) back to SDK users.
        return {
            ...e,
            data: {
                userGUID: ((_a = e.data) === null || _a === void 0 ? void 0 : _a.userGUID) || ((_b = e.payload) === null || _b === void 0 ? void 0 : _b.userGUID),
            },
        };
    }
    /**
     *
     * @param e
     * @param containerEl
     */
    function processNoCookieAccess(e, containerEl) {
        const { loginFailedMessage, suppressNoCookieAccessAlert, ignoreNoCookieAccess, suppressErrorAlerts, } = getEmbedConfig();
        if (!ignoreNoCookieAccess) {
            if (!suppressNoCookieAccessAlert && !suppressErrorAlerts) {
                // eslint-disable-next-line no-alert
                alert(ERROR_MESSAGE.THIRD_PARTY_COOKIE_BLOCKED_ALERT);
            }
            // eslint-disable-next-line no-param-reassign
            containerEl.innerHTML = loginFailedMessage;
        }
        notifyAuthFailure(exports.AuthFailureType.NO_COOKIE_ACCESS);
        return e;
    }
    /**
     *
     * @param e
     * @param containerEl
     */
    function processAuthFailure(e, containerEl) {
        var _a;
        const { loginFailedMessage, authType, disableLoginFailurePage, autoLogin, } = getEmbedConfig();
        const isEmbeddedSSO = authType === exports.AuthType.EmbeddedSSO;
        const isTrustedAuth = authType === exports.AuthType.TrustedAuthToken || authType === exports.AuthType.TrustedAuthTokenCookieless;
        const isEmbeddedSSOInfoFailure = isEmbeddedSSO && ((_a = e === null || e === void 0 ? void 0 : e.data) === null || _a === void 0 ? void 0 : _a.type) === exports.AuthFailureType.UNAUTHENTICATED_FAILURE;
        if (autoLogin && isTrustedAuth) {
            // eslint-disable-next-line no-param-reassign
            containerEl.innerHTML = loginFailedMessage;
            notifyAuthFailure(exports.AuthFailureType.IDLE_SESSION_TIMEOUT);
        }
        else if (authType !== exports.AuthType.None && !disableLoginFailurePage && !isEmbeddedSSOInfoFailure) {
            // eslint-disable-next-line no-param-reassign
            containerEl.innerHTML = loginFailedMessage;
            notifyAuthFailure(exports.AuthFailureType.OTHER);
        }
        resetCachedAuthToken();
        return e;
    }
    /**
     *
     * @param e
     * @param containerEl
     */
    function processAuthLogout(e, containerEl) {
        const { loginFailedMessage } = getEmbedConfig();
        // eslint-disable-next-line no-param-reassign
        containerEl.innerHTML = loginFailedMessage;
        resetCachedAuthToken();
        disableAutoLogin();
        notifyLogout();
        return e;
    }
    /**
     *
     * @param type
     * @param e
     * @param thoughtSpotHost
     * @param containerEl
     */
    function processEventData(type, e, thoughtSpotHost, containerEl) {
        switch (type) {
            case exports.EmbedEvent.CustomAction:
                return processCustomAction(e, thoughtSpotHost);
            case exports.EmbedEvent.AuthInit:
                return processAuthInit(e);
            case exports.EmbedEvent.NoCookieAccess:
                return processNoCookieAccess(e, containerEl);
            case exports.EmbedEvent.AuthFailure:
                return processAuthFailure(e, containerEl);
            case exports.EmbedEvent.AuthLogout:
                return processAuthLogout(e, containerEl);
        }
        return e;
    }

    var name="@thoughtspot/visual-embed-sdk";var version$1="1.38.0";var description="ThoughtSpot Embed SDK";var module="lib/src/index.js";var main="dist/tsembed.js";var types="lib/src/index.d.ts";var files=["dist/**","lib/**","src/**","cjs/**"];var exports$1={".":{"import":"./lib/src/index.js",require:"./cjs/src/index.js",types:"./lib/src/index.d.ts"},"./react":{"import":"./lib/src/react/all-types-export.js",require:"./cjs/src/react/all-types-export.js",types:"./lib/src/react/all-types-export.d.ts"},"./lib/src/react":{"import":"./lib/src/react/all-types-export.js",require:"./cjs/src/react/all-types-export.js",types:"./lib/src/react/all-types-export.d.ts"}};var typesVersions={"*":{react:["./lib/src/react/all-types-export.d.ts"]}};var scripts={lint:"eslint 'src/**'","lint:fix":"eslint 'src/**/*.*' --fix",tsc:"tsc -p . --incremental false; tsc -p . --incremental false --module commonjs --outDir cjs","build-and-publish":"npm run build:gatsby && npm run publish","bundle-dts-file":"dts-bundle --name @thoughtspot/visual-embed-sdk --out visual-embed-sdk.d.ts --main lib/src/index.d.ts","bundle-dts":"dts-bundle --name ../../dist/visual-embed-sdk --main lib/src/index.d.ts --outputAsModuleFolder=true","bundle-dts-react":"dts-bundle --name ../../../dist/visual-embed-sdk-react --main lib/src/react/index.d.ts --outputAsModuleFolder=true","bundle-dts-react-full":"dts-bundle --name ../../../dist/visual-embed-sdk-react-full --main lib/src/react/all-types-export.d.ts --outputAsModuleFolder=true",build:"rollup -c",watch:"rollup -cw",docgen:"typedoc --tsconfig tsconfig.json --theme typedoc-theme --json static/typedoc/typedoc.json --disableOutputCheck","test-sdk":"jest -c jest.config.sdk.js --runInBand",test:"npm run test-sdk",posttest:"cat ./coverage/sdk/lcov.info | coveralls","is-publish-allowed":"node scripts/is-publish-allowed.js",prepublishOnly:"npm run is-publish-allowed && npm run test && npm run tsc && npm run bundle-dts-file && npm run bundle-dts && npm run bundle-dts-react && npm run bundle-dts-react-full && npm run build","check-size":"npm run build && size-limit","publish-dev":"npm publish --tag dev","publish-prod":"npm publish --tag latest",dev:"vite -c vite.local.config.ts"};var peerDependencies={react:"> 16.8.0","react-dom":"> 16.8.0"};var dependencies={classnames:"^2.3.1",eventemitter3:"^4.0.7",lodash:"^4.17.21","mixpanel-browser":"2.47.0","ts-deepmerge":"^6.0.2",tslib:"^2.5.3","use-deep-compare-effect":"^1.8.1",yaml:"^2.5.1"};var devDependencies={"@mdx-js/mdx":"^1.6.22","@mdx-js/react":"^1.6.22","@react-icons/all-files":"^4.1.0","@rollup/plugin-commonjs":"^18.0.0","@rollup/plugin-json":"^4.1.0","@rollup/plugin-node-resolve":"^11.2.1","@rollup/plugin-replace":"^5.0.2","@size-limit/preset-big-lib":"^8.2.6","@testing-library/dom":"^7.31.0","@testing-library/jest-dom":"^5.14.1","@testing-library/react":"^11.2.7","@testing-library/user-event":"^13.1.8","@types/jest":"^22.2.3","@types/lodash":"^4.17.0","@types/mixpanel-browser":"^2.35.6","@types/react-test-renderer":"^17.0.1","@typescript-eslint/eslint-plugin":"^8.28.0","@typescript-eslint/parser":"^8.28.0",asciidoctor:"^2.2.1","babel-jest":"^26.6.3","babel-preset-gatsby":"^1.10.0","command-line-args":"^5.1.1",coveralls:"^3.1.0",crypto:"^1.0.1","current-git-branch":"^1.1.0","dts-bundle":"^0.7.3",eslint:"^9.23.0","eslint-config-airbnb-base":"^15.0.0","eslint-config-prettier":"^10.1.1","eslint-import-resolver-typescript":"^4.2.5","eslint-plugin-comment-length":"2.2.1","eslint-plugin-import":"^2.31.0","eslint-plugin-jsdoc":"^50.6.9","eslint-plugin-prettier":"^5.2.5","eslint-plugin-react":"^7.37.5","eslint-plugin-react-hooks":"^5.2.0","fs-extra":"^10.0.0","gh-pages":"6.3.0",globals:"^16.0.0","highlight.js":"^10.6.0","html-to-text":"^8.0.0","identity-obj-proxy":"^3.0.0","istanbul-merge":"^1.1.1",jest:"^26.6.3","jest-fetch-mock":"^3.0.3",jsdom:"^17.0.0",prettier:"2.1.2",react:"^16.14.0","react-dom":"^16.14.0","react-resizable":"^1.11.0","react-resize-detector":"^6.6.0","react-test-renderer":"^17.0.2","react-use-flexsearch":"^0.1.1",rollup:"4.24.0","rollup-plugin-typescript2":"0.27.3","ts-jest":"^26.5.5","ts-loader":"8.0.4",typedoc:"0.21.6","typedoc-plugin-toc-group":"thoughtspot/typedoc-plugin-toc-group",typescript:"^4.9.4","typescript-eslint":"^8.29.1","url-search-params-polyfill":"^8.1.0",util:"^0.12.4",vite:"^6.3.5"};var author="ThoughtSpot";var email="support@thoughtspot.com";var license="ThoughtSpot Development Tools End User License Agreement";var directories={lib:"lib"};var repository={type:"git",url:"git+https://github.com/thoughtspot/visual-embed-sdk.git"};var publishConfig={registry:"https://registry.npmjs.org"};var keywords=["thoughtspot","everywhere","embedded","embed","sdk","analytics"];var bugs={url:"https://github.com/thoughtspot/visual-embed-sdk/issues"};var homepage="https://github.com/thoughtspot/visual-embed-sdk#readme";var globals={window:{}};var pkgInfo = {name:name,version:version$1,description:description,module:module,main:main,types:types,files:files,exports:exports$1,typesVersions:typesVersions,"size-limit":[{path:"dist/tsembed.es.js",limit:"31 kB"}],scripts:scripts,peerDependencies:peerDependencies,dependencies:dependencies,devDependencies:devDependencies,author:author,email:email,license:license,directories:directories,repository:repository,publishConfig:publishConfig,keywords:keywords,bugs:bugs,homepage:homepage,globals:globals};

    /**
     * Reloads the ThoughtSpot iframe.
     * @param iFrame
     */
    const reload = (iFrame) => {
        const src = iFrame.src;
        iFrame.src = '';
        setTimeout(() => {
            iFrame.src = src;
        }, 100);
    };
    /**
     * Post iframe message.
     * @param iFrame
     * @param message
     * @param message.type
     * @param message.data
     * @param thoughtSpotHost
     * @param channel
     */
    function postIframeMessage(iFrame, message, thoughtSpotHost, channel) {
        return iFrame.contentWindow.postMessage(message, thoughtSpotHost, [channel === null || channel === void 0 ? void 0 : channel.port2]);
    }
    const TRIGGER_TIMEOUT = 30000;
    /**
     *
     * @param iFrame
     * @param messageType
     * @param thoughtSpotHost
     * @param data
     */
    function processTrigger(iFrame, messageType, thoughtSpotHost, data) {
        return new Promise((res, rej) => {
            if (messageType === exports.HostEvent.Reload) {
                reload(iFrame);
                return res(null);
            }
            const channel = new MessageChannel();
            channel.port1.onmessage = ({ data: responseData }) => {
                var _a;
                channel.port1.close();
                const error = responseData.error || ((_a = responseData === null || responseData === void 0 ? void 0 : responseData.data) === null || _a === void 0 ? void 0 : _a.error);
                if (error) {
                    rej(error);
                }
                else {
                    res(responseData);
                }
            };
            // Close the messageChannel and resolve the promise if timeout.
            setTimeout(() => {
                channel.port1.close();
                res(new Error(ERROR_MESSAGE.TRIGGER_TIMED_OUT));
            }, TRIGGER_TIMEOUT);
            return postIframeMessage(iFrame, { type: messageType, data }, thoughtSpotHost, channel);
        });
    }

    exports.UIPassthroughEvent = void 0;
    (function (UIPassthroughEvent) {
        UIPassthroughEvent["PinAnswerToLiveboard"] = "addVizToPinboard";
        UIPassthroughEvent["SaveAnswer"] = "saveAnswer";
        UIPassthroughEvent["GetDiscoverabilityStatus"] = "getDiscoverabilityStatus";
        UIPassthroughEvent["GetAvailableUIPassthroughs"] = "getAvailableUiPassthroughs";
        UIPassthroughEvent["GetAnswerConfig"] = "getAnswerPageConfig";
        UIPassthroughEvent["GetLiveboardConfig"] = "getPinboardPageConfig";
    })(exports.UIPassthroughEvent || (exports.UIPassthroughEvent = {}));

    class HostEventClient {
        constructor(iFrame) {
            this.iFrame = iFrame;
        }
        /**
         * A wrapper over process trigger to
         * @param {HostEvent} message Host event to send
         * @param {any} data Data to send with the host event
         * @returns {Promise<any>} - the response from the process trigger
         */
        async processTrigger(message, data) {
            if (!this.iFrame) {
                throw new Error('Iframe element is not set');
            }
            const thoughtspotHost = getEmbedConfig().thoughtSpotHost;
            return processTrigger(this.iFrame, message, thoughtspotHost, data);
        }
        async handleHostEventWithParam(apiName, parameters) {
            var _a, _b, _c, _d;
            const response = (_b = (_a = (await this.triggerUIPassthroughApi(apiName, parameters))) === null || _a === void 0 ? void 0 : _a.filter) === null || _b === void 0 ? void 0 : _b.call(_a, (r) => r.error || r.value)[0];
            if (!response) {
                const error = `No answer found${parameters.vizId ? ` for vizId: ${parameters.vizId}` : ''}.`;
                // eslint-disable-next-line no-throw-literal
                throw { error };
            }
            const errors = response.error
                || ((_c = response.value) === null || _c === void 0 ? void 0 : _c.errors)
                || ((_d = response.value) === null || _d === void 0 ? void 0 : _d.error);
            if (errors) {
                // eslint-disable-next-line no-throw-literal
                throw { error: response.error };
            }
            return { ...response.value };
        }
        async hostEventFallback(hostEvent, data) {
            return this.processTrigger(hostEvent, data);
        }
        /**
         * Setter for the iframe element used for host events
         * @param {HTMLIFrameElement} iFrame - the iframe element to set
         */
        setIframeElement(iFrame) {
            this.iFrame = iFrame;
        }
        async triggerUIPassthroughApi(apiName, parameters) {
            const res = await this.processTrigger(exports.HostEvent.UIPassthrough, {
                type: apiName,
                parameters,
            });
            return res;
        }
        async handlePinEvent(payload) {
            var _a, _b;
            if (!payload || !('newVizName' in payload)) {
                return this.hostEventFallback(exports.HostEvent.Pin, payload);
            }
            const formattedPayload = {
                ...payload,
                pinboardId: (_a = payload.liveboardId) !== null && _a !== void 0 ? _a : payload.pinboardId,
                newPinboardName: (_b = payload.newLiveboardName) !== null && _b !== void 0 ? _b : payload.newPinboardName,
            };
            const data = await this.handleHostEventWithParam(exports.UIPassthroughEvent.PinAnswerToLiveboard, formattedPayload);
            return {
                ...data,
                liveboardId: data.pinboardId,
            };
        }
        async handleSaveAnswerEvent(payload) {
            var _a, _b, _c, _d;
            if (!payload || !('name' in payload) || !('description' in payload)) {
                // Save is the fallback for SaveAnswer
                return this.hostEventFallback(exports.HostEvent.Save, payload);
            }
            const data = await this.handleHostEventWithParam(exports.UIPassthroughEvent.SaveAnswer, payload);
            return {
                ...data,
                answerId: (_d = (_c = (_b = (_a = data === null || data === void 0 ? void 0 : data.saveResponse) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.Answer__save) === null || _c === void 0 ? void 0 : _c.answer) === null || _d === void 0 ? void 0 : _d.id,
            };
        }
        async triggerHostEvent(hostEvent, payload) {
            switch (hostEvent) {
                case exports.HostEvent.Pin:
                    return this.handlePinEvent(payload);
                case exports.HostEvent.SaveAnswer:
                    return this.handleSaveAnswerEvent(payload);
                default:
                    return this.hostEventFallback(hostEvent, payload);
            }
        }
    }

    /**
     * Copyright (c) 2022
     *
     * Base classes
     * @summary Base classes
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    const { version } = pkgInfo;
    /**
     * Global prefix for all Thoughtspot postHash Params.
     */
    const THOUGHTSPOT_PARAM_PREFIX = 'ts-';
    const TS_EMBED_ID = '_thoughtspot-embed';
    /**
     * The event id map from v2 event names to v1 event id
     * v1 events are the classic embed events implemented in Blink v1
     * We cannot rename v1 event types to maintain backward compatibility
     * @internal
     */
    const V1EventMap = {};
    /**
     * Base class for embedding v2 experience
     * Note: the v2 version of ThoughtSpot Blink is built on the new stack:
     * React+GraphQL
     */
    class TsEmbed {
        /**
         * Setter for the iframe element
         * @param {HTMLIFrameElement} iFrame HTMLIFrameElement
         */
        setIframeElement(iFrame) {
            this.iFrame = iFrame;
            this.hostEventClient.setIframeElement(iFrame);
        }
        constructor(domSelector, viewConfig) {
            /**
             * The key to store the embed instance in the DOM node
             */
            this.embedNodeKey = '__tsEmbed';
            this.isAppInitialized = false;
            /**
             * Should we encode URL Query Params using base64 encoding which thoughtspot
             * will generate for embedding. This provides additional security to
             * thoughtspot clusters against Cross site scripting attacks.
             * @default false
             */
            this.shouldEncodeUrlQueryParams = false;
            this.defaultHiddenActions = [exports.Action.ReportError];
            this.subscribedListeners = {};
            /**
             * Send Custom style as part of payload of APP_INIT
             * @param _
             * @param responder
             */
            this.appInitCb = async (_, responder) => {
                try {
                    const appInitData = await this.getAppInitData();
                    this.isAppInitialized = true;
                    responder({
                        type: exports.EmbedEvent.APP_INIT,
                        data: appInitData,
                    });
                }
                catch (e) {
                    logger$3.error(`AppInit failed, Error : ${e === null || e === void 0 ? void 0 : e.message}`);
                }
            };
            /**
             * Sends updated auth token to the iFrame to avoid user logout
             * @param _
             * @param responder
             */
            this.updateAuthToken = async (_, responder) => {
                const { authType } = this.embedConfig;
                let { autoLogin } = this.embedConfig;
                // Default autoLogin: true for cookieless if undefined/null, otherwise false
                autoLogin = autoLogin !== null && autoLogin !== void 0 ? autoLogin : (authType === exports.AuthType.TrustedAuthTokenCookieless);
                if (autoLogin && authType === exports.AuthType.TrustedAuthTokenCookieless) {
                    try {
                        const authToken = await getAuthenticationToken(this.embedConfig);
                        responder({
                            type: exports.EmbedEvent.AuthExpire,
                            data: { authToken },
                        });
                    }
                    catch (e) {
                        logger$3.error(`${ERROR_MESSAGE.INVALID_TOKEN_ERROR} Error : ${e === null || e === void 0 ? void 0 : e.message}`);
                        processAuthFailure(e, this.isPreRendered ? this.preRenderWrapper : this.el);
                    }
                }
                else if (autoLogin) {
                    handleAuth();
                }
                notifyAuthFailure(exports.AuthFailureType.EXPIRY);
            };
            /**
             * Auto Login and send updated authToken to the iFrame to avoid user session logout
             * @param _
             * @param responder
             */
            this.idleSessionTimeout = (_, responder) => {
                handleAuth().then(async () => {
                    let authToken = '';
                    try {
                        authToken = await getAuthenticationToken(this.embedConfig);
                        responder({
                            type: exports.EmbedEvent.IdleSessionTimeout,
                            data: { authToken },
                        });
                    }
                    catch (e) {
                        logger$3.error(`${ERROR_MESSAGE.INVALID_TOKEN_ERROR} Error : ${e === null || e === void 0 ? void 0 : e.message}`);
                        processAuthFailure(e, this.isPreRendered ? this.preRenderWrapper : this.el);
                    }
                }).catch((e) => {
                    logger$3.error(`Auto Login failed, Error : ${e === null || e === void 0 ? void 0 : e.message}`);
                });
                notifyAuthFailure(exports.AuthFailureType.IDLE_SESSION_TIMEOUT);
            };
            /**
             * Register APP_INIT event and sendback init payload
             */
            this.registerAppInit = () => {
                this.on(exports.EmbedEvent.APP_INIT, this.appInitCb, { start: false }, true);
                this.on(exports.EmbedEvent.AuthExpire, this.updateAuthToken, { start: false }, true);
                this.on(exports.EmbedEvent.IdleSessionTimeout, this.idleSessionTimeout, { start: false }, true);
            };
            this.showPreRenderByDefault = false;
            this.validatePreRenderViewConfig = (viewConfig) => {
                var _a;
                const preRenderAllowedKeys = ['preRenderId', 'vizId', 'liveboardId'];
                const preRenderedObject = (_a = this.insertedDomEl) === null || _a === void 0 ? void 0 : _a[this.embedNodeKey];
                if (!preRenderedObject)
                    return;
                if (viewConfig.preRenderId) {
                    const allOtherKeys = Object.keys(viewConfig).filter((key) => !preRenderAllowedKeys.includes(key) && !key.startsWith('on'));
                    allOtherKeys.forEach((key) => {
                        if (!isUndefined$1(viewConfig[key])
                            && !isEqual_1(viewConfig[key], preRenderedObject.viewConfig[key])) {
                            logger$3.warn(`${viewConfig.embedComponentType || 'Component'} was pre-rendered with `
                                + `"${key}" as "${JSON.stringify(preRenderedObject.viewConfig[key])}" `
                                + `but a different value "${JSON.stringify(viewConfig[key])}" `
                                + 'was passed to the Embed component. '
                                + 'The new value provided is ignored, the value provided during '
                                + 'preRender is used.');
                        }
                    });
                }
            };
            this.el = getDOMNode(domSelector);
            this.eventHandlerMap = new Map();
            this.isError = false;
            this.viewConfig = {
                excludeRuntimeFiltersfromURL: false,
                excludeRuntimeParametersfromURL: false,
                ...viewConfig,
            };
            this.registerAppInit();
            uploadMixpanelEvent(MIXPANEL_EVENT.VISUAL_SDK_EMBED_CREATE, {
                ...viewConfig,
            });
            this.hostEventClient = new HostEventClient(this.iFrame);
            this.isReadyForRenderPromise = getInitPromise().then(async () => {
                const embedConfig = getEmbedConfig();
                this.embedConfig = embedConfig;
                if (!embedConfig.authTriggerContainer && !embedConfig.useEventForSAMLPopup) {
                    this.embedConfig.authTriggerContainer = domSelector;
                }
                this.thoughtSpotHost = getThoughtSpotHost(embedConfig);
                this.thoughtSpotV2Base = getV2BasePath(embedConfig);
                this.shouldEncodeUrlQueryParams = embedConfig.shouldEncodeUrlQueryParams;
            });
        }
        /**
         * Throws error encountered during initialization.
         */
        throwInitError() {
            this.handleError('You need to init the ThoughtSpot SDK module first');
        }
        /**
         * Handles errors within the SDK
         * @param error The error message or object
         */
        handleError(error) {
            this.isError = true;
            this.executeCallbacks(exports.EmbedEvent.Error, {
                error,
            });
            // Log error
            logger$3.error(error);
        }
        /**
         * Extracts the type field from the event payload
         * @param event The window message event
         */
        getEventType(event) {
            var _a, _b;
            // eslint-disable-next-line no-underscore-dangle
            return ((_a = event.data) === null || _a === void 0 ? void 0 : _a.type) || ((_b = event.data) === null || _b === void 0 ? void 0 : _b.__type);
        }
        /**
         * Extracts the port field from the event payload
         * @param event  The window message event
         * @returns
         */
        getEventPort(event) {
            if (event.ports.length && event.ports[0]) {
                return event.ports[0];
            }
            return null;
        }
        /**
         * Checks if preauth cache is enabled
         * from the view config and embed config
         * @returns boolean
         */
        isPreAuthCacheEnabled() {
            // Disable preauth cache when:
            // 1. overrideOrgId is present since:
            //    - cached auth info would be for wrong org
            //    - info call response changes for each different overrideOrgId
            // 2. disablePreauthCache is explicitly set to true
            const isDisabled = (this.viewConfig.overrideOrgId !== undefined
                || this.embedConfig.disablePreauthCache === true);
            return !isDisabled;
        }
        /**
         * fix for ts7.sep.cl
         * will be removed for ts7.oct.cl
         * @param event
         * @param eventType
         * @hidden
         */
        formatEventData(event, eventType) {
            const eventData = {
                ...event.data,
                type: eventType,
            };
            if (!eventData.data) {
                eventData.data = event.data.payload;
            }
            return eventData;
        }
        /**
         * Adds a global event listener to window for "message" events.
         * ThoughtSpot detects if a particular event is targeted to this
         * embed instance through an identifier contained in the payload,
         * and executes the registered callbacks accordingly.
         */
        subscribeToEvents() {
            this.unsubscribeToEvents();
            const messageEventListener = (event) => {
                const eventType = this.getEventType(event);
                const eventPort = this.getEventPort(event);
                const eventData = this.formatEventData(event, eventType);
                if (event.source === this.iFrame.contentWindow) {
                    this.executeCallbacks(eventType, processEventData(eventType, eventData, this.thoughtSpotHost, this.isPreRendered ? this.preRenderWrapper : this.el), eventPort);
                }
            };
            window.addEventListener('message', messageEventListener);
            const onlineEventListener = (e) => {
                this.trigger(exports.HostEvent.Reload);
            };
            window.addEventListener('online', onlineEventListener);
            const offlineEventListener = (e) => {
                const offlineWarning = 'Network not Detected. Embed is offline. Please reconnect and refresh';
                this.executeCallbacks(exports.EmbedEvent.Error, {
                    offlineWarning,
                });
                logger$3.warn(offlineWarning);
            };
            window.addEventListener('offline', offlineEventListener);
            this.subscribedListeners = {
                message: messageEventListener,
                online: onlineEventListener,
                offline: offlineEventListener,
            };
        }
        unsubscribeToEvents() {
            Object.keys(this.subscribedListeners).forEach((key) => {
                window.removeEventListener(key, this.subscribedListeners[key]);
            });
        }
        async getAuthTokenForCookielessInit() {
            let authToken = '';
            if (this.embedConfig.authType !== exports.AuthType.TrustedAuthTokenCookieless)
                return authToken;
            try {
                authToken = await getAuthenticationToken(this.embedConfig);
            }
            catch (e) {
                processAuthFailure(e, this.isPreRendered ? this.preRenderWrapper : this.el);
                throw e;
            }
            return authToken;
        }
        async getDefaultAppInitData() {
            var _a, _b;
            const authToken = await this.getAuthTokenForCookielessInit();
            return {
                customisations: getCustomisations(this.embedConfig, this.viewConfig),
                authToken,
                runtimeFilterParams: this.viewConfig.excludeRuntimeFiltersfromURL
                    ? getRuntimeFilters(this.viewConfig.runtimeFilters)
                    : null,
                runtimeParameterParams: this.viewConfig.excludeRuntimeParametersfromURL
                    ? getRuntimeParameters(this.viewConfig.runtimeParameters || [])
                    : null,
                hiddenHomepageModules: this.viewConfig.hiddenHomepageModules || [],
                reorderedHomepageModules: this.viewConfig.reorderedHomepageModules || [],
                hostConfig: this.embedConfig.hostConfig,
                hiddenHomeLeftNavItems: ((_a = this.viewConfig) === null || _a === void 0 ? void 0 : _a.hiddenHomeLeftNavItems)
                    ? (_b = this.viewConfig) === null || _b === void 0 ? void 0 : _b.hiddenHomeLeftNavItems
                    : [],
                customVariablesForThirdPartyTools: this.embedConfig.customVariablesForThirdPartyTools || {},
                hiddenListColumns: this.viewConfig.hiddenListColumns || [],
            };
        }
        async getAppInitData() {
            return this.getDefaultAppInitData();
        }
        /**
         * Constructs the base URL string to load the ThoughtSpot app.
         * @param query
         */
        getEmbedBasePath(query) {
            let queryString = query.startsWith('?') ? query : `?${query}`;
            if (this.shouldEncodeUrlQueryParams) {
                queryString = `?base64UrlEncodedFlags=${getEncodedQueryParamsString(queryString.substr(1))}`;
            }
            const basePath = [this.thoughtSpotHost, this.thoughtSpotV2Base, queryString]
                .filter((x) => x.length > 0)
                .join('/');
            return `${basePath}#`;
        }
        /**
         * Common query params set for all the embed modes.
         * @param queryParams
         * @returns queryParams
         */
        getBaseQueryParams(queryParams = {}) {
            var _a, _b, _c, _d;
            let hostAppUrl = ((_a = window === null || window === void 0 ? void 0 : window.location) === null || _a === void 0 ? void 0 : _a.host) || '';
            // The below check is needed because TS Cloud firewall, blocks
            // localhost/127.0.0.1 in any url param.
            if (hostAppUrl.includes('localhost') || hostAppUrl.includes('127.0.0.1')) {
                hostAppUrl = 'local-host';
            }
            const blockNonEmbedFullAppAccess = (_b = this.embedConfig.blockNonEmbedFullAppAccess) !== null && _b !== void 0 ? _b : true;
            queryParams[Param.EmbedApp] = true;
            queryParams[Param.HostAppUrl] = encodeURIComponent(hostAppUrl);
            queryParams[Param.ViewPortHeight] = window.innerHeight;
            queryParams[Param.ViewPortWidth] = window.innerWidth;
            queryParams[Param.Version] = version;
            queryParams[Param.AuthType] = this.embedConfig.authType;
            queryParams[Param.blockNonEmbedFullAppAccess] = blockNonEmbedFullAppAccess;
            queryParams[Param.AutoLogin] = this.embedConfig.autoLogin;
            if (this.embedConfig.disableLoginRedirect === true || this.embedConfig.autoLogin === true) {
                queryParams[Param.DisableLoginRedirect] = true;
            }
            if (this.embedConfig.authType === exports.AuthType.EmbeddedSSO) {
                queryParams[Param.ForceSAMLAutoRedirect] = true;
            }
            if (this.embedConfig.authType === exports.AuthType.TrustedAuthTokenCookieless) {
                queryParams[Param.cookieless] = true;
            }
            if (this.embedConfig.pendoTrackingKey) {
                queryParams[Param.PendoTrackingKey] = this.embedConfig.pendoTrackingKey;
            }
            if (this.embedConfig.numberFormatLocale) {
                queryParams[Param.NumberFormatLocale] = this.embedConfig.numberFormatLocale;
            }
            if (this.embedConfig.dateFormatLocale) {
                queryParams[Param.DateFormatLocale] = this.embedConfig.dateFormatLocale;
            }
            if (this.embedConfig.currencyFormat) {
                queryParams[Param.CurrencyFormat] = this.embedConfig.currencyFormat;
            }
            const { disabledActions, disabledActionReason, hiddenActions, visibleActions, hiddenTabs, visibleTabs, showAlerts, additionalFlags: additionalFlagsFromView, locale, customizations, contextMenuTrigger, linkOverride, insertInToSlide, disableRedirectionLinksInNewTab, overrideOrgId, exposeTranslationIDs, primaryAction, } = this.viewConfig;
            const { additionalFlags: additionalFlagsFromInit } = this.embedConfig;
            const additionalFlags = {
                ...additionalFlagsFromInit,
                ...additionalFlagsFromView,
            };
            if (Array.isArray(visibleActions) && Array.isArray(hiddenActions)) {
                this.handleError('You cannot have both hidden actions and visible actions');
                return queryParams;
            }
            if (Array.isArray(visibleTabs) && Array.isArray(hiddenTabs)) {
                this.handleError('You cannot have both hidden Tabs and visible Tabs');
                return queryParams;
            }
            if (primaryAction) {
                queryParams[Param.PrimaryAction] = primaryAction;
            }
            if (disabledActions === null || disabledActions === void 0 ? void 0 : disabledActions.length) {
                queryParams[Param.DisableActions] = disabledActions;
            }
            if (disabledActionReason) {
                queryParams[Param.DisableActionReason] = disabledActionReason;
            }
            if (exposeTranslationIDs) {
                queryParams[Param.ExposeTranslationIDs] = exposeTranslationIDs;
            }
            queryParams[Param.HideActions] = [...this.defaultHiddenActions, ...(hiddenActions !== null && hiddenActions !== void 0 ? hiddenActions : [])];
            if (Array.isArray(visibleActions)) {
                queryParams[Param.VisibleActions] = visibleActions;
            }
            if (Array.isArray(hiddenTabs)) {
                queryParams[Param.HiddenTabs] = hiddenTabs;
            }
            if (Array.isArray(visibleTabs)) {
                queryParams[Param.VisibleTabs] = visibleTabs;
            }
            /**
             * Default behavior for context menu will be left-click
             *  from version 9.2.0.cl the user have an option to override context
             *  menu click
             */
            if (contextMenuTrigger === exports.ContextMenuTriggerOptions.LEFT_CLICK) {
                queryParams[Param.ContextMenuTrigger] = 'left';
            }
            else if (contextMenuTrigger === exports.ContextMenuTriggerOptions.RIGHT_CLICK) {
                queryParams[Param.ContextMenuTrigger] = 'right';
            }
            else if (contextMenuTrigger === exports.ContextMenuTriggerOptions.BOTH_CLICKS) {
                queryParams[Param.ContextMenuTrigger] = 'both';
            }
            const embedCustomizations = this.embedConfig.customizations;
            const spriteUrl = (customizations === null || customizations === void 0 ? void 0 : customizations.iconSpriteUrl) || (embedCustomizations === null || embedCustomizations === void 0 ? void 0 : embedCustomizations.iconSpriteUrl);
            if (spriteUrl) {
                queryParams[Param.IconSpriteUrl] = spriteUrl.replace('https://', '');
            }
            const stringIDsUrl = ((_c = customizations === null || customizations === void 0 ? void 0 : customizations.content) === null || _c === void 0 ? void 0 : _c.stringIDsUrl)
                || ((_d = embedCustomizations === null || embedCustomizations === void 0 ? void 0 : embedCustomizations.content) === null || _d === void 0 ? void 0 : _d.stringIDsUrl);
            if (stringIDsUrl) {
                queryParams[Param.StringIDsUrl] = stringIDsUrl;
            }
            if (showAlerts !== undefined) {
                queryParams[Param.ShowAlerts] = showAlerts;
            }
            if (locale !== undefined) {
                queryParams[Param.Locale] = locale;
            }
            if (linkOverride) {
                queryParams[Param.LinkOverride] = linkOverride;
            }
            if (insertInToSlide) {
                queryParams[Param.ShowInsertToSlide] = insertInToSlide;
            }
            if (disableRedirectionLinksInNewTab) {
                queryParams[Param.DisableRedirectionLinksInNewTab] = disableRedirectionLinksInNewTab;
            }
            if (overrideOrgId !== undefined) {
                queryParams[Param.OverrideOrgId] = overrideOrgId;
            }
            if (this.isPreAuthCacheEnabled()) {
                queryParams[Param.preAuthCache] = true;
            }
            queryParams[Param.OverrideNativeConsole] = true;
            queryParams[Param.ClientLogLevel] = this.embedConfig.logLevel;
            if (isObject_1(additionalFlags) && !isEmpty_1(additionalFlags)) {
                Object.assign(queryParams, additionalFlags);
            }
            // Do not add any flags below this, as we want additional flags to
            // override other flags
            return queryParams;
        }
        /**
         * Constructs the base URL string to load v1 of the ThoughtSpot app.
         * This is used for embedding Liveboards, visualizations, and full application.
         * @param queryString The query string to append to the URL.
         * @param isAppEmbed A Boolean parameter to specify if you are embedding
         * the full application.
         */
        getV1EmbedBasePath(queryString) {
            const queryParams = this.shouldEncodeUrlQueryParams
                ? `?base64UrlEncodedFlags=${getEncodedQueryParamsString(queryString)}`
                : `?${queryString}`;
            const host = this.thoughtSpotHost;
            const path = `${host}/${queryParams}#`;
            return path;
        }
        getEmbedParams() {
            const queryParams = this.getBaseQueryParams();
            return getQueryParamString(queryParams);
        }
        getRootIframeSrc() {
            const query = this.getEmbedParams();
            return this.getEmbedBasePath(query);
        }
        createIframeEl(frameSrc) {
            const iFrame = document.createElement('iframe');
            iFrame.src = frameSrc;
            iFrame.id = TS_EMBED_ID;
            iFrame.setAttribute('data-ts-iframe', 'true');
            // according to screenfull.js documentation
            // allowFullscreen, webkitallowfullscreen and mozallowfullscreen must be
            // true
            iFrame.allowFullscreen = true;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            iFrame.webkitallowfullscreen = true;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            iFrame.mozallowfullscreen = true;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            iFrame.allow = 'clipboard-read; clipboard-write; fullscreen;';
            const frameParams = this.viewConfig.frameParams;
            const { height: frameHeight, width: frameWidth, ...restParams } = frameParams || {};
            const width = getCssDimension(frameWidth || DEFAULT_EMBED_WIDTH);
            const height = getCssDimension(frameHeight || DEFAULT_EMBED_HEIGHT);
            setAttributes(iFrame, restParams);
            iFrame.style.width = `${width}`;
            iFrame.style.height = `${height}`;
            // Set minimum height to the frame so that,
            // scaling down on the fullheight doesn't make it too small.
            iFrame.style.minHeight = `${height}`;
            iFrame.style.border = '0';
            iFrame.name = 'ThoughtSpot Embedded Analytics';
            return iFrame;
        }
        handleInsertionIntoDOM(child) {
            if (this.isPreRendered) {
                this.insertIntoDOMForPreRender(child);
            }
            else {
                this.insertIntoDOM(child);
            }
            if (this.insertedDomEl instanceof Node) {
                this.insertedDomEl[this.embedNodeKey] = this;
            }
        }
        /**
         * Renders the embedded ThoughtSpot app in an iframe and sets up
         * event listeners.
         * @param url - The URL of the embedded ThoughtSpot app.
         */
        async renderIFrame(url) {
            if (this.isError) {
                return null;
            }
            if (!this.thoughtSpotHost) {
                this.throwInitError();
            }
            if (url.length > URL_MAX_LENGTH) ;
            return renderInQueue((nextInQueue) => {
                var _a;
                const initTimestamp = Date.now();
                this.executeCallbacks(exports.EmbedEvent.Init, {
                    data: {
                        timestamp: initTimestamp,
                    },
                    type: exports.EmbedEvent.Init,
                });
                uploadMixpanelEvent(MIXPANEL_EVENT.VISUAL_SDK_RENDER_START);
                return (_a = getAuthPromise()) === null || _a === void 0 ? void 0 : _a.then((isLoggedIn) => {
                    if (!isLoggedIn) {
                        this.handleInsertionIntoDOM(this.embedConfig.loginFailedMessage);
                        return;
                    }
                    this.setIframeElement(this.iFrame || this.createIframeEl(url));
                    this.iFrame.addEventListener('load', () => {
                        nextInQueue();
                        const loadTimestamp = Date.now();
                        this.executeCallbacks(exports.EmbedEvent.Load, {
                            data: {
                                timestamp: loadTimestamp,
                            },
                            type: exports.EmbedEvent.Load,
                        });
                        uploadMixpanelEvent(MIXPANEL_EVENT.VISUAL_SDK_RENDER_COMPLETE, {
                            elWidth: this.iFrame.clientWidth,
                            elHeight: this.iFrame.clientHeight,
                            timeTookToLoad: loadTimestamp - initTimestamp,
                        });
                        // Send info event  if preauth cache is enabled
                        if (this.isPreAuthCacheEnabled()) {
                            getPreauthInfo().then((data) => {
                                if (data === null || data === void 0 ? void 0 : data.info) {
                                    this.trigger(exports.HostEvent.InfoSuccess, data);
                                }
                            });
                        }
                    });
                    this.iFrame.addEventListener('error', () => {
                        nextInQueue();
                    });
                    this.handleInsertionIntoDOM(this.iFrame);
                    const prefetchIframe = document.querySelectorAll('.prefetchIframe');
                    if (prefetchIframe.length) {
                        prefetchIframe.forEach((el) => {
                            el.remove();
                        });
                    }
                    this.subscribeToEvents();
                }).catch((error) => {
                    nextInQueue();
                    uploadMixpanelEvent(MIXPANEL_EVENT.VISUAL_SDK_RENDER_FAILED, {
                        error: JSON.stringify(error),
                    });
                    this.handleInsertionIntoDOM(this.embedConfig.loginFailedMessage);
                    this.handleError(error);
                });
            });
        }
        createPreRenderWrapper() {
            var _a;
            const preRenderIds = this.getPreRenderIds();
            (_a = document.getElementById(preRenderIds.wrapper)) === null || _a === void 0 ? void 0 : _a.remove();
            const preRenderWrapper = document.createElement('div');
            preRenderWrapper.id = preRenderIds.wrapper;
            const initialPreRenderWrapperStyle = {
                position: 'absolute',
                width: '100vw',
                height: '100vh',
            };
            setStyleProperties(preRenderWrapper, initialPreRenderWrapperStyle);
            return preRenderWrapper;
        }
        connectPreRendered() {
            const preRenderIds = this.getPreRenderIds();
            const preRenderWrapperElement = document.getElementById(preRenderIds.wrapper);
            this.preRenderWrapper = this.preRenderWrapper || preRenderWrapperElement;
            this.preRenderChild = this.preRenderChild || document.getElementById(preRenderIds.child);
            if (this.preRenderWrapper && this.preRenderChild) {
                this.isPreRendered = true;
                if (this.preRenderChild instanceof HTMLIFrameElement) {
                    this.setIframeElement(this.preRenderChild);
                }
                this.insertedDomEl = this.preRenderWrapper;
                this.isRendered = true;
            }
            return this.isPreRenderAvailable();
        }
        isPreRenderAvailable() {
            return (this.isRendered
                && this.isPreRendered
                && Boolean(this.preRenderWrapper && this.preRenderChild));
        }
        createPreRenderChild(child) {
            var _a;
            const preRenderIds = this.getPreRenderIds();
            (_a = document.getElementById(preRenderIds.child)) === null || _a === void 0 ? void 0 : _a.remove();
            if (child instanceof HTMLElement) {
                child.id = preRenderIds.child;
                return child;
            }
            const divChildNode = document.createElement('div');
            setStyleProperties(divChildNode, { width: '100%', height: '100%' });
            divChildNode.id = preRenderIds.child;
            if (typeof child === 'string') {
                divChildNode.innerHTML = child;
            }
            else {
                divChildNode.appendChild(child);
            }
            return divChildNode;
        }
        insertIntoDOMForPreRender(child) {
            const preRenderChild = this.createPreRenderChild(child);
            const preRenderWrapper = this.createPreRenderWrapper();
            preRenderWrapper.appendChild(preRenderChild);
            this.preRenderChild = preRenderChild;
            this.preRenderWrapper = preRenderWrapper;
            if (preRenderChild instanceof HTMLIFrameElement) {
                this.setIframeElement(preRenderChild);
            }
            this.insertedDomEl = preRenderWrapper;
            if (this.showPreRenderByDefault) {
                this.showPreRender();
            }
            else {
                this.hidePreRender();
            }
            document.body.appendChild(preRenderWrapper);
        }
        insertIntoDOM(child) {
            var _a;
            if (this.viewConfig.insertAsSibling) {
                if (typeof child === 'string') {
                    const div = document.createElement('div');
                    div.innerHTML = child;
                    div.id = TS_EMBED_ID;
                    // eslint-disable-next-line no-param-reassign
                    child = div;
                }
                if (((_a = this.el.nextElementSibling) === null || _a === void 0 ? void 0 : _a.id) === TS_EMBED_ID) {
                    this.el.nextElementSibling.remove();
                }
                this.el.parentElement.insertBefore(child, this.el.nextSibling);
                this.insertedDomEl = child;
            }
            else if (typeof child === 'string') {
                this.el.innerHTML = child;
                this.insertedDomEl = this.el.children[0];
            }
            else {
                this.el.innerHTML = '';
                this.el.appendChild(child);
                this.insertedDomEl = child;
            }
        }
        /**
         * Sets the height of the iframe
         * @param height The height in pixels
         */
        setIFrameHeight(height) {
            this.iFrame.style.height = getCssDimension(height);
        }
        /**
         * Executes all registered event handlers for a particular event type
         * @param eventType The event type
         * @param data The payload invoked with the event handler
         * @param eventPort The event Port for a specific MessageChannel
         */
        executeCallbacks(eventType, data, eventPort) {
            const eventHandlers = this.eventHandlerMap.get(eventType) || [];
            const allHandlers = this.eventHandlerMap.get(exports.EmbedEvent.ALL) || [];
            const callbacks = [...eventHandlers, ...allHandlers];
            const dataStatus = (data === null || data === void 0 ? void 0 : data.status) || embedEventStatus.END;
            callbacks.forEach((callbackObj) => {
                if (
                // When start status is true it trigger only start releated
                // payload
                (callbackObj.options.start && dataStatus === embedEventStatus.START)
                    // When start status is false it trigger only end releated
                    // payload
                    || (!callbackObj.options.start && dataStatus === embedEventStatus.END)) {
                    callbackObj.callback(data, (payload) => {
                        this.triggerEventOnPort(eventPort, payload);
                    });
                }
            });
        }
        /**
         * Returns the ThoughtSpot hostname or IP address.
         */
        getThoughtSpotHost() {
            return this.thoughtSpotHost;
        }
        /**
         * Gets the v1 event type (if applicable) for the EmbedEvent type
         * @param eventType The v2 event type
         * @returns The corresponding v1 event type if one exists
         * or else the v2 event type itself
         */
        getCompatibleEventType(eventType) {
            return V1EventMap[eventType] || eventType;
        }
        /**
         * Calculates the iframe center for the current visible viewPort
         * of iframe using Scroll position of Host App, offsetTop for iframe
         * in Host app. ViewPort height of the tab.
         * @returns iframe Center in visible viewport,
         *  Iframe height,
         *  View port height.
         */
        getIframeCenter() {
            const offsetTopClient = getOffsetTop(this.iFrame);
            const scrollTopClient = window.scrollY;
            const viewPortHeight = window.innerHeight;
            const iframeHeight = this.iFrame.offsetHeight;
            const iframeScrolled = scrollTopClient - offsetTopClient;
            let iframeVisibleViewPort;
            let iframeOffset;
            if (iframeScrolled < 0) {
                iframeVisibleViewPort = viewPortHeight - (offsetTopClient - scrollTopClient);
                iframeVisibleViewPort = Math.min(iframeHeight, iframeVisibleViewPort);
                iframeOffset = 0;
            }
            else {
                iframeVisibleViewPort = Math.min(iframeHeight - iframeScrolled, viewPortHeight);
                iframeOffset = iframeScrolled;
            }
            const iframeCenter = iframeOffset + iframeVisibleViewPort / 2;
            return {
                iframeCenter,
                iframeScrolled,
                iframeHeight,
                viewPortHeight,
                iframeVisibleViewPort,
            };
        }
        /**
         * Registers an event listener to trigger an alert when the ThoughtSpot app
         * sends an event of a particular message type to the host application.
         * @param messageType The message type
         * @param callback A callback as a function
         * @param options The message options
         * @param isSelf
         * @param isRegisteredBySDK
         * @example
         * ```js
         * tsEmbed.on(EmbedEvent.Error, (data) => {
         *   console.error(data);
         * });
         * ```
         * @example
         * ```js
         * tsEmbed.on(EmbedEvent.Save, (data) => {
         *   console.log("Answer save clicked", data);
         * }, {
         *   start: true // This will trigger the callback on start of save
         * });
         * ```
         */
        on(messageType, callback, options = { start: false }, isRegisteredBySDK = false) {
            uploadMixpanelEvent(`${MIXPANEL_EVENT.VISUAL_SDK_ON}-${messageType}`, {
                isRegisteredBySDK,
            });
            if (this.isRendered) {
                logger$3.warn('Please register event handlers before calling render');
            }
            const callbacks = this.eventHandlerMap.get(messageType) || [];
            callbacks.push({ options, callback });
            this.eventHandlerMap.set(messageType, callbacks);
            return this;
        }
        /**
         * Removes an event listener for a particular event type.
         * @param messageType The message type
         * @param callback The callback to remove
         * @example
         * ```js
         * const errorHandler = (data) => { console.error(data); };
         * tsEmbed.on(EmbedEvent.Error, errorHandler);
         * tsEmbed.off(EmbedEvent.Error, errorHandler);
         * ```
         */
        off(messageType, callback) {
            const callbacks = this.eventHandlerMap.get(messageType) || [];
            const index = callbacks.findIndex((cb) => cb.callback === callback);
            if (index > -1) {
                callbacks.splice(index, 1);
            }
            return this;
        }
        /**
         * Triggers an event on specific Port registered against
         * for the EmbedEvent
         * @param eventType The message type
         * @param data The payload to send
         * @param eventPort
         * @param payload
         */
        triggerEventOnPort(eventPort, payload) {
            if (eventPort) {
                try {
                    eventPort.postMessage({
                        type: payload.type,
                        data: payload.data,
                    });
                }
                catch (e) {
                    eventPort.postMessage({ error: e });
                    logger$3.log(e);
                }
            }
            else {
                logger$3.log('Event Port is not defined');
            }
        }
        /**
         * Triggers an event to the embedded app
         * @param {HostEvent} messageType The event type
         * @param {any} data The payload to send with the message
         * @returns A promise that resolves with the response from the embedded app
         */
        async trigger(messageType, data = {}) {
            uploadMixpanelEvent(`${MIXPANEL_EVENT.VISUAL_SDK_TRIGGER}-${messageType}`);
            if (!this.isRendered) {
                this.handleError('Please call render before triggering events');
                return null;
            }
            if (!messageType) {
                this.handleError('Host event type is undefined');
                return null;
            }
            // send an empty object, this is needed for liveboard default handlers
            return this.hostEventClient.triggerHostEvent(messageType, data);
        }
        /**
         * Triggers an event to the embedded app, skipping the UI flow.
         * @param {UIPassthroughEvent} apiName - The name of the API to be triggered.
         * @param {UIPassthroughRequest} parameters - The parameters to be passed to the API.
         * @returns {Promise<UIPassthroughRequest>} - A promise that resolves with the response
         * from the embedded app.
         */
        async triggerUIPassThrough(apiName, parameters) {
            const response = this.hostEventClient.triggerUIPassthroughApi(apiName, parameters);
            return response;
        }
        /**
         * Marks the ThoughtSpot object to have been rendered
         * Needs to be overridden by subclasses to do the actual
         * rendering of the iframe.
         * @param args
         */
        async render() {
            if (!getIsInitCalled()) {
                logger$3.error(ERROR_MESSAGE.RENDER_CALLED_BEFORE_INIT);
            }
            await this.isReadyForRenderPromise;
            this.isRendered = true;
            return this;
        }
        getIframeSrc() {
            return '';
        }
        handleRenderForPrerender() {
            return this.render();
        }
        /**
         * Creates the preRender shell
         * @param showPreRenderByDefault - Show the preRender after render, hidden by default
         */
        async preRender(showPreRenderByDefault = false) {
            if (!this.viewConfig.preRenderId) {
                logger$3.error(ERROR_MESSAGE.PRERENDER_ID_MISSING);
                return this;
            }
            this.isPreRendered = true;
            this.showPreRenderByDefault = showPreRenderByDefault;
            return this.handleRenderForPrerender();
        }
        /**
         * Get the Post Url Params for THOUGHTSPOT from the current
         * host app URL.
         * THOUGHTSPOT URL params starts with a prefix "ts-"
         * @version SDK: 1.14.0 | ThoughtSpot: 8.4.0.cl, 8.4.1-sw
         */
        getThoughtSpotPostUrlParams(additionalParams = {}) {
            const urlHash = window.location.hash;
            const queryParams = window.location.search;
            const postHashParams = urlHash.split('?');
            const postURLParams = postHashParams[postHashParams.length - 1];
            const queryParamsObj = new URLSearchParams(queryParams);
            const postURLParamsObj = new URLSearchParams(postURLParams);
            const params = new URLSearchParams();
            const addKeyValuePairCb = (value, key) => {
                if (key.startsWith(THOUGHTSPOT_PARAM_PREFIX)) {
                    params.append(key, value);
                }
            };
            queryParamsObj.forEach(addKeyValuePairCb);
            postURLParamsObj.forEach(addKeyValuePairCb);
            Object.entries(additionalParams).forEach(([k, v]) => params.append(k, v));
            let tsParams = params.toString();
            tsParams = tsParams ? `?${tsParams}` : '';
            return tsParams;
        }
        /**
         * Destroys the ThoughtSpot embed, and remove any nodes from the DOM.
         * @version SDK: 1.19.1 | ThoughtSpot: *
         */
        destroy() {
            var _a;
            try {
                (_a = this.insertedDomEl) === null || _a === void 0 ? void 0 : _a.parentNode.removeChild(this.insertedDomEl);
                this.unsubscribeToEvents();
            }
            catch (e) {
                logger$3.log('Error destroying TS Embed', e);
            }
        }
        getUnderlyingFrameElement() {
            return this.iFrame;
        }
        /**
         * Prerenders a generic instance of the TS component.
         * This means without the path but with the flags already applied.
         * This is useful for prerendering the component in the background.
         * @version SDK: 1.22.0
         * @returns
         */
        async prerenderGeneric() {
            if (!getIsInitCalled()) {
                logger$3.error(ERROR_MESSAGE.RENDER_CALLED_BEFORE_INIT);
            }
            await this.isReadyForRenderPromise;
            const prerenderFrameSrc = this.getRootIframeSrc();
            this.isRendered = true;
            return this.renderIFrame(prerenderFrameSrc);
        }
        beforePrerenderVisible() {
            // Override in subclass
        }
        /**
         * Displays the PreRender component.
         * If the component is not preRendered, it attempts to create and render it.
         * Also, synchronizes the style of the PreRender component with the embedding
         * element.
         */
        async showPreRender() {
            if (!this.viewConfig.preRenderId) {
                logger$3.error(ERROR_MESSAGE.PRERENDER_ID_MISSING);
                return this;
            }
            if (!this.isPreRenderAvailable()) {
                const isAvailable = this.connectPreRendered();
                if (!isAvailable) {
                    // if the Embed component is not preRendered , Render it now and
                    return this.preRender(true);
                }
                this.validatePreRenderViewConfig(this.viewConfig);
            }
            if (this.el) {
                this.syncPreRenderStyle();
                if (!this.viewConfig.doNotTrackPreRenderSize) {
                    this.resizeObserver = new ResizeObserver((entries) => {
                        entries.forEach((entry) => {
                            if (entry.contentRect && entry.target === this.el) {
                                setStyleProperties(this.preRenderWrapper, {
                                    width: `${entry.contentRect.width}px`,
                                    height: `${entry.contentRect.height}px`,
                                });
                            }
                        });
                    });
                    this.resizeObserver.observe(this.el);
                }
            }
            this.beforePrerenderVisible();
            removeStyleProperties(this.preRenderWrapper, ['z-index', 'opacity', 'pointer-events']);
            this.subscribeToEvents();
            return this;
        }
        /**
         * Synchronizes the style properties of the PreRender component with the embedding
         * element. This function adjusts the position, width, and height of the PreRender
         * component
         * to match the dimensions and position of the embedding element.
         * @throws {Error} Throws an error if the embedding element (passed as domSelector)
         * is not defined or not found.
         */
        syncPreRenderStyle() {
            if (!this.isPreRenderAvailable() || !this.el) {
                logger$3.error(ERROR_MESSAGE.SYNC_STYLE_CALLED_BEFORE_RENDER);
                return;
            }
            const elBoundingClient = this.el.getBoundingClientRect();
            setStyleProperties(this.preRenderWrapper, {
                top: `${elBoundingClient.y + window.scrollY}px`,
                left: `${elBoundingClient.x + window.scrollX}px`,
                width: `${elBoundingClient.width}px`,
                height: `${elBoundingClient.height}px`,
            });
        }
        /**
         * Hides the PreRender component if it is available.
         * If the component is not preRendered, it issues a warning.
         */
        hidePreRender() {
            if (!this.isPreRenderAvailable()) {
                // if the embed component is not preRendered , nothing to hide
                logger$3.warn('PreRender should be called before hiding it using hidePreRender.');
                return;
            }
            const preRenderHideStyles = {
                opacity: '0',
                pointerEvents: 'none',
                zIndex: '-1000',
                position: 'absolute ',
            };
            setStyleProperties(this.preRenderWrapper, preRenderHideStyles);
            if (this.resizeObserver) {
                this.resizeObserver.disconnect();
            }
            this.unsubscribeToEvents();
        }
        /**
         * Retrieves unique HTML element IDs for PreRender-related elements.
         * These IDs are constructed based on the provided 'preRenderId' from 'viewConfig'.
         * @returns {object} An object containing the IDs for the PreRender elements.
         * @property {string} wrapper - The HTML element ID for the PreRender wrapper.
         * @property {string} child - The HTML element ID for the PreRender child.
         */
        getPreRenderIds() {
            return {
                wrapper: `tsEmbed-pre-render-wrapper-${this.viewConfig.preRenderId}`,
                child: `tsEmbed-pre-render-child-${this.viewConfig.preRenderId}`,
            };
        }
        /**
         * Returns the answerService which can be used to make arbitrary graphql calls on top
         * session.
         * @param vizId [Optional] to get for a specific viz in case of a Liveboard.
         * @version SDK: 1.25.0 / ThoughtSpot 9.10.0
         */
        async getAnswerService(vizId) {
            const { session } = await this.trigger(exports.HostEvent.GetAnswerSession, vizId ? { vizId } : {});
            return new AnswerService(session, null, this.embedConfig.thoughtSpotHost);
        }
    }
    /**
     * Base class for embedding v1 experience
     * Note: The v1 version of ThoughtSpot Blink works on the AngularJS stack
     * which is currently under migration to v2
     * @inheritdoc
     */
    class V1Embed extends TsEmbed {
        constructor(domSelector, viewConfig) {
            super(domSelector, viewConfig);
            /**
             * Only for testing purposes.
             * @hidden
             */
            // eslint-disable-next-line camelcase
            this.test__executeCallbacks = this.executeCallbacks;
            this.viewConfig = { excludeRuntimeFiltersfromURL: false, ...viewConfig };
        }
        /**
         * Render the app in an iframe and set up event handlers
         * @param iframeSrc
         */
        renderV1Embed(iframeSrc) {
            return this.renderIFrame(iframeSrc);
        }
        getRootIframeSrc() {
            const queryParams = this.getEmbedParams();
            let queryString = queryParams;
            if (!this.viewConfig.excludeRuntimeParametersfromURL) {
                const runtimeParameters = this.viewConfig.runtimeParameters;
                const parameterQuery = getRuntimeParameters(runtimeParameters || []);
                queryString = [parameterQuery, queryParams].filter(Boolean).join('&');
            }
            if (!this.viewConfig.excludeRuntimeFiltersfromURL) {
                const runtimeFilters = this.viewConfig.runtimeFilters;
                const filterQuery = getFilterQuery(runtimeFilters || []);
                queryString = [filterQuery, queryString].filter(Boolean).join('&');
            }
            return this.viewConfig.enableV2Shell_experimental
                ? this.getEmbedBasePath(queryString)
                : this.getV1EmbedBasePath(queryString);
        }
        /**
         * @inheritdoc
         * @example
         * ```js
         * tsEmbed.on(EmbedEvent.Error, (data) => {
         *   console.error(data);
         * });
         * ```
         * @example
         * ```js
         * tsEmbed.on(EmbedEvent.Save, (data) => {
         *   console.log("Answer save clicked", data);
         * }, {
         *   start: true // This will trigger the callback on start of save
         * });
         * ```
         */
        on(messageType, callback, options = { start: false }) {
            const eventType = this.getCompatibleEventType(messageType);
            return super.on(eventType, callback, options);
        }
    }

    /**
     * Copyright (c) 2022
     *
     * Full application embedding
     * https://developers.thoughtspot.com/docs/?pageid=full-embed
     * @summary Full app embed
     * @module
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    /**
     * Pages within the ThoughtSpot app that can be embedded.
     */
    // eslint-disable-next-line no-shadow
    exports.Page = void 0;
    (function (Page) {
        /**
         * Home page
         */
        Page["Home"] = "home";
        /**
         * Search page
         */
        Page["Search"] = "search";
        /**
         * Saved answers listing page
         */
        Page["Answers"] = "answers";
        /**
         * Liveboards listing page
         */
        Page["Liveboards"] = "liveboards";
        /**
         * @hidden
         */
        Page["Pinboards"] = "pinboards";
        /**
         * Data management page
         */
        Page["Data"] = "data";
        /**
         * SpotIQ listing page
         */
        Page["SpotIQ"] = "insights";
        /**
         *  Monitor Alerts Page
         */
        Page["Monitor"] = "monitor";
    })(exports.Page || (exports.Page = {}));
    /**
     * Define the initial state os column custom group accordions
     * in data panel v2.
     */
    var DataPanelCustomColumnGroupsAccordionState$1;
    (function (DataPanelCustomColumnGroupsAccordionState) {
        /**
         * Expand all the accordion initially in data panel v2.
         */
        DataPanelCustomColumnGroupsAccordionState["EXPAND_ALL"] = "EXPAND_ALL";
        /**
         * Collapse all the accordions initially in data panel v2.
         */
        DataPanelCustomColumnGroupsAccordionState["COLLAPSE_ALL"] = "COLLAPSE_ALL";
        /**
         * Expand the first accordion and collapse the rest.
         */
        DataPanelCustomColumnGroupsAccordionState["EXPAND_FIRST"] = "EXPAND_FIRST";
    })(DataPanelCustomColumnGroupsAccordionState$1 || (DataPanelCustomColumnGroupsAccordionState$1 = {}));
    exports.HomePageSearchBarMode = void 0;
    (function (HomePageSearchBarMode) {
        HomePageSearchBarMode["OBJECT_SEARCH"] = "objectSearch";
        HomePageSearchBarMode["AI_ANSWER"] = "aiAnswer";
        HomePageSearchBarMode["NONE"] = "none";
    })(exports.HomePageSearchBarMode || (exports.HomePageSearchBarMode = {}));
    /**
     * Define the version of the primary navbar
     * @version SDK: 1.39.0 | Thoughtspot: 10.10.0.cl
     */
    exports.PrimaryNavbarVersion = void 0;
    (function (PrimaryNavbarVersion) {
        /**
         * Sliding (v3) introduces a new left-side navigation hub featuring a tab switcher,
         * along with updates to the top navigation bar.
         * It serves as the foundational version of the PrimaryNavBar.
         */
        PrimaryNavbarVersion["Sliding"] = "v3";
    })(exports.PrimaryNavbarVersion || (exports.PrimaryNavbarVersion = {}));
    /**
     * Define the version of the home page
     * @version SDK: 1.39.0 | Thoughtspot: 10.10.0.cl
     */
    exports.HomePage = void 0;
    (function (HomePage) {
        /**
         * Modular (v2) introduces the updated Modular Home Experience.
         * It serves as the foundational version of the home page.
         */
        HomePage["Modular"] = "v2";
    })(exports.HomePage || (exports.HomePage = {}));
    /**
     * Embeds full ThoughtSpot experience in a host application.
     * @group Embed components
     */
    class AppEmbed extends V1Embed {
        // eslint-disable-next-line no-useless-constructor
        constructor(domSelector, viewConfig) {
            viewConfig.embedComponentType = 'AppEmbed';
            super(domSelector, viewConfig);
            this.defaultHeight = '100%';
            /**
             * Set the iframe height as per the computed height received
             * from the ThoughtSpot app.
             * @param data The event payload
             */
            this.updateIFrameHeight = (data) => {
                var _a;
                this.setIFrameHeight(Math.max(data.data, (_a = this.iFrame) === null || _a === void 0 ? void 0 : _a.scrollHeight));
            };
            this.embedIframeCenter = (data, responder) => {
                const obj = this.getIframeCenter();
                responder({ type: exports.EmbedEvent.EmbedIframeCenter, data: obj });
            };
            this.setIframeHeightForNonEmbedLiveboard = (data) => {
                const { height: frameHeight, ...restParams } = this.viewConfig.frameParams || {};
                const liveboardRelatedRoutes = [
                    '/pinboard/',
                    '/insights/pinboard/',
                    '/schedules/',
                    '/embed/viz/',
                    '/embed/insights/viz/',
                    '/liveboard/',
                    '/insights/liveboard/',
                    '/tsl-editor/PINBOARD_ANSWER_BOOK/',
                    '/import-tsl/PINBOARD_ANSWER_BOOK/',
                ];
                if (liveboardRelatedRoutes.some((path) => data.data.currentPath.startsWith(path))) {
                    // Ignore the height reset of the frame, if the navigation is
                    // only within the liveboard page.
                    return;
                }
                this.setIFrameHeight(frameHeight || this.defaultHeight);
            };
            if (this.viewConfig.fullHeight === true) {
                this.on(exports.EmbedEvent.RouteChange, this.setIframeHeightForNonEmbedLiveboard);
                this.on(exports.EmbedEvent.EmbedHeight, this.updateIFrameHeight);
                this.on(exports.EmbedEvent.EmbedIframeCenter, this.embedIframeCenter);
            }
        }
        /**
         * Constructs a map of parameters to be passed on to the
         * embedded Liveboard or visualization.
         */
        getEmbedParams() {
            const { tag, hideObjects, liveboardV2, showPrimaryNavbar, disableProfileAndHelp, hideHamburger, hideObjectSearch, hideNotification, hideApplicationSwitcher, hideOrgSwitcher, enableSearchAssist, fullHeight, dataPanelV2 = false, hideLiveboardHeader = false, showLiveboardTitle = true, showLiveboardDescription = true, hideHomepageLeftNav = false, modularHomeExperience = false, isLiveboardHeaderSticky = true, enableAskSage, collapseSearchBarInitially = false, enable2ColumnLayout, enableCustomColumnGroups = false, isOnBeforeGetVizDataInterceptEnabled = false, 
            /* eslint-disable-next-line max-len */
            dataPanelCustomGroupsAccordionInitialState = DataPanelCustomColumnGroupsAccordionState$1.EXPAND_ALL, collapseSearchBar = true, isLiveboardCompactHeaderEnabled = false, showLiveboardVerifiedBadge = true, showLiveboardReverifyBanner = true, hideIrrelevantChipsInLiveboardTabs = false, homePageSearchBarMode, isUnifiedSearchExperienceEnabled = true, enablePendoHelp = true, discoveryExperience, } = this.viewConfig;
            let params = {};
            params[Param.PrimaryNavHidden] = !showPrimaryNavbar;
            params[Param.HideProfleAndHelp] = !!disableProfileAndHelp;
            params[Param.HideApplicationSwitcher] = !!hideApplicationSwitcher;
            params[Param.HideOrgSwitcher] = !!hideOrgSwitcher;
            params[Param.HideLiveboardHeader] = hideLiveboardHeader;
            params[Param.ShowLiveboardTitle] = showLiveboardTitle;
            params[Param.ShowLiveboardDescription] = !!showLiveboardDescription;
            params[Param.LiveboardHeaderSticky] = isLiveboardHeaderSticky;
            params[Param.IsFullAppEmbed] = true;
            params[Param.LiveboardHeaderV2] = isLiveboardCompactHeaderEnabled;
            params[Param.ShowLiveboardVerifiedBadge] = showLiveboardVerifiedBadge;
            params[Param.ShowLiveboardReverifyBanner] = showLiveboardReverifyBanner;
            params[Param.HideIrrelevantFiltersInTab] = hideIrrelevantChipsInLiveboardTabs;
            params[Param.IsUnifiedSearchExperienceEnabled] = isUnifiedSearchExperienceEnabled;
            params = this.getBaseQueryParams(params);
            if (hideObjectSearch) {
                params[Param.HideObjectSearch] = !!hideObjectSearch;
            }
            if (hideHamburger) {
                params[Param.HideHamburger] = !!hideHamburger;
            }
            if (hideNotification) {
                params[Param.HideNotification] = !!hideNotification;
            }
            if (fullHeight === true) {
                params[Param.fullHeight] = true;
            }
            if (tag) {
                params[Param.Tag] = tag;
            }
            if (hideObjects && hideObjects.length) {
                params[Param.HideObjects] = JSON.stringify(hideObjects);
            }
            if (liveboardV2 !== undefined) {
                params[Param.LiveboardV2Enabled] = liveboardV2;
            }
            if (enableSearchAssist !== undefined) {
                params[Param.EnableSearchAssist] = enableSearchAssist;
            }
            if (enable2ColumnLayout !== undefined) {
                params[Param.Enable2ColumnLayout] = enable2ColumnLayout;
            }
            if (enableAskSage) {
                params[Param.enableAskSage] = enableAskSage;
            }
            if (isOnBeforeGetVizDataInterceptEnabled) {
                /* eslint-disable-next-line max-len */
                params[Param.IsOnBeforeGetVizDataInterceptEnabled] = isOnBeforeGetVizDataInterceptEnabled;
            }
            if (homePageSearchBarMode) {
                params[Param.HomePageSearchBarMode] = homePageSearchBarMode;
            }
            if (enablePendoHelp !== undefined) {
                params[Param.EnablePendoHelp] = enablePendoHelp;
            }
            params[Param.DataPanelV2Enabled] = dataPanelV2;
            params[Param.HideHomepageLeftNav] = hideHomepageLeftNav;
            params[Param.ModularHomeExperienceEnabled] = modularHomeExperience;
            params[Param.CollapseSearchBarInitially] = collapseSearchBarInitially || collapseSearchBar;
            params[Param.EnableCustomColumnGroups] = enableCustomColumnGroups;
            if (dataPanelCustomGroupsAccordionInitialState
                === DataPanelCustomColumnGroupsAccordionState$1.COLLAPSE_ALL
                || dataPanelCustomGroupsAccordionInitialState
                    === DataPanelCustomColumnGroupsAccordionState$1.EXPAND_FIRST) {
                /* eslint-disable-next-line max-len */
                params[Param.DataPanelCustomGroupsAccordionInitialState] = dataPanelCustomGroupsAccordionInitialState;
            }
            else {
                /* eslint-disable-next-line max-len */
                params[Param.DataPanelCustomGroupsAccordionInitialState] = DataPanelCustomColumnGroupsAccordionState$1.EXPAND_ALL;
            }
            if (discoveryExperience) {
                // primaryNavbarVersion v3 will enabled the new left navigation
                if (discoveryExperience.primaryNavbarVersion === exports.PrimaryNavbarVersion.Sliding) {
                    params[Param.NavigationVersion] = discoveryExperience.primaryNavbarVersion;
                }
                // homePage v2 will enable the modular home page
                // and it will override the modularHomeExperience value
                if (discoveryExperience.homePage === exports.HomePage.Modular) {
                    params[Param.ModularHomeExperienceEnabled] = true;
                }
            }
            const queryParams = getQueryParamString(params, true);
            return queryParams;
        }
        /**
         * Constructs the URL of the ThoughtSpot app page to be rendered.
         * @param pageId The ID of the page to be embedded.
         */
        getIFrameSrc() {
            const { pageId, path, modularHomeExperience } = this.viewConfig;
            const pageRoute = this.formatPath(path) || this.getPageRoute(pageId, modularHomeExperience);
            let url = `${this.getRootIframeSrc()}/${pageRoute}`;
            const tsPostHashParams = this.getThoughtSpotPostUrlParams();
            url = `${url}${tsPostHashParams}`;
            return url;
        }
        /**
         * Gets the ThoughtSpot route of the page for a particular page ID.
         * @param pageId The identifier for a page in the ThoughtSpot app.
         * @param modularHomeExperience
         */
        getPageRoute(pageId, modularHomeExperience = false) {
            switch (pageId) {
                case exports.Page.Search:
                    return 'answer';
                case exports.Page.Answers:
                    return modularHomeExperience ? 'home/answers' : 'answers';
                case exports.Page.Liveboards:
                    return modularHomeExperience ? 'home/liveboards' : 'pinboards';
                case exports.Page.Pinboards:
                    return modularHomeExperience ? 'home/liveboards' : 'pinboards';
                case exports.Page.Data:
                    return 'data/tables';
                case exports.Page.SpotIQ:
                    return modularHomeExperience ? 'home/spotiq-analysis' : 'insights/results';
                case exports.Page.Monitor:
                    return modularHomeExperience ? 'home/monitor-alerts' : 'insights/monitor-alerts';
                case exports.Page.Home:
                default:
                    return 'home';
            }
        }
        /**
         * Formats the path provided by the user.
         * @param path The URL path.
         * @returns The URL path that the embedded app understands.
         */
        formatPath(path) {
            if (!path) {
                return null;
            }
            // remove leading slash
            if (path.indexOf('/') === 0) {
                return path.substring(1);
            }
            return path;
        }
        /**
         * Navigate to particular page for app embed. eg:answers/pinboards/home
         * This is used for embedding answers, pinboards, visualizations and full application
         * only.
         * @param path string | number The string, set to iframe src and navigate to new page
         * eg: appEmbed.navigateToPage('pinboards')
         * When used with `noReload` (default: true) this can also be a number
         * like 1/-1 to go forward/back.
         * @param noReload boolean Trigger the navigation without reloading the page
         * @version SDK: 1.12.0 | ThoughtSpot: 8.4.0.cl, 8.4.1-sw
         */
        navigateToPage(path, noReload = false) {
            if (!this.iFrame) {
                logger$3.log('Please call render before invoking this method');
                return;
            }
            if (noReload) {
                this.trigger(exports.HostEvent.Navigate, path);
            }
            else {
                if (typeof path !== 'string') {
                    logger$3.warn('Path can only by a string when triggered without noReload');
                    return;
                }
                const iframeSrc = this.iFrame.src;
                const embedPath = '#/embed';
                const currentPath = iframeSrc.includes(embedPath) ? embedPath : '#';
                this.iFrame.src = `${iframeSrc.split(currentPath)[0]}${currentPath}/${path.replace(/^\/?#?\//, '')}`;
            }
        }
        /**
         * Renders the embedded application pages in the ThoughtSpot app.
         * @param renderOptions An object containing the page ID
         * to be embedded.
         */
        async render() {
            await super.render();
            const src = this.getIFrameSrc();
            await this.renderV1Embed(src);
            return this;
        }
    }

    /* eslint-disable quotes */
    const getPreviewQuery = `
query GetEurekaVizSnapshots(
    $vizId: String!, $liveboardId: String!) {
    getEurekaVizSnapshot(
      id: $vizId
      reportBookId: $liveboardId
      reportBookType: "PINBOARD_ANSWER_BOOK"
      version: 9999999
    ) {
      id
      vizContent
      snapshotType
      createdMs
    }
  } 
`;
    /**
     *
     * @param thoughtSpotHost
     * @param vizId
     * @param liveboardId
     */
    async function getPreview(thoughtSpotHost, vizId, liveboardId) {
        return graphqlQuery({
            query: getPreviewQuery,
            variables: { vizId, liveboardId },
            thoughtSpotHost,
        });
    }

    const addPreviewStylesIfNotPresent = () => {
        const styleEl = document.getElementById('ts-preview-style');
        if (styleEl) {
            return;
        }
        const previewStyles = `
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/ag-grid-community@32.0.2/styles/ag-grid.min.css">
        <style id="ts-preview-style">
           .ts-viz-preview-loader {
                position: absolute;
                top: 0;
                left: 0;
                right: 0;
                bottom: 0;
                display: flex;
                justify-content: center;
                align-items: center;
                background: linear-gradient(-45deg, #eee 40%, #fafafa 50%, #eee 60%);
                background-size: 300%;
                background-position-x: 100%;
                animation: shimmer 1s infinite linear;
                z-index: 999;
                filter: grayscale(0.2);
           }

           @keyframes shimmer {
                to {
                    background-position-x: 0%
                }
           }

           .ts-viz-preview-loader .table-module__fullContainer {
                width: 100%;
                height: 100%;
           }
        </style>
    `;
        document.head.insertAdjacentHTML('beforeend', previewStyles);
    };

    /**
     * Copyright (c) 2022
     *
     * Embed a ThoughtSpot Liveboard or visualization
     * https://developers.thoughtspot.com/docs/?pageid=embed-pinboard
     * https://developers.thoughtspot.com/docs/?pageid=embed-a-viz
     * @summary Liveboard & visualization embed
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    const liveboardHeightWhitelistedRoutes = [
        '/embed/viz/',
        '/embed/insights/viz/',
        '/tsl-editor/PINBOARD_ANSWER_BOOK/',
        '/import-tsl/PINBOARD_ANSWER_BOOK/',
    ];
    /**
     * Embed a ThoughtSpot Liveboard or visualization. When rendered it already
     * waits for the authentication to complete, so you need not wait for
     * `AuthStatus.SUCCESS`.
     * @example
     * ```js
     * import { .. } from '@thoughtspot/visual-embed-sdk';
     * init({ ... });
     * const embed = new LiveboardEmbed("#container", {
     *   liveboardId: <your-id-here>,
     * // .. other params here.
     * })
     * ```
     * @group Embed components
     */
    class LiveboardEmbed extends V1Embed {
        // eslint-disable-next-line no-useless-constructor
        constructor(domSelector, viewConfig) {
            viewConfig.embedComponentType = 'LiveboardEmbed';
            super(domSelector, viewConfig);
            this.defaultHeight = 500;
            /**
             * Set the iframe height as per the computed height received
             * from the ThoughtSpot app.
             * @param data The event payload
             */
            this.updateIFrameHeight = (data) => {
                this.setIFrameHeight(Math.max(data.data, this.defaultHeight));
            };
            this.embedIframeCenter = (data, responder) => {
                const obj = this.getIframeCenter();
                responder({ type: exports.EmbedEvent.EmbedIframeCenter, data: obj });
            };
            this.setIframeHeightForNonEmbedLiveboard = (data) => {
                const routePath = data.data.currentPath;
                if (liveboardHeightWhitelistedRoutes.some((path) => routePath.startsWith(path))) {
                    return;
                }
                this.setIFrameHeight(this.defaultHeight);
            };
            if (this.viewConfig.fullHeight === true) {
                this.on(exports.EmbedEvent.RouteChange, this.setIframeHeightForNonEmbedLiveboard);
                this.on(exports.EmbedEvent.EmbedHeight, this.updateIFrameHeight);
                this.on(exports.EmbedEvent.EmbedIframeCenter, this.embedIframeCenter);
            }
        }
        /**
         * Construct a map of params to be passed on to the
         * embedded Liveboard or visualization.
         */
        getEmbedParams() {
            let params = {};
            params = this.getBaseQueryParams(params);
            const { enableVizTransformations, fullHeight, defaultHeight, visibleVizs, liveboardV2, vizId, hideTabPanel, activeTabId, hideLiveboardHeader, showLiveboardDescription, showLiveboardTitle, isLiveboardHeaderSticky = true, isLiveboardCompactHeaderEnabled = false, showLiveboardVerifiedBadge = true, showLiveboardReverifyBanner = true, hideIrrelevantChipsInLiveboardTabs = false, enableAskSage, enable2ColumnLayout, dataPanelV2 = false, enableCustomColumnGroups = false, oAuthPollingInterval, isForceRedirect, dataSourceId, coverAndFilterOptionInPDF, } = this.viewConfig;
            const preventLiveboardFilterRemoval = this.viewConfig.preventLiveboardFilterRemoval
                || this.viewConfig.preventPinboardFilterRemoval;
            if (fullHeight === true) {
                params[Param.fullHeight] = true;
            }
            if (defaultHeight) {
                this.defaultHeight = defaultHeight;
            }
            if (enableVizTransformations !== undefined) {
                params[Param.EnableVizTransformations] = enableVizTransformations.toString();
            }
            if (preventLiveboardFilterRemoval) {
                params[Param.preventLiveboardFilterRemoval] = true;
            }
            if (visibleVizs) {
                params[Param.visibleVizs] = visibleVizs;
            }
            params[Param.livedBoardEmbed] = true;
            if (vizId) {
                params[Param.vizEmbed] = true;
            }
            if (liveboardV2 !== undefined) {
                params[Param.LiveboardV2Enabled] = liveboardV2;
            }
            if (enable2ColumnLayout !== undefined) {
                params[Param.Enable2ColumnLayout] = enable2ColumnLayout;
            }
            if (hideTabPanel) {
                params[Param.HideTabPanel] = hideTabPanel;
            }
            if (hideLiveboardHeader) {
                params[Param.HideLiveboardHeader] = hideLiveboardHeader;
            }
            if (showLiveboardDescription) {
                params[Param.ShowLiveboardDescription] = showLiveboardDescription;
            }
            if (showLiveboardTitle) {
                params[Param.ShowLiveboardTitle] = showLiveboardTitle;
            }
            if (enableAskSage) {
                params[Param.enableAskSage] = enableAskSage;
            }
            if (oAuthPollingInterval !== undefined) {
                params[Param.OauthPollingInterval] = oAuthPollingInterval;
            }
            if (isForceRedirect) {
                params[Param.IsForceRedirect] = isForceRedirect;
            }
            if (dataSourceId !== undefined) {
                params[Param.DataSourceId] = dataSourceId;
            }
            if (coverAndFilterOptionInPDF !== undefined) {
                params[Param.CoverAndFilterOptionInPDF] = coverAndFilterOptionInPDF;
            }
            params[Param.LiveboardHeaderSticky] = isLiveboardHeaderSticky;
            params[Param.LiveboardHeaderV2] = isLiveboardCompactHeaderEnabled;
            params[Param.ShowLiveboardVerifiedBadge] = showLiveboardVerifiedBadge;
            params[Param.ShowLiveboardReverifyBanner] = showLiveboardReverifyBanner;
            params[Param.HideIrrelevantFiltersInTab] = hideIrrelevantChipsInLiveboardTabs;
            params[Param.DataPanelV2Enabled] = dataPanelV2;
            params[Param.EnableCustomColumnGroups] = enableCustomColumnGroups;
            const queryParams = getQueryParamString(params, true);
            return queryParams;
        }
        getIframeSuffixSrc(liveboardId, vizId, activeTabId) {
            let suffix = `/embed/viz/${liveboardId}`;
            if (activeTabId) {
                suffix = `${suffix}/tab/${activeTabId} `;
            }
            if (vizId) {
                suffix = `${suffix}/${vizId}`;
            }
            const tsPostHashParams = this.getThoughtSpotPostUrlParams();
            suffix = `${suffix}${tsPostHashParams}`;
            return suffix;
        }
        /**
         * Construct the URL of the embedded ThoughtSpot Liveboard or visualization
         * to be loaded within the iFrame.
         */
        getIFrameSrc() {
            var _a;
            const { vizId, activeTabId } = this.viewConfig;
            const liveboardId = (_a = this.viewConfig.liveboardId) !== null && _a !== void 0 ? _a : this.viewConfig.pinboardId;
            if (!liveboardId) {
                this.handleError(ERROR_MESSAGE.LIVEBOARD_VIZ_ID_VALIDATION);
            }
            return `${this.getRootIframeSrc()}${this.getIframeSuffixSrc(liveboardId, vizId, activeTabId)}`;
        }
        setActiveTab(data) {
            if (!this.viewConfig.vizId) {
                const prefixPath = this.iFrame.src.split('#/')[1].split('/tab')[0];
                const path = `${prefixPath}/tab/${data.tabId}`;
                super.trigger(exports.HostEvent.Navigate, path);
            }
        }
        async showPreviewLoader() {
            if (!this.viewConfig.showPreviewLoader || !this.viewConfig.vizId) {
                return;
            }
            try {
                const preview = await getPreview(this.thoughtSpotHost, this.viewConfig.vizId, this.viewConfig.liveboardId);
                if (!preview.vizContent) {
                    return;
                }
                addPreviewStylesIfNotPresent();
                const div = document.createElement('div');
                div.innerHTML = `
                <div class=ts-viz-preview-loader>
                    ${preview.vizContent}
                </div>
                `;
                const previewDiv = div.firstElementChild;
                this.el.appendChild(previewDiv);
                this.el.style.position = 'relative';
                this.on(exports.EmbedEvent.Data, () => {
                    previewDiv.remove();
                });
            }
            catch (error) {
                console.error('Error fetching preview', error);
            }
        }
        beforePrerenderVisible() {
            var _a;
            const embedObj = (_a = this.insertedDomEl) === null || _a === void 0 ? void 0 : _a[this.embedNodeKey];
            if (isUndefined$1(embedObj))
                return;
            const showDifferentLib = this.viewConfig.liveboardId
                && embedObj.viewConfig.liveboardId !== this.viewConfig.liveboardId;
            if (showDifferentLib) {
                const libId = this.viewConfig.liveboardId;
                this.navigateToLiveboard(libId);
            }
        }
        async handleRenderForPrerender() {
            if (isUndefined$1(this.viewConfig.liveboardId)) {
                return this.prerenderGeneric();
            }
            return super.handleRenderForPrerender();
        }
        /**
         * Triggers an event to the embedded app
         * @param {HostEvent} messageType The event type
         * @param {any} data The payload to send with the message
         * @returns A promise that resolves with the response from the embedded app
         */
        trigger(messageType, data = {}) {
            const dataWithVizId = data;
            if (messageType === exports.HostEvent.SetActiveTab) {
                this.setActiveTab(data);
                return Promise.resolve(null);
            }
            if (typeof dataWithVizId === 'object' && this.viewConfig.vizId) {
                dataWithVizId.vizId = this.viewConfig.vizId;
            }
            return super.trigger(messageType, dataWithVizId);
        }
        /**
         * Render an embedded ThoughtSpot Liveboard or visualization
         * @param renderOptions An object specifying the Liveboard ID,
         * visualization ID and the runtime filters.
         */
        async render() {
            await super.render();
            const src = this.getIFrameSrc();
            await this.renderV1Embed(src);
            this.showPreviewLoader();
            return this;
        }
        navigateToLiveboard(liveboardId, vizId, activeTabId) {
            const path = this.getIframeSuffixSrc(liveboardId, vizId, activeTabId);
            this.viewConfig.liveboardId = liveboardId;
            this.viewConfig.activeTabId = activeTabId;
            this.viewConfig.vizId = vizId;
            if (this.isRendered) {
                this.trigger(exports.HostEvent.Navigate, path.substring(1));
            }
            else if (this.viewConfig.preRenderId) {
                this.preRender(true);
            }
            else {
                this.render();
            }
        }
        /**
         * Returns the full url of the Liveboard/visualization which can be used to open
         * this Liveboard inside the full Thoughtspot application in a new tab.
         * @returns url string
         */
        getLiveboardUrl() {
            let url = `${this.thoughtSpotHost}/#/pinboard/${this.viewConfig.liveboardId}`;
            if (this.viewConfig.activeTabId) {
                url = `${url}/tab/${this.viewConfig.activeTabId}`;
            }
            if (this.viewConfig.vizId) {
                url = `${url}/${this.viewConfig.vizId}`;
            }
            return url;
        }
    }
    /**
     * @hidden
     */
    class PinboardEmbed extends LiveboardEmbed {
    }

    /**
     * Copyright (c) 2022
     *
     * Embed ThoughtSpot search or a saved answer
     * @summary Search embed
     * @author Ayon Ghosh <ayon.ghosh@thoughtspot.com>
     */
    /**
     * Define the initial state os column custom group accordions
     * in data panel v2.
     */
    var DataPanelCustomColumnGroupsAccordionState;
    (function (DataPanelCustomColumnGroupsAccordionState) {
        /**
         * Expand all the accordion initially in data panel v2.
         */
        DataPanelCustomColumnGroupsAccordionState["EXPAND_ALL"] = "EXPAND_ALL";
        /**
         * Collapse all the accordions initially in data panel v2.
         */
        DataPanelCustomColumnGroupsAccordionState["COLLAPSE_ALL"] = "COLLAPSE_ALL";
        /**
         * Expand the first accordion and collapse the rest.
         */
        DataPanelCustomColumnGroupsAccordionState["EXPAND_FIRST"] = "EXPAND_FIRST";
    })(DataPanelCustomColumnGroupsAccordionState || (DataPanelCustomColumnGroupsAccordionState = {}));
    const HiddenActionItemByDefaultForSearchEmbed = [
        exports.Action.EditACopy,
        exports.Action.SaveAsView,
        exports.Action.UpdateTML,
        exports.Action.EditTML,
        exports.Action.AnswerDelete,
    ];
    /**
     * Embed ThoughtSpot search
     * @group Embed components
     */
    class SearchEmbed extends TsEmbed {
        constructor(domSelector, viewConfig) {
            viewConfig.embedComponentType = 'SearchEmbed';
            super(domSelector, viewConfig);
        }
        /**
         * Get the state of the data sources panel that the embedded
         * ThoughtSpot search will be initialized with.
         */
        getDataSourceMode() {
            let dataSourceMode = exports.DataSourceVisualMode.Expanded;
            if (this.viewConfig.collapseDataSources === true
                || this.viewConfig.collapseDataPanel === true) {
                dataSourceMode = exports.DataSourceVisualMode.Collapsed;
            }
            if (this.viewConfig.hideDataSources === true) {
                dataSourceMode = exports.DataSourceVisualMode.Hidden;
            }
            return dataSourceMode;
        }
        getSearchInitData() {
            var _a;
            return {
                ...(this.viewConfig.excludeSearchTokenStringFromURL ? {
                    searchOptions: {
                        searchTokenString: (_a = this.viewConfig.searchOptions) === null || _a === void 0 ? void 0 : _a.searchTokenString,
                    },
                } : {}),
            };
        }
        async getAppInitData() {
            const defaultAppInitData = await super.getAppInitData();
            return { ...defaultAppInitData, ...this.getSearchInitData() };
        }
        getEmbedParams() {
            var _a;
            const { hideResults, enableSearchAssist, forceTable, searchOptions, runtimeFilters, dataSource, dataSources, excludeRuntimeFiltersfromURL, hideSearchBar, dataPanelV2 = false, useLastSelectedSources = false, runtimeParameters, collapseSearchBarInitially = false, enableCustomColumnGroups = false, isOnBeforeGetVizDataInterceptEnabled = false, 
            /* eslint-disable-next-line max-len */
            dataPanelCustomGroupsAccordionInitialState = DataPanelCustomColumnGroupsAccordionState.EXPAND_ALL, focusSearchBarOnRender = true, excludeRuntimeParametersfromURL, excludeSearchTokenStringFromURL, collapseSearchBar = true, } = this.viewConfig;
            const queryParams = this.getBaseQueryParams();
            queryParams[Param.HideActions] = [
                ...((_a = queryParams[Param.HideActions]) !== null && _a !== void 0 ? _a : []),
                ...HiddenActionItemByDefaultForSearchEmbed,
            ];
            if (dataSources && dataSources.length) {
                queryParams[Param.DataSources] = JSON.stringify(dataSources);
            }
            if (dataSource) {
                queryParams[Param.DataSources] = `["${dataSource}"]`;
            }
            if (searchOptions === null || searchOptions === void 0 ? void 0 : searchOptions.searchTokenString) {
                if (!excludeSearchTokenStringFromURL) {
                    queryParams[Param.searchTokenString] = encodeURIComponent(searchOptions.searchTokenString);
                }
                if (searchOptions.executeSearch) {
                    queryParams[Param.executeSearch] = true;
                }
            }
            if (enableSearchAssist) {
                queryParams[Param.EnableSearchAssist] = true;
            }
            if (hideResults) {
                queryParams[Param.HideResult] = true;
            }
            if (forceTable) {
                queryParams[Param.ForceTable] = true;
            }
            if (hideSearchBar) {
                queryParams[Param.HideSearchBar] = true;
            }
            if (isOnBeforeGetVizDataInterceptEnabled) {
                /* eslint-disable-next-line max-len */
                queryParams[Param.IsOnBeforeGetVizDataInterceptEnabled] = isOnBeforeGetVizDataInterceptEnabled;
            }
            if (!focusSearchBarOnRender) {
                queryParams[Param.FocusSearchBarOnRender] = focusSearchBarOnRender;
            }
            queryParams[Param.DataPanelV2Enabled] = dataPanelV2;
            queryParams[Param.DataSourceMode] = this.getDataSourceMode();
            queryParams[Param.UseLastSelectedDataSource] = useLastSelectedSources;
            if (dataSource || dataSources) {
                queryParams[Param.UseLastSelectedDataSource] = false;
            }
            queryParams[Param.searchEmbed] = true;
            /* eslint-disable-next-line max-len */
            queryParams[Param.CollapseSearchBarInitially] = collapseSearchBarInitially || collapseSearchBar;
            queryParams[Param.EnableCustomColumnGroups] = enableCustomColumnGroups;
            if (dataPanelCustomGroupsAccordionInitialState
                === DataPanelCustomColumnGroupsAccordionState.COLLAPSE_ALL
                || dataPanelCustomGroupsAccordionInitialState
                    === DataPanelCustomColumnGroupsAccordionState.EXPAND_FIRST) {
                /* eslint-disable-next-line max-len */
                queryParams[Param.DataPanelCustomGroupsAccordionInitialState] = dataPanelCustomGroupsAccordionInitialState;
            }
            else {
                /* eslint-disable-next-line max-len */
                queryParams[Param.DataPanelCustomGroupsAccordionInitialState] = DataPanelCustomColumnGroupsAccordionState.EXPAND_ALL;
            }
            let query = '';
            const queryParamsString = getQueryParamString(queryParams, true);
            if (queryParamsString) {
                query = `?${queryParamsString}`;
            }
            const parameterQuery = getRuntimeParameters(runtimeParameters || []);
            if (parameterQuery && !excludeRuntimeParametersfromURL)
                query += `&${parameterQuery}`;
            const filterQuery = getFilterQuery(runtimeFilters || []);
            if (filterQuery && !excludeRuntimeFiltersfromURL) {
                query += `&${filterQuery}`;
            }
            return query;
        }
        /**
         * Construct the URL of the embedded ThoughtSpot search to be
         * loaded in the iframe
         * @param answerId The GUID of a saved answer
         * @param dataSources A list of data source GUIDs
         */
        getIFrameSrc() {
            const { answerId } = this.viewConfig;
            const answerPath = answerId ? `saved-answer/${answerId}` : 'answer';
            const tsPostHashParams = this.getThoughtSpotPostUrlParams();
            return `${this.getRootIframeSrc()}/embed/${answerPath}${tsPostHashParams}`;
        }
        /**
         * Render the embedded ThoughtSpot search
         */
        async render() {
            await super.render();
            this.viewConfig;
            const src = this.getIFrameSrc();
            await this.renderIFrame(src);
            getAuthPromise().then(() => {
                if (checkReleaseVersionInBeta(getReleaseVersion(), getEmbedConfig().suppressSearchEmbedBetaWarning
                    || getEmbedConfig().suppressErrorAlerts)) {
                    alert(ERROR_MESSAGE.SEARCHEMBED_BETA_WRANING_MESSAGE);
                }
            });
            return this;
        }
    }

    /**
     * Embed ThoughtSpot search bar
     * @version: SDK: 1.18.0 | ThoughtSpot: 8.10.0.cl, 9.0.1-sw
     * @group Embed components
     */
    class SearchBarEmbed extends TsEmbed {
        constructor(domSelector, viewConfig) {
            super(domSelector);
            this.embedComponentType = 'SearchBarEmbed';
            this.viewConfig = viewConfig;
        }
        /**
         * Construct the URL of the embedded ThoughtSpot search to be
         * loaded in the iframe
         * @param dataSources A list of data source GUIDs
         */
        getIFrameSrc() {
            var _a;
            const { searchOptions, dataSource, dataSources, useLastSelectedSources = false, excludeSearchTokenStringFromURL, } = this.viewConfig;
            const path = 'search-bar-embed';
            const queryParams = this.getBaseQueryParams();
            queryParams[Param.HideActions] = [...((_a = queryParams[Param.HideActions]) !== null && _a !== void 0 ? _a : [])];
            if (dataSources && dataSources.length) {
                queryParams[Param.DataSources] = JSON.stringify(dataSources);
            }
            if (dataSource) {
                queryParams[Param.DataSources] = `["${dataSource}"]`;
            }
            if (searchOptions === null || searchOptions === void 0 ? void 0 : searchOptions.searchTokenString) {
                if (!excludeSearchTokenStringFromURL) {
                    queryParams[Param.searchTokenString] = encodeURIComponent(searchOptions.searchTokenString);
                }
                if (searchOptions.executeSearch) {
                    queryParams[Param.executeSearch] = true;
                }
            }
            queryParams[Param.UseLastSelectedDataSource] = useLastSelectedSources;
            if (dataSource || dataSources) {
                queryParams[Param.UseLastSelectedDataSource] = false;
            }
            queryParams[Param.searchEmbed] = true;
            let query = '';
            const queryParamsString = getQueryParamString(queryParams, true);
            if (queryParamsString) {
                query = `?${queryParamsString}`;
            }
            const tsPostHashParams = this.getThoughtSpotPostUrlParams();
            return `${this.getEmbedBasePath(query)}/embed/${path}${tsPostHashParams}`;
        }
        /**
         * Render the embedded ThoughtSpot search
         */
        async render() {
            await super.render();
            const src = this.getIFrameSrc();
            await this.renderIFrame(src);
            return this;
        }
        getSearchInitData() {
            return {
                searchOptions: this.viewConfig.excludeSearchTokenStringFromURL
                    ? this.viewConfig.searchOptions
                    : null,
            };
        }
        async getAppInitData() {
            const defaultAppInitData = await super.getAppInitData();
            return { ...defaultAppInitData, ...this.getSearchInitData() };
        }
    }

    const createConversation = `
mutation CreateConversation($params: Input_convassist_CreateConversationRequest) {
  ConvAssist__createConversation(request: $params) {
    convId
    initialCtx {
      type
      tsAnsCtx {
        sessionId
        genNo
        stateKey {
          transactionId
          generationNumber
        }
        worksheet {
          worksheetId
          worksheetName
        }
      }
    }
  }
}
`;
    const sendMessage = `
query SendMessage($params: Input_convassist_SendMessageRequest) {
  ConvAssist__sendMessage(request: $params) {
    responses {
      timestamp
      msgId
      data {
        asstRespData {
          tool
          asstRespText
          nlsAnsData {
            sageQuerySuggestions {
              sageQueryTokens {
                additions {
                  phrase {
                    isCompletePhrase
                    numTokens
                    phraseType
                    startIndex
                    __typename
                  }
                  tokens {
                    token
                    dataType
                    typeEnum
                    guid
                    tokenMetadata {
                      name
                      __typename
                    }
                    __typename
                  }
                  __typename
                }
                phrases {
                  isCompletePhrase
                  numTokens
                  phraseType
                  startIndex
                  __typename
                }
                removals {
                  phrase {
                    isCompletePhrase
                    numTokens
                    phraseType
                    startIndex
                    __typename
                  }
                  tokens {
                    token
                    dataType
                    typeEnum
                    guid
                    tokenMetadata {
                      name
                      __typename
                    }
                    __typename
                  }
                  __typename
                }
                tokens {
                  token
                  dataType
                  typeEnum
                  guid
                  tokenMetadata {
                    name
                    __typename
                  }
                  __typename
                }
                __typename
              }
              llmReasoning {
                assumptions
                clarifications
                interpretation
                __typename
              }
              tokens
              tmlTokens
              worksheetId
              tokens
              description
              title
              tmlTokens
              cached
              sqlQuery
              sessionId
              genNo
              formulaInfo {
                name
                expression
                __typename
              }
              tmlPhrases
              ambiguousPhrases {
                alternativePhrases {
                  phraseType
                  token {
                    token
                    dataType
                    typeEnum
                    guid
                    tokenMetadata {
                      name
                      __typename
                    }
                    __typename
                  }
                  __typename
                }
                ambiguityType
                token {
                  token
                  dataType
                  typeEnum
                  guid
                  tokenMetadata {
                    name
                    __typename
                  }
                  __typename
                }
                __typename
              }
              ambiguousTokens {
                alternativeTokens {
                  token
                  dataType
                  typeEnum
                  guid
                  tokenMetadata {
                    name
                    deprecatedTableGuid
                    deprecatedTableName
                    isFormula
                    rootTables {
                      created
                      description
                      guid
                      indexVersion
                      modified
                      name
                      __typename
                    }
                    schemaTableUserDefinedName
                    table {
                      created
                      description
                      guid
                      indexVersion
                      modified
                      name
                      __typename
                    }
                    __typename
                  }
                  __typename
                }
                ambiguityType
                token {
                  token
                  dataType
                  typeEnum
                  guid
                  tokenMetadata {
                    name
                    __typename
                  }
                  __typename
                }
                __typename
              }
              stateKey {
                transactionId
                generationNumber
                transactionId
                __typename
              }
              subQueries {
                tokens
                cohortConfig {
                  anchorColumnId
                  cohortAnswerGuid
                  cohortGroupingType
                  cohortGuid
                  cohortType
                  combineNonGroupValues
                  description
                  groupExcludedQueryValues
                  hideExcludedQueryValues
                  isEditable
                  name
                  nullOutputValue
                  returnColumnId
                  __typename
                }
                formulas {
                  name
                  expression
                  __typename
                }
                __typename
              }
              visualizationSuggestion {
                chartType
                displayMode
                axisConfigs {
                  category
                  color
                  hidden
                  size
                  sort
                  x
                  y
                  __typename
                }
                usersVizIntentApplied
                customChartConfigs {
                  dimensions {
                    columns
                    key
                    __typename
                  }
                  key
                  __typename
                }
                customChartGuid
                __typename
              }
              tableData {
                columnDataLite {
                  columnId
                  columnDataType
                  dataValue
                  columnName
                  __typename
                }
                __typename
              }
              warningType
              cached
              __typename
            }
            debugInfo {
              fewShotExamples {
                chartType
                id
                mappingId
                nlQuery
                nlQueryConcepts
                sageQuery
                scope
                sql
                tml
                __typename
              }
              __typename
            }
            __typename
          }
          __typename
        }
        errorData {
          tool
          errCode
          errTxt
          toolErrCode
          __typename
        }
        __typename
      }
      type
      __typename
    }
    prevCtx {
      genNo
      sessionId
      __typename
    }
    __typename
  }
}
`;

    class Conversation {
        constructor(thoughtSpotHost, worksheetId) {
            this.thoughtSpotHost = thoughtSpotHost;
            this.worksheetId = worksheetId;
            this.inProgress = null;
            this.inProgress = this.init();
        }
        async init() {
            const { convId } = await this.createConversation();
            this.conversationId = convId;
        }
        createConversation() {
            return this.executeQuery(createConversation, {
                params: {
                    initialCtx: {
                        tsWorksheetCtx: {
                            worksheet: {
                                worksheetId: this.worksheetId,
                            },
                        },
                        type: 'TS_WORKSHEET',
                    },
                    userInfo: {
                        tenantUrl: `${this.thoughtSpotHost}/prism`,
                    },
                },
            });
        }
        async sendMessage(userMessage) {
            await this.inProgress;
            try {
                const { responses } = await this.executeQuery(sendMessage, {
                    params: {
                        convId: this.conversationId,
                        headers: [],
                        msg: {
                            data: {
                                userCmdData: {
                                    cmdText: userMessage,
                                    nlsData: {
                                        worksheetId: this.worksheetId,
                                        questionType: 'ANSWER_SPEC_GENERATION',
                                    },
                                },
                            },
                            msgId: crypto.randomUUID(),
                            type: 'USER_COMMAND',
                        },
                    },
                });
                const data = responses[0].data;
                return {
                    data: data.asstRespData.nlsAnsData.sageQuerySuggestions[0],
                    error: null,
                };
            }
            catch (error) {
                return { error };
            }
        }
        async executeQuery(query, variables) {
            return graphqlQuery({
                query,
                variables,
                thoughtSpotHost: this.thoughtSpotHost,
                isCompositeQuery: false,
            });
        }
    }

    class ConversationMessage extends TsEmbed {
        constructor(container, viewConfig) {
            viewConfig.embedComponentType = 'bodyless-conversation';
            super(container, viewConfig);
            this.viewConfig = viewConfig;
        }
        getIframeSrc() {
            var _a;
            const { sessionId, genNo, acSessionId, acGenNo, } = this.viewConfig;
            const path = 'conv-assist-answer';
            const queryParams = this.getBaseQueryParams();
            queryParams[Param.HideActions] = [...((_a = queryParams[Param.HideActions]) !== null && _a !== void 0 ? _a : [])];
            queryParams[Param.isSpotterAgentEmbed] = true;
            let query = '';
            const queryParamsString = getQueryParamString(queryParams, true);
            if (queryParamsString) {
                query = `?${queryParamsString}`;
            }
            const tsPostHashParams = this.getThoughtSpotPostUrlParams({
                sessionId,
                genNo,
                acSessionId,
                acGenNo,
            });
            return `${this.getEmbedBasePath(query)}/embed/${path}${tsPostHashParams}`;
        }
        async render() {
            await super.render();
            const src = this.getIframeSrc();
            await this.renderIFrame(src);
            return this;
        }
    }
    /**
     * Create a conversation embed, which can be integrated inside
     * chatbots or other conversational interfaces.
     * @example
     * ```js
     * import { SpotterAgentEmbed } from '@thoughtspot/visual-embed-sdk';
     *
     * const conversation = new SpotterAgentEmbed({
     *  worksheetId: 'worksheetId',
     * });
     *
     * const { container, error } = await conversation.sendMessage('show me sales by region');
     *
     * // append the container to the DOM
     * document.body.appendChild(container); // or to any other element
     * ```
     * @group Embed components
     * @version SDK: 1.37.0 | ThoughtSpot: 10.9.0.cl
     */
    class SpotterAgentEmbed {
        constructor(viewConfig) {
            this.viewConfig = viewConfig;
            const embedConfig = getEmbedConfig();
            this.conversationService = new Conversation(embedConfig.thoughtSpotHost, viewConfig.worksheetId);
        }
        async sendMessage(userMessage) {
            const { data, error } = await this.conversationService.sendMessage(userMessage);
            if (error) {
                return { error };
            }
            const container = document.createElement('div');
            if (this.viewConfig.containerClassName) {
                container.className = this.viewConfig.containerClassName;
            }
            const embed = new ConversationMessage(container, {
                ...this.viewConfig,
                sessionId: data.sessionId,
                genNo: data.genNo,
                acSessionId: data.stateKey.transactionId,
                acGenNo: data.stateKey.generationNumber,
            });
            await embed.render();
            return { container, viz: embed };
        }
    }
    /**
     * Create a conversation embed, which can be integrated inside
     * chatbots or other conversational interfaces.
     * @deprecated from SDK: 1.38.0 | ThoughtSpot: 10.10.0.cl
     * Use {@link SpotterAgentEmbed} instead
     * @example
     * ```js
     * import { SpotterAgentEmbed } from '@thoughtspot/visual-embed-sdk';
     *
     * const conversation = new SpotterAgentEmbed({
     *  worksheetId: 'worksheetId',
     * });
     *
     * const { container, error } = await conversation.sendMessage('show me sales by region');
     *
     * // append the container to the DOM
     * document.body.appendChild(container); // or to any other element
     * ```
     * @group Embed components
     */
    class BodylessConversation extends SpotterAgentEmbed {
        constructor(viewConfig) {
            super(viewConfig);
        }
    }

    /**
     * Checks if `value` is `undefined`.
     *
     * @static
     * @since 0.1.0
     * @memberOf _
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is `undefined`, else `false`.
     * @example
     *
     * _.isUndefined(void 0);
     * // => true
     *
     * _.isUndefined(null);
     * // => false
     */
    function isUndefined(value) {
      return value === undefined;
    }

    var isUndefined_1 = isUndefined;

    /**
     * Embed ThoughtSpot AI Conversation.
     * @group Embed components
     * @example
     * ```js
     * const conversation = new SpotterEmbed('#tsEmbed', {
     *   worksheetId: 'worksheetId',
     *   searchOptions: {
     *     searchQuery: 'searchQuery',
     *   },
     * });
     * conversation.render();
     * ```
     * @version SDK: 1.37.0 | ThoughtSpot: 10.9.0.cl
     */
    class SpotterEmbed extends TsEmbed {
        constructor(container, viewConfig) {
            viewConfig.embedComponentType = 'conversation';
            super(container, viewConfig);
            this.viewConfig = viewConfig;
        }
        getIframeSrc() {
            const { worksheetId, searchOptions, disableSourceSelection, hideSourceSelection, dataPanelV2, showSpotterLimitations, hideSampleQuestions, } = this.viewConfig;
            const path = 'insights/conv-assist';
            if (!worksheetId) {
                this.handleError(ERROR_MESSAGE.SPOTTER_EMBED_WORKSHEED_ID_NOT_FOUND);
            }
            const queryParams = this.getBaseQueryParams();
            queryParams[Param.SpotterEnabled] = true;
            if (!isUndefined_1(disableSourceSelection)) {
                queryParams[Param.DisableSourceSelection] = !!disableSourceSelection;
            }
            if (!isUndefined_1(hideSourceSelection)) {
                queryParams[Param.HideSourceSelection] = !!hideSourceSelection;
            }
            if (!isUndefined_1(dataPanelV2)) {
                queryParams[Param.DataPanelV2Enabled] = !!dataPanelV2;
            }
            if (!isUndefined_1(showSpotterLimitations)) {
                queryParams[Param.ShowSpotterLimitations] = !!showSpotterLimitations;
            }
            if (!isUndefined_1(hideSampleQuestions)) {
                queryParams[Param.HideSampleQuestions] = !!hideSampleQuestions;
            }
            let query = '';
            const queryParamsString = getQueryParamString(queryParams, true);
            if (queryParamsString) {
                query = `?${queryParamsString}`;
            }
            const tsPostHashParams = this.getThoughtSpotPostUrlParams({
                worksheet: worksheetId,
                query: (searchOptions === null || searchOptions === void 0 ? void 0 : searchOptions.searchQuery) || '',
            });
            return `${this.getEmbedBasePath(query)}/embed/${path}${tsPostHashParams}`;
        }
        async render() {
            await super.render();
            const src = this.getIframeSrc();
            await this.renderIFrame(src);
            return this;
        }
    }
    /**
     * Embed ThoughtSpot AI Conversation.
     * @deprecated from SDK: 1.38.0 | ThoughtSpot: 10.10.0.cl
     * Use {@link SpotterEmbed} instead
     * @group Embed components
     * @example
     * ```js
     * const conversation = new SpotterEmbed('#tsEmbed', {
     *   worksheetId: 'worksheetId',
     *   searchOptions: {
     *     searchQuery: 'searchQuery',
     *   },
     * });
     * conversation.render();
     * ```
     * @version SDK: 1.37.0 | ThoughtSpot: 10.9.0.cl
     */
    class ConversationEmbed extends SpotterEmbed {
        constructor(container, viewConfig) {
            viewConfig.embedComponentType = 'conversation';
            super(container, viewConfig);
            this.viewConfig = viewConfig;
        }
    }

    /**
     * Copyright (c) 2023
     *
     * Embed ThoughtSpot Sage
     * @summary TS Sage embed
     * @author Mourya Balabhadra <mourya.balabhadra@thoughtspot.com>
     */
    /**
     * Embed ThoughtSpot LLM and GPT-based Natural Language Search component.
     * @version: SDK: 1.23.0 | ThoughtSpot: 9.4.0.cl, 9.5.1-sw
     * @group Embed components
     */
    class SageEmbed extends V1Embed {
        // eslint-disable-next-line no-useless-constructor
        constructor(domSelector, viewConfig) {
            viewConfig.embedComponentType = 'SageEmbed';
            super(domSelector, viewConfig);
        }
        /**
         * Constructs a map of parameters to be passed on to the
         * embedded Eureka or Sage search page.
         * @returns {string} query string
         */
        getEmbedParams() {
            const { disableWorksheetChange, hideWorksheetSelector, showObjectSuggestions, dataPanelV2, hideSampleQuestions, isProductTour, hideSageAnswerHeader, hideAutocompleteSuggestions, } = this.viewConfig;
            const params = this.getBaseQueryParams();
            params[Param.DataPanelV2Enabled] = !!dataPanelV2;
            params[Param.IsSageEmbed] = true;
            params[Param.DisableWorksheetChange] = !!disableWorksheetChange;
            params[Param.HideWorksheetSelector] = !!hideWorksheetSelector;
            params[Param.HideEurekaSuggestions] = !!hideAutocompleteSuggestions;
            if (showObjectSuggestions) {
                params[Param.HideEurekaSuggestions] = !showObjectSuggestions;
                // support backwards compatibility
            }
            params[Param.HideSampleQuestions] = !!hideSampleQuestions;
            params[Param.IsProductTour] = !!isProductTour;
            params[Param.HideSageAnswerHeader] = !!hideSageAnswerHeader;
            return getQueryParamString(params, true);
        }
        /**
         * Construct the URL of the embedded ThoughtSpot sage to be
         * loaded in the iframe
         * @returns {string} iframe url
         */
        getIFrameSrc() {
            const path = 'eureka';
            const postHashObj = {};
            const tsPostHashParams = this.getThoughtSpotPostUrlParams();
            const { dataSource, searchOptions, } = this.viewConfig;
            if (dataSource)
                postHashObj[Param.WorksheetId] = dataSource;
            if ((searchOptions === null || searchOptions === void 0 ? void 0 : searchOptions.searchQuery) && searchOptions.executeSearch) {
                postHashObj[Param.executeSearch] = true;
            }
            let sagePostHashParams = new URLSearchParams(postHashObj).toString();
            if (sagePostHashParams)
                sagePostHashParams = `${tsPostHashParams ? '&' : '?'}${sagePostHashParams}`;
            if (searchOptions === null || searchOptions === void 0 ? void 0 : searchOptions.searchQuery)
                sagePostHashParams += `${sagePostHashParams ? '&' : '?'}${[Param.Query]}=${encodeURIComponent(searchOptions.searchQuery)}`;
            // use encodeURIComponent for query instead of URLSearchParams
            // as it adds + instead of %20 for spaces
            return `${this.getRootIframeSrc()}/embed/${path}${tsPostHashParams}${sagePostHashParams}`;
        }
        /**
         * Render the embedded ThoughtSpot Sage
         * @returns {SageEmbed} Eureka/Sage embed
         */
        async render() {
            await super.render();
            const src = this.getIFrameSrc();
            await this.renderV1Embed(src);
            return this;
        }
    }

    const getAnswerSessionFromQuery = `
query GetEurekaResults($params: Input_eureka_SearchRequest) {
        queryRequest(request: $params) {
            ...eurekaResults
            __typename
        }
    }

        fragment eurekaResults on eureka_SearchResponse {
        facets {
            facetType
            facetValue
            facetValues {
            id
            resultCount
            name
            __typename
            }
            __typename
        }
        requestIdentifiers {
            apiRequestId
            appActivityId
            __typename
        }
        sageQuerySuggestions {
            llmReasoning {
                assumptions
                clarifications
                interpretation
                __typename
            }
            tokens
            tmlTokens
            worksheetId
            description
            title
            tmlTokens
            formulaInfo {
            name
            expression
            __typename
            }
            tmlPhrases
            ambiguousPhrases {
            alternativePhrases {
                phraseType
                token {
                token
                dataType
                typeEnum
                guid
                tokenMetadata {
                    name
                    __typename
                }
                __typename
                }
                __typename
            }
            ambiguityType
            token {
                token
                dataType
                typeEnum
                guid
                tokenMetadata {
                name
                __typename
                }
                __typename
            }
            __typename
            }
            ambiguousTokens {
            alternativeTokens {
                token
                dataType
                typeEnum
                guid
                tokenMetadata {
                name
                deprecatedTableGuid
                deprecatedTableName
                isFormula
                rootTables {
                    created
                    description
                    guid
                    indexVersion
                    modified
                    name
                    __typename
                }
                schemaTableUserDefinedName
                table {
                    created
                    description
                    guid
                    indexVersion
                    modified
                    name
                    __typename
                }
                __typename
                }
                __typename
            }
            ambiguityType
            token {
                token
                dataType
                typeEnum
                guid
                tokenMetadata {
                name
                __typename
                }
                __typename
            }
            __typename
            }
            sessionId
            genNo
            stateKey {
                generationNumber
                transactionId
            __typename
            }
            subQueries {
            tokens
            cohortConfig {
                anchorColumnId
                cohortAnswerGuid
                cohortGroupingType
                cohortGuid
                cohortType
                combineNonGroupValues
                description
                groupExcludedQueryValues
                hideExcludedQueryValues
                isEditable
                name
                nullOutputValue
                returnColumnId
                __typename
            }
            formulas {
                name
                expression
                __typename
            }
            __typename
            }
            visualizationSuggestion {
            chartType
            displayMode
            axisConfigs {
                category
                color
                hidden
                size
                sort
                x
                y
                __typename
            }
            usersVizIntentApplied
            customChartConfigs {
                dimensions {
                columns
                key
                __typename
                }
                key
                __typename
            }
            customChartGuid
            __typename
            }
            tableData {
            columnDataLite {
                columnId
                columnDataType
                dataValue
                columnName
                __typename
            }
            __typename
            }
            warningType
            cached
            warningDetails {
            warningType
            __typename
            }
            __typename
        }
        results {
            objectSecurityInfo {
            objectType
            objectId
            objectIdForDeletionCheck
            objectTypeForDeletionCheck
            isD13ySourced
            offset
            __typename
            }
            searchAnswer {
            ...eurekaAnswer
            __typename
            }
            searchPinboardViz {
            answer {
                ...eurekaAnswer
                __typename
            }
            pinboardHeader {
                id
                title
                __typename
            }
            __typename
            }
            searchPinboard {
            header {
                ...header
                __typename
            }
            usageInfo {
                ...usageInfo
                __typename
            }
            answers {
                ...eurekaAnswer
                __typename
            }
            vizCount {
                charts
                metrics
                tables
                __typename
            }
            __typename
            }
            snippetInfo {
            titleSnippet {
                snippetString
                highlights {
                start
                end
                __typename
                }
                __typename
            }
            descriptionSnippet {
                snippetString
                highlights {
                start
                end
                __typename
                }
                __typename
            }
            sageQuerySnippet {
                phrase {
                isCompletePhrase
                numTokens
                phraseType
                startIndex
                __typename
                }
                token {
                token
                dataType
                typeEnum
                __typename
                }
                __typename
            }
            sageQuerySnippetWithHighlights {
                highlights {
                start
                end
                __typename
                }
                phraseType
                phraseValue
                __typename
            }
            __typename
            }
            score
            debugInfo
            resultType
            sageQuery
            __typename
        }
        version
        nextPageOffset
        batchSizeRequired
        isFinalPage
        totalResults
        totalFacetResultCount
        errorCode
        debugInfo {
            fewShotExamples {
            chartType
            formulas {
                name
                expression
                __typename
            }
            id
            mappingId
            nlQuery
            nlQueryConcepts
            sageQuery
            scope
            sql
            tml
            feedbackType
            __typename
            }
            __typename
        }
        __typename
        }

        fragment eurekaAnswer on eureka_AnswerResult {
        header {
            ...header
            __typename
        }
        usageInfo {
            ...usageInfo
            __typename
        }
        preferredViz {
            ...visualizationMetadata
            __typename
        }
        worksheetInfo {
            ...worksheetInfo
            __typename
        }
        formatted {
            phrase {
            isCompletePhrase
            numTokens
            phraseType
            startIndex
            __typename
            }
            token {
            token
            typeEnum
            __typename
            }
            __typename
        }
        __typename
        }

        fragment header on eureka_Header {
        id
        title
        description
        authorGuid
        authorName
        createdOn
        tagIds
        __typename
        }

        fragment usageInfo on eureka_UsageInfo {
        favouriteCount
        viewCount
        __typename
        }

        fragment visualizationMetadata on eureka_VisualizationMetadata {
        vizType
        chartType
        vizSnapshotRequestData {
            parentReportbookGuid
            parentType
            version
            vizGuid
            __typename
        }
        __typename
        }

        fragment worksheetInfo on eureka_WorksheetInfo {
        id
        name
        __typename
        }`;

    /**
     * Get answer from natural language query
     * @param query string
     * @param worksheetId string
     * @returns AnswerService and the suggestion response.
     * @version SDK: 1.33.1 | ThoughtSpot: 10.3.0.cl
     * @example
     * ```js
     * const { answer } = await getAnswerFromQuery('revenue', 'worksheetId');
     * ```
     */
    const getAnswerFromQuery = async (query, worksheetId) => {
        const embedConfig = getEmbedConfig();
        const resp = await graphqlQuery({
            query: getAnswerSessionFromQuery,
            variables: {
                params: {
                    facetSelections: [],
                    filterSelections: [
                        {
                            facetType: 'WORKSHEETS',
                            facetValue: [
                                worksheetId,
                            ],
                        },
                    ],
                    query,
                    worksheetFacetPayload: {
                        worksheetId,
                    },
                    searchOption: 'AI_ANSWER',
                },
            },
            thoughtSpotHost: embedConfig.thoughtSpotHost,
            isCompositeQuery: false,
        });
        const suggestion = resp.sageQuerySuggestions[0];
        const answerSession = {
            sessionId: suggestion.sessionId,
            genNo: suggestion.genNo,
            acSession: {
                sessionId: suggestion.stateKey.transactionId,
                genNo: suggestion.stateKey.generationNumber,
            },
        };
        return {
            answer: new AnswerService(answerSession, null, embedConfig.thoughtSpotHost),
            suggestion,
        };
    };

    /**
     * Create a liveboard with the given answers
     * @param answers AnswerService[]
     * @param name string
     * @returns result Promise
     * @version SDK: 1.33.1 | ThoughtSpot: *
     * @example
     * ```js
     *   const lb = createLiveboardWithAnswers([
     *      new AnswerService(session, null, 'tshost'),
     *   ], "my-liveboard");
     * ```
     */
    const createLiveboardWithAnswers = async (answers, name) => {
        var _a;
        const { thoughtSpotHost, authType } = getEmbedConfig();
        const resp = await tokenizedFetch(`${thoughtSpotHost}/api/rest/2.0/metadata/search`, {
            method: 'POST',
            credentials: 'include',
            headers: {
                'content-type': 'application/json',
            },
            body: JSON.stringify({
                metadata: [{
                        type: 'LIVEBOARD',
                        identifier: name,
                    }],
            }),
        });
        const lbList = await resp.json();
        const liveboardId = (_a = lbList[0]) === null || _a === void 0 ? void 0 : _a.metadata_id;
        const answerTMLs = (await Promise.all(answers.map((a) => a.getTML())))
            .filter((tml) => tml.answer.search_query);
        const lbTml = {
            guid: liveboardId,
            liveboard: {
                name,
                visualizations: answerTMLs.map((tml, idx) => ({
                    id: `Viz_${idx}`,
                    answer: tml.answer,
                })),
                layout: {
                    tiles: answerTMLs.map((tml, idx) => ({
                        visualization_id: `Viz_${idx}`,
                        size: 'MEDIUM_SMALL',
                    })),
                },
            },
        };
        const result = await executeTML({
            metadata_tmls: [JSON.stringify(lbTml)],
            import_policy: 'ALL_OR_NONE',
        });
        return result;
    };

    const ALIAS = Symbol.for('yaml.alias');
    const DOC = Symbol.for('yaml.document');
    const MAP = Symbol.for('yaml.map');
    const PAIR = Symbol.for('yaml.pair');
    const SCALAR$1 = Symbol.for('yaml.scalar');
    const SEQ = Symbol.for('yaml.seq');
    const NODE_TYPE = Symbol.for('yaml.node.type');
    const isAlias = (node) => !!node && typeof node === 'object' && node[NODE_TYPE] === ALIAS;
    const isDocument = (node) => !!node && typeof node === 'object' && node[NODE_TYPE] === DOC;
    const isMap = (node) => !!node && typeof node === 'object' && node[NODE_TYPE] === MAP;
    const isPair = (node) => !!node && typeof node === 'object' && node[NODE_TYPE] === PAIR;
    const isScalar$1 = (node) => !!node && typeof node === 'object' && node[NODE_TYPE] === SCALAR$1;
    const isSeq = (node) => !!node && typeof node === 'object' && node[NODE_TYPE] === SEQ;
    function isCollection$1(node) {
        if (node && typeof node === 'object')
            switch (node[NODE_TYPE]) {
                case MAP:
                case SEQ:
                    return true;
            }
        return false;
    }
    function isNode(node) {
        if (node && typeof node === 'object')
            switch (node[NODE_TYPE]) {
                case ALIAS:
                case MAP:
                case SCALAR$1:
                case SEQ:
                    return true;
            }
        return false;
    }
    const hasAnchor = (node) => (isScalar$1(node) || isCollection$1(node)) && !!node.anchor;

    const BREAK$1 = Symbol('break visit');
    const SKIP$1 = Symbol('skip children');
    const REMOVE$1 = Symbol('remove node');
    /**
     * Apply a visitor to an AST node or document.
     *
     * Walks through the tree (depth-first) starting from `node`, calling a
     * `visitor` function with three arguments:
     *   - `key`: For sequence values and map `Pair`, the node's index in the
     *     collection. Within a `Pair`, `'key'` or `'value'`, correspondingly.
     *     `null` for the root node.
     *   - `node`: The current node.
     *   - `path`: The ancestry of the current node.
     *
     * The return value of the visitor may be used to control the traversal:
     *   - `undefined` (default): Do nothing and continue
     *   - `visit.SKIP`: Do not visit the children of this node, continue with next
     *     sibling
     *   - `visit.BREAK`: Terminate traversal completely
     *   - `visit.REMOVE`: Remove the current node, then continue with the next one
     *   - `Node`: Replace the current node, then continue by visiting it
     *   - `number`: While iterating the items of a sequence or map, set the index
     *     of the next step. This is useful especially if the index of the current
     *     node has changed.
     *
     * If `visitor` is a single function, it will be called with all values
     * encountered in the tree, including e.g. `null` values. Alternatively,
     * separate visitor functions may be defined for each `Map`, `Pair`, `Seq`,
     * `Alias` and `Scalar` node. To define the same visitor function for more than
     * one node type, use the `Collection` (map and seq), `Value` (map, seq & scalar)
     * and `Node` (alias, map, seq & scalar) targets. Of all these, only the most
     * specific defined one will be used for each node.
     */
    function visit$1(node, visitor) {
        const visitor_ = initVisitor(visitor);
        if (isDocument(node)) {
            const cd = visit_(null, node.contents, visitor_, Object.freeze([node]));
            if (cd === REMOVE$1)
                node.contents = null;
        }
        else
            visit_(null, node, visitor_, Object.freeze([]));
    }
    // Without the `as symbol` casts, TS declares these in the `visit`
    // namespace using `var`, but then complains about that because
    // `unique symbol` must be `const`.
    /** Terminate visit traversal completely */
    visit$1.BREAK = BREAK$1;
    /** Do not visit the children of the current node */
    visit$1.SKIP = SKIP$1;
    /** Remove the current node */
    visit$1.REMOVE = REMOVE$1;
    function visit_(key, node, visitor, path) {
        const ctrl = callVisitor(key, node, visitor, path);
        if (isNode(ctrl) || isPair(ctrl)) {
            replaceNode(key, path, ctrl);
            return visit_(key, ctrl, visitor, path);
        }
        if (typeof ctrl !== 'symbol') {
            if (isCollection$1(node)) {
                path = Object.freeze(path.concat(node));
                for (let i = 0; i < node.items.length; ++i) {
                    const ci = visit_(i, node.items[i], visitor, path);
                    if (typeof ci === 'number')
                        i = ci - 1;
                    else if (ci === BREAK$1)
                        return BREAK$1;
                    else if (ci === REMOVE$1) {
                        node.items.splice(i, 1);
                        i -= 1;
                    }
                }
            }
            else if (isPair(node)) {
                path = Object.freeze(path.concat(node));
                const ck = visit_('key', node.key, visitor, path);
                if (ck === BREAK$1)
                    return BREAK$1;
                else if (ck === REMOVE$1)
                    node.key = null;
                const cv = visit_('value', node.value, visitor, path);
                if (cv === BREAK$1)
                    return BREAK$1;
                else if (cv === REMOVE$1)
                    node.value = null;
            }
        }
        return ctrl;
    }
    /**
     * Apply an async visitor to an AST node or document.
     *
     * Walks through the tree (depth-first) starting from `node`, calling a
     * `visitor` function with three arguments:
     *   - `key`: For sequence values and map `Pair`, the node's index in the
     *     collection. Within a `Pair`, `'key'` or `'value'`, correspondingly.
     *     `null` for the root node.
     *   - `node`: The current node.
     *   - `path`: The ancestry of the current node.
     *
     * The return value of the visitor may be used to control the traversal:
     *   - `Promise`: Must resolve to one of the following values
     *   - `undefined` (default): Do nothing and continue
     *   - `visit.SKIP`: Do not visit the children of this node, continue with next
     *     sibling
     *   - `visit.BREAK`: Terminate traversal completely
     *   - `visit.REMOVE`: Remove the current node, then continue with the next one
     *   - `Node`: Replace the current node, then continue by visiting it
     *   - `number`: While iterating the items of a sequence or map, set the index
     *     of the next step. This is useful especially if the index of the current
     *     node has changed.
     *
     * If `visitor` is a single function, it will be called with all values
     * encountered in the tree, including e.g. `null` values. Alternatively,
     * separate visitor functions may be defined for each `Map`, `Pair`, `Seq`,
     * `Alias` and `Scalar` node. To define the same visitor function for more than
     * one node type, use the `Collection` (map and seq), `Value` (map, seq & scalar)
     * and `Node` (alias, map, seq & scalar) targets. Of all these, only the most
     * specific defined one will be used for each node.
     */
    async function visitAsync(node, visitor) {
        const visitor_ = initVisitor(visitor);
        if (isDocument(node)) {
            const cd = await visitAsync_(null, node.contents, visitor_, Object.freeze([node]));
            if (cd === REMOVE$1)
                node.contents = null;
        }
        else
            await visitAsync_(null, node, visitor_, Object.freeze([]));
    }
    // Without the `as symbol` casts, TS declares these in the `visit`
    // namespace using `var`, but then complains about that because
    // `unique symbol` must be `const`.
    /** Terminate visit traversal completely */
    visitAsync.BREAK = BREAK$1;
    /** Do not visit the children of the current node */
    visitAsync.SKIP = SKIP$1;
    /** Remove the current node */
    visitAsync.REMOVE = REMOVE$1;
    async function visitAsync_(key, node, visitor, path) {
        const ctrl = await callVisitor(key, node, visitor, path);
        if (isNode(ctrl) || isPair(ctrl)) {
            replaceNode(key, path, ctrl);
            return visitAsync_(key, ctrl, visitor, path);
        }
        if (typeof ctrl !== 'symbol') {
            if (isCollection$1(node)) {
                path = Object.freeze(path.concat(node));
                for (let i = 0; i < node.items.length; ++i) {
                    const ci = await visitAsync_(i, node.items[i], visitor, path);
                    if (typeof ci === 'number')
                        i = ci - 1;
                    else if (ci === BREAK$1)
                        return BREAK$1;
                    else if (ci === REMOVE$1) {
                        node.items.splice(i, 1);
                        i -= 1;
                    }
                }
            }
            else if (isPair(node)) {
                path = Object.freeze(path.concat(node));
                const ck = await visitAsync_('key', node.key, visitor, path);
                if (ck === BREAK$1)
                    return BREAK$1;
                else if (ck === REMOVE$1)
                    node.key = null;
                const cv = await visitAsync_('value', node.value, visitor, path);
                if (cv === BREAK$1)
                    return BREAK$1;
                else if (cv === REMOVE$1)
                    node.value = null;
            }
        }
        return ctrl;
    }
    function initVisitor(visitor) {
        if (typeof visitor === 'object' &&
            (visitor.Collection || visitor.Node || visitor.Value)) {
            return Object.assign({
                Alias: visitor.Node,
                Map: visitor.Node,
                Scalar: visitor.Node,
                Seq: visitor.Node
            }, visitor.Value && {
                Map: visitor.Value,
                Scalar: visitor.Value,
                Seq: visitor.Value
            }, visitor.Collection && {
                Map: visitor.Collection,
                Seq: visitor.Collection
            }, visitor);
        }
        return visitor;
    }
    function callVisitor(key, node, visitor, path) {
        if (typeof visitor === 'function')
            return visitor(key, node, path);
        if (isMap(node))
            return visitor.Map?.(key, node, path);
        if (isSeq(node))
            return visitor.Seq?.(key, node, path);
        if (isPair(node))
            return visitor.Pair?.(key, node, path);
        if (isScalar$1(node))
            return visitor.Scalar?.(key, node, path);
        if (isAlias(node))
            return visitor.Alias?.(key, node, path);
        return undefined;
    }
    function replaceNode(key, path, node) {
        const parent = path[path.length - 1];
        if (isCollection$1(parent)) {
            parent.items[key] = node;
        }
        else if (isPair(parent)) {
            if (key === 'key')
                parent.key = node;
            else
                parent.value = node;
        }
        else if (isDocument(parent)) {
            parent.contents = node;
        }
        else {
            const pt = isAlias(parent) ? 'alias' : 'scalar';
            throw new Error(`Cannot replace node with ${pt} parent`);
        }
    }

    const escapeChars = {
        '!': '%21',
        ',': '%2C',
        '[': '%5B',
        ']': '%5D',
        '{': '%7B',
        '}': '%7D'
    };
    const escapeTagName = (tn) => tn.replace(/[!,[\]{}]/g, ch => escapeChars[ch]);
    class Directives {
        constructor(yaml, tags) {
            /**
             * The directives-end/doc-start marker `---`. If `null`, a marker may still be
             * included in the document's stringified representation.
             */
            this.docStart = null;
            /** The doc-end marker `...`.  */
            this.docEnd = false;
            this.yaml = Object.assign({}, Directives.defaultYaml, yaml);
            this.tags = Object.assign({}, Directives.defaultTags, tags);
        }
        clone() {
            const copy = new Directives(this.yaml, this.tags);
            copy.docStart = this.docStart;
            return copy;
        }
        /**
         * During parsing, get a Directives instance for the current document and
         * update the stream state according to the current version's spec.
         */
        atDocument() {
            const res = new Directives(this.yaml, this.tags);
            switch (this.yaml.version) {
                case '1.1':
                    this.atNextDocument = true;
                    break;
                case '1.2':
                    this.atNextDocument = false;
                    this.yaml = {
                        explicit: Directives.defaultYaml.explicit,
                        version: '1.2'
                    };
                    this.tags = Object.assign({}, Directives.defaultTags);
                    break;
            }
            return res;
        }
        /**
         * @param onError - May be called even if the action was successful
         * @returns `true` on success
         */
        add(line, onError) {
            if (this.atNextDocument) {
                this.yaml = { explicit: Directives.defaultYaml.explicit, version: '1.1' };
                this.tags = Object.assign({}, Directives.defaultTags);
                this.atNextDocument = false;
            }
            const parts = line.trim().split(/[ \t]+/);
            const name = parts.shift();
            switch (name) {
                case '%TAG': {
                    if (parts.length !== 2) {
                        onError(0, '%TAG directive should contain exactly two parts');
                        if (parts.length < 2)
                            return false;
                    }
                    const [handle, prefix] = parts;
                    this.tags[handle] = prefix;
                    return true;
                }
                case '%YAML': {
                    this.yaml.explicit = true;
                    if (parts.length !== 1) {
                        onError(0, '%YAML directive should contain exactly one part');
                        return false;
                    }
                    const [version] = parts;
                    if (version === '1.1' || version === '1.2') {
                        this.yaml.version = version;
                        return true;
                    }
                    else {
                        const isValid = /^\d+\.\d+$/.test(version);
                        onError(6, `Unsupported YAML version ${version}`, isValid);
                        return false;
                    }
                }
                default:
                    onError(0, `Unknown directive ${name}`, true);
                    return false;
            }
        }
        /**
         * Resolves a tag, matching handles to those defined in %TAG directives.
         *
         * @returns Resolved tag, which may also be the non-specific tag `'!'` or a
         *   `'!local'` tag, or `null` if unresolvable.
         */
        tagName(source, onError) {
            if (source === '!')
                return '!'; // non-specific tag
            if (source[0] !== '!') {
                onError(`Not a valid tag: ${source}`);
                return null;
            }
            if (source[1] === '<') {
                const verbatim = source.slice(2, -1);
                if (verbatim === '!' || verbatim === '!!') {
                    onError(`Verbatim tags aren't resolved, so ${source} is invalid.`);
                    return null;
                }
                if (source[source.length - 1] !== '>')
                    onError('Verbatim tags must end with a >');
                return verbatim;
            }
            const [, handle, suffix] = source.match(/^(.*!)([^!]*)$/s);
            if (!suffix)
                onError(`The ${source} tag has no suffix`);
            const prefix = this.tags[handle];
            if (prefix) {
                try {
                    return prefix + decodeURIComponent(suffix);
                }
                catch (error) {
                    onError(String(error));
                    return null;
                }
            }
            if (handle === '!')
                return source; // local tag
            onError(`Could not resolve tag: ${source}`);
            return null;
        }
        /**
         * Given a fully resolved tag, returns its printable string form,
         * taking into account current tag prefixes and defaults.
         */
        tagString(tag) {
            for (const [handle, prefix] of Object.entries(this.tags)) {
                if (tag.startsWith(prefix))
                    return handle + escapeTagName(tag.substring(prefix.length));
            }
            return tag[0] === '!' ? tag : `!<${tag}>`;
        }
        toString(doc) {
            const lines = this.yaml.explicit
                ? [`%YAML ${this.yaml.version || '1.2'}`]
                : [];
            const tagEntries = Object.entries(this.tags);
            let tagNames;
            if (doc && tagEntries.length > 0 && isNode(doc.contents)) {
                const tags = {};
                visit$1(doc.contents, (_key, node) => {
                    if (isNode(node) && node.tag)
                        tags[node.tag] = true;
                });
                tagNames = Object.keys(tags);
            }
            else
                tagNames = [];
            for (const [handle, prefix] of tagEntries) {
                if (handle === '!!' && prefix === 'tag:yaml.org,2002:')
                    continue;
                if (!doc || tagNames.some(tn => tn.startsWith(prefix)))
                    lines.push(`%TAG ${handle} ${prefix}`);
            }
            return lines.join('\n');
        }
    }
    Directives.defaultYaml = { explicit: false, version: '1.2' };
    Directives.defaultTags = { '!!': 'tag:yaml.org,2002:' };

    /**
     * Verify that the input string is a valid anchor.
     *
     * Will throw on errors.
     */
    function anchorIsValid(anchor) {
        if (/[\x00-\x19\s,[\]{}]/.test(anchor)) {
            const sa = JSON.stringify(anchor);
            const msg = `Anchor must not contain whitespace or control characters: ${sa}`;
            throw new Error(msg);
        }
        return true;
    }
    function anchorNames(root) {
        const anchors = new Set();
        visit$1(root, {
            Value(_key, node) {
                if (node.anchor)
                    anchors.add(node.anchor);
            }
        });
        return anchors;
    }
    /** Find a new anchor name with the given `prefix` and a one-indexed suffix. */
    function findNewAnchor(prefix, exclude) {
        for (let i = 1; true; ++i) {
            const name = `${prefix}${i}`;
            if (!exclude.has(name))
                return name;
        }
    }
    function createNodeAnchors(doc, prefix) {
        const aliasObjects = [];
        const sourceObjects = new Map();
        let prevAnchors = null;
        return {
            onAnchor: (source) => {
                aliasObjects.push(source);
                if (!prevAnchors)
                    prevAnchors = anchorNames(doc);
                const anchor = findNewAnchor(prefix, prevAnchors);
                prevAnchors.add(anchor);
                return anchor;
            },
            /**
             * With circular references, the source node is only resolved after all
             * of its child nodes are. This is why anchors are set only after all of
             * the nodes have been created.
             */
            setAnchors: () => {
                for (const source of aliasObjects) {
                    const ref = sourceObjects.get(source);
                    if (typeof ref === 'object' &&
                        ref.anchor &&
                        (isScalar$1(ref.node) || isCollection$1(ref.node))) {
                        ref.node.anchor = ref.anchor;
                    }
                    else {
                        const error = new Error('Failed to resolve repeated object (this should not happen)');
                        error.source = source;
                        throw error;
                    }
                }
            },
            sourceObjects
        };
    }

    /**
     * Applies the JSON.parse reviver algorithm as defined in the ECMA-262 spec,
     * in section 24.5.1.1 "Runtime Semantics: InternalizeJSONProperty" of the
     * 2021 edition: https://tc39.es/ecma262/#sec-json.parse
     *
     * Includes extensions for handling Map and Set objects.
     */
    function applyReviver(reviver, obj, key, val) {
        if (val && typeof val === 'object') {
            if (Array.isArray(val)) {
                for (let i = 0, len = val.length; i < len; ++i) {
                    const v0 = val[i];
                    const v1 = applyReviver(reviver, val, String(i), v0);
                    // eslint-disable-next-line @typescript-eslint/no-array-delete
                    if (v1 === undefined)
                        delete val[i];
                    else if (v1 !== v0)
                        val[i] = v1;
                }
            }
            else if (val instanceof Map) {
                for (const k of Array.from(val.keys())) {
                    const v0 = val.get(k);
                    const v1 = applyReviver(reviver, val, k, v0);
                    if (v1 === undefined)
                        val.delete(k);
                    else if (v1 !== v0)
                        val.set(k, v1);
                }
            }
            else if (val instanceof Set) {
                for (const v0 of Array.from(val)) {
                    const v1 = applyReviver(reviver, val, v0, v0);
                    if (v1 === undefined)
                        val.delete(v0);
                    else if (v1 !== v0) {
                        val.delete(v0);
                        val.add(v1);
                    }
                }
            }
            else {
                for (const [k, v0] of Object.entries(val)) {
                    const v1 = applyReviver(reviver, val, k, v0);
                    if (v1 === undefined)
                        delete val[k];
                    else if (v1 !== v0)
                        val[k] = v1;
                }
            }
        }
        return reviver.call(obj, key, val);
    }

    /**
     * Recursively convert any node or its contents to native JavaScript
     *
     * @param value - The input value
     * @param arg - If `value` defines a `toJSON()` method, use this
     *   as its first argument
     * @param ctx - Conversion context, originally set in Document#toJS(). If
     *   `{ keep: true }` is not set, output should be suitable for JSON
     *   stringification.
     */
    function toJS(value, arg, ctx) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-return
        if (Array.isArray(value))
            return value.map((v, i) => toJS(v, String(i), ctx));
        if (value && typeof value.toJSON === 'function') {
            // eslint-disable-next-line @typescript-eslint/no-unsafe-call
            if (!ctx || !hasAnchor(value))
                return value.toJSON(arg, ctx);
            const data = { aliasCount: 0, count: 1, res: undefined };
            ctx.anchors.set(value, data);
            ctx.onCreate = res => {
                data.res = res;
                delete ctx.onCreate;
            };
            const res = value.toJSON(arg, ctx);
            if (ctx.onCreate)
                ctx.onCreate(res);
            return res;
        }
        if (typeof value === 'bigint' && !ctx?.keep)
            return Number(value);
        return value;
    }

    class NodeBase {
        constructor(type) {
            Object.defineProperty(this, NODE_TYPE, { value: type });
        }
        /** Create a copy of this node.  */
        clone() {
            const copy = Object.create(Object.getPrototypeOf(this), Object.getOwnPropertyDescriptors(this));
            if (this.range)
                copy.range = this.range.slice();
            return copy;
        }
        /** A plain JavaScript representation of this node. */
        toJS(doc, { mapAsMap, maxAliasCount, onAnchor, reviver } = {}) {
            if (!isDocument(doc))
                throw new TypeError('A document argument is required');
            const ctx = {
                anchors: new Map(),
                doc,
                keep: true,
                mapAsMap: mapAsMap === true,
                mapKeyWarned: false,
                maxAliasCount: typeof maxAliasCount === 'number' ? maxAliasCount : 100
            };
            const res = toJS(this, '', ctx);
            if (typeof onAnchor === 'function')
                for (const { count, res } of ctx.anchors.values())
                    onAnchor(res, count);
            return typeof reviver === 'function'
                ? applyReviver(reviver, { '': res }, '', res)
                : res;
        }
    }

    class Alias extends NodeBase {
        constructor(source) {
            super(ALIAS);
            this.source = source;
            Object.defineProperty(this, 'tag', {
                set() {
                    throw new Error('Alias nodes cannot have tags');
                }
            });
        }
        /**
         * Resolve the value of this alias within `doc`, finding the last
         * instance of the `source` anchor before this node.
         */
        resolve(doc) {
            let found = undefined;
            visit$1(doc, {
                Node: (_key, node) => {
                    if (node === this)
                        return visit$1.BREAK;
                    if (node.anchor === this.source)
                        found = node;
                }
            });
            return found;
        }
        toJSON(_arg, ctx) {
            if (!ctx)
                return { source: this.source };
            const { anchors, doc, maxAliasCount } = ctx;
            const source = this.resolve(doc);
            if (!source) {
                const msg = `Unresolved alias (the anchor must be set before the alias): ${this.source}`;
                throw new ReferenceError(msg);
            }
            let data = anchors.get(source);
            if (!data) {
                // Resolve anchors for Node.prototype.toJS()
                toJS(source, null, ctx);
                data = anchors.get(source);
            }
            /* istanbul ignore if */
            if (!data || data.res === undefined) {
                const msg = 'This should not happen: Alias anchor was not resolved?';
                throw new ReferenceError(msg);
            }
            if (maxAliasCount >= 0) {
                data.count += 1;
                if (data.aliasCount === 0)
                    data.aliasCount = getAliasCount(doc, source, anchors);
                if (data.count * data.aliasCount > maxAliasCount) {
                    const msg = 'Excessive alias count indicates a resource exhaustion attack';
                    throw new ReferenceError(msg);
                }
            }
            return data.res;
        }
        toString(ctx, _onComment, _onChompKeep) {
            const src = `*${this.source}`;
            if (ctx) {
                anchorIsValid(this.source);
                if (ctx.options.verifyAliasOrder && !ctx.anchors.has(this.source)) {
                    const msg = `Unresolved alias (the anchor must be set before the alias): ${this.source}`;
                    throw new Error(msg);
                }
                if (ctx.implicitKey)
                    return `${src} `;
            }
            return src;
        }
    }
    function getAliasCount(doc, node, anchors) {
        if (isAlias(node)) {
            const source = node.resolve(doc);
            const anchor = anchors && source && anchors.get(source);
            return anchor ? anchor.count * anchor.aliasCount : 0;
        }
        else if (isCollection$1(node)) {
            let count = 0;
            for (const item of node.items) {
                const c = getAliasCount(doc, item, anchors);
                if (c > count)
                    count = c;
            }
            return count;
        }
        else if (isPair(node)) {
            const kc = getAliasCount(doc, node.key, anchors);
            const vc = getAliasCount(doc, node.value, anchors);
            return Math.max(kc, vc);
        }
        return 1;
    }

    const isScalarValue = (value) => !value || (typeof value !== 'function' && typeof value !== 'object');
    class Scalar extends NodeBase {
        constructor(value) {
            super(SCALAR$1);
            this.value = value;
        }
        toJSON(arg, ctx) {
            return ctx?.keep ? this.value : toJS(this.value, arg, ctx);
        }
        toString() {
            return String(this.value);
        }
    }
    Scalar.BLOCK_FOLDED = 'BLOCK_FOLDED';
    Scalar.BLOCK_LITERAL = 'BLOCK_LITERAL';
    Scalar.PLAIN = 'PLAIN';
    Scalar.QUOTE_DOUBLE = 'QUOTE_DOUBLE';
    Scalar.QUOTE_SINGLE = 'QUOTE_SINGLE';

    const defaultTagPrefix = 'tag:yaml.org,2002:';
    function findTagObject(value, tagName, tags) {
        if (tagName) {
            const match = tags.filter(t => t.tag === tagName);
            const tagObj = match.find(t => !t.format) ?? match[0];
            if (!tagObj)
                throw new Error(`Tag ${tagName} not found`);
            return tagObj;
        }
        return tags.find(t => t.identify?.(value) && !t.format);
    }
    function createNode(value, tagName, ctx) {
        if (isDocument(value))
            value = value.contents;
        if (isNode(value))
            return value;
        if (isPair(value)) {
            const map = ctx.schema[MAP].createNode?.(ctx.schema, null, ctx);
            map.items.push(value);
            return map;
        }
        if (value instanceof String ||
            value instanceof Number ||
            value instanceof Boolean ||
            (typeof BigInt !== 'undefined' && value instanceof BigInt) // not supported everywhere
        ) {
            // https://tc39.es/ecma262/#sec-serializejsonproperty
            value = value.valueOf();
        }
        const { aliasDuplicateObjects, onAnchor, onTagObj, schema, sourceObjects } = ctx;
        // Detect duplicate references to the same object & use Alias nodes for all
        // after first. The `ref` wrapper allows for circular references to resolve.
        let ref = undefined;
        if (aliasDuplicateObjects && value && typeof value === 'object') {
            ref = sourceObjects.get(value);
            if (ref) {
                if (!ref.anchor)
                    ref.anchor = onAnchor(value);
                return new Alias(ref.anchor);
            }
            else {
                ref = { anchor: null, node: null };
                sourceObjects.set(value, ref);
            }
        }
        if (tagName?.startsWith('!!'))
            tagName = defaultTagPrefix + tagName.slice(2);
        let tagObj = findTagObject(value, tagName, schema.tags);
        if (!tagObj) {
            if (value && typeof value.toJSON === 'function') {
                // eslint-disable-next-line @typescript-eslint/no-unsafe-call
                value = value.toJSON();
            }
            if (!value || typeof value !== 'object') {
                const node = new Scalar(value);
                if (ref)
                    ref.node = node;
                return node;
            }
            tagObj =
                value instanceof Map
                    ? schema[MAP]
                    : Symbol.iterator in Object(value)
                        ? schema[SEQ]
                        : schema[MAP];
        }
        if (onTagObj) {
            onTagObj(tagObj);
            delete ctx.onTagObj;
        }
        const node = tagObj?.createNode
            ? tagObj.createNode(ctx.schema, value, ctx)
            : typeof tagObj?.nodeClass?.from === 'function'
                ? tagObj.nodeClass.from(ctx.schema, value, ctx)
                : new Scalar(value);
        if (tagName)
            node.tag = tagName;
        else if (!tagObj.default)
            node.tag = tagObj.tag;
        if (ref)
            ref.node = node;
        return node;
    }

    function collectionFromPath(schema, path, value) {
        let v = value;
        for (let i = path.length - 1; i >= 0; --i) {
            const k = path[i];
            if (typeof k === 'number' && Number.isInteger(k) && k >= 0) {
                const a = [];
                a[k] = v;
                v = a;
            }
            else {
                v = new Map([[k, v]]);
            }
        }
        return createNode(v, undefined, {
            aliasDuplicateObjects: false,
            keepUndefined: false,
            onAnchor: () => {
                throw new Error('This should not happen, please report a bug.');
            },
            schema,
            sourceObjects: new Map()
        });
    }
    // Type guard is intentionally a little wrong so as to be more useful,
    // as it does not cover untypable empty non-string iterables (e.g. []).
    const isEmptyPath = (path) => path == null ||
        (typeof path === 'object' && !!path[Symbol.iterator]().next().done);
    class Collection extends NodeBase {
        constructor(type, schema) {
            super(type);
            Object.defineProperty(this, 'schema', {
                value: schema,
                configurable: true,
                enumerable: false,
                writable: true
            });
        }
        /**
         * Create a copy of this collection.
         *
         * @param schema - If defined, overwrites the original's schema
         */
        clone(schema) {
            const copy = Object.create(Object.getPrototypeOf(this), Object.getOwnPropertyDescriptors(this));
            if (schema)
                copy.schema = schema;
            copy.items = copy.items.map(it => isNode(it) || isPair(it) ? it.clone(schema) : it);
            if (this.range)
                copy.range = this.range.slice();
            return copy;
        }
        /**
         * Adds a value to the collection. For `!!map` and `!!omap` the value must
         * be a Pair instance or a `{ key, value }` object, which may not have a key
         * that already exists in the map.
         */
        addIn(path, value) {
            if (isEmptyPath(path))
                this.add(value);
            else {
                const [key, ...rest] = path;
                const node = this.get(key, true);
                if (isCollection$1(node))
                    node.addIn(rest, value);
                else if (node === undefined && this.schema)
                    this.set(key, collectionFromPath(this.schema, rest, value));
                else
                    throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
            }
        }
        /**
         * Removes a value from the collection.
         * @returns `true` if the item was found and removed.
         */
        deleteIn(path) {
            const [key, ...rest] = path;
            if (rest.length === 0)
                return this.delete(key);
            const node = this.get(key, true);
            if (isCollection$1(node))
                return node.deleteIn(rest);
            else
                throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
        }
        /**
         * Returns item at `key`, or `undefined` if not found. By default unwraps
         * scalar values from their surrounding node; to disable set `keepScalar` to
         * `true` (collections are always returned intact).
         */
        getIn(path, keepScalar) {
            const [key, ...rest] = path;
            const node = this.get(key, true);
            if (rest.length === 0)
                return !keepScalar && isScalar$1(node) ? node.value : node;
            else
                return isCollection$1(node) ? node.getIn(rest, keepScalar) : undefined;
        }
        hasAllNullValues(allowScalar) {
            return this.items.every(node => {
                if (!isPair(node))
                    return false;
                const n = node.value;
                return (n == null ||
                    (allowScalar &&
                        isScalar$1(n) &&
                        n.value == null &&
                        !n.commentBefore &&
                        !n.comment &&
                        !n.tag));
            });
        }
        /**
         * Checks if the collection includes a value with the key `key`.
         */
        hasIn(path) {
            const [key, ...rest] = path;
            if (rest.length === 0)
                return this.has(key);
            const node = this.get(key, true);
            return isCollection$1(node) ? node.hasIn(rest) : false;
        }
        /**
         * Sets a value in this collection. For `!!set`, `value` needs to be a
         * boolean to add/remove the item from the set.
         */
        setIn(path, value) {
            const [key, ...rest] = path;
            if (rest.length === 0) {
                this.set(key, value);
            }
            else {
                const node = this.get(key, true);
                if (isCollection$1(node))
                    node.setIn(rest, value);
                else if (node === undefined && this.schema)
                    this.set(key, collectionFromPath(this.schema, rest, value));
                else
                    throw new Error(`Expected YAML collection at ${key}. Remaining path: ${rest}`);
            }
        }
    }

    /**
     * Stringifies a comment.
     *
     * Empty comment lines are left empty,
     * lines consisting of a single space are replaced by `#`,
     * and all other lines are prefixed with a `#`.
     */
    const stringifyComment = (str) => str.replace(/^(?!$)(?: $)?/gm, '#');
    function indentComment(comment, indent) {
        if (/^\n+$/.test(comment))
            return comment.substring(1);
        return indent ? comment.replace(/^(?! *$)/gm, indent) : comment;
    }
    const lineComment = (str, indent, comment) => str.endsWith('\n')
        ? indentComment(comment, indent)
        : comment.includes('\n')
            ? '\n' + indentComment(comment, indent)
            : (str.endsWith(' ') ? '' : ' ') + comment;

    const FOLD_FLOW = 'flow';
    const FOLD_BLOCK = 'block';
    const FOLD_QUOTED = 'quoted';
    /**
     * Tries to keep input at up to `lineWidth` characters, splitting only on spaces
     * not followed by newlines or spaces unless `mode` is `'quoted'`. Lines are
     * terminated with `\n` and started with `indent`.
     */
    function foldFlowLines(text, indent, mode = 'flow', { indentAtStart, lineWidth = 80, minContentWidth = 20, onFold, onOverflow } = {}) {
        if (!lineWidth || lineWidth < 0)
            return text;
        if (lineWidth < minContentWidth)
            minContentWidth = 0;
        const endStep = Math.max(1 + minContentWidth, 1 + lineWidth - indent.length);
        if (text.length <= endStep)
            return text;
        const folds = [];
        const escapedFolds = {};
        let end = lineWidth - indent.length;
        if (typeof indentAtStart === 'number') {
            if (indentAtStart > lineWidth - Math.max(2, minContentWidth))
                folds.push(0);
            else
                end = lineWidth - indentAtStart;
        }
        let split = undefined;
        let prev = undefined;
        let overflow = false;
        let i = -1;
        let escStart = -1;
        let escEnd = -1;
        if (mode === FOLD_BLOCK) {
            i = consumeMoreIndentedLines(text, i, indent.length);
            if (i !== -1)
                end = i + endStep;
        }
        for (let ch; (ch = text[(i += 1)]);) {
            if (mode === FOLD_QUOTED && ch === '\\') {
                escStart = i;
                switch (text[i + 1]) {
                    case 'x':
                        i += 3;
                        break;
                    case 'u':
                        i += 5;
                        break;
                    case 'U':
                        i += 9;
                        break;
                    default:
                        i += 1;
                }
                escEnd = i;
            }
            if (ch === '\n') {
                if (mode === FOLD_BLOCK)
                    i = consumeMoreIndentedLines(text, i, indent.length);
                end = i + indent.length + endStep;
                split = undefined;
            }
            else {
                if (ch === ' ' &&
                    prev &&
                    prev !== ' ' &&
                    prev !== '\n' &&
                    prev !== '\t') {
                    // space surrounded by non-space can be replaced with newline + indent
                    const next = text[i + 1];
                    if (next && next !== ' ' && next !== '\n' && next !== '\t')
                        split = i;
                }
                if (i >= end) {
                    if (split) {
                        folds.push(split);
                        end = split + endStep;
                        split = undefined;
                    }
                    else if (mode === FOLD_QUOTED) {
                        // white-space collected at end may stretch past lineWidth
                        while (prev === ' ' || prev === '\t') {
                            prev = ch;
                            ch = text[(i += 1)];
                            overflow = true;
                        }
                        // Account for newline escape, but don't break preceding escape
                        const j = i > escEnd + 1 ? i - 2 : escStart - 1;
                        // Bail out if lineWidth & minContentWidth are shorter than an escape string
                        if (escapedFolds[j])
                            return text;
                        folds.push(j);
                        escapedFolds[j] = true;
                        end = j + endStep;
                        split = undefined;
                    }
                    else {
                        overflow = true;
                    }
                }
            }
            prev = ch;
        }
        if (overflow && onOverflow)
            onOverflow();
        if (folds.length === 0)
            return text;
        if (onFold)
            onFold();
        let res = text.slice(0, folds[0]);
        for (let i = 0; i < folds.length; ++i) {
            const fold = folds[i];
            const end = folds[i + 1] || text.length;
            if (fold === 0)
                res = `\n${indent}${text.slice(0, end)}`;
            else {
                if (mode === FOLD_QUOTED && escapedFolds[fold])
                    res += `${text[fold]}\\`;
                res += `\n${indent}${text.slice(fold + 1, end)}`;
            }
        }
        return res;
    }
    /**
     * Presumes `i + 1` is at the start of a line
     * @returns index of last newline in more-indented block
     */
    function consumeMoreIndentedLines(text, i, indent) {
        let end = i;
        let start = i + 1;
        let ch = text[start];
        while (ch === ' ' || ch === '\t') {
            if (i < start + indent) {
                ch = text[++i];
            }
            else {
                do {
                    ch = text[++i];
                } while (ch && ch !== '\n');
                end = i;
                start = i + 1;
                ch = text[start];
            }
        }
        return end;
    }

    const getFoldOptions = (ctx, isBlock) => ({
        indentAtStart: isBlock ? ctx.indent.length : ctx.indentAtStart,
        lineWidth: ctx.options.lineWidth,
        minContentWidth: ctx.options.minContentWidth
    });
    // Also checks for lines starting with %, as parsing the output as YAML 1.1 will
    // presume that's starting a new document.
    const containsDocumentMarker = (str) => /^(%|---|\.\.\.)/m.test(str);
    function lineLengthOverLimit(str, lineWidth, indentLength) {
        if (!lineWidth || lineWidth < 0)
            return false;
        const limit = lineWidth - indentLength;
        const strLen = str.length;
        if (strLen <= limit)
            return false;
        for (let i = 0, start = 0; i < strLen; ++i) {
            if (str[i] === '\n') {
                if (i - start > limit)
                    return true;
                start = i + 1;
                if (strLen - start <= limit)
                    return false;
            }
        }
        return true;
    }
    function doubleQuotedString(value, ctx) {
        const json = JSON.stringify(value);
        if (ctx.options.doubleQuotedAsJSON)
            return json;
        const { implicitKey } = ctx;
        const minMultiLineLength = ctx.options.doubleQuotedMinMultiLineLength;
        const indent = ctx.indent || (containsDocumentMarker(value) ? '  ' : '');
        let str = '';
        let start = 0;
        for (let i = 0, ch = json[i]; ch; ch = json[++i]) {
            if (ch === ' ' && json[i + 1] === '\\' && json[i + 2] === 'n') {
                // space before newline needs to be escaped to not be folded
                str += json.slice(start, i) + '\\ ';
                i += 1;
                start = i;
                ch = '\\';
            }
            if (ch === '\\')
                switch (json[i + 1]) {
                    case 'u':
                        {
                            str += json.slice(start, i);
                            const code = json.substr(i + 2, 4);
                            switch (code) {
                                case '0000':
                                    str += '\\0';
                                    break;
                                case '0007':
                                    str += '\\a';
                                    break;
                                case '000b':
                                    str += '\\v';
                                    break;
                                case '001b':
                                    str += '\\e';
                                    break;
                                case '0085':
                                    str += '\\N';
                                    break;
                                case '00a0':
                                    str += '\\_';
                                    break;
                                case '2028':
                                    str += '\\L';
                                    break;
                                case '2029':
                                    str += '\\P';
                                    break;
                                default:
                                    if (code.substr(0, 2) === '00')
                                        str += '\\x' + code.substr(2);
                                    else
                                        str += json.substr(i, 6);
                            }
                            i += 5;
                            start = i + 1;
                        }
                        break;
                    case 'n':
                        if (implicitKey ||
                            json[i + 2] === '"' ||
                            json.length < minMultiLineLength) {
                            i += 1;
                        }
                        else {
                            // folding will eat first newline
                            str += json.slice(start, i) + '\n\n';
                            while (json[i + 2] === '\\' &&
                                json[i + 3] === 'n' &&
                                json[i + 4] !== '"') {
                                str += '\n';
                                i += 2;
                            }
                            str += indent;
                            // space after newline needs to be escaped to not be folded
                            if (json[i + 2] === ' ')
                                str += '\\';
                            i += 1;
                            start = i + 1;
                        }
                        break;
                    default:
                        i += 1;
                }
        }
        str = start ? str + json.slice(start) : json;
        return implicitKey
            ? str
            : foldFlowLines(str, indent, FOLD_QUOTED, getFoldOptions(ctx, false));
    }
    function singleQuotedString(value, ctx) {
        if (ctx.options.singleQuote === false ||
            (ctx.implicitKey && value.includes('\n')) ||
            /[ \t]\n|\n[ \t]/.test(value) // single quoted string can't have leading or trailing whitespace around newline
        )
            return doubleQuotedString(value, ctx);
        const indent = ctx.indent || (containsDocumentMarker(value) ? '  ' : '');
        const res = "'" + value.replace(/'/g, "''").replace(/\n+/g, `$&\n${indent}`) + "'";
        return ctx.implicitKey
            ? res
            : foldFlowLines(res, indent, FOLD_FLOW, getFoldOptions(ctx, false));
    }
    function quotedString(value, ctx) {
        const { singleQuote } = ctx.options;
        let qs;
        if (singleQuote === false)
            qs = doubleQuotedString;
        else {
            const hasDouble = value.includes('"');
            const hasSingle = value.includes("'");
            if (hasDouble && !hasSingle)
                qs = singleQuotedString;
            else if (hasSingle && !hasDouble)
                qs = doubleQuotedString;
            else
                qs = singleQuote ? singleQuotedString : doubleQuotedString;
        }
        return qs(value, ctx);
    }
    // The negative lookbehind avoids a polynomial search,
    // but isn't supported yet on Safari: https://caniuse.com/js-regexp-lookbehind
    let blockEndNewlines;
    try {
        blockEndNewlines = new RegExp('(^|(?<!\n))\n+(?!\n|$)', 'g');
    }
    catch {
        blockEndNewlines = /\n+(?!\n|$)/g;
    }
    function blockString({ comment, type, value }, ctx, onComment, onChompKeep) {
        const { blockQuote, commentString, lineWidth } = ctx.options;
        // 1. Block can't end in whitespace unless the last line is non-empty.
        // 2. Strings consisting of only whitespace are best rendered explicitly.
        if (!blockQuote || /\n[\t ]+$/.test(value) || /^\s*$/.test(value)) {
            return quotedString(value, ctx);
        }
        const indent = ctx.indent ||
            (ctx.forceBlockIndent || containsDocumentMarker(value) ? '  ' : '');
        const literal = blockQuote === 'literal'
            ? true
            : blockQuote === 'folded' || type === Scalar.BLOCK_FOLDED
                ? false
                : type === Scalar.BLOCK_LITERAL
                    ? true
                    : !lineLengthOverLimit(value, lineWidth, indent.length);
        if (!value)
            return literal ? '|\n' : '>\n';
        // determine chomping from whitespace at value end
        let chomp;
        let endStart;
        for (endStart = value.length; endStart > 0; --endStart) {
            const ch = value[endStart - 1];
            if (ch !== '\n' && ch !== '\t' && ch !== ' ')
                break;
        }
        let end = value.substring(endStart);
        const endNlPos = end.indexOf('\n');
        if (endNlPos === -1) {
            chomp = '-'; // strip
        }
        else if (value === end || endNlPos !== end.length - 1) {
            chomp = '+'; // keep
            if (onChompKeep)
                onChompKeep();
        }
        else {
            chomp = ''; // clip
        }
        if (end) {
            value = value.slice(0, -end.length);
            if (end[end.length - 1] === '\n')
                end = end.slice(0, -1);
            end = end.replace(blockEndNewlines, `$&${indent}`);
        }
        // determine indent indicator from whitespace at value start
        let startWithSpace = false;
        let startEnd;
        let startNlPos = -1;
        for (startEnd = 0; startEnd < value.length; ++startEnd) {
            const ch = value[startEnd];
            if (ch === ' ')
                startWithSpace = true;
            else if (ch === '\n')
                startNlPos = startEnd;
            else
                break;
        }
        let start = value.substring(0, startNlPos < startEnd ? startNlPos + 1 : startEnd);
        if (start) {
            value = value.substring(start.length);
            start = start.replace(/\n+/g, `$&${indent}`);
        }
        const indentSize = indent ? '2' : '1'; // root is at -1
        let header = (literal ? '|' : '>') + (startWithSpace ? indentSize : '') + chomp;
        if (comment) {
            header += ' ' + commentString(comment.replace(/ ?[\r\n]+/g, ' '));
            if (onComment)
                onComment();
        }
        if (literal) {
            value = value.replace(/\n+/g, `$&${indent}`);
            return `${header}\n${indent}${start}${value}${end}`;
        }
        value = value
            .replace(/\n+/g, '\n$&')
            .replace(/(?:^|\n)([\t ].*)(?:([\n\t ]*)\n(?![\n\t ]))?/g, '$1$2') // more-indented lines aren't folded
            //                ^ more-ind. ^ empty     ^ capture next empty lines only at end of indent
            .replace(/\n+/g, `$&${indent}`);
        const body = foldFlowLines(`${start}${value}${end}`, indent, FOLD_BLOCK, getFoldOptions(ctx, true));
        return `${header}\n${indent}${body}`;
    }
    function plainString(item, ctx, onComment, onChompKeep) {
        const { type, value } = item;
        const { actualString, implicitKey, indent, indentStep, inFlow } = ctx;
        if ((implicitKey && value.includes('\n')) ||
            (inFlow && /[[\]{},]/.test(value))) {
            return quotedString(value, ctx);
        }
        if (!value ||
            /^[\n\t ,[\]{}#&*!|>'"%@`]|^[?-]$|^[?-][ \t]|[\n:][ \t]|[ \t]\n|[\n\t ]#|[\n\t :]$/.test(value)) {
            // not allowed:
            // - empty string, '-' or '?'
            // - start with an indicator character (except [?:-]) or /[?-] /
            // - '\n ', ': ' or ' \n' anywhere
            // - '#' not preceded by a non-space char
            // - end with ' ' or ':'
            return implicitKey || inFlow || !value.includes('\n')
                ? quotedString(value, ctx)
                : blockString(item, ctx, onComment, onChompKeep);
        }
        if (!implicitKey &&
            !inFlow &&
            type !== Scalar.PLAIN &&
            value.includes('\n')) {
            // Where allowed & type not set explicitly, prefer block style for multiline strings
            return blockString(item, ctx, onComment, onChompKeep);
        }
        if (containsDocumentMarker(value)) {
            if (indent === '') {
                ctx.forceBlockIndent = true;
                return blockString(item, ctx, onComment, onChompKeep);
            }
            else if (implicitKey && indent === indentStep) {
                return quotedString(value, ctx);
            }
        }
        const str = value.replace(/\n+/g, `$&\n${indent}`);
        // Verify that output will be parsed as a string, as e.g. plain numbers and
        // booleans get parsed with those types in v1.2 (e.g. '42', 'true' & '0.9e-3'),
        // and others in v1.1.
        if (actualString) {
            const test = (tag) => tag.default && tag.tag !== 'tag:yaml.org,2002:str' && tag.test?.test(str);
            const { compat, tags } = ctx.doc.schema;
            if (tags.some(test) || compat?.some(test))
                return quotedString(value, ctx);
        }
        return implicitKey
            ? str
            : foldFlowLines(str, indent, FOLD_FLOW, getFoldOptions(ctx, false));
    }
    function stringifyString(item, ctx, onComment, onChompKeep) {
        const { implicitKey, inFlow } = ctx;
        const ss = typeof item.value === 'string'
            ? item
            : Object.assign({}, item, { value: String(item.value) });
        let { type } = item;
        if (type !== Scalar.QUOTE_DOUBLE) {
            // force double quotes on control characters & unpaired surrogates
            if (/[\x00-\x08\x0b-\x1f\x7f-\x9f\u{D800}-\u{DFFF}]/u.test(ss.value))
                type = Scalar.QUOTE_DOUBLE;
        }
        const _stringify = (_type) => {
            switch (_type) {
                case Scalar.BLOCK_FOLDED:
                case Scalar.BLOCK_LITERAL:
                    return implicitKey || inFlow
                        ? quotedString(ss.value, ctx) // blocks are not valid inside flow containers
                        : blockString(ss, ctx, onComment, onChompKeep);
                case Scalar.QUOTE_DOUBLE:
                    return doubleQuotedString(ss.value, ctx);
                case Scalar.QUOTE_SINGLE:
                    return singleQuotedString(ss.value, ctx);
                case Scalar.PLAIN:
                    return plainString(ss, ctx, onComment, onChompKeep);
                default:
                    return null;
            }
        };
        let res = _stringify(type);
        if (res === null) {
            const { defaultKeyType, defaultStringType } = ctx.options;
            const t = (implicitKey && defaultKeyType) || defaultStringType;
            res = _stringify(t);
            if (res === null)
                throw new Error(`Unsupported default string type ${t}`);
        }
        return res;
    }

    function createStringifyContext(doc, options) {
        const opt = Object.assign({
            blockQuote: true,
            commentString: stringifyComment,
            defaultKeyType: null,
            defaultStringType: 'PLAIN',
            directives: null,
            doubleQuotedAsJSON: false,
            doubleQuotedMinMultiLineLength: 40,
            falseStr: 'false',
            flowCollectionPadding: true,
            indentSeq: true,
            lineWidth: 80,
            minContentWidth: 20,
            nullStr: 'null',
            simpleKeys: false,
            singleQuote: null,
            trueStr: 'true',
            verifyAliasOrder: true
        }, doc.schema.toStringOptions, options);
        let inFlow;
        switch (opt.collectionStyle) {
            case 'block':
                inFlow = false;
                break;
            case 'flow':
                inFlow = true;
                break;
            default:
                inFlow = null;
        }
        return {
            anchors: new Set(),
            doc,
            flowCollectionPadding: opt.flowCollectionPadding ? ' ' : '',
            indent: '',
            indentStep: typeof opt.indent === 'number' ? ' '.repeat(opt.indent) : '  ',
            inFlow,
            options: opt
        };
    }
    function getTagObject(tags, item) {
        if (item.tag) {
            const match = tags.filter(t => t.tag === item.tag);
            if (match.length > 0)
                return match.find(t => t.format === item.format) ?? match[0];
        }
        let tagObj = undefined;
        let obj;
        if (isScalar$1(item)) {
            obj = item.value;
            const match = tags.filter(t => t.identify?.(obj));
            tagObj =
                match.find(t => t.format === item.format) ?? match.find(t => !t.format);
        }
        else {
            obj = item;
            tagObj = tags.find(t => t.nodeClass && obj instanceof t.nodeClass);
        }
        if (!tagObj) {
            const name = obj?.constructor?.name ?? typeof obj;
            throw new Error(`Tag not resolved for ${name} value`);
        }
        return tagObj;
    }
    // needs to be called before value stringifier to allow for circular anchor refs
    function stringifyProps(node, tagObj, { anchors, doc }) {
        if (!doc.directives)
            return '';
        const props = [];
        const anchor = (isScalar$1(node) || isCollection$1(node)) && node.anchor;
        if (anchor && anchorIsValid(anchor)) {
            anchors.add(anchor);
            props.push(`&${anchor}`);
        }
        const tag = node.tag ? node.tag : tagObj.default ? null : tagObj.tag;
        if (tag)
            props.push(doc.directives.tagString(tag));
        return props.join(' ');
    }
    function stringify$2(item, ctx, onComment, onChompKeep) {
        if (isPair(item))
            return item.toString(ctx, onComment, onChompKeep);
        if (isAlias(item)) {
            if (ctx.doc.directives)
                return item.toString(ctx);
            if (ctx.resolvedAliases?.has(item)) {
                throw new TypeError(`Cannot stringify circular structure without alias nodes`);
            }
            else {
                if (ctx.resolvedAliases)
                    ctx.resolvedAliases.add(item);
                else
                    ctx.resolvedAliases = new Set([item]);
                item = item.resolve(ctx.doc);
            }
        }
        let tagObj = undefined;
        const node = isNode(item)
            ? item
            : ctx.doc.createNode(item, { onTagObj: o => (tagObj = o) });
        if (!tagObj)
            tagObj = getTagObject(ctx.doc.schema.tags, node);
        const props = stringifyProps(node, tagObj, ctx);
        if (props.length > 0)
            ctx.indentAtStart = (ctx.indentAtStart ?? 0) + props.length + 1;
        const str = typeof tagObj.stringify === 'function'
            ? tagObj.stringify(node, ctx, onComment, onChompKeep)
            : isScalar$1(node)
                ? stringifyString(node, ctx, onComment, onChompKeep)
                : node.toString(ctx, onComment, onChompKeep);
        if (!props)
            return str;
        return isScalar$1(node) || str[0] === '{' || str[0] === '['
            ? `${props} ${str}`
            : `${props}\n${ctx.indent}${str}`;
    }

    function stringifyPair({ key, value }, ctx, onComment, onChompKeep) {
        const { allNullValues, doc, indent, indentStep, options: { commentString, indentSeq, simpleKeys } } = ctx;
        let keyComment = (isNode(key) && key.comment) || null;
        if (simpleKeys) {
            if (keyComment) {
                throw new Error('With simple keys, key nodes cannot have comments');
            }
            if (isCollection$1(key) || (!isNode(key) && typeof key === 'object')) {
                const msg = 'With simple keys, collection cannot be used as a key value';
                throw new Error(msg);
            }
        }
        let explicitKey = !simpleKeys &&
            (!key ||
                (keyComment && value == null && !ctx.inFlow) ||
                isCollection$1(key) ||
                (isScalar$1(key)
                    ? key.type === Scalar.BLOCK_FOLDED || key.type === Scalar.BLOCK_LITERAL
                    : typeof key === 'object'));
        ctx = Object.assign({}, ctx, {
            allNullValues: false,
            implicitKey: !explicitKey && (simpleKeys || !allNullValues),
            indent: indent + indentStep
        });
        let keyCommentDone = false;
        let chompKeep = false;
        let str = stringify$2(key, ctx, () => (keyCommentDone = true), () => (chompKeep = true));
        if (!explicitKey && !ctx.inFlow && str.length > 1024) {
            if (simpleKeys)
                throw new Error('With simple keys, single line scalar must not span more than 1024 characters');
            explicitKey = true;
        }
        if (ctx.inFlow) {
            if (allNullValues || value == null) {
                if (keyCommentDone && onComment)
                    onComment();
                return str === '' ? '?' : explicitKey ? `? ${str}` : str;
            }
        }
        else if ((allNullValues && !simpleKeys) || (value == null && explicitKey)) {
            str = `? ${str}`;
            if (keyComment && !keyCommentDone) {
                str += lineComment(str, ctx.indent, commentString(keyComment));
            }
            else if (chompKeep && onChompKeep)
                onChompKeep();
            return str;
        }
        if (keyCommentDone)
            keyComment = null;
        if (explicitKey) {
            if (keyComment)
                str += lineComment(str, ctx.indent, commentString(keyComment));
            str = `? ${str}\n${indent}:`;
        }
        else {
            str = `${str}:`;
            if (keyComment)
                str += lineComment(str, ctx.indent, commentString(keyComment));
        }
        let vsb, vcb, valueComment;
        if (isNode(value)) {
            vsb = !!value.spaceBefore;
            vcb = value.commentBefore;
            valueComment = value.comment;
        }
        else {
            vsb = false;
            vcb = null;
            valueComment = null;
            if (value && typeof value === 'object')
                value = doc.createNode(value);
        }
        ctx.implicitKey = false;
        if (!explicitKey && !keyComment && isScalar$1(value))
            ctx.indentAtStart = str.length + 1;
        chompKeep = false;
        if (!indentSeq &&
            indentStep.length >= 2 &&
            !ctx.inFlow &&
            !explicitKey &&
            isSeq(value) &&
            !value.flow &&
            !value.tag &&
            !value.anchor) {
            // If indentSeq === false, consider '- ' as part of indentation where possible
            ctx.indent = ctx.indent.substring(2);
        }
        let valueCommentDone = false;
        const valueStr = stringify$2(value, ctx, () => (valueCommentDone = true), () => (chompKeep = true));
        let ws = ' ';
        if (keyComment || vsb || vcb) {
            ws = vsb ? '\n' : '';
            if (vcb) {
                const cs = commentString(vcb);
                ws += `\n${indentComment(cs, ctx.indent)}`;
            }
            if (valueStr === '' && !ctx.inFlow) {
                if (ws === '\n')
                    ws = '\n\n';
            }
            else {
                ws += `\n${ctx.indent}`;
            }
        }
        else if (!explicitKey && isCollection$1(value)) {
            const vs0 = valueStr[0];
            const nl0 = valueStr.indexOf('\n');
            const hasNewline = nl0 !== -1;
            const flow = ctx.inFlow ?? value.flow ?? value.items.length === 0;
            if (hasNewline || !flow) {
                let hasPropsLine = false;
                if (hasNewline && (vs0 === '&' || vs0 === '!')) {
                    let sp0 = valueStr.indexOf(' ');
                    if (vs0 === '&' &&
                        sp0 !== -1 &&
                        sp0 < nl0 &&
                        valueStr[sp0 + 1] === '!') {
                        sp0 = valueStr.indexOf(' ', sp0 + 1);
                    }
                    if (sp0 === -1 || nl0 < sp0)
                        hasPropsLine = true;
                }
                if (!hasPropsLine)
                    ws = `\n${ctx.indent}`;
            }
        }
        else if (valueStr === '' || valueStr[0] === '\n') {
            ws = '';
        }
        str += ws + valueStr;
        if (ctx.inFlow) {
            if (valueCommentDone && onComment)
                onComment();
        }
        else if (valueComment && !valueCommentDone) {
            str += lineComment(str, ctx.indent, commentString(valueComment));
        }
        else if (chompKeep && onChompKeep) {
            onChompKeep();
        }
        return str;
    }

    function warn(logLevel, warning) {
        if (logLevel === 'debug' || logLevel === 'warn') {
            if (typeof process !== 'undefined' && process.emitWarning)
                process.emitWarning(warning);
            else
                console.warn(warning);
        }
    }

    const MERGE_KEY = '<<';
    function addPairToJSMap(ctx, map, { key, value }) {
        if (ctx?.doc.schema.merge && isMergeKey(key)) {
            value = isAlias(value) ? value.resolve(ctx.doc) : value;
            if (isSeq(value))
                for (const it of value.items)
                    mergeToJSMap(ctx, map, it);
            else if (Array.isArray(value))
                for (const it of value)
                    mergeToJSMap(ctx, map, it);
            else
                mergeToJSMap(ctx, map, value);
        }
        else {
            const jsKey = toJS(key, '', ctx);
            if (map instanceof Map) {
                map.set(jsKey, toJS(value, jsKey, ctx));
            }
            else if (map instanceof Set) {
                map.add(jsKey);
            }
            else {
                const stringKey = stringifyKey(key, jsKey, ctx);
                const jsValue = toJS(value, stringKey, ctx);
                if (stringKey in map)
                    Object.defineProperty(map, stringKey, {
                        value: jsValue,
                        writable: true,
                        enumerable: true,
                        configurable: true
                    });
                else
                    map[stringKey] = jsValue;
            }
        }
        return map;
    }
    const isMergeKey = (key) => key === MERGE_KEY ||
        (isScalar$1(key) &&
            key.value === MERGE_KEY &&
            (!key.type || key.type === Scalar.PLAIN));
    // If the value associated with a merge key is a single mapping node, each of
    // its key/value pairs is inserted into the current mapping, unless the key
    // already exists in it. If the value associated with the merge key is a
    // sequence, then this sequence is expected to contain mapping nodes and each
    // of these nodes is merged in turn according to its order in the sequence.
    // Keys in mapping nodes earlier in the sequence override keys specified in
    // later mapping nodes. -- http://yaml.org/type/merge.html
    function mergeToJSMap(ctx, map, value) {
        const source = ctx && isAlias(value) ? value.resolve(ctx.doc) : value;
        if (!isMap(source))
            throw new Error('Merge sources must be maps or map aliases');
        const srcMap = source.toJSON(null, ctx, Map);
        for (const [key, value] of srcMap) {
            if (map instanceof Map) {
                if (!map.has(key))
                    map.set(key, value);
            }
            else if (map instanceof Set) {
                map.add(key);
            }
            else if (!Object.prototype.hasOwnProperty.call(map, key)) {
                Object.defineProperty(map, key, {
                    value,
                    writable: true,
                    enumerable: true,
                    configurable: true
                });
            }
        }
        return map;
    }
    function stringifyKey(key, jsKey, ctx) {
        if (jsKey === null)
            return '';
        if (typeof jsKey !== 'object')
            return String(jsKey);
        if (isNode(key) && ctx?.doc) {
            const strCtx = createStringifyContext(ctx.doc, {});
            strCtx.anchors = new Set();
            for (const node of ctx.anchors.keys())
                strCtx.anchors.add(node.anchor);
            strCtx.inFlow = true;
            strCtx.inStringifyKey = true;
            const strKey = key.toString(strCtx);
            if (!ctx.mapKeyWarned) {
                let jsonStr = JSON.stringify(strKey);
                if (jsonStr.length > 40)
                    jsonStr = jsonStr.substring(0, 36) + '..."';
                warn(ctx.doc.options.logLevel, `Keys with collection values will be stringified due to JS Object restrictions: ${jsonStr}. Set mapAsMap: true to use object keys.`);
                ctx.mapKeyWarned = true;
            }
            return strKey;
        }
        return JSON.stringify(jsKey);
    }

    function createPair(key, value, ctx) {
        const k = createNode(key, undefined, ctx);
        const v = createNode(value, undefined, ctx);
        return new Pair(k, v);
    }
    class Pair {
        constructor(key, value = null) {
            Object.defineProperty(this, NODE_TYPE, { value: PAIR });
            this.key = key;
            this.value = value;
        }
        clone(schema) {
            let { key, value } = this;
            if (isNode(key))
                key = key.clone(schema);
            if (isNode(value))
                value = value.clone(schema);
            return new Pair(key, value);
        }
        toJSON(_, ctx) {
            const pair = ctx?.mapAsMap ? new Map() : {};
            return addPairToJSMap(ctx, pair, this);
        }
        toString(ctx, onComment, onChompKeep) {
            return ctx?.doc
                ? stringifyPair(this, ctx, onComment, onChompKeep)
                : JSON.stringify(this);
        }
    }

    function stringifyCollection(collection, ctx, options) {
        const flow = ctx.inFlow ?? collection.flow;
        const stringify = flow ? stringifyFlowCollection : stringifyBlockCollection;
        return stringify(collection, ctx, options);
    }
    function stringifyBlockCollection({ comment, items }, ctx, { blockItemPrefix, flowChars, itemIndent, onChompKeep, onComment }) {
        const { indent, options: { commentString } } = ctx;
        const itemCtx = Object.assign({}, ctx, { indent: itemIndent, type: null });
        let chompKeep = false; // flag for the preceding node's status
        const lines = [];
        for (let i = 0; i < items.length; ++i) {
            const item = items[i];
            let comment = null;
            if (isNode(item)) {
                if (!chompKeep && item.spaceBefore)
                    lines.push('');
                addCommentBefore(ctx, lines, item.commentBefore, chompKeep);
                if (item.comment)
                    comment = item.comment;
            }
            else if (isPair(item)) {
                const ik = isNode(item.key) ? item.key : null;
                if (ik) {
                    if (!chompKeep && ik.spaceBefore)
                        lines.push('');
                    addCommentBefore(ctx, lines, ik.commentBefore, chompKeep);
                }
            }
            chompKeep = false;
            let str = stringify$2(item, itemCtx, () => (comment = null), () => (chompKeep = true));
            if (comment)
                str += lineComment(str, itemIndent, commentString(comment));
            if (chompKeep && comment)
                chompKeep = false;
            lines.push(blockItemPrefix + str);
        }
        let str;
        if (lines.length === 0) {
            str = flowChars.start + flowChars.end;
        }
        else {
            str = lines[0];
            for (let i = 1; i < lines.length; ++i) {
                const line = lines[i];
                str += line ? `\n${indent}${line}` : '\n';
            }
        }
        if (comment) {
            str += '\n' + indentComment(commentString(comment), indent);
            if (onComment)
                onComment();
        }
        else if (chompKeep && onChompKeep)
            onChompKeep();
        return str;
    }
    function stringifyFlowCollection({ items }, ctx, { flowChars, itemIndent }) {
        const { indent, indentStep, flowCollectionPadding: fcPadding, options: { commentString } } = ctx;
        itemIndent += indentStep;
        const itemCtx = Object.assign({}, ctx, {
            indent: itemIndent,
            inFlow: true,
            type: null
        });
        let reqNewline = false;
        let linesAtValue = 0;
        const lines = [];
        for (let i = 0; i < items.length; ++i) {
            const item = items[i];
            let comment = null;
            if (isNode(item)) {
                if (item.spaceBefore)
                    lines.push('');
                addCommentBefore(ctx, lines, item.commentBefore, false);
                if (item.comment)
                    comment = item.comment;
            }
            else if (isPair(item)) {
                const ik = isNode(item.key) ? item.key : null;
                if (ik) {
                    if (ik.spaceBefore)
                        lines.push('');
                    addCommentBefore(ctx, lines, ik.commentBefore, false);
                    if (ik.comment)
                        reqNewline = true;
                }
                const iv = isNode(item.value) ? item.value : null;
                if (iv) {
                    if (iv.comment)
                        comment = iv.comment;
                    if (iv.commentBefore)
                        reqNewline = true;
                }
                else if (item.value == null && ik?.comment) {
                    comment = ik.comment;
                }
            }
            if (comment)
                reqNewline = true;
            let str = stringify$2(item, itemCtx, () => (comment = null));
            if (i < items.length - 1)
                str += ',';
            if (comment)
                str += lineComment(str, itemIndent, commentString(comment));
            if (!reqNewline && (lines.length > linesAtValue || str.includes('\n')))
                reqNewline = true;
            lines.push(str);
            linesAtValue = lines.length;
        }
        const { start, end } = flowChars;
        if (lines.length === 0) {
            return start + end;
        }
        else {
            if (!reqNewline) {
                const len = lines.reduce((sum, line) => sum + line.length + 2, 2);
                reqNewline = ctx.options.lineWidth > 0 && len > ctx.options.lineWidth;
            }
            if (reqNewline) {
                let str = start;
                for (const line of lines)
                    str += line ? `\n${indentStep}${indent}${line}` : '\n';
                return `${str}\n${indent}${end}`;
            }
            else {
                return `${start}${fcPadding}${lines.join(' ')}${fcPadding}${end}`;
            }
        }
    }
    function addCommentBefore({ indent, options: { commentString } }, lines, comment, chompKeep) {
        if (comment && chompKeep)
            comment = comment.replace(/^\n+/, '');
        if (comment) {
            const ic = indentComment(commentString(comment), indent);
            lines.push(ic.trimStart()); // Avoid double indent on first line
        }
    }

    function findPair(items, key) {
        const k = isScalar$1(key) ? key.value : key;
        for (const it of items) {
            if (isPair(it)) {
                if (it.key === key || it.key === k)
                    return it;
                if (isScalar$1(it.key) && it.key.value === k)
                    return it;
            }
        }
        return undefined;
    }
    class YAMLMap extends Collection {
        static get tagName() {
            return 'tag:yaml.org,2002:map';
        }
        constructor(schema) {
            super(MAP, schema);
            this.items = [];
        }
        /**
         * A generic collection parsing method that can be extended
         * to other node classes that inherit from YAMLMap
         */
        static from(schema, obj, ctx) {
            const { keepUndefined, replacer } = ctx;
            const map = new this(schema);
            const add = (key, value) => {
                if (typeof replacer === 'function')
                    value = replacer.call(obj, key, value);
                else if (Array.isArray(replacer) && !replacer.includes(key))
                    return;
                if (value !== undefined || keepUndefined)
                    map.items.push(createPair(key, value, ctx));
            };
            if (obj instanceof Map) {
                for (const [key, value] of obj)
                    add(key, value);
            }
            else if (obj && typeof obj === 'object') {
                for (const key of Object.keys(obj))
                    add(key, obj[key]);
            }
            if (typeof schema.sortMapEntries === 'function') {
                map.items.sort(schema.sortMapEntries);
            }
            return map;
        }
        /**
         * Adds a value to the collection.
         *
         * @param overwrite - If not set `true`, using a key that is already in the
         *   collection will throw. Otherwise, overwrites the previous value.
         */
        add(pair, overwrite) {
            let _pair;
            if (isPair(pair))
                _pair = pair;
            else if (!pair || typeof pair !== 'object' || !('key' in pair)) {
                // In TypeScript, this never happens.
                _pair = new Pair(pair, pair?.value);
            }
            else
                _pair = new Pair(pair.key, pair.value);
            const prev = findPair(this.items, _pair.key);
            const sortEntries = this.schema?.sortMapEntries;
            if (prev) {
                if (!overwrite)
                    throw new Error(`Key ${_pair.key} already set`);
                // For scalars, keep the old node & its comments and anchors
                if (isScalar$1(prev.value) && isScalarValue(_pair.value))
                    prev.value.value = _pair.value;
                else
                    prev.value = _pair.value;
            }
            else if (sortEntries) {
                const i = this.items.findIndex(item => sortEntries(_pair, item) < 0);
                if (i === -1)
                    this.items.push(_pair);
                else
                    this.items.splice(i, 0, _pair);
            }
            else {
                this.items.push(_pair);
            }
        }
        delete(key) {
            const it = findPair(this.items, key);
            if (!it)
                return false;
            const del = this.items.splice(this.items.indexOf(it), 1);
            return del.length > 0;
        }
        get(key, keepScalar) {
            const it = findPair(this.items, key);
            const node = it?.value;
            return (!keepScalar && isScalar$1(node) ? node.value : node) ?? undefined;
        }
        has(key) {
            return !!findPair(this.items, key);
        }
        set(key, value) {
            this.add(new Pair(key, value), true);
        }
        /**
         * @param ctx - Conversion context, originally set in Document#toJS()
         * @param {Class} Type - If set, forces the returned collection type
         * @returns Instance of Type, Map, or Object
         */
        toJSON(_, ctx, Type) {
            const map = Type ? new Type() : ctx?.mapAsMap ? new Map() : {};
            if (ctx?.onCreate)
                ctx.onCreate(map);
            for (const item of this.items)
                addPairToJSMap(ctx, map, item);
            return map;
        }
        toString(ctx, onComment, onChompKeep) {
            if (!ctx)
                return JSON.stringify(this);
            for (const item of this.items) {
                if (!isPair(item))
                    throw new Error(`Map items must all be pairs; found ${JSON.stringify(item)} instead`);
            }
            if (!ctx.allNullValues && this.hasAllNullValues(false))
                ctx = Object.assign({}, ctx, { allNullValues: true });
            return stringifyCollection(this, ctx, {
                blockItemPrefix: '',
                flowChars: { start: '{', end: '}' },
                itemIndent: ctx.indent || '',
                onChompKeep,
                onComment
            });
        }
    }

    const map = {
        collection: 'map',
        default: true,
        nodeClass: YAMLMap,
        tag: 'tag:yaml.org,2002:map',
        resolve(map, onError) {
            if (!isMap(map))
                onError('Expected a mapping for this tag');
            return map;
        },
        createNode: (schema, obj, ctx) => YAMLMap.from(schema, obj, ctx)
    };

    class YAMLSeq extends Collection {
        static get tagName() {
            return 'tag:yaml.org,2002:seq';
        }
        constructor(schema) {
            super(SEQ, schema);
            this.items = [];
        }
        add(value) {
            this.items.push(value);
        }
        /**
         * Removes a value from the collection.
         *
         * `key` must contain a representation of an integer for this to succeed.
         * It may be wrapped in a `Scalar`.
         *
         * @returns `true` if the item was found and removed.
         */
        delete(key) {
            const idx = asItemIndex(key);
            if (typeof idx !== 'number')
                return false;
            const del = this.items.splice(idx, 1);
            return del.length > 0;
        }
        get(key, keepScalar) {
            const idx = asItemIndex(key);
            if (typeof idx !== 'number')
                return undefined;
            const it = this.items[idx];
            return !keepScalar && isScalar$1(it) ? it.value : it;
        }
        /**
         * Checks if the collection includes a value with the key `key`.
         *
         * `key` must contain a representation of an integer for this to succeed.
         * It may be wrapped in a `Scalar`.
         */
        has(key) {
            const idx = asItemIndex(key);
            return typeof idx === 'number' && idx < this.items.length;
        }
        /**
         * Sets a value in this collection. For `!!set`, `value` needs to be a
         * boolean to add/remove the item from the set.
         *
         * If `key` does not contain a representation of an integer, this will throw.
         * It may be wrapped in a `Scalar`.
         */
        set(key, value) {
            const idx = asItemIndex(key);
            if (typeof idx !== 'number')
                throw new Error(`Expected a valid index, not ${key}.`);
            const prev = this.items[idx];
            if (isScalar$1(prev) && isScalarValue(value))
                prev.value = value;
            else
                this.items[idx] = value;
        }
        toJSON(_, ctx) {
            const seq = [];
            if (ctx?.onCreate)
                ctx.onCreate(seq);
            let i = 0;
            for (const item of this.items)
                seq.push(toJS(item, String(i++), ctx));
            return seq;
        }
        toString(ctx, onComment, onChompKeep) {
            if (!ctx)
                return JSON.stringify(this);
            return stringifyCollection(this, ctx, {
                blockItemPrefix: '- ',
                flowChars: { start: '[', end: ']' },
                itemIndent: (ctx.indent || '') + '  ',
                onChompKeep,
                onComment
            });
        }
        static from(schema, obj, ctx) {
            const { replacer } = ctx;
            const seq = new this(schema);
            if (obj && Symbol.iterator in Object(obj)) {
                let i = 0;
                for (let it of obj) {
                    if (typeof replacer === 'function') {
                        const key = obj instanceof Set ? it : String(i++);
                        it = replacer.call(obj, key, it);
                    }
                    seq.items.push(createNode(it, undefined, ctx));
                }
            }
            return seq;
        }
    }
    function asItemIndex(key) {
        let idx = isScalar$1(key) ? key.value : key;
        if (idx && typeof idx === 'string')
            idx = Number(idx);
        return typeof idx === 'number' && Number.isInteger(idx) && idx >= 0
            ? idx
            : null;
    }

    const seq = {
        collection: 'seq',
        default: true,
        nodeClass: YAMLSeq,
        tag: 'tag:yaml.org,2002:seq',
        resolve(seq, onError) {
            if (!isSeq(seq))
                onError('Expected a sequence for this tag');
            return seq;
        },
        createNode: (schema, obj, ctx) => YAMLSeq.from(schema, obj, ctx)
    };

    const string = {
        identify: value => typeof value === 'string',
        default: true,
        tag: 'tag:yaml.org,2002:str',
        resolve: str => str,
        stringify(item, ctx, onComment, onChompKeep) {
            ctx = Object.assign({ actualString: true }, ctx);
            return stringifyString(item, ctx, onComment, onChompKeep);
        }
    };

    const nullTag = {
        identify: value => value == null,
        createNode: () => new Scalar(null),
        default: true,
        tag: 'tag:yaml.org,2002:null',
        test: /^(?:~|[Nn]ull|NULL)?$/,
        resolve: () => new Scalar(null),
        stringify: ({ source }, ctx) => typeof source === 'string' && nullTag.test.test(source)
            ? source
            : ctx.options.nullStr
    };

    const boolTag = {
        identify: value => typeof value === 'boolean',
        default: true,
        tag: 'tag:yaml.org,2002:bool',
        test: /^(?:[Tt]rue|TRUE|[Ff]alse|FALSE)$/,
        resolve: str => new Scalar(str[0] === 't' || str[0] === 'T'),
        stringify({ source, value }, ctx) {
            if (source && boolTag.test.test(source)) {
                const sv = source[0] === 't' || source[0] === 'T';
                if (value === sv)
                    return source;
            }
            return value ? ctx.options.trueStr : ctx.options.falseStr;
        }
    };

    function stringifyNumber({ format, minFractionDigits, tag, value }) {
        if (typeof value === 'bigint')
            return String(value);
        const num = typeof value === 'number' ? value : Number(value);
        if (!isFinite(num))
            return isNaN(num) ? '.nan' : num < 0 ? '-.inf' : '.inf';
        let n = JSON.stringify(value);
        if (!format &&
            minFractionDigits &&
            (!tag || tag === 'tag:yaml.org,2002:float') &&
            /^\d/.test(n)) {
            let i = n.indexOf('.');
            if (i < 0) {
                i = n.length;
                n += '.';
            }
            let d = minFractionDigits - (n.length - i - 1);
            while (d-- > 0)
                n += '0';
        }
        return n;
    }

    const floatNaN$1 = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        test: /^(?:[-+]?\.(?:inf|Inf|INF)|\.nan|\.NaN|\.NAN)$/,
        resolve: str => str.slice(-3).toLowerCase() === 'nan'
            ? NaN
            : str[0] === '-'
                ? Number.NEGATIVE_INFINITY
                : Number.POSITIVE_INFINITY,
        stringify: stringifyNumber
    };
    const floatExp$1 = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        format: 'EXP',
        test: /^[-+]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)[eE][-+]?[0-9]+$/,
        resolve: str => parseFloat(str),
        stringify(node) {
            const num = Number(node.value);
            return isFinite(num) ? num.toExponential() : stringifyNumber(node);
        }
    };
    const float$1 = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        test: /^[-+]?(?:\.[0-9]+|[0-9]+\.[0-9]*)$/,
        resolve(str) {
            const node = new Scalar(parseFloat(str));
            const dot = str.indexOf('.');
            if (dot !== -1 && str[str.length - 1] === '0')
                node.minFractionDigits = str.length - dot - 1;
            return node;
        },
        stringify: stringifyNumber
    };

    const intIdentify$2 = (value) => typeof value === 'bigint' || Number.isInteger(value);
    const intResolve$1 = (str, offset, radix, { intAsBigInt }) => (intAsBigInt ? BigInt(str) : parseInt(str.substring(offset), radix));
    function intStringify$1(node, radix, prefix) {
        const { value } = node;
        if (intIdentify$2(value) && value >= 0)
            return prefix + value.toString(radix);
        return stringifyNumber(node);
    }
    const intOct$1 = {
        identify: value => intIdentify$2(value) && value >= 0,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        format: 'OCT',
        test: /^0o[0-7]+$/,
        resolve: (str, _onError, opt) => intResolve$1(str, 2, 8, opt),
        stringify: node => intStringify$1(node, 8, '0o')
    };
    const int$1 = {
        identify: intIdentify$2,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        test: /^[-+]?[0-9]+$/,
        resolve: (str, _onError, opt) => intResolve$1(str, 0, 10, opt),
        stringify: stringifyNumber
    };
    const intHex$1 = {
        identify: value => intIdentify$2(value) && value >= 0,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        format: 'HEX',
        test: /^0x[0-9a-fA-F]+$/,
        resolve: (str, _onError, opt) => intResolve$1(str, 2, 16, opt),
        stringify: node => intStringify$1(node, 16, '0x')
    };

    const schema$2 = [
        map,
        seq,
        string,
        nullTag,
        boolTag,
        intOct$1,
        int$1,
        intHex$1,
        floatNaN$1,
        floatExp$1,
        float$1
    ];

    function intIdentify$1(value) {
        return typeof value === 'bigint' || Number.isInteger(value);
    }
    const stringifyJSON = ({ value }) => JSON.stringify(value);
    const jsonScalars = [
        {
            identify: value => typeof value === 'string',
            default: true,
            tag: 'tag:yaml.org,2002:str',
            resolve: str => str,
            stringify: stringifyJSON
        },
        {
            identify: value => value == null,
            createNode: () => new Scalar(null),
            default: true,
            tag: 'tag:yaml.org,2002:null',
            test: /^null$/,
            resolve: () => null,
            stringify: stringifyJSON
        },
        {
            identify: value => typeof value === 'boolean',
            default: true,
            tag: 'tag:yaml.org,2002:bool',
            test: /^true|false$/,
            resolve: str => str === 'true',
            stringify: stringifyJSON
        },
        {
            identify: intIdentify$1,
            default: true,
            tag: 'tag:yaml.org,2002:int',
            test: /^-?(?:0|[1-9][0-9]*)$/,
            resolve: (str, _onError, { intAsBigInt }) => intAsBigInt ? BigInt(str) : parseInt(str, 10),
            stringify: ({ value }) => intIdentify$1(value) ? value.toString() : JSON.stringify(value)
        },
        {
            identify: value => typeof value === 'number',
            default: true,
            tag: 'tag:yaml.org,2002:float',
            test: /^-?(?:0|[1-9][0-9]*)(?:\.[0-9]*)?(?:[eE][-+]?[0-9]+)?$/,
            resolve: str => parseFloat(str),
            stringify: stringifyJSON
        }
    ];
    const jsonError = {
        default: true,
        tag: '',
        test: /^/,
        resolve(str, onError) {
            onError(`Unresolved plain scalar ${JSON.stringify(str)}`);
            return str;
        }
    };
    const schema$1 = [map, seq].concat(jsonScalars, jsonError);

    const binary = {
        identify: value => value instanceof Uint8Array, // Buffer inherits from Uint8Array
        default: false,
        tag: 'tag:yaml.org,2002:binary',
        /**
         * Returns a Buffer in node and an Uint8Array in browsers
         *
         * To use the resulting buffer as an image, you'll want to do something like:
         *
         *   const blob = new Blob([buffer], { type: 'image/jpeg' })
         *   document.querySelector('#photo').src = URL.createObjectURL(blob)
         */
        resolve(src, onError) {
            if (typeof Buffer === 'function') {
                return Buffer.from(src, 'base64');
            }
            else if (typeof atob === 'function') {
                // On IE 11, atob() can't handle newlines
                const str = atob(src.replace(/[\n\r]/g, ''));
                const buffer = new Uint8Array(str.length);
                for (let i = 0; i < str.length; ++i)
                    buffer[i] = str.charCodeAt(i);
                return buffer;
            }
            else {
                onError('This environment does not support reading binary tags; either Buffer or atob is required');
                return src;
            }
        },
        stringify({ comment, type, value }, ctx, onComment, onChompKeep) {
            const buf = value; // checked earlier by binary.identify()
            let str;
            if (typeof Buffer === 'function') {
                str =
                    buf instanceof Buffer
                        ? buf.toString('base64')
                        : Buffer.from(buf.buffer).toString('base64');
            }
            else if (typeof btoa === 'function') {
                let s = '';
                for (let i = 0; i < buf.length; ++i)
                    s += String.fromCharCode(buf[i]);
                str = btoa(s);
            }
            else {
                throw new Error('This environment does not support writing binary tags; either Buffer or btoa is required');
            }
            if (!type)
                type = Scalar.BLOCK_LITERAL;
            if (type !== Scalar.QUOTE_DOUBLE) {
                const lineWidth = Math.max(ctx.options.lineWidth - ctx.indent.length, ctx.options.minContentWidth);
                const n = Math.ceil(str.length / lineWidth);
                const lines = new Array(n);
                for (let i = 0, o = 0; i < n; ++i, o += lineWidth) {
                    lines[i] = str.substr(o, lineWidth);
                }
                str = lines.join(type === Scalar.BLOCK_LITERAL ? '\n' : ' ');
            }
            return stringifyString({ comment, type, value: str }, ctx, onComment, onChompKeep);
        }
    };

    function resolvePairs(seq, onError) {
        if (isSeq(seq)) {
            for (let i = 0; i < seq.items.length; ++i) {
                let item = seq.items[i];
                if (isPair(item))
                    continue;
                else if (isMap(item)) {
                    if (item.items.length > 1)
                        onError('Each pair must have its own sequence indicator');
                    const pair = item.items[0] || new Pair(new Scalar(null));
                    if (item.commentBefore)
                        pair.key.commentBefore = pair.key.commentBefore
                            ? `${item.commentBefore}\n${pair.key.commentBefore}`
                            : item.commentBefore;
                    if (item.comment) {
                        const cn = pair.value ?? pair.key;
                        cn.comment = cn.comment
                            ? `${item.comment}\n${cn.comment}`
                            : item.comment;
                    }
                    item = pair;
                }
                seq.items[i] = isPair(item) ? item : new Pair(item);
            }
        }
        else
            onError('Expected a sequence for this tag');
        return seq;
    }
    function createPairs(schema, iterable, ctx) {
        const { replacer } = ctx;
        const pairs = new YAMLSeq(schema);
        pairs.tag = 'tag:yaml.org,2002:pairs';
        let i = 0;
        if (iterable && Symbol.iterator in Object(iterable))
            for (let it of iterable) {
                if (typeof replacer === 'function')
                    it = replacer.call(iterable, String(i++), it);
                let key, value;
                if (Array.isArray(it)) {
                    if (it.length === 2) {
                        key = it[0];
                        value = it[1];
                    }
                    else
                        throw new TypeError(`Expected [key, value] tuple: ${it}`);
                }
                else if (it && it instanceof Object) {
                    const keys = Object.keys(it);
                    if (keys.length === 1) {
                        key = keys[0];
                        value = it[key];
                    }
                    else {
                        throw new TypeError(`Expected tuple with one key, not ${keys.length} keys`);
                    }
                }
                else {
                    key = it;
                }
                pairs.items.push(createPair(key, value, ctx));
            }
        return pairs;
    }
    const pairs = {
        collection: 'seq',
        default: false,
        tag: 'tag:yaml.org,2002:pairs',
        resolve: resolvePairs,
        createNode: createPairs
    };

    class YAMLOMap extends YAMLSeq {
        constructor() {
            super();
            this.add = YAMLMap.prototype.add.bind(this);
            this.delete = YAMLMap.prototype.delete.bind(this);
            this.get = YAMLMap.prototype.get.bind(this);
            this.has = YAMLMap.prototype.has.bind(this);
            this.set = YAMLMap.prototype.set.bind(this);
            this.tag = YAMLOMap.tag;
        }
        /**
         * If `ctx` is given, the return type is actually `Map<unknown, unknown>`,
         * but TypeScript won't allow widening the signature of a child method.
         */
        toJSON(_, ctx) {
            if (!ctx)
                return super.toJSON(_);
            const map = new Map();
            if (ctx?.onCreate)
                ctx.onCreate(map);
            for (const pair of this.items) {
                let key, value;
                if (isPair(pair)) {
                    key = toJS(pair.key, '', ctx);
                    value = toJS(pair.value, key, ctx);
                }
                else {
                    key = toJS(pair, '', ctx);
                }
                if (map.has(key))
                    throw new Error('Ordered maps must not include duplicate keys');
                map.set(key, value);
            }
            return map;
        }
        static from(schema, iterable, ctx) {
            const pairs = createPairs(schema, iterable, ctx);
            const omap = new this();
            omap.items = pairs.items;
            return omap;
        }
    }
    YAMLOMap.tag = 'tag:yaml.org,2002:omap';
    const omap = {
        collection: 'seq',
        identify: value => value instanceof Map,
        nodeClass: YAMLOMap,
        default: false,
        tag: 'tag:yaml.org,2002:omap',
        resolve(seq, onError) {
            const pairs = resolvePairs(seq, onError);
            const seenKeys = [];
            for (const { key } of pairs.items) {
                if (isScalar$1(key)) {
                    if (seenKeys.includes(key.value)) {
                        onError(`Ordered maps must not include duplicate keys: ${key.value}`);
                    }
                    else {
                        seenKeys.push(key.value);
                    }
                }
            }
            return Object.assign(new YAMLOMap(), pairs);
        },
        createNode: (schema, iterable, ctx) => YAMLOMap.from(schema, iterable, ctx)
    };

    function boolStringify({ value, source }, ctx) {
        const boolObj = value ? trueTag : falseTag;
        if (source && boolObj.test.test(source))
            return source;
        return value ? ctx.options.trueStr : ctx.options.falseStr;
    }
    const trueTag = {
        identify: value => value === true,
        default: true,
        tag: 'tag:yaml.org,2002:bool',
        test: /^(?:Y|y|[Yy]es|YES|[Tt]rue|TRUE|[Oo]n|ON)$/,
        resolve: () => new Scalar(true),
        stringify: boolStringify
    };
    const falseTag = {
        identify: value => value === false,
        default: true,
        tag: 'tag:yaml.org,2002:bool',
        test: /^(?:N|n|[Nn]o|NO|[Ff]alse|FALSE|[Oo]ff|OFF)$/,
        resolve: () => new Scalar(false),
        stringify: boolStringify
    };

    const floatNaN = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        test: /^(?:[-+]?\.(?:inf|Inf|INF)|\.nan|\.NaN|\.NAN)$/,
        resolve: (str) => str.slice(-3).toLowerCase() === 'nan'
            ? NaN
            : str[0] === '-'
                ? Number.NEGATIVE_INFINITY
                : Number.POSITIVE_INFINITY,
        stringify: stringifyNumber
    };
    const floatExp = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        format: 'EXP',
        test: /^[-+]?(?:[0-9][0-9_]*)?(?:\.[0-9_]*)?[eE][-+]?[0-9]+$/,
        resolve: (str) => parseFloat(str.replace(/_/g, '')),
        stringify(node) {
            const num = Number(node.value);
            return isFinite(num) ? num.toExponential() : stringifyNumber(node);
        }
    };
    const float = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        test: /^[-+]?(?:[0-9][0-9_]*)?\.[0-9_]*$/,
        resolve(str) {
            const node = new Scalar(parseFloat(str.replace(/_/g, '')));
            const dot = str.indexOf('.');
            if (dot !== -1) {
                const f = str.substring(dot + 1).replace(/_/g, '');
                if (f[f.length - 1] === '0')
                    node.minFractionDigits = f.length;
            }
            return node;
        },
        stringify: stringifyNumber
    };

    const intIdentify = (value) => typeof value === 'bigint' || Number.isInteger(value);
    function intResolve(str, offset, radix, { intAsBigInt }) {
        const sign = str[0];
        if (sign === '-' || sign === '+')
            offset += 1;
        str = str.substring(offset).replace(/_/g, '');
        if (intAsBigInt) {
            switch (radix) {
                case 2:
                    str = `0b${str}`;
                    break;
                case 8:
                    str = `0o${str}`;
                    break;
                case 16:
                    str = `0x${str}`;
                    break;
            }
            const n = BigInt(str);
            return sign === '-' ? BigInt(-1) * n : n;
        }
        const n = parseInt(str, radix);
        return sign === '-' ? -1 * n : n;
    }
    function intStringify(node, radix, prefix) {
        const { value } = node;
        if (intIdentify(value)) {
            const str = value.toString(radix);
            return value < 0 ? '-' + prefix + str.substr(1) : prefix + str;
        }
        return stringifyNumber(node);
    }
    const intBin = {
        identify: intIdentify,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        format: 'BIN',
        test: /^[-+]?0b[0-1_]+$/,
        resolve: (str, _onError, opt) => intResolve(str, 2, 2, opt),
        stringify: node => intStringify(node, 2, '0b')
    };
    const intOct = {
        identify: intIdentify,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        format: 'OCT',
        test: /^[-+]?0[0-7_]+$/,
        resolve: (str, _onError, opt) => intResolve(str, 1, 8, opt),
        stringify: node => intStringify(node, 8, '0')
    };
    const int = {
        identify: intIdentify,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        test: /^[-+]?[0-9][0-9_]*$/,
        resolve: (str, _onError, opt) => intResolve(str, 0, 10, opt),
        stringify: stringifyNumber
    };
    const intHex = {
        identify: intIdentify,
        default: true,
        tag: 'tag:yaml.org,2002:int',
        format: 'HEX',
        test: /^[-+]?0x[0-9a-fA-F_]+$/,
        resolve: (str, _onError, opt) => intResolve(str, 2, 16, opt),
        stringify: node => intStringify(node, 16, '0x')
    };

    class YAMLSet extends YAMLMap {
        constructor(schema) {
            super(schema);
            this.tag = YAMLSet.tag;
        }
        add(key) {
            let pair;
            if (isPair(key))
                pair = key;
            else if (key &&
                typeof key === 'object' &&
                'key' in key &&
                'value' in key &&
                key.value === null)
                pair = new Pair(key.key, null);
            else
                pair = new Pair(key, null);
            const prev = findPair(this.items, pair.key);
            if (!prev)
                this.items.push(pair);
        }
        /**
         * If `keepPair` is `true`, returns the Pair matching `key`.
         * Otherwise, returns the value of that Pair's key.
         */
        get(key, keepPair) {
            const pair = findPair(this.items, key);
            return !keepPair && isPair(pair)
                ? isScalar$1(pair.key)
                    ? pair.key.value
                    : pair.key
                : pair;
        }
        set(key, value) {
            if (typeof value !== 'boolean')
                throw new Error(`Expected boolean value for set(key, value) in a YAML set, not ${typeof value}`);
            const prev = findPair(this.items, key);
            if (prev && !value) {
                this.items.splice(this.items.indexOf(prev), 1);
            }
            else if (!prev && value) {
                this.items.push(new Pair(key));
            }
        }
        toJSON(_, ctx) {
            return super.toJSON(_, ctx, Set);
        }
        toString(ctx, onComment, onChompKeep) {
            if (!ctx)
                return JSON.stringify(this);
            if (this.hasAllNullValues(true))
                return super.toString(Object.assign({}, ctx, { allNullValues: true }), onComment, onChompKeep);
            else
                throw new Error('Set items must all have null values');
        }
        static from(schema, iterable, ctx) {
            const { replacer } = ctx;
            const set = new this(schema);
            if (iterable && Symbol.iterator in Object(iterable))
                for (let value of iterable) {
                    if (typeof replacer === 'function')
                        value = replacer.call(iterable, value, value);
                    set.items.push(createPair(value, null, ctx));
                }
            return set;
        }
    }
    YAMLSet.tag = 'tag:yaml.org,2002:set';
    const set = {
        collection: 'map',
        identify: value => value instanceof Set,
        nodeClass: YAMLSet,
        default: false,
        tag: 'tag:yaml.org,2002:set',
        createNode: (schema, iterable, ctx) => YAMLSet.from(schema, iterable, ctx),
        resolve(map, onError) {
            if (isMap(map)) {
                if (map.hasAllNullValues(true))
                    return Object.assign(new YAMLSet(), map);
                else
                    onError('Set items must all have null values');
            }
            else
                onError('Expected a mapping for this tag');
            return map;
        }
    };

    /** Internal types handle bigint as number, because TS can't figure it out. */
    function parseSexagesimal(str, asBigInt) {
        const sign = str[0];
        const parts = sign === '-' || sign === '+' ? str.substring(1) : str;
        const num = (n) => asBigInt ? BigInt(n) : Number(n);
        const res = parts
            .replace(/_/g, '')
            .split(':')
            .reduce((res, p) => res * num(60) + num(p), num(0));
        return (sign === '-' ? num(-1) * res : res);
    }
    /**
     * hhhh:mm:ss.sss
     *
     * Internal types handle bigint as number, because TS can't figure it out.
     */
    function stringifySexagesimal(node) {
        let { value } = node;
        let num = (n) => n;
        if (typeof value === 'bigint')
            num = n => BigInt(n);
        else if (isNaN(value) || !isFinite(value))
            return stringifyNumber(node);
        let sign = '';
        if (value < 0) {
            sign = '-';
            value *= num(-1);
        }
        const _60 = num(60);
        const parts = [value % _60]; // seconds, including ms
        if (value < 60) {
            parts.unshift(0); // at least one : is required
        }
        else {
            value = (value - parts[0]) / _60;
            parts.unshift(value % _60); // minutes
            if (value >= 60) {
                value = (value - parts[0]) / _60;
                parts.unshift(value); // hours
            }
        }
        return (sign +
            parts
                .map(n => String(n).padStart(2, '0'))
                .join(':')
                .replace(/000000\d*$/, '') // % 60 may introduce error
        );
    }
    const intTime = {
        identify: value => typeof value === 'bigint' || Number.isInteger(value),
        default: true,
        tag: 'tag:yaml.org,2002:int',
        format: 'TIME',
        test: /^[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+$/,
        resolve: (str, _onError, { intAsBigInt }) => parseSexagesimal(str, intAsBigInt),
        stringify: stringifySexagesimal
    };
    const floatTime = {
        identify: value => typeof value === 'number',
        default: true,
        tag: 'tag:yaml.org,2002:float',
        format: 'TIME',
        test: /^[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\.[0-9_]*$/,
        resolve: str => parseSexagesimal(str, false),
        stringify: stringifySexagesimal
    };
    const timestamp = {
        identify: value => value instanceof Date,
        default: true,
        tag: 'tag:yaml.org,2002:timestamp',
        // If the time zone is omitted, the timestamp is assumed to be specified in UTC. The time part
        // may be omitted altogether, resulting in a date format. In such a case, the time part is
        // assumed to be 00:00:00Z (start of day, UTC).
        test: RegExp('^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})' + // YYYY-Mm-Dd
            '(?:' + // time is optional
            '(?:t|T|[ \\t]+)' + // t | T | whitespace
            '([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)' + // Hh:Mm:Ss(.ss)?
            '(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?' + // Z | +5 | -03:30
            ')?$'),
        resolve(str) {
            const match = str.match(timestamp.test);
            if (!match)
                throw new Error('!!timestamp expects a date, starting with yyyy-mm-dd');
            const [, year, month, day, hour, minute, second] = match.map(Number);
            const millisec = match[7] ? Number((match[7] + '00').substr(1, 3)) : 0;
            let date = Date.UTC(year, month - 1, day, hour || 0, minute || 0, second || 0, millisec);
            const tz = match[8];
            if (tz && tz !== 'Z') {
                let d = parseSexagesimal(tz, false);
                if (Math.abs(d) < 30)
                    d *= 60;
                date -= 60000 * d;
            }
            return new Date(date);
        },
        stringify: ({ value }) => value.toISOString().replace(/((T00:00)?:00)?\.000Z$/, '')
    };

    const schema = [
        map,
        seq,
        string,
        nullTag,
        trueTag,
        falseTag,
        intBin,
        intOct,
        int,
        intHex,
        floatNaN,
        floatExp,
        float,
        binary,
        omap,
        pairs,
        set,
        intTime,
        floatTime,
        timestamp
    ];

    const schemas = new Map([
        ['core', schema$2],
        ['failsafe', [map, seq, string]],
        ['json', schema$1],
        ['yaml11', schema],
        ['yaml-1.1', schema]
    ]);
    const tagsByName = {
        binary,
        bool: boolTag,
        float: float$1,
        floatExp: floatExp$1,
        floatNaN: floatNaN$1,
        floatTime,
        int: int$1,
        intHex: intHex$1,
        intOct: intOct$1,
        intTime,
        map,
        null: nullTag,
        omap,
        pairs,
        seq,
        set,
        timestamp
    };
    const coreKnownTags = {
        'tag:yaml.org,2002:binary': binary,
        'tag:yaml.org,2002:omap': omap,
        'tag:yaml.org,2002:pairs': pairs,
        'tag:yaml.org,2002:set': set,
        'tag:yaml.org,2002:timestamp': timestamp
    };
    function getTags(customTags, schemaName) {
        let tags = schemas.get(schemaName);
        if (!tags) {
            if (Array.isArray(customTags))
                tags = [];
            else {
                const keys = Array.from(schemas.keys())
                    .filter(key => key !== 'yaml11')
                    .map(key => JSON.stringify(key))
                    .join(', ');
                throw new Error(`Unknown schema "${schemaName}"; use one of ${keys} or define customTags array`);
            }
        }
        if (Array.isArray(customTags)) {
            for (const tag of customTags)
                tags = tags.concat(tag);
        }
        else if (typeof customTags === 'function') {
            tags = customTags(tags.slice());
        }
        return tags.map(tag => {
            if (typeof tag !== 'string')
                return tag;
            const tagObj = tagsByName[tag];
            if (tagObj)
                return tagObj;
            const keys = Object.keys(tagsByName)
                .map(key => JSON.stringify(key))
                .join(', ');
            throw new Error(`Unknown custom tag "${tag}"; use one of ${keys}`);
        });
    }

    const sortMapEntriesByKey = (a, b) => a.key < b.key ? -1 : a.key > b.key ? 1 : 0;
    class Schema {
        constructor({ compat, customTags, merge, resolveKnownTags, schema, sortMapEntries, toStringDefaults }) {
            this.compat = Array.isArray(compat)
                ? getTags(compat, 'compat')
                : compat
                    ? getTags(null, compat)
                    : null;
            this.merge = !!merge;
            this.name = (typeof schema === 'string' && schema) || 'core';
            this.knownTags = resolveKnownTags ? coreKnownTags : {};
            this.tags = getTags(customTags, this.name);
            this.toStringOptions = toStringDefaults ?? null;
            Object.defineProperty(this, MAP, { value: map });
            Object.defineProperty(this, SCALAR$1, { value: string });
            Object.defineProperty(this, SEQ, { value: seq });
            // Used by createMap()
            this.sortMapEntries =
                typeof sortMapEntries === 'function'
                    ? sortMapEntries
                    : sortMapEntries === true
                        ? sortMapEntriesByKey
                        : null;
        }
        clone() {
            const copy = Object.create(Schema.prototype, Object.getOwnPropertyDescriptors(this));
            copy.tags = this.tags.slice();
            return copy;
        }
    }

    function stringifyDocument(doc, options) {
        const lines = [];
        let hasDirectives = options.directives === true;
        if (options.directives !== false && doc.directives) {
            const dir = doc.directives.toString(doc);
            if (dir) {
                lines.push(dir);
                hasDirectives = true;
            }
            else if (doc.directives.docStart)
                hasDirectives = true;
        }
        if (hasDirectives)
            lines.push('---');
        const ctx = createStringifyContext(doc, options);
        const { commentString } = ctx.options;
        if (doc.commentBefore) {
            if (lines.length !== 1)
                lines.unshift('');
            const cs = commentString(doc.commentBefore);
            lines.unshift(indentComment(cs, ''));
        }
        let chompKeep = false;
        let contentComment = null;
        if (doc.contents) {
            if (isNode(doc.contents)) {
                if (doc.contents.spaceBefore && hasDirectives)
                    lines.push('');
                if (doc.contents.commentBefore) {
                    const cs = commentString(doc.contents.commentBefore);
                    lines.push(indentComment(cs, ''));
                }
                // top-level block scalars need to be indented if followed by a comment
                ctx.forceBlockIndent = !!doc.comment;
                contentComment = doc.contents.comment;
            }
            const onChompKeep = contentComment ? undefined : () => (chompKeep = true);
            let body = stringify$2(doc.contents, ctx, () => (contentComment = null), onChompKeep);
            if (contentComment)
                body += lineComment(body, '', commentString(contentComment));
            if ((body[0] === '|' || body[0] === '>') &&
                lines[lines.length - 1] === '---') {
                // Top-level block scalars with a preceding doc marker ought to use the
                // same line for their header.
                lines[lines.length - 1] = `--- ${body}`;
            }
            else
                lines.push(body);
        }
        else {
            lines.push(stringify$2(doc.contents, ctx));
        }
        if (doc.directives?.docEnd) {
            if (doc.comment) {
                const cs = commentString(doc.comment);
                if (cs.includes('\n')) {
                    lines.push('...');
                    lines.push(indentComment(cs, ''));
                }
                else {
                    lines.push(`... ${cs}`);
                }
            }
            else {
                lines.push('...');
            }
        }
        else {
            let dc = doc.comment;
            if (dc && chompKeep)
                dc = dc.replace(/^\n+/, '');
            if (dc) {
                if ((!chompKeep || contentComment) && lines[lines.length - 1] !== '')
                    lines.push('');
                lines.push(indentComment(commentString(dc), ''));
            }
        }
        return lines.join('\n') + '\n';
    }

    class Document {
        constructor(value, replacer, options) {
            /** A comment before this Document */
            this.commentBefore = null;
            /** A comment immediately after this Document */
            this.comment = null;
            /** Errors encountered during parsing. */
            this.errors = [];
            /** Warnings encountered during parsing. */
            this.warnings = [];
            Object.defineProperty(this, NODE_TYPE, { value: DOC });
            let _replacer = null;
            if (typeof replacer === 'function' || Array.isArray(replacer)) {
                _replacer = replacer;
            }
            else if (options === undefined && replacer) {
                options = replacer;
                replacer = undefined;
            }
            const opt = Object.assign({
                intAsBigInt: false,
                keepSourceTokens: false,
                logLevel: 'warn',
                prettyErrors: true,
                strict: true,
                uniqueKeys: true,
                version: '1.2'
            }, options);
            this.options = opt;
            let { version } = opt;
            if (options?._directives) {
                this.directives = options._directives.atDocument();
                if (this.directives.yaml.explicit)
                    version = this.directives.yaml.version;
            }
            else
                this.directives = new Directives({ version });
            this.setSchema(version, options);
            // @ts-expect-error We can't really know that this matches Contents.
            this.contents =
                value === undefined ? null : this.createNode(value, _replacer, options);
        }
        /**
         * Create a deep copy of this Document and its contents.
         *
         * Custom Node values that inherit from `Object` still refer to their original instances.
         */
        clone() {
            const copy = Object.create(Document.prototype, {
                [NODE_TYPE]: { value: DOC }
            });
            copy.commentBefore = this.commentBefore;
            copy.comment = this.comment;
            copy.errors = this.errors.slice();
            copy.warnings = this.warnings.slice();
            copy.options = Object.assign({}, this.options);
            if (this.directives)
                copy.directives = this.directives.clone();
            copy.schema = this.schema.clone();
            // @ts-expect-error We can't really know that this matches Contents.
            copy.contents = isNode(this.contents)
                ? this.contents.clone(copy.schema)
                : this.contents;
            if (this.range)
                copy.range = this.range.slice();
            return copy;
        }
        /** Adds a value to the document. */
        add(value) {
            if (assertCollection(this.contents))
                this.contents.add(value);
        }
        /** Adds a value to the document. */
        addIn(path, value) {
            if (assertCollection(this.contents))
                this.contents.addIn(path, value);
        }
        /**
         * Create a new `Alias` node, ensuring that the target `node` has the required anchor.
         *
         * If `node` already has an anchor, `name` is ignored.
         * Otherwise, the `node.anchor` value will be set to `name`,
         * or if an anchor with that name is already present in the document,
         * `name` will be used as a prefix for a new unique anchor.
         * If `name` is undefined, the generated anchor will use 'a' as a prefix.
         */
        createAlias(node, name) {
            if (!node.anchor) {
                const prev = anchorNames(this);
                node.anchor =
                    // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
                    !name || prev.has(name) ? findNewAnchor(name || 'a', prev) : name;
            }
            return new Alias(node.anchor);
        }
        createNode(value, replacer, options) {
            let _replacer = undefined;
            if (typeof replacer === 'function') {
                value = replacer.call({ '': value }, '', value);
                _replacer = replacer;
            }
            else if (Array.isArray(replacer)) {
                const keyToStr = (v) => typeof v === 'number' || v instanceof String || v instanceof Number;
                const asStr = replacer.filter(keyToStr).map(String);
                if (asStr.length > 0)
                    replacer = replacer.concat(asStr);
                _replacer = replacer;
            }
            else if (options === undefined && replacer) {
                options = replacer;
                replacer = undefined;
            }
            const { aliasDuplicateObjects, anchorPrefix, flow, keepUndefined, onTagObj, tag } = options ?? {};
            const { onAnchor, setAnchors, sourceObjects } = createNodeAnchors(this, 
            // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
            anchorPrefix || 'a');
            const ctx = {
                aliasDuplicateObjects: aliasDuplicateObjects ?? true,
                keepUndefined: keepUndefined ?? false,
                onAnchor,
                onTagObj,
                replacer: _replacer,
                schema: this.schema,
                sourceObjects
            };
            const node = createNode(value, tag, ctx);
            if (flow && isCollection$1(node))
                node.flow = true;
            setAnchors();
            return node;
        }
        /**
         * Convert a key and a value into a `Pair` using the current schema,
         * recursively wrapping all values as `Scalar` or `Collection` nodes.
         */
        createPair(key, value, options = {}) {
            const k = this.createNode(key, null, options);
            const v = this.createNode(value, null, options);
            return new Pair(k, v);
        }
        /**
         * Removes a value from the document.
         * @returns `true` if the item was found and removed.
         */
        delete(key) {
            return assertCollection(this.contents) ? this.contents.delete(key) : false;
        }
        /**
         * Removes a value from the document.
         * @returns `true` if the item was found and removed.
         */
        deleteIn(path) {
            if (isEmptyPath(path)) {
                if (this.contents == null)
                    return false;
                // @ts-expect-error Presumed impossible if Strict extends false
                this.contents = null;
                return true;
            }
            return assertCollection(this.contents)
                ? this.contents.deleteIn(path)
                : false;
        }
        /**
         * Returns item at `key`, or `undefined` if not found. By default unwraps
         * scalar values from their surrounding node; to disable set `keepScalar` to
         * `true` (collections are always returned intact).
         */
        get(key, keepScalar) {
            return isCollection$1(this.contents)
                ? this.contents.get(key, keepScalar)
                : undefined;
        }
        /**
         * Returns item at `path`, or `undefined` if not found. By default unwraps
         * scalar values from their surrounding node; to disable set `keepScalar` to
         * `true` (collections are always returned intact).
         */
        getIn(path, keepScalar) {
            if (isEmptyPath(path))
                return !keepScalar && isScalar$1(this.contents)
                    ? this.contents.value
                    : this.contents;
            return isCollection$1(this.contents)
                ? this.contents.getIn(path, keepScalar)
                : undefined;
        }
        /**
         * Checks if the document includes a value with the key `key`.
         */
        has(key) {
            return isCollection$1(this.contents) ? this.contents.has(key) : false;
        }
        /**
         * Checks if the document includes a value at `path`.
         */
        hasIn(path) {
            if (isEmptyPath(path))
                return this.contents !== undefined;
            return isCollection$1(this.contents) ? this.contents.hasIn(path) : false;
        }
        /**
         * Sets a value in this document. For `!!set`, `value` needs to be a
         * boolean to add/remove the item from the set.
         */
        set(key, value) {
            if (this.contents == null) {
                // @ts-expect-error We can't really know that this matches Contents.
                this.contents = collectionFromPath(this.schema, [key], value);
            }
            else if (assertCollection(this.contents)) {
                this.contents.set(key, value);
            }
        }
        /**
         * Sets a value in this document. For `!!set`, `value` needs to be a
         * boolean to add/remove the item from the set.
         */
        setIn(path, value) {
            if (isEmptyPath(path)) {
                // @ts-expect-error We can't really know that this matches Contents.
                this.contents = value;
            }
            else if (this.contents == null) {
                // @ts-expect-error We can't really know that this matches Contents.
                this.contents = collectionFromPath(this.schema, Array.from(path), value);
            }
            else if (assertCollection(this.contents)) {
                this.contents.setIn(path, value);
            }
        }
        /**
         * Change the YAML version and schema used by the document.
         * A `null` version disables support for directives, explicit tags, anchors, and aliases.
         * It also requires the `schema` option to be given as a `Schema` instance value.
         *
         * Overrides all previously set schema options.
         */
        setSchema(version, options = {}) {
            if (typeof version === 'number')
                version = String(version);
            let opt;
            switch (version) {
                case '1.1':
                    if (this.directives)
                        this.directives.yaml.version = '1.1';
                    else
                        this.directives = new Directives({ version: '1.1' });
                    opt = { merge: true, resolveKnownTags: false, schema: 'yaml-1.1' };
                    break;
                case '1.2':
                case 'next':
                    if (this.directives)
                        this.directives.yaml.version = version;
                    else
                        this.directives = new Directives({ version });
                    opt = { merge: false, resolveKnownTags: true, schema: 'core' };
                    break;
                case null:
                    if (this.directives)
                        delete this.directives;
                    opt = null;
                    break;
                default: {
                    const sv = JSON.stringify(version);
                    throw new Error(`Expected '1.1', '1.2' or null as first argument, but found: ${sv}`);
                }
            }
            // Not using `instanceof Schema` to allow for duck typing
            if (options.schema instanceof Object)
                this.schema = options.schema;
            else if (opt)
                this.schema = new Schema(Object.assign(opt, options));
            else
                throw new Error(`With a null YAML version, the { schema: Schema } option is required`);
        }
        // json & jsonArg are only used from toJSON()
        toJS({ json, jsonArg, mapAsMap, maxAliasCount, onAnchor, reviver } = {}) {
            const ctx = {
                anchors: new Map(),
                doc: this,
                keep: !json,
                mapAsMap: mapAsMap === true,
                mapKeyWarned: false,
                maxAliasCount: typeof maxAliasCount === 'number' ? maxAliasCount : 100
            };
            const res = toJS(this.contents, jsonArg ?? '', ctx);
            if (typeof onAnchor === 'function')
                for (const { count, res } of ctx.anchors.values())
                    onAnchor(res, count);
            return typeof reviver === 'function'
                ? applyReviver(reviver, { '': res }, '', res)
                : res;
        }
        /**
         * A JSON representation of the document `contents`.
         *
         * @param jsonArg Used by `JSON.stringify` to indicate the array index or
         *   property name.
         */
        toJSON(jsonArg, onAnchor) {
            return this.toJS({ json: true, jsonArg, mapAsMap: false, onAnchor });
        }
        /** A YAML representation of the document. */
        toString(options = {}) {
            if (this.errors.length > 0)
                throw new Error('Document with errors cannot be stringified');
            if ('indent' in options &&
                (!Number.isInteger(options.indent) || Number(options.indent) <= 0)) {
                const s = JSON.stringify(options.indent);
                throw new Error(`"indent" option must be a positive integer, not ${s}`);
            }
            return stringifyDocument(this, options);
        }
    }
    function assertCollection(contents) {
        if (isCollection$1(contents))
            return true;
        throw new Error('Expected a YAML collection as document contents');
    }

    class YAMLError extends Error {
        constructor(name, pos, code, message) {
            super();
            this.name = name;
            this.code = code;
            this.message = message;
            this.pos = pos;
        }
    }
    class YAMLParseError extends YAMLError {
        constructor(pos, code, message) {
            super('YAMLParseError', pos, code, message);
        }
    }
    class YAMLWarning extends YAMLError {
        constructor(pos, code, message) {
            super('YAMLWarning', pos, code, message);
        }
    }
    const prettifyError = (src, lc) => (error) => {
        if (error.pos[0] === -1)
            return;
        error.linePos = error.pos.map(pos => lc.linePos(pos));
        const { line, col } = error.linePos[0];
        error.message += ` at line ${line}, column ${col}`;
        let ci = col - 1;
        let lineStr = src
            .substring(lc.lineStarts[line - 1], lc.lineStarts[line])
            .replace(/[\n\r]+$/, '');
        // Trim to max 80 chars, keeping col position near the middle
        if (ci >= 60 && lineStr.length > 80) {
            const trimStart = Math.min(ci - 39, lineStr.length - 79);
            lineStr = '…' + lineStr.substring(trimStart);
            ci -= trimStart - 1;
        }
        if (lineStr.length > 80)
            lineStr = lineStr.substring(0, 79) + '…';
        // Include previous line in context if pointing at line start
        if (line > 1 && /^ *$/.test(lineStr.substring(0, ci))) {
            // Regexp won't match if start is trimmed
            let prev = src.substring(lc.lineStarts[line - 2], lc.lineStarts[line - 1]);
            if (prev.length > 80)
                prev = prev.substring(0, 79) + '…\n';
            lineStr = prev + lineStr;
        }
        if (/[^ ]/.test(lineStr)) {
            let count = 1;
            const end = error.linePos[1];
            if (end && end.line === line && end.col > col) {
                count = Math.max(1, Math.min(end.col - col, 80 - ci));
            }
            const pointer = ' '.repeat(ci) + '^'.repeat(count);
            error.message += `:\n\n${lineStr}\n${pointer}\n`;
        }
    };

    function resolveProps(tokens, { flow, indicator, next, offset, onError, parentIndent, startOnNewline }) {
        let spaceBefore = false;
        let atNewline = startOnNewline;
        let hasSpace = startOnNewline;
        let comment = '';
        let commentSep = '';
        let hasNewline = false;
        let reqSpace = false;
        let tab = null;
        let anchor = null;
        let tag = null;
        let newlineAfterProp = null;
        let comma = null;
        let found = null;
        let start = null;
        for (const token of tokens) {
            if (reqSpace) {
                if (token.type !== 'space' &&
                    token.type !== 'newline' &&
                    token.type !== 'comma')
                    onError(token.offset, 'MISSING_CHAR', 'Tags and anchors must be separated from the next token by white space');
                reqSpace = false;
            }
            if (tab) {
                if (atNewline && token.type !== 'comment' && token.type !== 'newline') {
                    onError(tab, 'TAB_AS_INDENT', 'Tabs are not allowed as indentation');
                }
                tab = null;
            }
            switch (token.type) {
                case 'space':
                    // At the doc level, tabs at line start may be parsed
                    // as leading white space rather than indentation.
                    // In a flow collection, only the parser handles indent.
                    if (!flow &&
                        (indicator !== 'doc-start' || next?.type !== 'flow-collection') &&
                        token.source.includes('\t')) {
                        tab = token;
                    }
                    hasSpace = true;
                    break;
                case 'comment': {
                    if (!hasSpace)
                        onError(token, 'MISSING_CHAR', 'Comments must be separated from other tokens by white space characters');
                    const cb = token.source.substring(1) || ' ';
                    if (!comment)
                        comment = cb;
                    else
                        comment += commentSep + cb;
                    commentSep = '';
                    atNewline = false;
                    break;
                }
                case 'newline':
                    if (atNewline) {
                        if (comment)
                            comment += token.source;
                        else
                            spaceBefore = true;
                    }
                    else
                        commentSep += token.source;
                    atNewline = true;
                    hasNewline = true;
                    if (anchor || tag)
                        newlineAfterProp = token;
                    hasSpace = true;
                    break;
                case 'anchor':
                    if (anchor)
                        onError(token, 'MULTIPLE_ANCHORS', 'A node can have at most one anchor');
                    if (token.source.endsWith(':'))
                        onError(token.offset + token.source.length - 1, 'BAD_ALIAS', 'Anchor ending in : is ambiguous', true);
                    anchor = token;
                    if (start === null)
                        start = token.offset;
                    atNewline = false;
                    hasSpace = false;
                    reqSpace = true;
                    break;
                case 'tag': {
                    if (tag)
                        onError(token, 'MULTIPLE_TAGS', 'A node can have at most one tag');
                    tag = token;
                    if (start === null)
                        start = token.offset;
                    atNewline = false;
                    hasSpace = false;
                    reqSpace = true;
                    break;
                }
                case indicator:
                    // Could here handle preceding comments differently
                    if (anchor || tag)
                        onError(token, 'BAD_PROP_ORDER', `Anchors and tags must be after the ${token.source} indicator`);
                    if (found)
                        onError(token, 'UNEXPECTED_TOKEN', `Unexpected ${token.source} in ${flow ?? 'collection'}`);
                    found = token;
                    atNewline =
                        indicator === 'seq-item-ind' || indicator === 'explicit-key-ind';
                    hasSpace = false;
                    break;
                case 'comma':
                    if (flow) {
                        if (comma)
                            onError(token, 'UNEXPECTED_TOKEN', `Unexpected , in ${flow}`);
                        comma = token;
                        atNewline = false;
                        hasSpace = false;
                        break;
                    }
                // else fallthrough
                default:
                    onError(token, 'UNEXPECTED_TOKEN', `Unexpected ${token.type} token`);
                    atNewline = false;
                    hasSpace = false;
            }
        }
        const last = tokens[tokens.length - 1];
        const end = last ? last.offset + last.source.length : offset;
        if (reqSpace &&
            next &&
            next.type !== 'space' &&
            next.type !== 'newline' &&
            next.type !== 'comma' &&
            (next.type !== 'scalar' || next.source !== '')) {
            onError(next.offset, 'MISSING_CHAR', 'Tags and anchors must be separated from the next token by white space');
        }
        if (tab &&
            ((atNewline && tab.indent <= parentIndent) ||
                next?.type === 'block-map' ||
                next?.type === 'block-seq'))
            onError(tab, 'TAB_AS_INDENT', 'Tabs are not allowed as indentation');
        return {
            comma,
            found,
            spaceBefore,
            comment,
            hasNewline,
            anchor,
            tag,
            newlineAfterProp,
            end,
            start: start ?? end
        };
    }

    function containsNewline(key) {
        if (!key)
            return null;
        switch (key.type) {
            case 'alias':
            case 'scalar':
            case 'double-quoted-scalar':
            case 'single-quoted-scalar':
                if (key.source.includes('\n'))
                    return true;
                if (key.end)
                    for (const st of key.end)
                        if (st.type === 'newline')
                            return true;
                return false;
            case 'flow-collection':
                for (const it of key.items) {
                    for (const st of it.start)
                        if (st.type === 'newline')
                            return true;
                    if (it.sep)
                        for (const st of it.sep)
                            if (st.type === 'newline')
                                return true;
                    if (containsNewline(it.key) || containsNewline(it.value))
                        return true;
                }
                return false;
            default:
                return true;
        }
    }

    function flowIndentCheck(indent, fc, onError) {
        if (fc?.type === 'flow-collection') {
            const end = fc.end[0];
            if (end.indent === indent &&
                (end.source === ']' || end.source === '}') &&
                containsNewline(fc)) {
                const msg = 'Flow end indicator should be more indented than parent';
                onError(end, 'BAD_INDENT', msg, true);
            }
        }
    }

    function mapIncludes(ctx, items, search) {
        const { uniqueKeys } = ctx.options;
        if (uniqueKeys === false)
            return false;
        const isEqual = typeof uniqueKeys === 'function'
            ? uniqueKeys
            : (a, b) => a === b ||
                (isScalar$1(a) &&
                    isScalar$1(b) &&
                    a.value === b.value &&
                    !(a.value === '<<' && ctx.schema.merge));
        return items.some(pair => isEqual(pair.key, search));
    }

    const startColMsg = 'All mapping items must start at the same column';
    function resolveBlockMap({ composeNode, composeEmptyNode }, ctx, bm, onError, tag) {
        const NodeClass = tag?.nodeClass ?? YAMLMap;
        const map = new NodeClass(ctx.schema);
        if (ctx.atRoot)
            ctx.atRoot = false;
        let offset = bm.offset;
        let commentEnd = null;
        for (const collItem of bm.items) {
            const { start, key, sep, value } = collItem;
            // key properties
            const keyProps = resolveProps(start, {
                indicator: 'explicit-key-ind',
                next: key ?? sep?.[0],
                offset,
                onError,
                parentIndent: bm.indent,
                startOnNewline: true
            });
            const implicitKey = !keyProps.found;
            if (implicitKey) {
                if (key) {
                    if (key.type === 'block-seq')
                        onError(offset, 'BLOCK_AS_IMPLICIT_KEY', 'A block sequence may not be used as an implicit map key');
                    else if ('indent' in key && key.indent !== bm.indent)
                        onError(offset, 'BAD_INDENT', startColMsg);
                }
                if (!keyProps.anchor && !keyProps.tag && !sep) {
                    commentEnd = keyProps.end;
                    if (keyProps.comment) {
                        if (map.comment)
                            map.comment += '\n' + keyProps.comment;
                        else
                            map.comment = keyProps.comment;
                    }
                    continue;
                }
                if (keyProps.newlineAfterProp || containsNewline(key)) {
                    onError(key ?? start[start.length - 1], 'MULTILINE_IMPLICIT_KEY', 'Implicit keys need to be on a single line');
                }
            }
            else if (keyProps.found?.indent !== bm.indent) {
                onError(offset, 'BAD_INDENT', startColMsg);
            }
            // key value
            const keyStart = keyProps.end;
            const keyNode = key
                ? composeNode(ctx, key, keyProps, onError)
                : composeEmptyNode(ctx, keyStart, start, null, keyProps, onError);
            if (ctx.schema.compat)
                flowIndentCheck(bm.indent, key, onError);
            if (mapIncludes(ctx, map.items, keyNode))
                onError(keyStart, 'DUPLICATE_KEY', 'Map keys must be unique');
            // value properties
            const valueProps = resolveProps(sep ?? [], {
                indicator: 'map-value-ind',
                next: value,
                offset: keyNode.range[2],
                onError,
                parentIndent: bm.indent,
                startOnNewline: !key || key.type === 'block-scalar'
            });
            offset = valueProps.end;
            if (valueProps.found) {
                if (implicitKey) {
                    if (value?.type === 'block-map' && !valueProps.hasNewline)
                        onError(offset, 'BLOCK_AS_IMPLICIT_KEY', 'Nested mappings are not allowed in compact mappings');
                    if (ctx.options.strict &&
                        keyProps.start < valueProps.found.offset - 1024)
                        onError(keyNode.range, 'KEY_OVER_1024_CHARS', 'The : indicator must be at most 1024 chars after the start of an implicit block mapping key');
                }
                // value value
                const valueNode = value
                    ? composeNode(ctx, value, valueProps, onError)
                    : composeEmptyNode(ctx, offset, sep, null, valueProps, onError);
                if (ctx.schema.compat)
                    flowIndentCheck(bm.indent, value, onError);
                offset = valueNode.range[2];
                const pair = new Pair(keyNode, valueNode);
                if (ctx.options.keepSourceTokens)
                    pair.srcToken = collItem;
                map.items.push(pair);
            }
            else {
                // key with no value
                if (implicitKey)
                    onError(keyNode.range, 'MISSING_CHAR', 'Implicit map keys need to be followed by map values');
                if (valueProps.comment) {
                    if (keyNode.comment)
                        keyNode.comment += '\n' + valueProps.comment;
                    else
                        keyNode.comment = valueProps.comment;
                }
                const pair = new Pair(keyNode);
                if (ctx.options.keepSourceTokens)
                    pair.srcToken = collItem;
                map.items.push(pair);
            }
        }
        if (commentEnd && commentEnd < offset)
            onError(commentEnd, 'IMPOSSIBLE', 'Map comment with trailing content');
        map.range = [bm.offset, offset, commentEnd ?? offset];
        return map;
    }

    function resolveBlockSeq({ composeNode, composeEmptyNode }, ctx, bs, onError, tag) {
        const NodeClass = tag?.nodeClass ?? YAMLSeq;
        const seq = new NodeClass(ctx.schema);
        if (ctx.atRoot)
            ctx.atRoot = false;
        let offset = bs.offset;
        let commentEnd = null;
        for (const { start, value } of bs.items) {
            const props = resolveProps(start, {
                indicator: 'seq-item-ind',
                next: value,
                offset,
                onError,
                parentIndent: bs.indent,
                startOnNewline: true
            });
            if (!props.found) {
                if (props.anchor || props.tag || value) {
                    if (value && value.type === 'block-seq')
                        onError(props.end, 'BAD_INDENT', 'All sequence items must start at the same column');
                    else
                        onError(offset, 'MISSING_CHAR', 'Sequence item without - indicator');
                }
                else {
                    commentEnd = props.end;
                    if (props.comment)
                        seq.comment = props.comment;
                    continue;
                }
            }
            const node = value
                ? composeNode(ctx, value, props, onError)
                : composeEmptyNode(ctx, props.end, start, null, props, onError);
            if (ctx.schema.compat)
                flowIndentCheck(bs.indent, value, onError);
            offset = node.range[2];
            seq.items.push(node);
        }
        seq.range = [bs.offset, offset, commentEnd ?? offset];
        return seq;
    }

    function resolveEnd(end, offset, reqSpace, onError) {
        let comment = '';
        if (end) {
            let hasSpace = false;
            let sep = '';
            for (const token of end) {
                const { source, type } = token;
                switch (type) {
                    case 'space':
                        hasSpace = true;
                        break;
                    case 'comment': {
                        if (reqSpace && !hasSpace)
                            onError(token, 'MISSING_CHAR', 'Comments must be separated from other tokens by white space characters');
                        const cb = source.substring(1) || ' ';
                        if (!comment)
                            comment = cb;
                        else
                            comment += sep + cb;
                        sep = '';
                        break;
                    }
                    case 'newline':
                        if (comment)
                            sep += source;
                        hasSpace = true;
                        break;
                    default:
                        onError(token, 'UNEXPECTED_TOKEN', `Unexpected ${type} at node end`);
                }
                offset += source.length;
            }
        }
        return { comment, offset };
    }

    const blockMsg = 'Block collections are not allowed within flow collections';
    const isBlock = (token) => token && (token.type === 'block-map' || token.type === 'block-seq');
    function resolveFlowCollection({ composeNode, composeEmptyNode }, ctx, fc, onError, tag) {
        const isMap = fc.start.source === '{';
        const fcName = isMap ? 'flow map' : 'flow sequence';
        const NodeClass = (tag?.nodeClass ?? (isMap ? YAMLMap : YAMLSeq));
        const coll = new NodeClass(ctx.schema);
        coll.flow = true;
        const atRoot = ctx.atRoot;
        if (atRoot)
            ctx.atRoot = false;
        let offset = fc.offset + fc.start.source.length;
        for (let i = 0; i < fc.items.length; ++i) {
            const collItem = fc.items[i];
            const { start, key, sep, value } = collItem;
            const props = resolveProps(start, {
                flow: fcName,
                indicator: 'explicit-key-ind',
                next: key ?? sep?.[0],
                offset,
                onError,
                parentIndent: fc.indent,
                startOnNewline: false
            });
            if (!props.found) {
                if (!props.anchor && !props.tag && !sep && !value) {
                    if (i === 0 && props.comma)
                        onError(props.comma, 'UNEXPECTED_TOKEN', `Unexpected , in ${fcName}`);
                    else if (i < fc.items.length - 1)
                        onError(props.start, 'UNEXPECTED_TOKEN', `Unexpected empty item in ${fcName}`);
                    if (props.comment) {
                        if (coll.comment)
                            coll.comment += '\n' + props.comment;
                        else
                            coll.comment = props.comment;
                    }
                    offset = props.end;
                    continue;
                }
                if (!isMap && ctx.options.strict && containsNewline(key))
                    onError(key, // checked by containsNewline()
                    'MULTILINE_IMPLICIT_KEY', 'Implicit keys of flow sequence pairs need to be on a single line');
            }
            if (i === 0) {
                if (props.comma)
                    onError(props.comma, 'UNEXPECTED_TOKEN', `Unexpected , in ${fcName}`);
            }
            else {
                if (!props.comma)
                    onError(props.start, 'MISSING_CHAR', `Missing , between ${fcName} items`);
                if (props.comment) {
                    let prevItemComment = '';
                    loop: for (const st of start) {
                        switch (st.type) {
                            case 'comma':
                            case 'space':
                                break;
                            case 'comment':
                                prevItemComment = st.source.substring(1);
                                break loop;
                            default:
                                break loop;
                        }
                    }
                    if (prevItemComment) {
                        let prev = coll.items[coll.items.length - 1];
                        if (isPair(prev))
                            prev = prev.value ?? prev.key;
                        if (prev.comment)
                            prev.comment += '\n' + prevItemComment;
                        else
                            prev.comment = prevItemComment;
                        props.comment = props.comment.substring(prevItemComment.length + 1);
                    }
                }
            }
            if (!isMap && !sep && !props.found) {
                // item is a value in a seq
                // → key & sep are empty, start does not include ? or :
                const valueNode = value
                    ? composeNode(ctx, value, props, onError)
                    : composeEmptyNode(ctx, props.end, sep, null, props, onError);
                coll.items.push(valueNode);
                offset = valueNode.range[2];
                if (isBlock(value))
                    onError(valueNode.range, 'BLOCK_IN_FLOW', blockMsg);
            }
            else {
                // item is a key+value pair
                // key value
                const keyStart = props.end;
                const keyNode = key
                    ? composeNode(ctx, key, props, onError)
                    : composeEmptyNode(ctx, keyStart, start, null, props, onError);
                if (isBlock(key))
                    onError(keyNode.range, 'BLOCK_IN_FLOW', blockMsg);
                // value properties
                const valueProps = resolveProps(sep ?? [], {
                    flow: fcName,
                    indicator: 'map-value-ind',
                    next: value,
                    offset: keyNode.range[2],
                    onError,
                    parentIndent: fc.indent,
                    startOnNewline: false
                });
                if (valueProps.found) {
                    if (!isMap && !props.found && ctx.options.strict) {
                        if (sep)
                            for (const st of sep) {
                                if (st === valueProps.found)
                                    break;
                                if (st.type === 'newline') {
                                    onError(st, 'MULTILINE_IMPLICIT_KEY', 'Implicit keys of flow sequence pairs need to be on a single line');
                                    break;
                                }
                            }
                        if (props.start < valueProps.found.offset - 1024)
                            onError(valueProps.found, 'KEY_OVER_1024_CHARS', 'The : indicator must be at most 1024 chars after the start of an implicit flow sequence key');
                    }
                }
                else if (value) {
                    if ('source' in value && value.source && value.source[0] === ':')
                        onError(value, 'MISSING_CHAR', `Missing space after : in ${fcName}`);
                    else
                        onError(valueProps.start, 'MISSING_CHAR', `Missing , or : between ${fcName} items`);
                }
                // value value
                const valueNode = value
                    ? composeNode(ctx, value, valueProps, onError)
                    : valueProps.found
                        ? composeEmptyNode(ctx, valueProps.end, sep, null, valueProps, onError)
                        : null;
                if (valueNode) {
                    if (isBlock(value))
                        onError(valueNode.range, 'BLOCK_IN_FLOW', blockMsg);
                }
                else if (valueProps.comment) {
                    if (keyNode.comment)
                        keyNode.comment += '\n' + valueProps.comment;
                    else
                        keyNode.comment = valueProps.comment;
                }
                const pair = new Pair(keyNode, valueNode);
                if (ctx.options.keepSourceTokens)
                    pair.srcToken = collItem;
                if (isMap) {
                    const map = coll;
                    if (mapIncludes(ctx, map.items, keyNode))
                        onError(keyStart, 'DUPLICATE_KEY', 'Map keys must be unique');
                    map.items.push(pair);
                }
                else {
                    const map = new YAMLMap(ctx.schema);
                    map.flow = true;
                    map.items.push(pair);
                    const endRange = (valueNode ?? keyNode).range;
                    map.range = [keyNode.range[0], endRange[1], endRange[2]];
                    coll.items.push(map);
                }
                offset = valueNode ? valueNode.range[2] : valueProps.end;
            }
        }
        const expectedEnd = isMap ? '}' : ']';
        const [ce, ...ee] = fc.end;
        let cePos = offset;
        if (ce && ce.source === expectedEnd)
            cePos = ce.offset + ce.source.length;
        else {
            const name = fcName[0].toUpperCase() + fcName.substring(1);
            const msg = atRoot
                ? `${name} must end with a ${expectedEnd}`
                : `${name} in block collection must be sufficiently indented and end with a ${expectedEnd}`;
            onError(offset, atRoot ? 'MISSING_CHAR' : 'BAD_INDENT', msg);
            if (ce && ce.source.length !== 1)
                ee.unshift(ce);
        }
        if (ee.length > 0) {
            const end = resolveEnd(ee, cePos, ctx.options.strict, onError);
            if (end.comment) {
                if (coll.comment)
                    coll.comment += '\n' + end.comment;
                else
                    coll.comment = end.comment;
            }
            coll.range = [fc.offset, cePos, end.offset];
        }
        else {
            coll.range = [fc.offset, cePos, cePos];
        }
        return coll;
    }

    function resolveCollection(CN, ctx, token, onError, tagName, tag) {
        const coll = token.type === 'block-map'
            ? resolveBlockMap(CN, ctx, token, onError, tag)
            : token.type === 'block-seq'
                ? resolveBlockSeq(CN, ctx, token, onError, tag)
                : resolveFlowCollection(CN, ctx, token, onError, tag);
        const Coll = coll.constructor;
        // If we got a tagName matching the class, or the tag name is '!',
        // then use the tagName from the node class used to create it.
        if (tagName === '!' || tagName === Coll.tagName) {
            coll.tag = Coll.tagName;
            return coll;
        }
        if (tagName)
            coll.tag = tagName;
        return coll;
    }
    function composeCollection(CN, ctx, token, props, onError) {
        const tagToken = props.tag;
        const tagName = !tagToken
            ? null
            : ctx.directives.tagName(tagToken.source, msg => onError(tagToken, 'TAG_RESOLVE_FAILED', msg));
        if (token.type === 'block-seq') {
            const { anchor, newlineAfterProp: nl } = props;
            const lastProp = anchor && tagToken
                ? anchor.offset > tagToken.offset
                    ? anchor
                    : tagToken
                : (anchor ?? tagToken);
            if (lastProp && (!nl || nl.offset < lastProp.offset)) {
                const message = 'Missing newline after block sequence props';
                onError(lastProp, 'MISSING_CHAR', message);
            }
        }
        const expType = token.type === 'block-map'
            ? 'map'
            : token.type === 'block-seq'
                ? 'seq'
                : token.start.source === '{'
                    ? 'map'
                    : 'seq';
        // shortcut: check if it's a generic YAMLMap or YAMLSeq
        // before jumping into the custom tag logic.
        if (!tagToken ||
            !tagName ||
            tagName === '!' ||
            (tagName === YAMLMap.tagName && expType === 'map') ||
            (tagName === YAMLSeq.tagName && expType === 'seq')) {
            return resolveCollection(CN, ctx, token, onError, tagName);
        }
        let tag = ctx.schema.tags.find(t => t.tag === tagName && t.collection === expType);
        if (!tag) {
            const kt = ctx.schema.knownTags[tagName];
            if (kt && kt.collection === expType) {
                ctx.schema.tags.push(Object.assign({}, kt, { default: false }));
                tag = kt;
            }
            else {
                if (kt?.collection) {
                    onError(tagToken, 'BAD_COLLECTION_TYPE', `${kt.tag} used for ${expType} collection, but expects ${kt.collection}`, true);
                }
                else {
                    onError(tagToken, 'TAG_RESOLVE_FAILED', `Unresolved tag: ${tagName}`, true);
                }
                return resolveCollection(CN, ctx, token, onError, tagName);
            }
        }
        const coll = resolveCollection(CN, ctx, token, onError, tagName, tag);
        const res = tag.resolve?.(coll, msg => onError(tagToken, 'TAG_RESOLVE_FAILED', msg), ctx.options) ?? coll;
        const node = isNode(res)
            ? res
            : new Scalar(res);
        node.range = coll.range;
        node.tag = tagName;
        if (tag?.format)
            node.format = tag.format;
        return node;
    }

    function resolveBlockScalar(ctx, scalar, onError) {
        const start = scalar.offset;
        const header = parseBlockScalarHeader(scalar, ctx.options.strict, onError);
        if (!header)
            return { value: '', type: null, comment: '', range: [start, start, start] };
        const type = header.mode === '>' ? Scalar.BLOCK_FOLDED : Scalar.BLOCK_LITERAL;
        const lines = scalar.source ? splitLines(scalar.source) : [];
        // determine the end of content & start of chomping
        let chompStart = lines.length;
        for (let i = lines.length - 1; i >= 0; --i) {
            const content = lines[i][1];
            if (content === '' || content === '\r')
                chompStart = i;
            else
                break;
        }
        // shortcut for empty contents
        if (chompStart === 0) {
            const value = header.chomp === '+' && lines.length > 0
                ? '\n'.repeat(Math.max(1, lines.length - 1))
                : '';
            let end = start + header.length;
            if (scalar.source)
                end += scalar.source.length;
            return { value, type, comment: header.comment, range: [start, end, end] };
        }
        // find the indentation level to trim from start
        let trimIndent = scalar.indent + header.indent;
        let offset = scalar.offset + header.length;
        let contentStart = 0;
        for (let i = 0; i < chompStart; ++i) {
            const [indent, content] = lines[i];
            if (content === '' || content === '\r') {
                if (header.indent === 0 && indent.length > trimIndent)
                    trimIndent = indent.length;
            }
            else {
                if (indent.length < trimIndent) {
                    const message = 'Block scalars with more-indented leading empty lines must use an explicit indentation indicator';
                    onError(offset + indent.length, 'MISSING_CHAR', message);
                }
                if (header.indent === 0)
                    trimIndent = indent.length;
                contentStart = i;
                if (trimIndent === 0 && !ctx.atRoot) {
                    const message = 'Block scalar values in collections must be indented';
                    onError(offset, 'BAD_INDENT', message);
                }
                break;
            }
            offset += indent.length + content.length + 1;
        }
        // include trailing more-indented empty lines in content
        for (let i = lines.length - 1; i >= chompStart; --i) {
            if (lines[i][0].length > trimIndent)
                chompStart = i + 1;
        }
        let value = '';
        let sep = '';
        let prevMoreIndented = false;
        // leading whitespace is kept intact
        for (let i = 0; i < contentStart; ++i)
            value += lines[i][0].slice(trimIndent) + '\n';
        for (let i = contentStart; i < chompStart; ++i) {
            let [indent, content] = lines[i];
            offset += indent.length + content.length + 1;
            const crlf = content[content.length - 1] === '\r';
            if (crlf)
                content = content.slice(0, -1);
            /* istanbul ignore if already caught in lexer */
            if (content && indent.length < trimIndent) {
                const src = header.indent
                    ? 'explicit indentation indicator'
                    : 'first line';
                const message = `Block scalar lines must not be less indented than their ${src}`;
                onError(offset - content.length - (crlf ? 2 : 1), 'BAD_INDENT', message);
                indent = '';
            }
            if (type === Scalar.BLOCK_LITERAL) {
                value += sep + indent.slice(trimIndent) + content;
                sep = '\n';
            }
            else if (indent.length > trimIndent || content[0] === '\t') {
                // more-indented content within a folded block
                if (sep === ' ')
                    sep = '\n';
                else if (!prevMoreIndented && sep === '\n')
                    sep = '\n\n';
                value += sep + indent.slice(trimIndent) + content;
                sep = '\n';
                prevMoreIndented = true;
            }
            else if (content === '') {
                // empty line
                if (sep === '\n')
                    value += '\n';
                else
                    sep = '\n';
            }
            else {
                value += sep + content;
                sep = ' ';
                prevMoreIndented = false;
            }
        }
        switch (header.chomp) {
            case '-':
                break;
            case '+':
                for (let i = chompStart; i < lines.length; ++i)
                    value += '\n' + lines[i][0].slice(trimIndent);
                if (value[value.length - 1] !== '\n')
                    value += '\n';
                break;
            default:
                value += '\n';
        }
        const end = start + header.length + scalar.source.length;
        return { value, type, comment: header.comment, range: [start, end, end] };
    }
    function parseBlockScalarHeader({ offset, props }, strict, onError) {
        /* istanbul ignore if should not happen */
        if (props[0].type !== 'block-scalar-header') {
            onError(props[0], 'IMPOSSIBLE', 'Block scalar header not found');
            return null;
        }
        const { source } = props[0];
        const mode = source[0];
        let indent = 0;
        let chomp = '';
        let error = -1;
        for (let i = 1; i < source.length; ++i) {
            const ch = source[i];
            if (!chomp && (ch === '-' || ch === '+'))
                chomp = ch;
            else {
                const n = Number(ch);
                if (!indent && n)
                    indent = n;
                else if (error === -1)
                    error = offset + i;
            }
        }
        if (error !== -1)
            onError(error, 'UNEXPECTED_TOKEN', `Block scalar header includes extra characters: ${source}`);
        let hasSpace = false;
        let comment = '';
        let length = source.length;
        for (let i = 1; i < props.length; ++i) {
            const token = props[i];
            switch (token.type) {
                case 'space':
                    hasSpace = true;
                // fallthrough
                case 'newline':
                    length += token.source.length;
                    break;
                case 'comment':
                    if (strict && !hasSpace) {
                        const message = 'Comments must be separated from other tokens by white space characters';
                        onError(token, 'MISSING_CHAR', message);
                    }
                    length += token.source.length;
                    comment = token.source.substring(1);
                    break;
                case 'error':
                    onError(token, 'UNEXPECTED_TOKEN', token.message);
                    length += token.source.length;
                    break;
                /* istanbul ignore next should not happen */
                default: {
                    const message = `Unexpected token in block scalar header: ${token.type}`;
                    onError(token, 'UNEXPECTED_TOKEN', message);
                    const ts = token.source;
                    if (ts && typeof ts === 'string')
                        length += ts.length;
                }
            }
        }
        return { mode, indent, chomp, comment, length };
    }
    /** @returns Array of lines split up as `[indent, content]` */
    function splitLines(source) {
        const split = source.split(/\n( *)/);
        const first = split[0];
        const m = first.match(/^( *)/);
        const line0 = m?.[1]
            ? [m[1], first.slice(m[1].length)]
            : ['', first];
        const lines = [line0];
        for (let i = 1; i < split.length; i += 2)
            lines.push([split[i], split[i + 1]]);
        return lines;
    }

    function resolveFlowScalar(scalar, strict, onError) {
        const { offset, type, source, end } = scalar;
        let _type;
        let value;
        const _onError = (rel, code, msg) => onError(offset + rel, code, msg);
        switch (type) {
            case 'scalar':
                _type = Scalar.PLAIN;
                value = plainValue(source, _onError);
                break;
            case 'single-quoted-scalar':
                _type = Scalar.QUOTE_SINGLE;
                value = singleQuotedValue(source, _onError);
                break;
            case 'double-quoted-scalar':
                _type = Scalar.QUOTE_DOUBLE;
                value = doubleQuotedValue(source, _onError);
                break;
            /* istanbul ignore next should not happen */
            default:
                onError(scalar, 'UNEXPECTED_TOKEN', `Expected a flow scalar value, but found: ${type}`);
                return {
                    value: '',
                    type: null,
                    comment: '',
                    range: [offset, offset + source.length, offset + source.length]
                };
        }
        const valueEnd = offset + source.length;
        const re = resolveEnd(end, valueEnd, strict, onError);
        return {
            value,
            type: _type,
            comment: re.comment,
            range: [offset, valueEnd, re.offset]
        };
    }
    function plainValue(source, onError) {
        let badChar = '';
        switch (source[0]) {
            /* istanbul ignore next should not happen */
            case '\t':
                badChar = 'a tab character';
                break;
            case ',':
                badChar = 'flow indicator character ,';
                break;
            case '%':
                badChar = 'directive indicator character %';
                break;
            case '|':
            case '>': {
                badChar = `block scalar indicator ${source[0]}`;
                break;
            }
            case '@':
            case '`': {
                badChar = `reserved character ${source[0]}`;
                break;
            }
        }
        if (badChar)
            onError(0, 'BAD_SCALAR_START', `Plain value cannot start with ${badChar}`);
        return foldLines(source);
    }
    function singleQuotedValue(source, onError) {
        if (source[source.length - 1] !== "'" || source.length === 1)
            onError(source.length, 'MISSING_CHAR', "Missing closing 'quote");
        return foldLines(source.slice(1, -1)).replace(/''/g, "'");
    }
    function foldLines(source) {
        /**
         * The negative lookbehind here and in the `re` RegExp is to
         * prevent causing a polynomial search time in certain cases.
         *
         * The try-catch is for Safari, which doesn't support this yet:
         * https://caniuse.com/js-regexp-lookbehind
         */
        let first, line;
        try {
            first = new RegExp('(.*?)(?<![ \t])[ \t]*\r?\n', 'sy');
            line = new RegExp('[ \t]*(.*?)(?:(?<![ \t])[ \t]*)?\r?\n', 'sy');
        }
        catch {
            first = /(.*?)[ \t]*\r?\n/sy;
            line = /[ \t]*(.*?)[ \t]*\r?\n/sy;
        }
        let match = first.exec(source);
        if (!match)
            return source;
        let res = match[1];
        let sep = ' ';
        let pos = first.lastIndex;
        line.lastIndex = pos;
        while ((match = line.exec(source))) {
            if (match[1] === '') {
                if (sep === '\n')
                    res += sep;
                else
                    sep = '\n';
            }
            else {
                res += sep + match[1];
                sep = ' ';
            }
            pos = line.lastIndex;
        }
        const last = /[ \t]*(.*)/sy;
        last.lastIndex = pos;
        match = last.exec(source);
        return res + sep + (match?.[1] ?? '');
    }
    function doubleQuotedValue(source, onError) {
        let res = '';
        for (let i = 1; i < source.length - 1; ++i) {
            const ch = source[i];
            if (ch === '\r' && source[i + 1] === '\n')
                continue;
            if (ch === '\n') {
                const { fold, offset } = foldNewline(source, i);
                res += fold;
                i = offset;
            }
            else if (ch === '\\') {
                let next = source[++i];
                const cc = escapeCodes[next];
                if (cc)
                    res += cc;
                else if (next === '\n') {
                    // skip escaped newlines, but still trim the following line
                    next = source[i + 1];
                    while (next === ' ' || next === '\t')
                        next = source[++i + 1];
                }
                else if (next === '\r' && source[i + 1] === '\n') {
                    // skip escaped CRLF newlines, but still trim the following line
                    next = source[++i + 1];
                    while (next === ' ' || next === '\t')
                        next = source[++i + 1];
                }
                else if (next === 'x' || next === 'u' || next === 'U') {
                    const length = { x: 2, u: 4, U: 8 }[next];
                    res += parseCharCode(source, i + 1, length, onError);
                    i += length;
                }
                else {
                    const raw = source.substr(i - 1, 2);
                    onError(i - 1, 'BAD_DQ_ESCAPE', `Invalid escape sequence ${raw}`);
                    res += raw;
                }
            }
            else if (ch === ' ' || ch === '\t') {
                // trim trailing whitespace
                const wsStart = i;
                let next = source[i + 1];
                while (next === ' ' || next === '\t')
                    next = source[++i + 1];
                if (next !== '\n' && !(next === '\r' && source[i + 2] === '\n'))
                    res += i > wsStart ? source.slice(wsStart, i + 1) : ch;
            }
            else {
                res += ch;
            }
        }
        if (source[source.length - 1] !== '"' || source.length === 1)
            onError(source.length, 'MISSING_CHAR', 'Missing closing "quote');
        return res;
    }
    /**
     * Fold a single newline into a space, multiple newlines to N - 1 newlines.
     * Presumes `source[offset] === '\n'`
     */
    function foldNewline(source, offset) {
        let fold = '';
        let ch = source[offset + 1];
        while (ch === ' ' || ch === '\t' || ch === '\n' || ch === '\r') {
            if (ch === '\r' && source[offset + 2] !== '\n')
                break;
            if (ch === '\n')
                fold += '\n';
            offset += 1;
            ch = source[offset + 1];
        }
        if (!fold)
            fold = ' ';
        return { fold, offset };
    }
    const escapeCodes = {
        '0': '\0', // null character
        a: '\x07', // bell character
        b: '\b', // backspace
        e: '\x1b', // escape character
        f: '\f', // form feed
        n: '\n', // line feed
        r: '\r', // carriage return
        t: '\t', // horizontal tab
        v: '\v', // vertical tab
        N: '\u0085', // Unicode next line
        _: '\u00a0', // Unicode non-breaking space
        L: '\u2028', // Unicode line separator
        P: '\u2029', // Unicode paragraph separator
        ' ': ' ',
        '"': '"',
        '/': '/',
        '\\': '\\',
        '\t': '\t'
    };
    function parseCharCode(source, offset, length, onError) {
        const cc = source.substr(offset, length);
        const ok = cc.length === length && /^[0-9a-fA-F]+$/.test(cc);
        const code = ok ? parseInt(cc, 16) : NaN;
        if (isNaN(code)) {
            const raw = source.substr(offset - 2, length + 2);
            onError(offset - 2, 'BAD_DQ_ESCAPE', `Invalid escape sequence ${raw}`);
            return raw;
        }
        return String.fromCodePoint(code);
    }

    function composeScalar(ctx, token, tagToken, onError) {
        const { value, type, comment, range } = token.type === 'block-scalar'
            ? resolveBlockScalar(ctx, token, onError)
            : resolveFlowScalar(token, ctx.options.strict, onError);
        const tagName = tagToken
            ? ctx.directives.tagName(tagToken.source, msg => onError(tagToken, 'TAG_RESOLVE_FAILED', msg))
            : null;
        const tag = tagToken && tagName
            ? findScalarTagByName(ctx.schema, value, tagName, tagToken, onError)
            : token.type === 'scalar'
                ? findScalarTagByTest(ctx, value, token, onError)
                : ctx.schema[SCALAR$1];
        let scalar;
        try {
            const res = tag.resolve(value, msg => onError(tagToken ?? token, 'TAG_RESOLVE_FAILED', msg), ctx.options);
            scalar = isScalar$1(res) ? res : new Scalar(res);
        }
        catch (error) {
            const msg = error instanceof Error ? error.message : String(error);
            onError(tagToken ?? token, 'TAG_RESOLVE_FAILED', msg);
            scalar = new Scalar(value);
        }
        scalar.range = range;
        scalar.source = value;
        if (type)
            scalar.type = type;
        if (tagName)
            scalar.tag = tagName;
        if (tag.format)
            scalar.format = tag.format;
        if (comment)
            scalar.comment = comment;
        return scalar;
    }
    function findScalarTagByName(schema, value, tagName, tagToken, onError) {
        if (tagName === '!')
            return schema[SCALAR$1]; // non-specific tag
        const matchWithTest = [];
        for (const tag of schema.tags) {
            if (!tag.collection && tag.tag === tagName) {
                if (tag.default && tag.test)
                    matchWithTest.push(tag);
                else
                    return tag;
            }
        }
        for (const tag of matchWithTest)
            if (tag.test?.test(value))
                return tag;
        const kt = schema.knownTags[tagName];
        if (kt && !kt.collection) {
            // Ensure that the known tag is available for stringifying,
            // but does not get used by default.
            schema.tags.push(Object.assign({}, kt, { default: false, test: undefined }));
            return kt;
        }
        onError(tagToken, 'TAG_RESOLVE_FAILED', `Unresolved tag: ${tagName}`, tagName !== 'tag:yaml.org,2002:str');
        return schema[SCALAR$1];
    }
    function findScalarTagByTest({ directives, schema }, value, token, onError) {
        const tag = schema.tags.find(tag => tag.default && tag.test?.test(value)) || schema[SCALAR$1];
        if (schema.compat) {
            const compat = schema.compat.find(tag => tag.default && tag.test?.test(value)) ??
                schema[SCALAR$1];
            if (tag.tag !== compat.tag) {
                const ts = directives.tagString(tag.tag);
                const cs = directives.tagString(compat.tag);
                const msg = `Value may be parsed as either ${ts} or ${cs}`;
                onError(token, 'TAG_RESOLVE_FAILED', msg, true);
            }
        }
        return tag;
    }

    function emptyScalarPosition(offset, before, pos) {
        if (before) {
            if (pos === null)
                pos = before.length;
            for (let i = pos - 1; i >= 0; --i) {
                let st = before[i];
                switch (st.type) {
                    case 'space':
                    case 'comment':
                    case 'newline':
                        offset -= st.source.length;
                        continue;
                }
                // Technically, an empty scalar is immediately after the last non-empty
                // node, but it's more useful to place it after any whitespace.
                st = before[++i];
                while (st?.type === 'space') {
                    offset += st.source.length;
                    st = before[++i];
                }
                break;
            }
        }
        return offset;
    }

    const CN = { composeNode, composeEmptyNode };
    function composeNode(ctx, token, props, onError) {
        const { spaceBefore, comment, anchor, tag } = props;
        let node;
        let isSrcToken = true;
        switch (token.type) {
            case 'alias':
                node = composeAlias(ctx, token, onError);
                if (anchor || tag)
                    onError(token, 'ALIAS_PROPS', 'An alias node must not specify any properties');
                break;
            case 'scalar':
            case 'single-quoted-scalar':
            case 'double-quoted-scalar':
            case 'block-scalar':
                node = composeScalar(ctx, token, tag, onError);
                if (anchor)
                    node.anchor = anchor.source.substring(1);
                break;
            case 'block-map':
            case 'block-seq':
            case 'flow-collection':
                node = composeCollection(CN, ctx, token, props, onError);
                if (anchor)
                    node.anchor = anchor.source.substring(1);
                break;
            default: {
                const message = token.type === 'error'
                    ? token.message
                    : `Unsupported token (type: ${token.type})`;
                onError(token, 'UNEXPECTED_TOKEN', message);
                node = composeEmptyNode(ctx, token.offset, undefined, null, props, onError);
                isSrcToken = false;
            }
        }
        if (anchor && node.anchor === '')
            onError(anchor, 'BAD_ALIAS', 'Anchor cannot be an empty string');
        if (spaceBefore)
            node.spaceBefore = true;
        if (comment) {
            if (token.type === 'scalar' && token.source === '')
                node.comment = comment;
            else
                node.commentBefore = comment;
        }
        // @ts-expect-error Type checking misses meaning of isSrcToken
        if (ctx.options.keepSourceTokens && isSrcToken)
            node.srcToken = token;
        return node;
    }
    function composeEmptyNode(ctx, offset, before, pos, { spaceBefore, comment, anchor, tag, end }, onError) {
        const token = {
            type: 'scalar',
            offset: emptyScalarPosition(offset, before, pos),
            indent: -1,
            source: ''
        };
        const node = composeScalar(ctx, token, tag, onError);
        if (anchor) {
            node.anchor = anchor.source.substring(1);
            if (node.anchor === '')
                onError(anchor, 'BAD_ALIAS', 'Anchor cannot be an empty string');
        }
        if (spaceBefore)
            node.spaceBefore = true;
        if (comment) {
            node.comment = comment;
            node.range[2] = end;
        }
        return node;
    }
    function composeAlias({ options }, { offset, source, end }, onError) {
        const alias = new Alias(source.substring(1));
        if (alias.source === '')
            onError(offset, 'BAD_ALIAS', 'Alias cannot be an empty string');
        if (alias.source.endsWith(':'))
            onError(offset + source.length - 1, 'BAD_ALIAS', 'Alias ending in : is ambiguous', true);
        const valueEnd = offset + source.length;
        const re = resolveEnd(end, valueEnd, options.strict, onError);
        alias.range = [offset, valueEnd, re.offset];
        if (re.comment)
            alias.comment = re.comment;
        return alias;
    }

    function composeDoc(options, directives, { offset, start, value, end }, onError) {
        const opts = Object.assign({ _directives: directives }, options);
        const doc = new Document(undefined, opts);
        const ctx = {
            atRoot: true,
            directives: doc.directives,
            options: doc.options,
            schema: doc.schema
        };
        const props = resolveProps(start, {
            indicator: 'doc-start',
            next: value ?? end?.[0],
            offset,
            onError,
            parentIndent: 0,
            startOnNewline: true
        });
        if (props.found) {
            doc.directives.docStart = true;
            if (value &&
                (value.type === 'block-map' || value.type === 'block-seq') &&
                !props.hasNewline)
                onError(props.end, 'MISSING_CHAR', 'Block collection cannot start on same line with directives-end marker');
        }
        // @ts-expect-error If Contents is set, let's trust the user
        doc.contents = value
            ? composeNode(ctx, value, props, onError)
            : composeEmptyNode(ctx, props.end, start, null, props, onError);
        const contentEnd = doc.contents.range[2];
        const re = resolveEnd(end, contentEnd, false, onError);
        if (re.comment)
            doc.comment = re.comment;
        doc.range = [offset, contentEnd, re.offset];
        return doc;
    }

    function getErrorPos(src) {
        if (typeof src === 'number')
            return [src, src + 1];
        if (Array.isArray(src))
            return src.length === 2 ? src : [src[0], src[1]];
        const { offset, source } = src;
        return [offset, offset + (typeof source === 'string' ? source.length : 1)];
    }
    function parsePrelude(prelude) {
        let comment = '';
        let atComment = false;
        let afterEmptyLine = false;
        for (let i = 0; i < prelude.length; ++i) {
            const source = prelude[i];
            switch (source[0]) {
                case '#':
                    comment +=
                        (comment === '' ? '' : afterEmptyLine ? '\n\n' : '\n') +
                            (source.substring(1) || ' ');
                    atComment = true;
                    afterEmptyLine = false;
                    break;
                case '%':
                    if (prelude[i + 1]?.[0] !== '#')
                        i += 1;
                    atComment = false;
                    break;
                default:
                    // This may be wrong after doc-end, but in that case it doesn't matter
                    if (!atComment)
                        afterEmptyLine = true;
                    atComment = false;
            }
        }
        return { comment, afterEmptyLine };
    }
    /**
     * Compose a stream of CST nodes into a stream of YAML Documents.
     *
     * ```ts
     * import { Composer, Parser } from 'yaml'
     *
     * const src: string = ...
     * const tokens = new Parser().parse(src)
     * const docs = new Composer().compose(tokens)
     * ```
     */
    class Composer {
        constructor(options = {}) {
            this.doc = null;
            this.atDirectives = false;
            this.prelude = [];
            this.errors = [];
            this.warnings = [];
            this.onError = (source, code, message, warning) => {
                const pos = getErrorPos(source);
                if (warning)
                    this.warnings.push(new YAMLWarning(pos, code, message));
                else
                    this.errors.push(new YAMLParseError(pos, code, message));
            };
            // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
            this.directives = new Directives({ version: options.version || '1.2' });
            this.options = options;
        }
        decorate(doc, afterDoc) {
            const { comment, afterEmptyLine } = parsePrelude(this.prelude);
            //console.log({ dc: doc.comment, prelude, comment })
            if (comment) {
                const dc = doc.contents;
                if (afterDoc) {
                    doc.comment = doc.comment ? `${doc.comment}\n${comment}` : comment;
                }
                else if (afterEmptyLine || doc.directives.docStart || !dc) {
                    doc.commentBefore = comment;
                }
                else if (isCollection$1(dc) && !dc.flow && dc.items.length > 0) {
                    let it = dc.items[0];
                    if (isPair(it))
                        it = it.key;
                    const cb = it.commentBefore;
                    it.commentBefore = cb ? `${comment}\n${cb}` : comment;
                }
                else {
                    const cb = dc.commentBefore;
                    dc.commentBefore = cb ? `${comment}\n${cb}` : comment;
                }
            }
            if (afterDoc) {
                Array.prototype.push.apply(doc.errors, this.errors);
                Array.prototype.push.apply(doc.warnings, this.warnings);
            }
            else {
                doc.errors = this.errors;
                doc.warnings = this.warnings;
            }
            this.prelude = [];
            this.errors = [];
            this.warnings = [];
        }
        /**
         * Current stream status information.
         *
         * Mostly useful at the end of input for an empty stream.
         */
        streamInfo() {
            return {
                comment: parsePrelude(this.prelude).comment,
                directives: this.directives,
                errors: this.errors,
                warnings: this.warnings
            };
        }
        /**
         * Compose tokens into documents.
         *
         * @param forceDoc - If the stream contains no document, still emit a final document including any comments and directives that would be applied to a subsequent document.
         * @param endOffset - Should be set if `forceDoc` is also set, to set the document range end and to indicate errors correctly.
         */
        *compose(tokens, forceDoc = false, endOffset = -1) {
            for (const token of tokens)
                yield* this.next(token);
            yield* this.end(forceDoc, endOffset);
        }
        /** Advance the composer by one CST token. */
        *next(token) {
            switch (token.type) {
                case 'directive':
                    this.directives.add(token.source, (offset, message, warning) => {
                        const pos = getErrorPos(token);
                        pos[0] += offset;
                        this.onError(pos, 'BAD_DIRECTIVE', message, warning);
                    });
                    this.prelude.push(token.source);
                    this.atDirectives = true;
                    break;
                case 'document': {
                    const doc = composeDoc(this.options, this.directives, token, this.onError);
                    if (this.atDirectives && !doc.directives.docStart)
                        this.onError(token, 'MISSING_CHAR', 'Missing directives-end/doc-start indicator line');
                    this.decorate(doc, false);
                    if (this.doc)
                        yield this.doc;
                    this.doc = doc;
                    this.atDirectives = false;
                    break;
                }
                case 'byte-order-mark':
                case 'space':
                    break;
                case 'comment':
                case 'newline':
                    this.prelude.push(token.source);
                    break;
                case 'error': {
                    const msg = token.source
                        ? `${token.message}: ${JSON.stringify(token.source)}`
                        : token.message;
                    const error = new YAMLParseError(getErrorPos(token), 'UNEXPECTED_TOKEN', msg);
                    if (this.atDirectives || !this.doc)
                        this.errors.push(error);
                    else
                        this.doc.errors.push(error);
                    break;
                }
                case 'doc-end': {
                    if (!this.doc) {
                        const msg = 'Unexpected doc-end without preceding document';
                        this.errors.push(new YAMLParseError(getErrorPos(token), 'UNEXPECTED_TOKEN', msg));
                        break;
                    }
                    this.doc.directives.docEnd = true;
                    const end = resolveEnd(token.end, token.offset + token.source.length, this.doc.options.strict, this.onError);
                    this.decorate(this.doc, true);
                    if (end.comment) {
                        const dc = this.doc.comment;
                        this.doc.comment = dc ? `${dc}\n${end.comment}` : end.comment;
                    }
                    this.doc.range[2] = end.offset;
                    break;
                }
                default:
                    this.errors.push(new YAMLParseError(getErrorPos(token), 'UNEXPECTED_TOKEN', `Unsupported token ${token.type}`));
            }
        }
        /**
         * Call at end of input to yield any remaining document.
         *
         * @param forceDoc - If the stream contains no document, still emit a final document including any comments and directives that would be applied to a subsequent document.
         * @param endOffset - Should be set if `forceDoc` is also set, to set the document range end and to indicate errors correctly.
         */
        *end(forceDoc = false, endOffset = -1) {
            if (this.doc) {
                this.decorate(this.doc, true);
                yield this.doc;
                this.doc = null;
            }
            else if (forceDoc) {
                const opts = Object.assign({ _directives: this.directives }, this.options);
                const doc = new Document(undefined, opts);
                if (this.atDirectives)
                    this.onError(endOffset, 'MISSING_CHAR', 'Missing directives-end indicator line');
                doc.range = [0, endOffset, endOffset];
                this.decorate(doc, false);
                yield doc;
            }
        }
    }

    function resolveAsScalar(token, strict = true, onError) {
        if (token) {
            const _onError = (pos, code, message) => {
                const offset = typeof pos === 'number' ? pos : Array.isArray(pos) ? pos[0] : pos.offset;
                if (onError)
                    onError(offset, code, message);
                else
                    throw new YAMLParseError([offset, offset + 1], code, message);
            };
            switch (token.type) {
                case 'scalar':
                case 'single-quoted-scalar':
                case 'double-quoted-scalar':
                    return resolveFlowScalar(token, strict, _onError);
                case 'block-scalar':
                    return resolveBlockScalar({ options: { strict } }, token, _onError);
            }
        }
        return null;
    }
    /**
     * Create a new scalar token with `value`
     *
     * Values that represent an actual string but may be parsed as a different type should use a `type` other than `'PLAIN'`,
     * as this function does not support any schema operations and won't check for such conflicts.
     *
     * @param value The string representation of the value, which will have its content properly indented.
     * @param context.end Comments and whitespace after the end of the value, or after the block scalar header. If undefined, a newline will be added.
     * @param context.implicitKey Being within an implicit key may affect the resolved type of the token's value.
     * @param context.indent The indent level of the token.
     * @param context.inFlow Is this scalar within a flow collection? This may affect the resolved type of the token's value.
     * @param context.offset The offset position of the token.
     * @param context.type The preferred type of the scalar token. If undefined, the previous type of the `token` will be used, defaulting to `'PLAIN'`.
     */
    function createScalarToken(value, context) {
        const { implicitKey = false, indent, inFlow = false, offset = -1, type = 'PLAIN' } = context;
        const source = stringifyString({ type, value }, {
            implicitKey,
            indent: indent > 0 ? ' '.repeat(indent) : '',
            inFlow,
            options: { blockQuote: true, lineWidth: -1 }
        });
        const end = context.end ?? [
            { type: 'newline', offset: -1, indent, source: '\n' }
        ];
        switch (source[0]) {
            case '|':
            case '>': {
                const he = source.indexOf('\n');
                const head = source.substring(0, he);
                const body = source.substring(he + 1) + '\n';
                const props = [
                    { type: 'block-scalar-header', offset, indent, source: head }
                ];
                if (!addEndtoBlockProps(props, end))
                    props.push({ type: 'newline', offset: -1, indent, source: '\n' });
                return { type: 'block-scalar', offset, indent, props, source: body };
            }
            case '"':
                return { type: 'double-quoted-scalar', offset, indent, source, end };
            case "'":
                return { type: 'single-quoted-scalar', offset, indent, source, end };
            default:
                return { type: 'scalar', offset, indent, source, end };
        }
    }
    /**
     * Set the value of `token` to the given string `value`, overwriting any previous contents and type that it may have.
     *
     * Best efforts are made to retain any comments previously associated with the `token`,
     * though all contents within a collection's `items` will be overwritten.
     *
     * Values that represent an actual string but may be parsed as a different type should use a `type` other than `'PLAIN'`,
     * as this function does not support any schema operations and won't check for such conflicts.
     *
     * @param token Any token. If it does not include an `indent` value, the value will be stringified as if it were an implicit key.
     * @param value The string representation of the value, which will have its content properly indented.
     * @param context.afterKey In most cases, values after a key should have an additional level of indentation.
     * @param context.implicitKey Being within an implicit key may affect the resolved type of the token's value.
     * @param context.inFlow Being within a flow collection may affect the resolved type of the token's value.
     * @param context.type The preferred type of the scalar token. If undefined, the previous type of the `token` will be used, defaulting to `'PLAIN'`.
     */
    function setScalarValue(token, value, context = {}) {
        let { afterKey = false, implicitKey = false, inFlow = false, type } = context;
        let indent = 'indent' in token ? token.indent : null;
        if (afterKey && typeof indent === 'number')
            indent += 2;
        if (!type)
            switch (token.type) {
                case 'single-quoted-scalar':
                    type = 'QUOTE_SINGLE';
                    break;
                case 'double-quoted-scalar':
                    type = 'QUOTE_DOUBLE';
                    break;
                case 'block-scalar': {
                    const header = token.props[0];
                    if (header.type !== 'block-scalar-header')
                        throw new Error('Invalid block scalar header');
                    type = header.source[0] === '>' ? 'BLOCK_FOLDED' : 'BLOCK_LITERAL';
                    break;
                }
                default:
                    type = 'PLAIN';
            }
        const source = stringifyString({ type, value }, {
            implicitKey: implicitKey || indent === null,
            indent: indent !== null && indent > 0 ? ' '.repeat(indent) : '',
            inFlow,
            options: { blockQuote: true, lineWidth: -1 }
        });
        switch (source[0]) {
            case '|':
            case '>':
                setBlockScalarValue(token, source);
                break;
            case '"':
                setFlowScalarValue(token, source, 'double-quoted-scalar');
                break;
            case "'":
                setFlowScalarValue(token, source, 'single-quoted-scalar');
                break;
            default:
                setFlowScalarValue(token, source, 'scalar');
        }
    }
    function setBlockScalarValue(token, source) {
        const he = source.indexOf('\n');
        const head = source.substring(0, he);
        const body = source.substring(he + 1) + '\n';
        if (token.type === 'block-scalar') {
            const header = token.props[0];
            if (header.type !== 'block-scalar-header')
                throw new Error('Invalid block scalar header');
            header.source = head;
            token.source = body;
        }
        else {
            const { offset } = token;
            const indent = 'indent' in token ? token.indent : -1;
            const props = [
                { type: 'block-scalar-header', offset, indent, source: head }
            ];
            if (!addEndtoBlockProps(props, 'end' in token ? token.end : undefined))
                props.push({ type: 'newline', offset: -1, indent, source: '\n' });
            for (const key of Object.keys(token))
                if (key !== 'type' && key !== 'offset')
                    delete token[key];
            Object.assign(token, { type: 'block-scalar', indent, props, source: body });
        }
    }
    /** @returns `true` if last token is a newline */
    function addEndtoBlockProps(props, end) {
        if (end)
            for (const st of end)
                switch (st.type) {
                    case 'space':
                    case 'comment':
                        props.push(st);
                        break;
                    case 'newline':
                        props.push(st);
                        return true;
                }
        return false;
    }
    function setFlowScalarValue(token, source, type) {
        switch (token.type) {
            case 'scalar':
            case 'double-quoted-scalar':
            case 'single-quoted-scalar':
                token.type = type;
                token.source = source;
                break;
            case 'block-scalar': {
                const end = token.props.slice(1);
                let oa = source.length;
                if (token.props[0].type === 'block-scalar-header')
                    oa -= token.props[0].source.length;
                for (const tok of end)
                    tok.offset += oa;
                delete token.props;
                Object.assign(token, { type, source, end });
                break;
            }
            case 'block-map':
            case 'block-seq': {
                const offset = token.offset + source.length;
                const nl = { type: 'newline', offset, indent: token.indent, source: '\n' };
                delete token.items;
                Object.assign(token, { type, source, end: [nl] });
                break;
            }
            default: {
                const indent = 'indent' in token ? token.indent : -1;
                const end = 'end' in token && Array.isArray(token.end)
                    ? token.end.filter(st => st.type === 'space' ||
                        st.type === 'comment' ||
                        st.type === 'newline')
                    : [];
                for (const key of Object.keys(token))
                    if (key !== 'type' && key !== 'offset')
                        delete token[key];
                Object.assign(token, { type, indent, source, end });
            }
        }
    }

    /**
     * Stringify a CST document, token, or collection item
     *
     * Fair warning: This applies no validation whatsoever, and
     * simply concatenates the sources in their logical order.
     */
    const stringify$1 = (cst) => 'type' in cst ? stringifyToken(cst) : stringifyItem(cst);
    function stringifyToken(token) {
        switch (token.type) {
            case 'block-scalar': {
                let res = '';
                for (const tok of token.props)
                    res += stringifyToken(tok);
                return res + token.source;
            }
            case 'block-map':
            case 'block-seq': {
                let res = '';
                for (const item of token.items)
                    res += stringifyItem(item);
                return res;
            }
            case 'flow-collection': {
                let res = token.start.source;
                for (const item of token.items)
                    res += stringifyItem(item);
                for (const st of token.end)
                    res += st.source;
                return res;
            }
            case 'document': {
                let res = stringifyItem(token);
                if (token.end)
                    for (const st of token.end)
                        res += st.source;
                return res;
            }
            default: {
                let res = token.source;
                if ('end' in token && token.end)
                    for (const st of token.end)
                        res += st.source;
                return res;
            }
        }
    }
    function stringifyItem({ start, key, sep, value }) {
        let res = '';
        for (const st of start)
            res += st.source;
        if (key)
            res += stringifyToken(key);
        if (sep)
            for (const st of sep)
                res += st.source;
        if (value)
            res += stringifyToken(value);
        return res;
    }

    const BREAK = Symbol('break visit');
    const SKIP = Symbol('skip children');
    const REMOVE = Symbol('remove item');
    /**
     * Apply a visitor to a CST document or item.
     *
     * Walks through the tree (depth-first) starting from the root, calling a
     * `visitor` function with two arguments when entering each item:
     *   - `item`: The current item, which included the following members:
     *     - `start: SourceToken[]` – Source tokens before the key or value,
     *       possibly including its anchor or tag.
     *     - `key?: Token | null` – Set for pair values. May then be `null`, if
     *       the key before the `:` separator is empty.
     *     - `sep?: SourceToken[]` – Source tokens between the key and the value,
     *       which should include the `:` map value indicator if `value` is set.
     *     - `value?: Token` – The value of a sequence item, or of a map pair.
     *   - `path`: The steps from the root to the current node, as an array of
     *     `['key' | 'value', number]` tuples.
     *
     * The return value of the visitor may be used to control the traversal:
     *   - `undefined` (default): Do nothing and continue
     *   - `visit.SKIP`: Do not visit the children of this token, continue with
     *      next sibling
     *   - `visit.BREAK`: Terminate traversal completely
     *   - `visit.REMOVE`: Remove the current item, then continue with the next one
     *   - `number`: Set the index of the next step. This is useful especially if
     *     the index of the current token has changed.
     *   - `function`: Define the next visitor for this item. After the original
     *     visitor is called on item entry, next visitors are called after handling
     *     a non-empty `key` and when exiting the item.
     */
    function visit(cst, visitor) {
        if ('type' in cst && cst.type === 'document')
            cst = { start: cst.start, value: cst.value };
        _visit(Object.freeze([]), cst, visitor);
    }
    // Without the `as symbol` casts, TS declares these in the `visit`
    // namespace using `var`, but then complains about that because
    // `unique symbol` must be `const`.
    /** Terminate visit traversal completely */
    visit.BREAK = BREAK;
    /** Do not visit the children of the current item */
    visit.SKIP = SKIP;
    /** Remove the current item */
    visit.REMOVE = REMOVE;
    /** Find the item at `path` from `cst` as the root */
    visit.itemAtPath = (cst, path) => {
        let item = cst;
        for (const [field, index] of path) {
            const tok = item?.[field];
            if (tok && 'items' in tok) {
                item = tok.items[index];
            }
            else
                return undefined;
        }
        return item;
    };
    /**
     * Get the immediate parent collection of the item at `path` from `cst` as the root.
     *
     * Throws an error if the collection is not found, which should never happen if the item itself exists.
     */
    visit.parentCollection = (cst, path) => {
        const parent = visit.itemAtPath(cst, path.slice(0, -1));
        const field = path[path.length - 1][0];
        const coll = parent?.[field];
        if (coll && 'items' in coll)
            return coll;
        throw new Error('Parent collection not found');
    };
    function _visit(path, item, visitor) {
        let ctrl = visitor(item, path);
        if (typeof ctrl === 'symbol')
            return ctrl;
        for (const field of ['key', 'value']) {
            const token = item[field];
            if (token && 'items' in token) {
                for (let i = 0; i < token.items.length; ++i) {
                    const ci = _visit(Object.freeze(path.concat([[field, i]])), token.items[i], visitor);
                    if (typeof ci === 'number')
                        i = ci - 1;
                    else if (ci === BREAK)
                        return BREAK;
                    else if (ci === REMOVE) {
                        token.items.splice(i, 1);
                        i -= 1;
                    }
                }
                if (typeof ctrl === 'function' && field === 'key')
                    ctrl = ctrl(item, path);
            }
        }
        return typeof ctrl === 'function' ? ctrl(item, path) : ctrl;
    }

    /** The byte order mark */
    const BOM = '\u{FEFF}';
    /** Start of doc-mode */
    const DOCUMENT = '\x02'; // C0: Start of Text
    /** Unexpected end of flow-mode */
    const FLOW_END = '\x18'; // C0: Cancel
    /** Next token is a scalar value */
    const SCALAR = '\x1f'; // C0: Unit Separator
    /** @returns `true` if `token` is a flow or block collection */
    const isCollection = (token) => !!token && 'items' in token;
    /** @returns `true` if `token` is a flow or block scalar; not an alias */
    const isScalar = (token) => !!token &&
        (token.type === 'scalar' ||
            token.type === 'single-quoted-scalar' ||
            token.type === 'double-quoted-scalar' ||
            token.type === 'block-scalar');
    /* istanbul ignore next */
    /** Get a printable representation of a lexer token */
    function prettyToken(token) {
        switch (token) {
            case BOM:
                return '<BOM>';
            case DOCUMENT:
                return '<DOC>';
            case FLOW_END:
                return '<FLOW_END>';
            case SCALAR:
                return '<SCALAR>';
            default:
                return JSON.stringify(token);
        }
    }
    /** Identify the type of a lexer token. May return `null` for unknown tokens. */
    function tokenType(source) {
        switch (source) {
            case BOM:
                return 'byte-order-mark';
            case DOCUMENT:
                return 'doc-mode';
            case FLOW_END:
                return 'flow-error-end';
            case SCALAR:
                return 'scalar';
            case '---':
                return 'doc-start';
            case '...':
                return 'doc-end';
            case '':
            case '\n':
            case '\r\n':
                return 'newline';
            case '-':
                return 'seq-item-ind';
            case '?':
                return 'explicit-key-ind';
            case ':':
                return 'map-value-ind';
            case '{':
                return 'flow-map-start';
            case '}':
                return 'flow-map-end';
            case '[':
                return 'flow-seq-start';
            case ']':
                return 'flow-seq-end';
            case ',':
                return 'comma';
        }
        switch (source[0]) {
            case ' ':
            case '\t':
                return 'space';
            case '#':
                return 'comment';
            case '%':
                return 'directive-line';
            case '*':
                return 'alias';
            case '&':
                return 'anchor';
            case '!':
                return 'tag';
            case "'":
                return 'single-quoted-scalar';
            case '"':
                return 'double-quoted-scalar';
            case '|':
            case '>':
                return 'block-scalar-header';
        }
        return null;
    }

    var cst = /*#__PURE__*/Object.freeze({
        __proto__: null,
        BOM: BOM,
        DOCUMENT: DOCUMENT,
        FLOW_END: FLOW_END,
        SCALAR: SCALAR,
        createScalarToken: createScalarToken,
        isCollection: isCollection,
        isScalar: isScalar,
        prettyToken: prettyToken,
        resolveAsScalar: resolveAsScalar,
        setScalarValue: setScalarValue,
        stringify: stringify$1,
        tokenType: tokenType,
        visit: visit
    });

    /*
    START -> stream

    stream
      directive -> line-end -> stream
      indent + line-end -> stream
      [else] -> line-start

    line-end
      comment -> line-end
      newline -> .
      input-end -> END

    line-start
      doc-start -> doc
      doc-end -> stream
      [else] -> indent -> block-start

    block-start
      seq-item-start -> block-start
      explicit-key-start -> block-start
      map-value-start -> block-start
      [else] -> doc

    doc
      line-end -> line-start
      spaces -> doc
      anchor -> doc
      tag -> doc
      flow-start -> flow -> doc
      flow-end -> error -> doc
      seq-item-start -> error -> doc
      explicit-key-start -> error -> doc
      map-value-start -> doc
      alias -> doc
      quote-start -> quoted-scalar -> doc
      block-scalar-header -> line-end -> block-scalar(min) -> line-start
      [else] -> plain-scalar(false, min) -> doc

    flow
      line-end -> flow
      spaces -> flow
      anchor -> flow
      tag -> flow
      flow-start -> flow -> flow
      flow-end -> .
      seq-item-start -> error -> flow
      explicit-key-start -> flow
      map-value-start -> flow
      alias -> flow
      quote-start -> quoted-scalar -> flow
      comma -> flow
      [else] -> plain-scalar(true, 0) -> flow

    quoted-scalar
      quote-end -> .
      [else] -> quoted-scalar

    block-scalar(min)
      newline + peek(indent < min) -> .
      [else] -> block-scalar(min)

    plain-scalar(is-flow, min)
      scalar-end(is-flow) -> .
      peek(newline + (indent < min)) -> .
      [else] -> plain-scalar(min)
    */
    function isEmpty(ch) {
        switch (ch) {
            case undefined:
            case ' ':
            case '\n':
            case '\r':
            case '\t':
                return true;
            default:
                return false;
        }
    }
    const hexDigits = new Set('0123456789ABCDEFabcdef');
    const tagChars = new Set("0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-#;/?:@&=+$_.!~*'()");
    const flowIndicatorChars = new Set(',[]{}');
    const invalidAnchorChars = new Set(' ,[]{}\n\r\t');
    const isNotAnchorChar = (ch) => !ch || invalidAnchorChars.has(ch);
    /**
     * Splits an input string into lexical tokens, i.e. smaller strings that are
     * easily identifiable by `tokens.tokenType()`.
     *
     * Lexing starts always in a "stream" context. Incomplete input may be buffered
     * until a complete token can be emitted.
     *
     * In addition to slices of the original input, the following control characters
     * may also be emitted:
     *
     * - `\x02` (Start of Text): A document starts with the next token
     * - `\x18` (Cancel): Unexpected end of flow-mode (indicates an error)
     * - `\x1f` (Unit Separator): Next token is a scalar value
     * - `\u{FEFF}` (Byte order mark): Emitted separately outside documents
     */
    class Lexer {
        constructor() {
            /**
             * Flag indicating whether the end of the current buffer marks the end of
             * all input
             */
            this.atEnd = false;
            /**
             * Explicit indent set in block scalar header, as an offset from the current
             * minimum indent, so e.g. set to 1 from a header `|2+`. Set to -1 if not
             * explicitly set.
             */
            this.blockScalarIndent = -1;
            /**
             * Block scalars that include a + (keep) chomping indicator in their header
             * include trailing empty lines, which are otherwise excluded from the
             * scalar's contents.
             */
            this.blockScalarKeep = false;
            /** Current input */
            this.buffer = '';
            /**
             * Flag noting whether the map value indicator : can immediately follow this
             * node within a flow context.
             */
            this.flowKey = false;
            /** Count of surrounding flow collection levels. */
            this.flowLevel = 0;
            /**
             * Minimum level of indentation required for next lines to be parsed as a
             * part of the current scalar value.
             */
            this.indentNext = 0;
            /** Indentation level of the current line. */
            this.indentValue = 0;
            /** Position of the next \n character. */
            this.lineEndPos = null;
            /** Stores the state of the lexer if reaching the end of incpomplete input */
            this.next = null;
            /** A pointer to `buffer`; the current position of the lexer. */
            this.pos = 0;
        }
        /**
         * Generate YAML tokens from the `source` string. If `incomplete`,
         * a part of the last line may be left as a buffer for the next call.
         *
         * @returns A generator of lexical tokens
         */
        *lex(source, incomplete = false) {
            if (source) {
                if (typeof source !== 'string')
                    throw TypeError('source is not a string');
                this.buffer = this.buffer ? this.buffer + source : source;
                this.lineEndPos = null;
            }
            this.atEnd = !incomplete;
            let next = this.next ?? 'stream';
            while (next && (incomplete || this.hasChars(1)))
                next = yield* this.parseNext(next);
        }
        atLineEnd() {
            let i = this.pos;
            let ch = this.buffer[i];
            while (ch === ' ' || ch === '\t')
                ch = this.buffer[++i];
            if (!ch || ch === '#' || ch === '\n')
                return true;
            if (ch === '\r')
                return this.buffer[i + 1] === '\n';
            return false;
        }
        charAt(n) {
            return this.buffer[this.pos + n];
        }
        continueScalar(offset) {
            let ch = this.buffer[offset];
            if (this.indentNext > 0) {
                let indent = 0;
                while (ch === ' ')
                    ch = this.buffer[++indent + offset];
                if (ch === '\r') {
                    const next = this.buffer[indent + offset + 1];
                    if (next === '\n' || (!next && !this.atEnd))
                        return offset + indent + 1;
                }
                return ch === '\n' || indent >= this.indentNext || (!ch && !this.atEnd)
                    ? offset + indent
                    : -1;
            }
            if (ch === '-' || ch === '.') {
                const dt = this.buffer.substr(offset, 3);
                if ((dt === '---' || dt === '...') && isEmpty(this.buffer[offset + 3]))
                    return -1;
            }
            return offset;
        }
        getLine() {
            let end = this.lineEndPos;
            if (typeof end !== 'number' || (end !== -1 && end < this.pos)) {
                end = this.buffer.indexOf('\n', this.pos);
                this.lineEndPos = end;
            }
            if (end === -1)
                return this.atEnd ? this.buffer.substring(this.pos) : null;
            if (this.buffer[end - 1] === '\r')
                end -= 1;
            return this.buffer.substring(this.pos, end);
        }
        hasChars(n) {
            return this.pos + n <= this.buffer.length;
        }
        setNext(state) {
            this.buffer = this.buffer.substring(this.pos);
            this.pos = 0;
            this.lineEndPos = null;
            this.next = state;
            return null;
        }
        peek(n) {
            return this.buffer.substr(this.pos, n);
        }
        *parseNext(next) {
            switch (next) {
                case 'stream':
                    return yield* this.parseStream();
                case 'line-start':
                    return yield* this.parseLineStart();
                case 'block-start':
                    return yield* this.parseBlockStart();
                case 'doc':
                    return yield* this.parseDocument();
                case 'flow':
                    return yield* this.parseFlowCollection();
                case 'quoted-scalar':
                    return yield* this.parseQuotedScalar();
                case 'block-scalar':
                    return yield* this.parseBlockScalar();
                case 'plain-scalar':
                    return yield* this.parsePlainScalar();
            }
        }
        *parseStream() {
            let line = this.getLine();
            if (line === null)
                return this.setNext('stream');
            if (line[0] === BOM) {
                yield* this.pushCount(1);
                line = line.substring(1);
            }
            if (line[0] === '%') {
                let dirEnd = line.length;
                let cs = line.indexOf('#');
                while (cs !== -1) {
                    const ch = line[cs - 1];
                    if (ch === ' ' || ch === '\t') {
                        dirEnd = cs - 1;
                        break;
                    }
                    else {
                        cs = line.indexOf('#', cs + 1);
                    }
                }
                while (true) {
                    const ch = line[dirEnd - 1];
                    if (ch === ' ' || ch === '\t')
                        dirEnd -= 1;
                    else
                        break;
                }
                const n = (yield* this.pushCount(dirEnd)) + (yield* this.pushSpaces(true));
                yield* this.pushCount(line.length - n); // possible comment
                this.pushNewline();
                return 'stream';
            }
            if (this.atLineEnd()) {
                const sp = yield* this.pushSpaces(true);
                yield* this.pushCount(line.length - sp);
                yield* this.pushNewline();
                return 'stream';
            }
            yield DOCUMENT;
            return yield* this.parseLineStart();
        }
        *parseLineStart() {
            const ch = this.charAt(0);
            if (!ch && !this.atEnd)
                return this.setNext('line-start');
            if (ch === '-' || ch === '.') {
                if (!this.atEnd && !this.hasChars(4))
                    return this.setNext('line-start');
                const s = this.peek(3);
                if ((s === '---' || s === '...') && isEmpty(this.charAt(3))) {
                    yield* this.pushCount(3);
                    this.indentValue = 0;
                    this.indentNext = 0;
                    return s === '---' ? 'doc' : 'stream';
                }
            }
            this.indentValue = yield* this.pushSpaces(false);
            if (this.indentNext > this.indentValue && !isEmpty(this.charAt(1)))
                this.indentNext = this.indentValue;
            return yield* this.parseBlockStart();
        }
        *parseBlockStart() {
            const [ch0, ch1] = this.peek(2);
            if (!ch1 && !this.atEnd)
                return this.setNext('block-start');
            if ((ch0 === '-' || ch0 === '?' || ch0 === ':') && isEmpty(ch1)) {
                const n = (yield* this.pushCount(1)) + (yield* this.pushSpaces(true));
                this.indentNext = this.indentValue + 1;
                this.indentValue += n;
                return yield* this.parseBlockStart();
            }
            return 'doc';
        }
        *parseDocument() {
            yield* this.pushSpaces(true);
            const line = this.getLine();
            if (line === null)
                return this.setNext('doc');
            let n = yield* this.pushIndicators();
            switch (line[n]) {
                case '#':
                    yield* this.pushCount(line.length - n);
                // fallthrough
                case undefined:
                    yield* this.pushNewline();
                    return yield* this.parseLineStart();
                case '{':
                case '[':
                    yield* this.pushCount(1);
                    this.flowKey = false;
                    this.flowLevel = 1;
                    return 'flow';
                case '}':
                case ']':
                    // this is an error
                    yield* this.pushCount(1);
                    return 'doc';
                case '*':
                    yield* this.pushUntil(isNotAnchorChar);
                    return 'doc';
                case '"':
                case "'":
                    return yield* this.parseQuotedScalar();
                case '|':
                case '>':
                    n += yield* this.parseBlockScalarHeader();
                    n += yield* this.pushSpaces(true);
                    yield* this.pushCount(line.length - n);
                    yield* this.pushNewline();
                    return yield* this.parseBlockScalar();
                default:
                    return yield* this.parsePlainScalar();
            }
        }
        *parseFlowCollection() {
            let nl, sp;
            let indent = -1;
            do {
                nl = yield* this.pushNewline();
                if (nl > 0) {
                    sp = yield* this.pushSpaces(false);
                    this.indentValue = indent = sp;
                }
                else {
                    sp = 0;
                }
                sp += yield* this.pushSpaces(true);
            } while (nl + sp > 0);
            const line = this.getLine();
            if (line === null)
                return this.setNext('flow');
            if ((indent !== -1 && indent < this.indentNext && line[0] !== '#') ||
                (indent === 0 &&
                    (line.startsWith('---') || line.startsWith('...')) &&
                    isEmpty(line[3]))) {
                // Allowing for the terminal ] or } at the same (rather than greater)
                // indent level as the initial [ or { is technically invalid, but
                // failing here would be surprising to users.
                const atFlowEndMarker = indent === this.indentNext - 1 &&
                    this.flowLevel === 1 &&
                    (line[0] === ']' || line[0] === '}');
                if (!atFlowEndMarker) {
                    // this is an error
                    this.flowLevel = 0;
                    yield FLOW_END;
                    return yield* this.parseLineStart();
                }
            }
            let n = 0;
            while (line[n] === ',') {
                n += yield* this.pushCount(1);
                n += yield* this.pushSpaces(true);
                this.flowKey = false;
            }
            n += yield* this.pushIndicators();
            switch (line[n]) {
                case undefined:
                    return 'flow';
                case '#':
                    yield* this.pushCount(line.length - n);
                    return 'flow';
                case '{':
                case '[':
                    yield* this.pushCount(1);
                    this.flowKey = false;
                    this.flowLevel += 1;
                    return 'flow';
                case '}':
                case ']':
                    yield* this.pushCount(1);
                    this.flowKey = true;
                    this.flowLevel -= 1;
                    return this.flowLevel ? 'flow' : 'doc';
                case '*':
                    yield* this.pushUntil(isNotAnchorChar);
                    return 'flow';
                case '"':
                case "'":
                    this.flowKey = true;
                    return yield* this.parseQuotedScalar();
                case ':': {
                    const next = this.charAt(1);
                    if (this.flowKey || isEmpty(next) || next === ',') {
                        this.flowKey = false;
                        yield* this.pushCount(1);
                        yield* this.pushSpaces(true);
                        return 'flow';
                    }
                }
                // fallthrough
                default:
                    this.flowKey = false;
                    return yield* this.parsePlainScalar();
            }
        }
        *parseQuotedScalar() {
            const quote = this.charAt(0);
            let end = this.buffer.indexOf(quote, this.pos + 1);
            if (quote === "'") {
                while (end !== -1 && this.buffer[end + 1] === "'")
                    end = this.buffer.indexOf("'", end + 2);
            }
            else {
                // double-quote
                while (end !== -1) {
                    let n = 0;
                    while (this.buffer[end - 1 - n] === '\\')
                        n += 1;
                    if (n % 2 === 0)
                        break;
                    end = this.buffer.indexOf('"', end + 1);
                }
            }
            // Only looking for newlines within the quotes
            const qb = this.buffer.substring(0, end);
            let nl = qb.indexOf('\n', this.pos);
            if (nl !== -1) {
                while (nl !== -1) {
                    const cs = this.continueScalar(nl + 1);
                    if (cs === -1)
                        break;
                    nl = qb.indexOf('\n', cs);
                }
                if (nl !== -1) {
                    // this is an error caused by an unexpected unindent
                    end = nl - (qb[nl - 1] === '\r' ? 2 : 1);
                }
            }
            if (end === -1) {
                if (!this.atEnd)
                    return this.setNext('quoted-scalar');
                end = this.buffer.length;
            }
            yield* this.pushToIndex(end + 1, false);
            return this.flowLevel ? 'flow' : 'doc';
        }
        *parseBlockScalarHeader() {
            this.blockScalarIndent = -1;
            this.blockScalarKeep = false;
            let i = this.pos;
            while (true) {
                const ch = this.buffer[++i];
                if (ch === '+')
                    this.blockScalarKeep = true;
                else if (ch > '0' && ch <= '9')
                    this.blockScalarIndent = Number(ch) - 1;
                else if (ch !== '-')
                    break;
            }
            return yield* this.pushUntil(ch => isEmpty(ch) || ch === '#');
        }
        *parseBlockScalar() {
            let nl = this.pos - 1; // may be -1 if this.pos === 0
            let indent = 0;
            let ch;
            loop: for (let i = this.pos; (ch = this.buffer[i]); ++i) {
                switch (ch) {
                    case ' ':
                        indent += 1;
                        break;
                    case '\n':
                        nl = i;
                        indent = 0;
                        break;
                    case '\r': {
                        const next = this.buffer[i + 1];
                        if (!next && !this.atEnd)
                            return this.setNext('block-scalar');
                        if (next === '\n')
                            break;
                    } // fallthrough
                    default:
                        break loop;
                }
            }
            if (!ch && !this.atEnd)
                return this.setNext('block-scalar');
            if (indent >= this.indentNext) {
                if (this.blockScalarIndent === -1)
                    this.indentNext = indent;
                else {
                    this.indentNext =
                        this.blockScalarIndent + (this.indentNext === 0 ? 1 : this.indentNext);
                }
                do {
                    const cs = this.continueScalar(nl + 1);
                    if (cs === -1)
                        break;
                    nl = this.buffer.indexOf('\n', cs);
                } while (nl !== -1);
                if (nl === -1) {
                    if (!this.atEnd)
                        return this.setNext('block-scalar');
                    nl = this.buffer.length;
                }
            }
            // Trailing insufficiently indented tabs are invalid.
            // To catch that during parsing, we include them in the block scalar value.
            let i = nl + 1;
            ch = this.buffer[i];
            while (ch === ' ')
                ch = this.buffer[++i];
            if (ch === '\t') {
                while (ch === '\t' || ch === ' ' || ch === '\r' || ch === '\n')
                    ch = this.buffer[++i];
                nl = i - 1;
            }
            else if (!this.blockScalarKeep) {
                do {
                    let i = nl - 1;
                    let ch = this.buffer[i];
                    if (ch === '\r')
                        ch = this.buffer[--i];
                    const lastChar = i; // Drop the line if last char not more indented
                    while (ch === ' ')
                        ch = this.buffer[--i];
                    if (ch === '\n' && i >= this.pos && i + 1 + indent > lastChar)
                        nl = i;
                    else
                        break;
                } while (true);
            }
            yield SCALAR;
            yield* this.pushToIndex(nl + 1, true);
            return yield* this.parseLineStart();
        }
        *parsePlainScalar() {
            const inFlow = this.flowLevel > 0;
            let end = this.pos - 1;
            let i = this.pos - 1;
            let ch;
            while ((ch = this.buffer[++i])) {
                if (ch === ':') {
                    const next = this.buffer[i + 1];
                    if (isEmpty(next) || (inFlow && flowIndicatorChars.has(next)))
                        break;
                    end = i;
                }
                else if (isEmpty(ch)) {
                    let next = this.buffer[i + 1];
                    if (ch === '\r') {
                        if (next === '\n') {
                            i += 1;
                            ch = '\n';
                            next = this.buffer[i + 1];
                        }
                        else
                            end = i;
                    }
                    if (next === '#' || (inFlow && flowIndicatorChars.has(next)))
                        break;
                    if (ch === '\n') {
                        const cs = this.continueScalar(i + 1);
                        if (cs === -1)
                            break;
                        i = Math.max(i, cs - 2); // to advance, but still account for ' #'
                    }
                }
                else {
                    if (inFlow && flowIndicatorChars.has(ch))
                        break;
                    end = i;
                }
            }
            if (!ch && !this.atEnd)
                return this.setNext('plain-scalar');
            yield SCALAR;
            yield* this.pushToIndex(end + 1, true);
            return inFlow ? 'flow' : 'doc';
        }
        *pushCount(n) {
            if (n > 0) {
                yield this.buffer.substr(this.pos, n);
                this.pos += n;
                return n;
            }
            return 0;
        }
        *pushToIndex(i, allowEmpty) {
            const s = this.buffer.slice(this.pos, i);
            if (s) {
                yield s;
                this.pos += s.length;
                return s.length;
            }
            else if (allowEmpty)
                yield '';
            return 0;
        }
        *pushIndicators() {
            switch (this.charAt(0)) {
                case '!':
                    return ((yield* this.pushTag()) +
                        (yield* this.pushSpaces(true)) +
                        (yield* this.pushIndicators()));
                case '&':
                    return ((yield* this.pushUntil(isNotAnchorChar)) +
                        (yield* this.pushSpaces(true)) +
                        (yield* this.pushIndicators()));
                case '-': // this is an error
                case '?': // this is an error outside flow collections
                case ':': {
                    const inFlow = this.flowLevel > 0;
                    const ch1 = this.charAt(1);
                    if (isEmpty(ch1) || (inFlow && flowIndicatorChars.has(ch1))) {
                        if (!inFlow)
                            this.indentNext = this.indentValue + 1;
                        else if (this.flowKey)
                            this.flowKey = false;
                        return ((yield* this.pushCount(1)) +
                            (yield* this.pushSpaces(true)) +
                            (yield* this.pushIndicators()));
                    }
                }
            }
            return 0;
        }
        *pushTag() {
            if (this.charAt(1) === '<') {
                let i = this.pos + 2;
                let ch = this.buffer[i];
                while (!isEmpty(ch) && ch !== '>')
                    ch = this.buffer[++i];
                return yield* this.pushToIndex(ch === '>' ? i + 1 : i, false);
            }
            else {
                let i = this.pos + 1;
                let ch = this.buffer[i];
                while (ch) {
                    if (tagChars.has(ch))
                        ch = this.buffer[++i];
                    else if (ch === '%' &&
                        hexDigits.has(this.buffer[i + 1]) &&
                        hexDigits.has(this.buffer[i + 2])) {
                        ch = this.buffer[(i += 3)];
                    }
                    else
                        break;
                }
                return yield* this.pushToIndex(i, false);
            }
        }
        *pushNewline() {
            const ch = this.buffer[this.pos];
            if (ch === '\n')
                return yield* this.pushCount(1);
            else if (ch === '\r' && this.charAt(1) === '\n')
                return yield* this.pushCount(2);
            else
                return 0;
        }
        *pushSpaces(allowTabs) {
            let i = this.pos - 1;
            let ch;
            do {
                ch = this.buffer[++i];
            } while (ch === ' ' || (allowTabs && ch === '\t'));
            const n = i - this.pos;
            if (n > 0) {
                yield this.buffer.substr(this.pos, n);
                this.pos = i;
            }
            return n;
        }
        *pushUntil(test) {
            let i = this.pos;
            let ch = this.buffer[i];
            while (!test(ch))
                ch = this.buffer[++i];
            return yield* this.pushToIndex(i, false);
        }
    }

    /**
     * Tracks newlines during parsing in order to provide an efficient API for
     * determining the one-indexed `{ line, col }` position for any offset
     * within the input.
     */
    class LineCounter {
        constructor() {
            this.lineStarts = [];
            /**
             * Should be called in ascending order. Otherwise, call
             * `lineCounter.lineStarts.sort()` before calling `linePos()`.
             */
            this.addNewLine = (offset) => this.lineStarts.push(offset);
            /**
             * Performs a binary search and returns the 1-indexed { line, col }
             * position of `offset`. If `line === 0`, `addNewLine` has never been
             * called or `offset` is before the first known newline.
             */
            this.linePos = (offset) => {
                let low = 0;
                let high = this.lineStarts.length;
                while (low < high) {
                    const mid = (low + high) >> 1; // Math.floor((low + high) / 2)
                    if (this.lineStarts[mid] < offset)
                        low = mid + 1;
                    else
                        high = mid;
                }
                if (this.lineStarts[low] === offset)
                    return { line: low + 1, col: 1 };
                if (low === 0)
                    return { line: 0, col: offset };
                const start = this.lineStarts[low - 1];
                return { line: low, col: offset - start + 1 };
            };
        }
    }

    function includesToken(list, type) {
        for (let i = 0; i < list.length; ++i)
            if (list[i].type === type)
                return true;
        return false;
    }
    function findNonEmptyIndex(list) {
        for (let i = 0; i < list.length; ++i) {
            switch (list[i].type) {
                case 'space':
                case 'comment':
                case 'newline':
                    break;
                default:
                    return i;
            }
        }
        return -1;
    }
    function isFlowToken(token) {
        switch (token?.type) {
            case 'alias':
            case 'scalar':
            case 'single-quoted-scalar':
            case 'double-quoted-scalar':
            case 'flow-collection':
                return true;
            default:
                return false;
        }
    }
    function getPrevProps(parent) {
        switch (parent.type) {
            case 'document':
                return parent.start;
            case 'block-map': {
                const it = parent.items[parent.items.length - 1];
                return it.sep ?? it.start;
            }
            case 'block-seq':
                return parent.items[parent.items.length - 1].start;
            /* istanbul ignore next should not happen */
            default:
                return [];
        }
    }
    /** Note: May modify input array */
    function getFirstKeyStartProps(prev) {
        if (prev.length === 0)
            return [];
        let i = prev.length;
        loop: while (--i >= 0) {
            switch (prev[i].type) {
                case 'doc-start':
                case 'explicit-key-ind':
                case 'map-value-ind':
                case 'seq-item-ind':
                case 'newline':
                    break loop;
            }
        }
        while (prev[++i]?.type === 'space') {
            /* loop */
        }
        return prev.splice(i, prev.length);
    }
    function fixFlowSeqItems(fc) {
        if (fc.start.type === 'flow-seq-start') {
            for (const it of fc.items) {
                if (it.sep &&
                    !it.value &&
                    !includesToken(it.start, 'explicit-key-ind') &&
                    !includesToken(it.sep, 'map-value-ind')) {
                    if (it.key)
                        it.value = it.key;
                    delete it.key;
                    if (isFlowToken(it.value)) {
                        if (it.value.end)
                            Array.prototype.push.apply(it.value.end, it.sep);
                        else
                            it.value.end = it.sep;
                    }
                    else
                        Array.prototype.push.apply(it.start, it.sep);
                    delete it.sep;
                }
            }
        }
    }
    /**
     * A YAML concrete syntax tree (CST) parser
     *
     * ```ts
     * const src: string = ...
     * for (const token of new Parser().parse(src)) {
     *   // token: Token
     * }
     * ```
     *
     * To use the parser with a user-provided lexer:
     *
     * ```ts
     * function* parse(source: string, lexer: Lexer) {
     *   const parser = new Parser()
     *   for (const lexeme of lexer.lex(source))
     *     yield* parser.next(lexeme)
     *   yield* parser.end()
     * }
     *
     * const src: string = ...
     * const lexer = new Lexer()
     * for (const token of parse(src, lexer)) {
     *   // token: Token
     * }
     * ```
     */
    class Parser {
        /**
         * @param onNewLine - If defined, called separately with the start position of
         *   each new line (in `parse()`, including the start of input).
         */
        constructor(onNewLine) {
            /** If true, space and sequence indicators count as indentation */
            this.atNewLine = true;
            /** If true, next token is a scalar value */
            this.atScalar = false;
            /** Current indentation level */
            this.indent = 0;
            /** Current offset since the start of parsing */
            this.offset = 0;
            /** On the same line with a block map key */
            this.onKeyLine = false;
            /** Top indicates the node that's currently being built */
            this.stack = [];
            /** The source of the current token, set in parse() */
            this.source = '';
            /** The type of the current token, set in parse() */
            this.type = '';
            // Must be defined after `next()`
            this.lexer = new Lexer();
            this.onNewLine = onNewLine;
        }
        /**
         * Parse `source` as a YAML stream.
         * If `incomplete`, a part of the last line may be left as a buffer for the next call.
         *
         * Errors are not thrown, but yielded as `{ type: 'error', message }` tokens.
         *
         * @returns A generator of tokens representing each directive, document, and other structure.
         */
        *parse(source, incomplete = false) {
            if (this.onNewLine && this.offset === 0)
                this.onNewLine(0);
            for (const lexeme of this.lexer.lex(source, incomplete))
                yield* this.next(lexeme);
            if (!incomplete)
                yield* this.end();
        }
        /**
         * Advance the parser by the `source` of one lexical token.
         */
        *next(source) {
            this.source = source;
            if (this.atScalar) {
                this.atScalar = false;
                yield* this.step();
                this.offset += source.length;
                return;
            }
            const type = tokenType(source);
            if (!type) {
                const message = `Not a YAML token: ${source}`;
                yield* this.pop({ type: 'error', offset: this.offset, message, source });
                this.offset += source.length;
            }
            else if (type === 'scalar') {
                this.atNewLine = false;
                this.atScalar = true;
                this.type = 'scalar';
            }
            else {
                this.type = type;
                yield* this.step();
                switch (type) {
                    case 'newline':
                        this.atNewLine = true;
                        this.indent = 0;
                        if (this.onNewLine)
                            this.onNewLine(this.offset + source.length);
                        break;
                    case 'space':
                        if (this.atNewLine && source[0] === ' ')
                            this.indent += source.length;
                        break;
                    case 'explicit-key-ind':
                    case 'map-value-ind':
                    case 'seq-item-ind':
                        if (this.atNewLine)
                            this.indent += source.length;
                        break;
                    case 'doc-mode':
                    case 'flow-error-end':
                        return;
                    default:
                        this.atNewLine = false;
                }
                this.offset += source.length;
            }
        }
        /** Call at end of input to push out any remaining constructions */
        *end() {
            while (this.stack.length > 0)
                yield* this.pop();
        }
        get sourceToken() {
            const st = {
                type: this.type,
                offset: this.offset,
                indent: this.indent,
                source: this.source
            };
            return st;
        }
        *step() {
            const top = this.peek(1);
            if (this.type === 'doc-end' && (!top || top.type !== 'doc-end')) {
                while (this.stack.length > 0)
                    yield* this.pop();
                this.stack.push({
                    type: 'doc-end',
                    offset: this.offset,
                    source: this.source
                });
                return;
            }
            if (!top)
                return yield* this.stream();
            switch (top.type) {
                case 'document':
                    return yield* this.document(top);
                case 'alias':
                case 'scalar':
                case 'single-quoted-scalar':
                case 'double-quoted-scalar':
                    return yield* this.scalar(top);
                case 'block-scalar':
                    return yield* this.blockScalar(top);
                case 'block-map':
                    return yield* this.blockMap(top);
                case 'block-seq':
                    return yield* this.blockSequence(top);
                case 'flow-collection':
                    return yield* this.flowCollection(top);
                case 'doc-end':
                    return yield* this.documentEnd(top);
            }
            /* istanbul ignore next should not happen */
            yield* this.pop();
        }
        peek(n) {
            return this.stack[this.stack.length - n];
        }
        *pop(error) {
            const token = error ?? this.stack.pop();
            /* istanbul ignore if should not happen */
            if (!token) {
                const message = 'Tried to pop an empty stack';
                yield { type: 'error', offset: this.offset, source: '', message };
            }
            else if (this.stack.length === 0) {
                yield token;
            }
            else {
                const top = this.peek(1);
                if (token.type === 'block-scalar') {
                    // Block scalars use their parent rather than header indent
                    token.indent = 'indent' in top ? top.indent : 0;
                }
                else if (token.type === 'flow-collection' && top.type === 'document') {
                    // Ignore all indent for top-level flow collections
                    token.indent = 0;
                }
                if (token.type === 'flow-collection')
                    fixFlowSeqItems(token);
                switch (top.type) {
                    case 'document':
                        top.value = token;
                        break;
                    case 'block-scalar':
                        top.props.push(token); // error
                        break;
                    case 'block-map': {
                        const it = top.items[top.items.length - 1];
                        if (it.value) {
                            top.items.push({ start: [], key: token, sep: [] });
                            this.onKeyLine = true;
                            return;
                        }
                        else if (it.sep) {
                            it.value = token;
                        }
                        else {
                            Object.assign(it, { key: token, sep: [] });
                            this.onKeyLine = !it.explicitKey;
                            return;
                        }
                        break;
                    }
                    case 'block-seq': {
                        const it = top.items[top.items.length - 1];
                        if (it.value)
                            top.items.push({ start: [], value: token });
                        else
                            it.value = token;
                        break;
                    }
                    case 'flow-collection': {
                        const it = top.items[top.items.length - 1];
                        if (!it || it.value)
                            top.items.push({ start: [], key: token, sep: [] });
                        else if (it.sep)
                            it.value = token;
                        else
                            Object.assign(it, { key: token, sep: [] });
                        return;
                    }
                    /* istanbul ignore next should not happen */
                    default:
                        yield* this.pop();
                        yield* this.pop(token);
                }
                if ((top.type === 'document' ||
                    top.type === 'block-map' ||
                    top.type === 'block-seq') &&
                    (token.type === 'block-map' || token.type === 'block-seq')) {
                    const last = token.items[token.items.length - 1];
                    if (last &&
                        !last.sep &&
                        !last.value &&
                        last.start.length > 0 &&
                        findNonEmptyIndex(last.start) === -1 &&
                        (token.indent === 0 ||
                            last.start.every(st => st.type !== 'comment' || st.indent < token.indent))) {
                        if (top.type === 'document')
                            top.end = last.start;
                        else
                            top.items.push({ start: last.start });
                        token.items.splice(-1, 1);
                    }
                }
            }
        }
        *stream() {
            switch (this.type) {
                case 'directive-line':
                    yield { type: 'directive', offset: this.offset, source: this.source };
                    return;
                case 'byte-order-mark':
                case 'space':
                case 'comment':
                case 'newline':
                    yield this.sourceToken;
                    return;
                case 'doc-mode':
                case 'doc-start': {
                    const doc = {
                        type: 'document',
                        offset: this.offset,
                        start: []
                    };
                    if (this.type === 'doc-start')
                        doc.start.push(this.sourceToken);
                    this.stack.push(doc);
                    return;
                }
            }
            yield {
                type: 'error',
                offset: this.offset,
                message: `Unexpected ${this.type} token in YAML stream`,
                source: this.source
            };
        }
        *document(doc) {
            if (doc.value)
                return yield* this.lineEnd(doc);
            switch (this.type) {
                case 'doc-start': {
                    if (findNonEmptyIndex(doc.start) !== -1) {
                        yield* this.pop();
                        yield* this.step();
                    }
                    else
                        doc.start.push(this.sourceToken);
                    return;
                }
                case 'anchor':
                case 'tag':
                case 'space':
                case 'comment':
                case 'newline':
                    doc.start.push(this.sourceToken);
                    return;
            }
            const bv = this.startBlockValue(doc);
            if (bv)
                this.stack.push(bv);
            else {
                yield {
                    type: 'error',
                    offset: this.offset,
                    message: `Unexpected ${this.type} token in YAML document`,
                    source: this.source
                };
            }
        }
        *scalar(scalar) {
            if (this.type === 'map-value-ind') {
                const prev = getPrevProps(this.peek(2));
                const start = getFirstKeyStartProps(prev);
                let sep;
                if (scalar.end) {
                    sep = scalar.end;
                    sep.push(this.sourceToken);
                    delete scalar.end;
                }
                else
                    sep = [this.sourceToken];
                const map = {
                    type: 'block-map',
                    offset: scalar.offset,
                    indent: scalar.indent,
                    items: [{ start, key: scalar, sep }]
                };
                this.onKeyLine = true;
                this.stack[this.stack.length - 1] = map;
            }
            else
                yield* this.lineEnd(scalar);
        }
        *blockScalar(scalar) {
            switch (this.type) {
                case 'space':
                case 'comment':
                case 'newline':
                    scalar.props.push(this.sourceToken);
                    return;
                case 'scalar':
                    scalar.source = this.source;
                    // block-scalar source includes trailing newline
                    this.atNewLine = true;
                    this.indent = 0;
                    if (this.onNewLine) {
                        let nl = this.source.indexOf('\n') + 1;
                        while (nl !== 0) {
                            this.onNewLine(this.offset + nl);
                            nl = this.source.indexOf('\n', nl) + 1;
                        }
                    }
                    yield* this.pop();
                    break;
                /* istanbul ignore next should not happen */
                default:
                    yield* this.pop();
                    yield* this.step();
            }
        }
        *blockMap(map) {
            const it = map.items[map.items.length - 1];
            // it.sep is true-ish if pair already has key or : separator
            switch (this.type) {
                case 'newline':
                    this.onKeyLine = false;
                    if (it.value) {
                        const end = 'end' in it.value ? it.value.end : undefined;
                        const last = Array.isArray(end) ? end[end.length - 1] : undefined;
                        if (last?.type === 'comment')
                            end?.push(this.sourceToken);
                        else
                            map.items.push({ start: [this.sourceToken] });
                    }
                    else if (it.sep) {
                        it.sep.push(this.sourceToken);
                    }
                    else {
                        it.start.push(this.sourceToken);
                    }
                    return;
                case 'space':
                case 'comment':
                    if (it.value) {
                        map.items.push({ start: [this.sourceToken] });
                    }
                    else if (it.sep) {
                        it.sep.push(this.sourceToken);
                    }
                    else {
                        if (this.atIndentedComment(it.start, map.indent)) {
                            const prev = map.items[map.items.length - 2];
                            const end = prev?.value?.end;
                            if (Array.isArray(end)) {
                                Array.prototype.push.apply(end, it.start);
                                end.push(this.sourceToken);
                                map.items.pop();
                                return;
                            }
                        }
                        it.start.push(this.sourceToken);
                    }
                    return;
            }
            if (this.indent >= map.indent) {
                const atMapIndent = !this.onKeyLine && this.indent === map.indent;
                const atNextItem = atMapIndent &&
                    (it.sep || it.explicitKey) &&
                    this.type !== 'seq-item-ind';
                // For empty nodes, assign newline-separated not indented empty tokens to following node
                let start = [];
                if (atNextItem && it.sep && !it.value) {
                    const nl = [];
                    for (let i = 0; i < it.sep.length; ++i) {
                        const st = it.sep[i];
                        switch (st.type) {
                            case 'newline':
                                nl.push(i);
                                break;
                            case 'space':
                                break;
                            case 'comment':
                                if (st.indent > map.indent)
                                    nl.length = 0;
                                break;
                            default:
                                nl.length = 0;
                        }
                    }
                    if (nl.length >= 2)
                        start = it.sep.splice(nl[1]);
                }
                switch (this.type) {
                    case 'anchor':
                    case 'tag':
                        if (atNextItem || it.value) {
                            start.push(this.sourceToken);
                            map.items.push({ start });
                            this.onKeyLine = true;
                        }
                        else if (it.sep) {
                            it.sep.push(this.sourceToken);
                        }
                        else {
                            it.start.push(this.sourceToken);
                        }
                        return;
                    case 'explicit-key-ind':
                        if (!it.sep && !it.explicitKey) {
                            it.start.push(this.sourceToken);
                            it.explicitKey = true;
                        }
                        else if (atNextItem || it.value) {
                            start.push(this.sourceToken);
                            map.items.push({ start, explicitKey: true });
                        }
                        else {
                            this.stack.push({
                                type: 'block-map',
                                offset: this.offset,
                                indent: this.indent,
                                items: [{ start: [this.sourceToken], explicitKey: true }]
                            });
                        }
                        this.onKeyLine = true;
                        return;
                    case 'map-value-ind':
                        if (it.explicitKey) {
                            if (!it.sep) {
                                if (includesToken(it.start, 'newline')) {
                                    Object.assign(it, { key: null, sep: [this.sourceToken] });
                                }
                                else {
                                    const start = getFirstKeyStartProps(it.start);
                                    this.stack.push({
                                        type: 'block-map',
                                        offset: this.offset,
                                        indent: this.indent,
                                        items: [{ start, key: null, sep: [this.sourceToken] }]
                                    });
                                }
                            }
                            else if (it.value) {
                                map.items.push({ start: [], key: null, sep: [this.sourceToken] });
                            }
                            else if (includesToken(it.sep, 'map-value-ind')) {
                                this.stack.push({
                                    type: 'block-map',
                                    offset: this.offset,
                                    indent: this.indent,
                                    items: [{ start, key: null, sep: [this.sourceToken] }]
                                });
                            }
                            else if (isFlowToken(it.key) &&
                                !includesToken(it.sep, 'newline')) {
                                const start = getFirstKeyStartProps(it.start);
                                const key = it.key;
                                const sep = it.sep;
                                sep.push(this.sourceToken);
                                // @ts-expect-error type guard is wrong here
                                delete it.key;
                                // @ts-expect-error type guard is wrong here
                                delete it.sep;
                                this.stack.push({
                                    type: 'block-map',
                                    offset: this.offset,
                                    indent: this.indent,
                                    items: [{ start, key, sep }]
                                });
                            }
                            else if (start.length > 0) {
                                // Not actually at next item
                                it.sep = it.sep.concat(start, this.sourceToken);
                            }
                            else {
                                it.sep.push(this.sourceToken);
                            }
                        }
                        else {
                            if (!it.sep) {
                                Object.assign(it, { key: null, sep: [this.sourceToken] });
                            }
                            else if (it.value || atNextItem) {
                                map.items.push({ start, key: null, sep: [this.sourceToken] });
                            }
                            else if (includesToken(it.sep, 'map-value-ind')) {
                                this.stack.push({
                                    type: 'block-map',
                                    offset: this.offset,
                                    indent: this.indent,
                                    items: [{ start: [], key: null, sep: [this.sourceToken] }]
                                });
                            }
                            else {
                                it.sep.push(this.sourceToken);
                            }
                        }
                        this.onKeyLine = true;
                        return;
                    case 'alias':
                    case 'scalar':
                    case 'single-quoted-scalar':
                    case 'double-quoted-scalar': {
                        const fs = this.flowScalar(this.type);
                        if (atNextItem || it.value) {
                            map.items.push({ start, key: fs, sep: [] });
                            this.onKeyLine = true;
                        }
                        else if (it.sep) {
                            this.stack.push(fs);
                        }
                        else {
                            Object.assign(it, { key: fs, sep: [] });
                            this.onKeyLine = true;
                        }
                        return;
                    }
                    default: {
                        const bv = this.startBlockValue(map);
                        if (bv) {
                            if (atMapIndent && bv.type !== 'block-seq') {
                                map.items.push({ start });
                            }
                            this.stack.push(bv);
                            return;
                        }
                    }
                }
            }
            yield* this.pop();
            yield* this.step();
        }
        *blockSequence(seq) {
            const it = seq.items[seq.items.length - 1];
            switch (this.type) {
                case 'newline':
                    if (it.value) {
                        const end = 'end' in it.value ? it.value.end : undefined;
                        const last = Array.isArray(end) ? end[end.length - 1] : undefined;
                        if (last?.type === 'comment')
                            end?.push(this.sourceToken);
                        else
                            seq.items.push({ start: [this.sourceToken] });
                    }
                    else
                        it.start.push(this.sourceToken);
                    return;
                case 'space':
                case 'comment':
                    if (it.value)
                        seq.items.push({ start: [this.sourceToken] });
                    else {
                        if (this.atIndentedComment(it.start, seq.indent)) {
                            const prev = seq.items[seq.items.length - 2];
                            const end = prev?.value?.end;
                            if (Array.isArray(end)) {
                                Array.prototype.push.apply(end, it.start);
                                end.push(this.sourceToken);
                                seq.items.pop();
                                return;
                            }
                        }
                        it.start.push(this.sourceToken);
                    }
                    return;
                case 'anchor':
                case 'tag':
                    if (it.value || this.indent <= seq.indent)
                        break;
                    it.start.push(this.sourceToken);
                    return;
                case 'seq-item-ind':
                    if (this.indent !== seq.indent)
                        break;
                    if (it.value || includesToken(it.start, 'seq-item-ind'))
                        seq.items.push({ start: [this.sourceToken] });
                    else
                        it.start.push(this.sourceToken);
                    return;
            }
            if (this.indent > seq.indent) {
                const bv = this.startBlockValue(seq);
                if (bv) {
                    this.stack.push(bv);
                    return;
                }
            }
            yield* this.pop();
            yield* this.step();
        }
        *flowCollection(fc) {
            const it = fc.items[fc.items.length - 1];
            if (this.type === 'flow-error-end') {
                let top;
                do {
                    yield* this.pop();
                    top = this.peek(1);
                } while (top && top.type === 'flow-collection');
            }
            else if (fc.end.length === 0) {
                switch (this.type) {
                    case 'comma':
                    case 'explicit-key-ind':
                        if (!it || it.sep)
                            fc.items.push({ start: [this.sourceToken] });
                        else
                            it.start.push(this.sourceToken);
                        return;
                    case 'map-value-ind':
                        if (!it || it.value)
                            fc.items.push({ start: [], key: null, sep: [this.sourceToken] });
                        else if (it.sep)
                            it.sep.push(this.sourceToken);
                        else
                            Object.assign(it, { key: null, sep: [this.sourceToken] });
                        return;
                    case 'space':
                    case 'comment':
                    case 'newline':
                    case 'anchor':
                    case 'tag':
                        if (!it || it.value)
                            fc.items.push({ start: [this.sourceToken] });
                        else if (it.sep)
                            it.sep.push(this.sourceToken);
                        else
                            it.start.push(this.sourceToken);
                        return;
                    case 'alias':
                    case 'scalar':
                    case 'single-quoted-scalar':
                    case 'double-quoted-scalar': {
                        const fs = this.flowScalar(this.type);
                        if (!it || it.value)
                            fc.items.push({ start: [], key: fs, sep: [] });
                        else if (it.sep)
                            this.stack.push(fs);
                        else
                            Object.assign(it, { key: fs, sep: [] });
                        return;
                    }
                    case 'flow-map-end':
                    case 'flow-seq-end':
                        fc.end.push(this.sourceToken);
                        return;
                }
                const bv = this.startBlockValue(fc);
                /* istanbul ignore else should not happen */
                if (bv)
                    this.stack.push(bv);
                else {
                    yield* this.pop();
                    yield* this.step();
                }
            }
            else {
                const parent = this.peek(2);
                if (parent.type === 'block-map' &&
                    ((this.type === 'map-value-ind' && parent.indent === fc.indent) ||
                        (this.type === 'newline' &&
                            !parent.items[parent.items.length - 1].sep))) {
                    yield* this.pop();
                    yield* this.step();
                }
                else if (this.type === 'map-value-ind' &&
                    parent.type !== 'flow-collection') {
                    const prev = getPrevProps(parent);
                    const start = getFirstKeyStartProps(prev);
                    fixFlowSeqItems(fc);
                    const sep = fc.end.splice(1, fc.end.length);
                    sep.push(this.sourceToken);
                    const map = {
                        type: 'block-map',
                        offset: fc.offset,
                        indent: fc.indent,
                        items: [{ start, key: fc, sep }]
                    };
                    this.onKeyLine = true;
                    this.stack[this.stack.length - 1] = map;
                }
                else {
                    yield* this.lineEnd(fc);
                }
            }
        }
        flowScalar(type) {
            if (this.onNewLine) {
                let nl = this.source.indexOf('\n') + 1;
                while (nl !== 0) {
                    this.onNewLine(this.offset + nl);
                    nl = this.source.indexOf('\n', nl) + 1;
                }
            }
            return {
                type,
                offset: this.offset,
                indent: this.indent,
                source: this.source
            };
        }
        startBlockValue(parent) {
            switch (this.type) {
                case 'alias':
                case 'scalar':
                case 'single-quoted-scalar':
                case 'double-quoted-scalar':
                    return this.flowScalar(this.type);
                case 'block-scalar-header':
                    return {
                        type: 'block-scalar',
                        offset: this.offset,
                        indent: this.indent,
                        props: [this.sourceToken],
                        source: ''
                    };
                case 'flow-map-start':
                case 'flow-seq-start':
                    return {
                        type: 'flow-collection',
                        offset: this.offset,
                        indent: this.indent,
                        start: this.sourceToken,
                        items: [],
                        end: []
                    };
                case 'seq-item-ind':
                    return {
                        type: 'block-seq',
                        offset: this.offset,
                        indent: this.indent,
                        items: [{ start: [this.sourceToken] }]
                    };
                case 'explicit-key-ind': {
                    this.onKeyLine = true;
                    const prev = getPrevProps(parent);
                    const start = getFirstKeyStartProps(prev);
                    start.push(this.sourceToken);
                    return {
                        type: 'block-map',
                        offset: this.offset,
                        indent: this.indent,
                        items: [{ start, explicitKey: true }]
                    };
                }
                case 'map-value-ind': {
                    this.onKeyLine = true;
                    const prev = getPrevProps(parent);
                    const start = getFirstKeyStartProps(prev);
                    return {
                        type: 'block-map',
                        offset: this.offset,
                        indent: this.indent,
                        items: [{ start, key: null, sep: [this.sourceToken] }]
                    };
                }
            }
            return null;
        }
        atIndentedComment(start, indent) {
            if (this.type !== 'comment')
                return false;
            if (this.indent <= indent)
                return false;
            return start.every(st => st.type === 'newline' || st.type === 'space');
        }
        *documentEnd(docEnd) {
            if (this.type !== 'doc-mode') {
                if (docEnd.end)
                    docEnd.end.push(this.sourceToken);
                else
                    docEnd.end = [this.sourceToken];
                if (this.type === 'newline')
                    yield* this.pop();
            }
        }
        *lineEnd(token) {
            switch (this.type) {
                case 'comma':
                case 'doc-start':
                case 'doc-end':
                case 'flow-seq-end':
                case 'flow-map-end':
                case 'map-value-ind':
                    yield* this.pop();
                    yield* this.step();
                    break;
                case 'newline':
                    this.onKeyLine = false;
                // fallthrough
                case 'space':
                case 'comment':
                default:
                    // all other values are errors
                    if (token.end)
                        token.end.push(this.sourceToken);
                    else
                        token.end = [this.sourceToken];
                    if (this.type === 'newline')
                        yield* this.pop();
            }
        }
    }

    function parseOptions(options) {
        const prettyErrors = options.prettyErrors !== false;
        const lineCounter = options.lineCounter || (prettyErrors && new LineCounter()) || null;
        return { lineCounter, prettyErrors };
    }
    /**
     * Parse the input as a stream of YAML documents.
     *
     * Documents should be separated from each other by `...` or `---` marker lines.
     *
     * @returns If an empty `docs` array is returned, it will be of type
     *   EmptyStream and contain additional stream information. In
     *   TypeScript, you should use `'empty' in docs` as a type guard for it.
     */
    function parseAllDocuments(source, options = {}) {
        const { lineCounter, prettyErrors } = parseOptions(options);
        const parser = new Parser(lineCounter?.addNewLine);
        const composer = new Composer(options);
        const docs = Array.from(composer.compose(parser.parse(source)));
        if (prettyErrors && lineCounter)
            for (const doc of docs) {
                doc.errors.forEach(prettifyError(source, lineCounter));
                doc.warnings.forEach(prettifyError(source, lineCounter));
            }
        if (docs.length > 0)
            return docs;
        return Object.assign([], { empty: true }, composer.streamInfo());
    }
    /** Parse an input string into a single YAML.Document */
    function parseDocument(source, options = {}) {
        const { lineCounter, prettyErrors } = parseOptions(options);
        const parser = new Parser(lineCounter?.addNewLine);
        const composer = new Composer(options);
        // `doc` is always set by compose.end(true) at the very latest
        let doc = null;
        for (const _doc of composer.compose(parser.parse(source), true, source.length)) {
            if (!doc)
                doc = _doc;
            else if (doc.options.logLevel !== 'silent') {
                doc.errors.push(new YAMLParseError(_doc.range.slice(0, 2), 'MULTIPLE_DOCS', 'Source contains multiple documents; please use YAML.parseAllDocuments()'));
                break;
            }
        }
        if (prettyErrors && lineCounter) {
            doc.errors.forEach(prettifyError(source, lineCounter));
            doc.warnings.forEach(prettifyError(source, lineCounter));
        }
        return doc;
    }
    function parse(src, reviver, options) {
        let _reviver = undefined;
        if (typeof reviver === 'function') {
            _reviver = reviver;
        }
        else if (options === undefined && reviver && typeof reviver === 'object') {
            options = reviver;
        }
        const doc = parseDocument(src, options);
        if (!doc)
            return null;
        doc.warnings.forEach(warning => warn(doc.options.logLevel, warning));
        if (doc.errors.length > 0) {
            if (doc.options.logLevel !== 'silent')
                throw doc.errors[0];
            else
                doc.errors = [];
        }
        return doc.toJS(Object.assign({ reviver: _reviver }, options));
    }
    function stringify(value, replacer, options) {
        let _replacer = null;
        if (typeof replacer === 'function' || Array.isArray(replacer)) {
            _replacer = replacer;
        }
        else if (options === undefined && replacer) {
            options = replacer;
        }
        if (typeof options === 'string')
            options = options.length;
        if (typeof options === 'number') {
            const indent = Math.round(options);
            options = indent < 1 ? undefined : indent > 8 ? { indent: 8 } : { indent };
        }
        if (value === undefined) {
            const { keepUndefined } = options ?? replacer ?? {};
            if (!keepUndefined)
                return undefined;
        }
        return new Document(value, _replacer, options).toString(options);
    }

    var YAML = /*#__PURE__*/Object.freeze({
        __proto__: null,
        Alias: Alias,
        CST: cst,
        Composer: Composer,
        Document: Document,
        Lexer: Lexer,
        LineCounter: LineCounter,
        Pair: Pair,
        Parser: Parser,
        Scalar: Scalar,
        Schema: Schema,
        YAMLError: YAMLError,
        YAMLMap: YAMLMap,
        YAMLParseError: YAMLParseError,
        YAMLSeq: YAMLSeq,
        YAMLWarning: YAMLWarning,
        isAlias: isAlias,
        isCollection: isCollection$1,
        isDocument: isDocument,
        isMap: isMap,
        isNode: isNode,
        isPair: isPair,
        isScalar: isScalar$1,
        isSeq: isSeq,
        parse: parse,
        parseAllDocuments: parseAllDocuments,
        parseDocument: parseDocument,
        stringify: stringify,
        visit: visit$1,
        visitAsync: visitAsync
    });

    // `export * as default from ...` fails on Webpack v4
    // https://github.com/eemeli/yaml/issues/228

    var index = /*#__PURE__*/Object.freeze({
        __proto__: null,
        Alias: Alias,
        CST: cst,
        Composer: Composer,
        Document: Document,
        Lexer: Lexer,
        LineCounter: LineCounter,
        Pair: Pair,
        Parser: Parser,
        Scalar: Scalar,
        Schema: Schema,
        YAMLError: YAMLError,
        YAMLMap: YAMLMap,
        YAMLParseError: YAMLParseError,
        YAMLSeq: YAMLSeq,
        YAMLWarning: YAMLWarning,
        default: YAML,
        isAlias: isAlias,
        isCollection: isCollection$1,
        isDocument: isDocument,
        isMap: isMap,
        isNode: isNode,
        isPair: isPair,
        isScalar: isScalar$1,
        isSeq: isSeq,
        parse: parse,
        parseAllDocuments: parseAllDocuments,
        parseDocument: parseDocument,
        stringify: stringify,
        visit: visit$1,
        visitAsync: visitAsync
    });

    exports.AnswerService = AnswerService;
    exports.AppEmbed = AppEmbed;
    exports.BodylessConversation = BodylessConversation;
    exports.ConversationEmbed = ConversationEmbed;
    exports.LiveboardEmbed = LiveboardEmbed;
    exports.MIXPANEL_EVENT = MIXPANEL_EVENT;
    exports.PinboardEmbed = PinboardEmbed;
    exports.SageEmbed = SageEmbed;
    exports.SearchBarEmbed = SearchBarEmbed;
    exports.SearchEmbed = SearchEmbed;
    exports.SpotterAgentEmbed = SpotterAgentEmbed;
    exports.SpotterEmbed = SpotterEmbed;
    exports.createLiveboardWithAnswers = createLiveboardWithAnswers;
    exports.executeTML = executeTML;
    exports.exportTML = exportTML;
    exports.getAnswerFromQuery = getAnswerFromQuery;
    exports.getInitConfig = getEmbedConfig;
    exports.getSessionInfo = getSessionInfo;
    exports.init = init;
    exports.logout = logout;
    exports.prefetch = prefetch;
    exports.resetCachedAuthToken = resetCachedAuthToken;
    exports.tokenizedFetch = tokenizedFetch;
    exports.uploadMixpanelEvent = uploadMixpanelEvent;

}));
